/*
 * Copyright AMD,NAG 2003-2017
 */

/*
  This is the RNG header file. It contains function prototypes
  to allow a C programmer to call RNG routines via their C
  or Fortran interfaces.

  C interfaces to RNG routines differ from FORTRAN interfaces in
  the following major respects:

#if defined(WIN32_VF)
    (i) The FORTRAN interface names are in upper case.
#elif defined(WIN_IFORT) // ! WIN32
    (i) The FORTRAN interface names are in upper case.
#else // ! WIN32
    (i) The FORTRAN interface names are appended by an underscore.
#endif // ! WIN32
   (ii) The C interfaces contain no workspace arguments; all
        workspace memory is allocated internally.

  (iii) Scalar input arguments are passed by value in C interfaces.
        FORTRAN interfaces pass all arguments (except for character
        string "length" arguments that are normally hidden from
        FORTRAN programmers) by reference.

   (iv) Most arguments that are passed as character string pointers
        to FORTRAN interfaces are passed by value as single
        characters to C interfaces. The character string "length"
        arguments of FORTRAN interfaces are not required in the
        C interfaces.

  It is important to note that in both the FORTRAN and C interfaces,
  2-dimensional arrays are assumed to be stored in column-major order.
  e.g. the matrix A = [ 1.0 2.0 ]
                      [ 3.0 4.0 ]
  would be stored in memory as 1.0, 3.0, 2.0, 4.0. This storage order
  corresponds to a FORTRAN-style 2-D array declaration A(2,2), but not
  to an array declared as a[2][2] in C which would be stored in
  row-major order as 1.0, 2.0, 3.0, 4.0.

  As an example, compare the FORTRAN and C interfaces of LAPACK
  routine dsytrf as implemented in RNG.

#if defined(WIN32_VF)

  FORTRAN:
    void DSYTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda,
                rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
#elif defined(WIN_IFORT) // ! WIN32

  FORTRAN:
    void DSYTRF(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv,
                double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
#else // ! WIN32

  FORTRAN:
    void dsytrf_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv,
                 double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
#endif // ! WIN32

  C:
    void dsytrf(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);

  C code calling both the above variants might look like this:

    double *a;
    rng_int_t *ipiv;
    double *work;
    rng_int_t n, lda, lwork, info;

    //
    // Assume that all arrays and variables are allocated and initialized
    // as required by dsytrf.
#if defined(WIN32_VF)
    //
    // Call the FORTRAN version of dsytrf. The first argument is a character
    // string, and the second argument is the length of that string. The input
    // scalar arguments n, lda and lwork, as well as the output scalar
    // argument info, are all passed by reference.
    DSYTRF("Upper", 5, &n, a, &lda, ipiv, work, &lwork, &info);
#elif defined(WIN_IFORT) // ! WIN32
    //
    // Call the FORTRAN version of dsytrf. The first argument is a character
    // string, and the last argument is the length of that string. The input
    // scalar arguments n, lda and lwork, as well as the output scalar
    // argument info, are all passed by reference.
    DSYTRF("Upper", &n, a, &lda, ipiv, work, &lwork, &info, 5);
#else // ! WIN32
    //
    // Call the FORTRAN version of dsytrf. The first argument is a character
    // string, and the last argument is the length of that string. The input
    // scalar arguments n, lda and lwork, as well as the output scalar
    // argument info, are all passed by reference.
    dsytrf_("Upper", &n, a, &lda, ipiv, work, &lwork, &info, 5);
#endif // ! WIN32
    //
    // Call the C version of dsytrf. The first argument is a character,
    // workspace is not required, and input scalar arguments n and lda are
    // passed by value. Output scalar argument info is passed by reference.
    dsytrf('U', n, a, lda, ipiv, &info);

*/

#ifndef _RNG_H
#define _RNG_H

/* Under Windows math.h defines "complex" to mean "_complex". */
#include <math.h>
#undef complex

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* ------------------------------------------------------------------ */

/* All lines containing _RNG_INT_T or INTEGER64 get          _RNG_INT_T
   filtered out of the distributed copy of rng.h             _RNG_INT_T */
/* _RNG_INT_T The RNG integer type, either 32-bit or 64-bit */
#ifndef _RNG_INT_T
#define _RNG_INT_T
#ifdef INTEGER64
/* _RNG_INT_T  N.B. even in 64-bit integer variants of RNG, hidden
   _RNG_INT_T  Fortran string length arguments (type rng_strlen_t)
   _RNG_INT_T  are of type int rather than long */
#ifdef WIN64 /* INTEGER64 */
  typedef __int64 rng_int_t;             /* _RNG_INT_T */
  typedef unsigned __int64 rng_uint_t;   /* _RNG_INT_T */
  typedef int rng_strlen_t;              /* _RNG_INT_T */
#else /* INTEGER64 */
  typedef long rng_int_t;                /* _RNG_INT_T */
  typedef unsigned long rng_uint_t;      /* _RNG_INT_T */
  typedef int rng_strlen_t;              /* _RNG_INT_T */
#endif /* INTEGER64 */
#else /* ! INTEGER64 */
typedef int rng_int_t;                 /* _RNG_INT_T */
typedef unsigned int rng_uint_t;       /* _RNG_INT_T */
typedef int rng_strlen_t;              /* _RNG_INT_T */
#endif /* ! INTEGER64 */
#endif /* _RNG_INT_T */

/* A complex datatype for use by the C interfaces to RNG routines */
#ifndef _RNG_COMPLEX
#define _RNG_COMPLEX
typedef struct
{
  float real, imag;
} complex;
typedef struct
{
  double real, imag;
} doublecomplex;
#endif /* !defined(_RNG_COMPLEX) */

#if defined(WIN32_VF)
  #ifdef USE_CDECL
    #define RNGCDECL __cdecl
    #define RNGSTDCALL __cdecl
  #else /* USE_CDECL */
    #define RNGCDECL _stdcall
    #define RNGSTDCALL _stdcall
  #endif /* USE_CDECL */
#elif defined(WIN32_PVF) /* ! WIN32_VF */
  #define RNGCDECL
  #define RNGSTDCALL
#else /* ! WIN32_VF */
  #define RNGSTDCALL
  #define RNGCDECL
#endif /* ! WIN32_VF */

/*
   These typedefs are for routines that are arguments to other routines,
   e.g. RNG_CGEES_SELECT describes the argument "select" of routine cgees.
 */
typedef rng_int_t (RNGSTDCALL * RNG_CGEES_SELECT)(complex *);
typedef rng_int_t (RNGSTDCALL * RNG_CGEESX_SELECT)(complex *);
typedef rng_int_t (RNGSTDCALL * RNG_CGGES_SELCTG)(complex *, complex *);
typedef rng_int_t (RNGSTDCALL * RNG_CGGESX_SELCTG)(complex *, complex *);
typedef rng_int_t (RNGSTDCALL * RNG_DGEES_SELECT)(double *, double *);
typedef rng_int_t (RNGSTDCALL * RNG_DGEESX_SELECT)(double *, double *);
typedef rng_int_t (RNGSTDCALL * RNG_DGGES_DELCTG)(double *, double *, double *);
typedef rng_int_t (RNGSTDCALL * RNG_DGGESX_DELCTG)(double *, double *, double *);
typedef rng_int_t (RNGSTDCALL * RNG_SGEES_SELECT)(float *, float *);
typedef rng_int_t (RNGSTDCALL * RNG_SGEESX_SELECT)(float *, float *);
typedef rng_int_t (RNGSTDCALL * RNG_SGGES_SELCTG)(float *, float *, float *);
typedef rng_int_t (RNGSTDCALL * RNG_SGGESX_SELCTG)(float *, float *, float *);
typedef rng_int_t (RNGSTDCALL * RNG_ZGEES_SELECT)(doublecomplex *);
typedef rng_int_t (RNGSTDCALL * RNG_ZGEESX_SELECT)(doublecomplex *);
typedef rng_int_t (RNGSTDCALL * RNG_ZGGES_DELCTG)(doublecomplex *, doublecomplex *);
typedef rng_int_t (RNGSTDCALL * RNG_ZGGESX_DELCTG)(doublecomplex *, doublecomplex *);
typedef void (RNGSTDCALL * RNG_DRANDINITIALIZEUSER_UINI)(rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *);
typedef void (RNGSTDCALL * RNG_DRANDINITIALIZEUSER_UGEN)(rng_int_t *, rng_int_t *, double *, rng_int_t *);
typedef void (RNGSTDCALL * RNG_SRANDINITIALIZEUSER_UINI)(rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *, rng_int_t *);
typedef void (RNGSTDCALL * RNG_SRANDINITIALIZEUSER_UGEN)(rng_int_t *, rng_int_t *, float *, rng_int_t *);

/* ------------------------------------------------------------------ */
/* Below are prototypes for the C interfaces to RNG routines */

/* BLAS C interfaces */
extern void RNGCDECL caxpy(rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *y, rng_int_t incy);
extern void RNGCDECL ccopy(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy);
extern complex RNGCDECL cdotc(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy);
extern complex RNGCDECL cdotu(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy);
extern void RNGCDECL cgbmv(char transa, rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, complex *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, complex *beta, complex *y, rng_int_t incy);
extern void RNGCDECL cgemm(char transa, char transb, rng_int_t m, rng_int_t n, rng_int_t k, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *beta, complex *c, rng_int_t ldc);
extern void RNGCDECL cgemv(char transa, rng_int_t m, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, complex *beta, complex *y, rng_int_t incy);
extern void RNGCDECL cgerc(rng_int_t m, rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *y, rng_int_t incy, complex *a, rng_int_t lda);
extern void RNGCDECL cgeru(rng_int_t m, rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *y, rng_int_t incy, complex *a, rng_int_t lda);
extern void RNGCDECL chbmv(char uplo, rng_int_t n, rng_int_t ndiag, complex *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, complex *beta, complex *y, rng_int_t incy);
extern void RNGCDECL chemm(char side, char uplo, rng_int_t m, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *beta, complex *c, rng_int_t ldc);
extern void RNGCDECL chemv(char uplo, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, complex *beta, complex *y, rng_int_t incy);
extern void RNGCDECL cher(char uplo, rng_int_t n, float alpha, complex *x, rng_int_t incx, complex *a, rng_int_t lda);
extern void RNGCDECL cher2(char uplo, rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *y, rng_int_t incy, complex *a, rng_int_t lda);
extern void RNGCDECL cher2k(char uplo, char transa, rng_int_t n, rng_int_t k, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float beta, complex *c, rng_int_t ldc);
extern void RNGCDECL cherk(char uplo, char transa, rng_int_t n, rng_int_t k, float alpha, complex *a, rng_int_t lda, float beta, complex *c, rng_int_t ldc);
extern void RNGCDECL chpmv(char uplo, rng_int_t n, complex *alpha, complex *a, complex *x, rng_int_t incx, complex *beta, complex *y, rng_int_t incy);
extern void RNGCDECL chpr(char uplo, rng_int_t n, float alpha, complex *x, rng_int_t incx, complex *a);
extern void RNGCDECL chpr2(char uplo, rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *y, rng_int_t incy, complex *a);
extern void RNGCDECL classq(rng_int_t n, complex *x, rng_int_t incx, float *scale, float *sumsq);
extern void RNGCDECL crotg(complex *a, complex *b, float *c, complex *s);
extern void RNGCDECL cscal(rng_int_t n, complex *alpha, complex *y, rng_int_t incy);
extern void RNGCDECL csrot(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy, float c, float s);
extern void RNGCDECL csscal(rng_int_t n, float alpha, complex *y, rng_int_t incy);
extern void RNGCDECL cstemr(char jobz, char range, rng_int_t n, float *d, float *e, float vl, float vu, rng_int_t il, rng_int_t iu, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, rng_int_t *info);
extern void RNGCDECL cswap(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy);
extern void RNGCDECL csymm(char side, char uplo, rng_int_t m, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *beta, complex *c, rng_int_t ldc);
extern void RNGCDECL csyr2k(char uplo, char transa, rng_int_t n, rng_int_t k, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *beta, complex *c, rng_int_t ldc);
extern void RNGCDECL csyrk(char uplo, char transa, rng_int_t n, rng_int_t k, complex *alpha, complex *a, rng_int_t lda, complex *beta, complex *c, rng_int_t ldc);
extern void RNGCDECL ctbmv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, complex *y, rng_int_t incy);
extern void RNGCDECL ctbsv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, complex *y, rng_int_t incy);
extern void RNGCDECL ctpmv(char uplo, char transa, char diag, rng_int_t n, complex *a, complex *y, rng_int_t incy);
extern void RNGCDECL ctpsv(char uplo, char transa, char diag, rng_int_t n, complex *a, complex *y, rng_int_t incy);
extern void RNGCDECL ctrmm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb);
extern void RNGCDECL ctrmv(char uplo, char transa, char diag, rng_int_t n, complex *a, rng_int_t lda, complex *y, rng_int_t incy);
extern void RNGCDECL ctrsm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, complex *alpha, complex *a, rng_int_t lda, complex *b, rng_int_t ldb);
extern void RNGCDECL ctrsv(char uplo, char transa, char diag, rng_int_t n, complex *a, rng_int_t lda, complex *y, rng_int_t incy);
extern double RNGCDECL dasum(rng_int_t n, double *x, rng_int_t incx);
extern void RNGCDECL daxpy(rng_int_t n, double alpha, double *x, rng_int_t incx, double *y, rng_int_t incy);
extern void RNGCDECL dcopy(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy);
extern double RNGCDECL ddot(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy);
extern void RNGCDECL dgbmv(char transa, rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, double alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dgemm(char transa, char transb, rng_int_t m, rng_int_t n, rng_int_t k, double alpha, double *a, rng_int_t lda, double *b, rng_int_t ldb, double beta, double *c, rng_int_t ldc);
extern void RNGCDECL dgemv(char transa, rng_int_t m, rng_int_t n, double alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dger(rng_int_t m, rng_int_t n, double alpha, double *x, rng_int_t incx, double *y, rng_int_t incy, double *a, rng_int_t lda);
extern double RNGCDECL dnrm2(rng_int_t n, double *x, rng_int_t incx);
extern void RNGCDECL drot(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy, double c, double s);
extern void RNGCDECL drotg(double *a, double *b, double *c, double *s);
extern void RNGCDECL drotm(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy, double *param);
extern void RNGCDECL drotmg(double d1, double d2, double b1, double b2, double *param);
extern void RNGCDECL dsbmv(char uplo, rng_int_t n, rng_int_t ndiag, double alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dscal(rng_int_t n, double alpha, double *y, rng_int_t incy);
extern double RNGCDECL dsdot(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy);
extern void RNGCDECL dspmv(char uplo, rng_int_t n, double alpha, double *a, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dspr(char uplo, rng_int_t n, double alpha, double *x, rng_int_t incx, double *a);
extern void RNGCDECL dspr2(char uplo, rng_int_t n, double alpha, double *x, rng_int_t incx, double *y, rng_int_t incy, double *a);
extern void RNGCDECL dswap(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy);
extern void RNGCDECL dsymm(char side, char uplo, rng_int_t m, rng_int_t n, double alpha, double *a, rng_int_t lda, double *b, rng_int_t ldb, double beta, double *c, rng_int_t ldc);
extern void RNGCDECL dsymv(char uplo, rng_int_t n, double alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dsyr(char uplo, rng_int_t n, double alpha, double *x, rng_int_t incx, double *a, rng_int_t lda);
extern void RNGCDECL dsyr2(char uplo, rng_int_t n, double alpha, double *x, rng_int_t incx, double *y, rng_int_t incy, double *a, rng_int_t lda);
extern void RNGCDECL dsyr2k(char uplo, char transa, rng_int_t n, rng_int_t k, double alpha, double *a, rng_int_t lda, double *b, rng_int_t ldb, double beta, double *c, rng_int_t ldc);
extern void RNGCDECL dsyrk(char uplo, char transa, rng_int_t n, rng_int_t k, double alpha, double *a, rng_int_t lda, double beta, double *c, rng_int_t ldc);
extern void RNGCDECL dtbmv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *y, rng_int_t incy);
extern void RNGCDECL dtbsv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *y, rng_int_t incy);
extern void RNGCDECL dtpmv(char uplo, char transa, char diag, rng_int_t n, double *a, double *y, rng_int_t incy);
extern void RNGCDECL dtpsv(char uplo, char transa, char diag, rng_int_t n, double *a, double *y, rng_int_t incy);
extern void RNGCDECL dtrmm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, double alpha, double *a, rng_int_t lda, double *b, rng_int_t ldb);
extern void RNGCDECL dtrmv(char uplo, char transa, char diag, rng_int_t n, double *a, rng_int_t lda, double *y, rng_int_t incy);
extern void RNGCDECL dtrsm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, double alpha, double *a, rng_int_t lda, double *b, rng_int_t ldb);
extern void RNGCDECL dtrsv(char uplo, char transa, char diag, rng_int_t n, double *a, rng_int_t lda, double *y, rng_int_t incy);
extern double RNGCDECL dzasum(rng_int_t n, doublecomplex *x, rng_int_t incx);
extern double RNGCDECL dznrm2(rng_int_t n, doublecomplex *x, rng_int_t incx);
extern rng_int_t RNGCDECL icamax(rng_int_t n, complex *x, rng_int_t incx);
extern rng_int_t RNGCDECL idamax(rng_int_t n, double *x, rng_int_t incx);
extern rng_int_t RNGCDECL isamax(rng_int_t n, float *x, rng_int_t incx);
extern rng_int_t RNGCDECL izamax(rng_int_t n, doublecomplex *x, rng_int_t incx);
extern rng_int_t RNGCDECL lsame(char ca, char cb);
extern float RNGCDECL sasum(rng_int_t n, float *x, rng_int_t incx);
extern void RNGCDECL saxpy(rng_int_t n, float alpha, float *x, rng_int_t incx, float *y, rng_int_t incy);
extern float RNGCDECL scasum(rng_int_t n, complex *x, rng_int_t incx);
extern float RNGCDECL scnrm2(rng_int_t n, complex *x, rng_int_t incx);
extern void RNGCDECL scopy(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy);
extern float RNGCDECL sdot(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy);
extern float RNGCDECL sdsdot(rng_int_t n, float sb, float *sx, rng_int_t incx, float *sy, rng_int_t incy);
extern void RNGCDECL sgbmv(char transa, rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, float alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sgemm(char transa, char transb, rng_int_t m, rng_int_t n, rng_int_t k, float alpha, float *a, rng_int_t lda, float *b, rng_int_t ldb, float beta, float *c, rng_int_t ldc);
extern void RNGCDECL sgemv(char transa, rng_int_t m, rng_int_t n, float alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sger(rng_int_t m, rng_int_t n, float alpha, float *x, rng_int_t incx, float *y, rng_int_t incy, float *a, rng_int_t lda);
extern float RNGCDECL snrm2(rng_int_t n, float *x, rng_int_t incx);
extern void RNGCDECL srot(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy, float c, float s);
extern void RNGCDECL srotg(float *a, float *b, float *c, float *s);
extern void RNGCDECL srotm(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy, float *param);
extern void RNGCDECL srotmg(float d1, float d2, float b1, float b2, float *param);
extern void RNGCDECL ssbmv(char uplo, rng_int_t n, rng_int_t ndiag, float alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sscal(rng_int_t n, float alpha, float *x, rng_int_t incx);
extern void RNGCDECL sspmv(char uplo, rng_int_t n, float alpha, float *a, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sspr(char uplo, rng_int_t n, float alpha, float *x, rng_int_t incx, float *a);
extern void RNGCDECL sspr2(char uplo, rng_int_t n, float alpha, float *x, rng_int_t incx, float *y, rng_int_t incy, float *a);
extern void RNGCDECL sstemr(char jobz, char range, rng_int_t n, float *d, float *e, float vl, float vu, rng_int_t il, rng_int_t iu, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, rng_int_t *info);
extern void RNGCDECL sswap(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy);
extern void RNGCDECL ssymm(char side, char uplo, rng_int_t m, rng_int_t n, float alpha, float *a, rng_int_t lda, float *b, rng_int_t ldb, float beta, float *c, rng_int_t ldc);
extern void RNGCDECL ssymv(char uplo, rng_int_t n, float alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL ssyr(char uplo, rng_int_t n, float alpha, float *x, rng_int_t incx, float *a, rng_int_t lda);
extern void RNGCDECL ssyr2(char uplo, rng_int_t n, float alpha, float *x, rng_int_t incx, float *y, rng_int_t incy, float *a, rng_int_t lda);
extern void RNGCDECL ssyr2k(char uplo, char transa, rng_int_t n, rng_int_t k, float alpha, float *a, rng_int_t lda, float *b, rng_int_t ldb, float beta, float *c, rng_int_t ldc);
extern void RNGCDECL ssyrk(char uplo, char transa, rng_int_t n, rng_int_t k, float alpha, float *a, rng_int_t lda, float beta, float *c, rng_int_t ldc);
extern void RNGCDECL stbmv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *y, rng_int_t incy);
extern void RNGCDECL stbsv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *y, rng_int_t incy);
extern void RNGCDECL stpmv(char uplo, char transa, char diag, rng_int_t n, float *a, float *y, rng_int_t incy);
extern void RNGCDECL stpsv(char uplo, char transa, char diag, rng_int_t n, float *a, float *y, rng_int_t incy);
extern void RNGCDECL strmm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, float alpha, float *a, rng_int_t lda, float *b, rng_int_t ldb);
extern void RNGCDECL strmv(char uplo, char transa, char diag, rng_int_t n, float *a, rng_int_t lda, float *y, rng_int_t incy);
extern void RNGCDECL strsm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, float alpha, float *a, rng_int_t lda, float *b, rng_int_t ldb);
extern void RNGCDECL strsv(char uplo, char transa, char diag, rng_int_t n, float *a, rng_int_t lda, float *y, rng_int_t incy);
extern void RNGCDECL xerbla(const char *srname, rng_int_t *info);
extern void RNGCDECL zaxpy(rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zcopy(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy);
extern doublecomplex RNGCDECL zdotc(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy);
extern doublecomplex RNGCDECL zdotu(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zdrot(rng_int_t n, doublecomplex *cx, rng_int_t incx, doublecomplex *cy, rng_int_t incy, double c, double s);
extern void RNGCDECL zdscal(rng_int_t n, double alpha, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zgbmv(char transa, rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, doublecomplex *beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zgemm(char transa, char transb, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zgemv(char transa, rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, doublecomplex *beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zgerc(rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zgeru(rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zhbmv(char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, doublecomplex *beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zhemm(char side, char uplo, rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zhemv(char uplo, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, doublecomplex *beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zher(char uplo, rng_int_t n, double alpha, doublecomplex *x, rng_int_t incx, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zher2(char uplo, rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zher2k(char uplo, char transa, rng_int_t n, rng_int_t k, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zherk(char uplo, char transa, rng_int_t n, rng_int_t k, double alpha, doublecomplex *a, rng_int_t lda, double beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zhpmv(char uplo, rng_int_t n, doublecomplex *alpha, doublecomplex *a, doublecomplex *x, rng_int_t incx, doublecomplex *beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zhpr(char uplo, rng_int_t n, double alpha, doublecomplex *x, rng_int_t incx, doublecomplex *a);
extern void RNGCDECL zhpr2(char uplo, rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, doublecomplex *a);
extern void RNGCDECL zlassq(rng_int_t n, doublecomplex *x, rng_int_t incx, double *scale, double *sumsq);
extern void RNGCDECL zrotg(doublecomplex *a, doublecomplex *b, double *c, doublecomplex *s);
extern void RNGCDECL zscal(rng_int_t n, doublecomplex *alpha, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zstemr(char jobz, char range, rng_int_t n, double *d, double *e, double vl, double vu, rng_int_t il, rng_int_t iu, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, rng_int_t *info);
extern void RNGCDECL zswap(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zsymm(char side, char uplo, rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zsyr2k(char uplo, char transa, rng_int_t n, rng_int_t k, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zsyrk(char uplo, char transa, rng_int_t n, rng_int_t k, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *beta, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL ztbmv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL ztbsv(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL ztpmv(char uplo, char transa, char diag, rng_int_t n, doublecomplex *a, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL ztpsv(char uplo, char transa, char diag, rng_int_t n, doublecomplex *a, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL ztrmm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL ztrmv(char uplo, char transa, char diag, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL ztrsm(char side, char uplo, char transa, char diag, rng_int_t m, rng_int_t n, doublecomplex *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL ztrsv(char uplo, char transa, char diag, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *y, rng_int_t incy);

/* LAPACK C interfaces */
extern void RNGCDECL cbbcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, rng_int_t m, rng_int_t p, rng_int_t q, float *theta, float *phi, complex *u1, rng_int_t ldu1, complex *u2, rng_int_t ldu2, complex *v1t, rng_int_t ldv1t, complex *v2t, rng_int_t ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, rng_int_t *info);
extern void RNGCDECL cbdsqr(char uplo, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, float *d, float *e, complex *vt, rng_int_t ldvt, complex *u, rng_int_t ldu, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cgbbrd(char vect, rng_int_t m, rng_int_t n, rng_int_t ncc, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, float *d, float *e, complex *q, rng_int_t ldq, complex *pt, rng_int_t ldpt, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cgbcon(char norm, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, complex *a, rng_int_t lda, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cgbequ(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, complex *a, rng_int_t lda, float *rowsc, float *colsc, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL cgbequb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL cgbrfs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cgbrfsx(char trans, char equed, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cgbsv(rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);

/* N.B. In this C interface to cgbsvx, rpvgrw returns what is returned in
   the first element of RWORK by the FORTRAN interface */
extern void RNGCDECL cgbsvx(char fact, char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *rowsc, float *colsc, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, float *rpvgrw, rng_int_t *info);

extern void RNGCDECL cgbsvxx(char fact, char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb, rng_int_t *ipiv, char equed, float *r, float *c, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cgbtrf(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgbtrs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cgebak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *scale, rng_int_t m, complex *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL cgebal(char job, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info);
extern void RNGCDECL cgebrd(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *d, float *e, complex *tauq, complex *taup, rng_int_t *info);
extern void RNGCDECL cgecon(char norm, rng_int_t n, complex *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cgeequ(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *rowsc, float *colsc, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL cgeequb(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL cgees(char jobz, char sortev, RNG_CGEES_SELECT select, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *nout, complex *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL cgeesx(char jobz, char sortev, RNG_CGEESX_SELECT select, char sense, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *nout, complex *w, complex *z, rng_int_t ldz, float *rcone, float *rconv, rng_int_t *info);
extern void RNGCDECL cgeev(char jobvl, char jobvr, rng_int_t n, complex *a, rng_int_t lda, complex *w, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL cgeevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, complex *a, rng_int_t lda, complex *w, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, rng_int_t *info);
extern void RNGCDECL cgegs(char jobvsl, char jobvsr, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *vsl, rng_int_t ldvsl, complex *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL cgegv(char jobvl, char jobvr, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL cgehrd(rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgelqf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgels(char trans, rng_int_t m, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cgelsd(rng_int_t m, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float *s, float rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL cgelss(rng_int_t m, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float *sing, float rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL cgelsx(rng_int_t m, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *jpivot, float rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL cgelsy(rng_int_t m, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *jpvt, float rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL cgemqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t nb, complex *v, rng_int_t ldv, complex *t, rng_int_t ldt, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cgeqlf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqp3(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *jpvt, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqpf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *jpvt, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqr2p(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqrf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqrfp(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqrt(rng_int_t m, rng_int_t n, rng_int_t nb, complex *a, rng_int_t lda, complex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL cgeqrt2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL cgeqrt3(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL cgerfs(char transa, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cgerfsx(char trans, char equed, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cgerqf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgesdd(char jobz, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *s, complex *u, rng_int_t ldu, complex *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL cgesv(rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cgesvd(char jobu, char jobvt, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *sing, complex *u, rng_int_t ldu, complex *vt, rng_int_t ldvt, rng_int_t *info);

/* N.B. In this C interface to cgesvx, rpvgrw returns what is returned in
   the first element of RWORK by the FORTRAN interface */
extern void RNGCDECL cgesvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *rowsc, float *colsc, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, float *rpvgrw, rng_int_t *info);

extern void RNGCDECL cgesvxx(char fact, char trans, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *r, float *c, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cgetrf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgetri(rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgetrs(char transa, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cggbak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *lscale, float *rscale, rng_int_t m, complex *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL cggbal(char job, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *info);
extern void RNGCDECL cgges(char jobvsl, char jobvsr, char sort, RNG_CGGES_SELCTG selctg, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t ldvsl, complex *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL cggesx(char jobvsl, char jobvsr, char sort, RNG_CGGESX_SELCTG selctg, char sense, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t ldvsl, complex *vsr, rng_int_t ldvsr, float *rconde, float *rcondv, rng_int_t *info);
extern void RNGCDECL cggev(char jobvl, char jobvr, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL cggevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, rng_int_t *info);
extern void RNGCDECL cggglm(rng_int_t n, rng_int_t m, rng_int_t p, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *d, complex *x, complex *y, rng_int_t *info);
extern void RNGCDECL cgghrd(char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *q, rng_int_t ldq, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL cgglse(rng_int_t m, rng_int_t n, rng_int_t p, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *c, complex *d, complex *x, rng_int_t *info);
extern void RNGCDECL cggqrf(rng_int_t n, rng_int_t m, rng_int_t p, complex *a, rng_int_t lda, complex *taua, complex *b, rng_int_t ldb, complex *taub, rng_int_t *info);
extern void RNGCDECL cggrqf(rng_int_t m, rng_int_t p, rng_int_t n, complex *a, rng_int_t lda, complex *taua, complex *b, rng_int_t ldb, complex *taub, rng_int_t *info);
extern void RNGCDECL cggsvd(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t n, rng_int_t p, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float *alpha, float *beta, complex *u, rng_int_t ldu, complex *v, rng_int_t ldv, complex *q, rng_int_t ldq, rng_int_t *iwork, rng_int_t *info);
extern void RNGCDECL cggsvp(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float tola, float tolb, rng_int_t *k, rng_int_t *l, complex *u, rng_int_t ldu, complex *v, rng_int_t ldv, complex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL cgtcon(char norm, rng_int_t n, complex *low, complex *diag, complex *up1, complex *up2, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cgtrfs(char transa, rng_int_t n, rng_int_t nrhs, complex *low, complex *diag, complex *up, complex *lowf, complex *diagf, complex *upf1, complex *upf2, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cgtsv(rng_int_t n, rng_int_t nrhs, complex *low, complex *diag, complex *up, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cgtsvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, complex *low, complex *diag, complex *up, complex *lowf, complex *diagf, complex *upf1, complex *upf2, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cgttrf(rng_int_t n, complex *low, complex *diag, complex *up1, complex *up2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgttrs(char transa, rng_int_t n, rng_int_t nrhs, complex *low, complex *diag, complex *up1, complex *up2, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern char RNGCDECL chla_transtype(rng_int_t trans);
extern void RNGCDECL chbev(char jobz, char uplo, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chbevd(char jobz, char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chbevx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, complex *q, rng_int_t ldq, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL chbgst(char vect, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, complex *ab, rng_int_t ldab, complex *bb, rng_int_t ldbb, complex *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL chbgv(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, complex *ab, rng_int_t ldab, complex *bb, rng_int_t ldbb, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chbgvd(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, complex *ab, rng_int_t ldab, complex *bb, rng_int_t ldbb, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chbgvx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, complex *ab, rng_int_t ldab, complex *bb, rng_int_t ldbb, complex *q, rng_int_t ldq, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL chbtrd(char vect, char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, float *d, float *e, complex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL checon(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cheequb(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL cheev(char jobz, char uplo, rng_int_t n, complex *a, rng_int_t lda, float *w, rng_int_t *info);
extern void RNGCDECL cheevd(char jobz, char uplo, rng_int_t n, complex *a, rng_int_t lda, float *w, rng_int_t *info);
extern void RNGCDECL cheevr(char jobz, char range, char uplo, rng_int_t n, complex *a, rng_int_t lda, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL cheevx(char jobz, char range, char uplo, rng_int_t n, complex *a, rng_int_t lda, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL chegst(rng_int_t itype, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chegv(rng_int_t itype, char jobz, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float *w, rng_int_t *info);
extern void RNGCDECL chegvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float *w, rng_int_t *info);
extern void RNGCDECL chegvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL cherfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cherfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL chesv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chesvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL chesvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cheswapr(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL chetrd(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *d, float *e, complex *tau, rng_int_t *info);
extern void RNGCDECL chetrf(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL chetri(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL chetri2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL chetri2x(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL chetrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chetrs2(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chfrk(char transr, char uplo, char trans, rng_int_t n, rng_int_t k, float alpha, complex *a, rng_int_t lda, float beta, complex *c);
extern void RNGCDECL chgeqz(char job, char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *q, rng_int_t ldq, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chpcon(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL chpev(char jobz, char uplo, rng_int_t n, complex *a, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chpevd(char jobz, char uplo, rng_int_t n, complex *ap, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chpevx(char jobz, char range, char uplo, rng_int_t n, complex *a, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL chpgst(rng_int_t itype, char uplo, rng_int_t n, complex *ap, complex *bp, rng_int_t *info);
extern void RNGCDECL chpgv(rng_int_t itype, char jobz, char uplo, rng_int_t n, complex *a, complex *b, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chpgvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, complex *ap, complex *bp, float *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL chpgvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, complex *ap, complex *bp, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL chprfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL chpsv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chpsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL chptrd(char uplo, rng_int_t n, complex *ap, float *d, float *e, complex *tau, rng_int_t *info);
extern void RNGCDECL chptrf(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL chptri(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL chptrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chsein(char side, char eigsrc, char initv, rng_int_t *select, rng_int_t n, complex *h, rng_int_t ldh, complex *w, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGCDECL chseqr(char job, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *h, rng_int_t ldh, complex *w, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL cla_gbamv(rng_int_t trans, rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, float alpha, complex *ab, rng_int_t ldab, complex *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern float RNGCDECL cla_gbrcond_c(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb, rng_int_t *ipiv, float *c, int capply, rng_int_t *info);
extern float RNGCDECL cla_gbrcond_x(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb, rng_int_t *ipiv, complex *x, rng_int_t *info);
extern void RNGCDECL cla_gbrfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb, rng_int_t *ipiv, int colequ, float *c, complex *b, rng_int_t ldb, complex *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern float RNGCDECL cla_gbrpvgrw(rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t ncols, complex *ab, rng_int_t ldab, complex *afb, rng_int_t ldafb);
extern void RNGCDECL cla_geamv(rng_int_t trans, rng_int_t m, rng_int_t n, float alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern float RNGCDECL cla_gercond_c(char trans, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *c, int capply, rng_int_t *info);
extern float RNGCDECL cla_gercond_x(char trans, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info);
extern void RNGCDECL cla_gerfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, float *c, complex *b, rng_int_t ldb, complex *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *errs_n, float *errs_c, complex *res, float *ayb, complex *dy, complex *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern float RNGCDECL cla_gerpvgrw(rng_int_t n, rng_int_t ncols, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf);
extern void RNGCDECL cla_heamv(rng_int_t uplo, rng_int_t n, float *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, float *beta, float *y, rng_int_t incy);
extern float RNGCDECL cla_hercond_c(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *c, int capply, rng_int_t *info);
extern float RNGCDECL cla_hercond_x(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info);
extern void RNGCDECL cla_herfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, float *c, complex *b, rng_int_t ldb, complex *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern float RNGCDECL cla_herpvgrw(char uplo, rng_int_t n, rng_int_t *info, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv);
extern void RNGCDECL cla_lin_berr(rng_int_t n, rng_int_t nz, rng_int_t nrhs, complex *res, float *ayb, float *berr);
extern float RNGCDECL cla_porcond_c(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, float *c, int capply, rng_int_t *info);
extern float RNGCDECL cla_porcond_x(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, complex *x, rng_int_t *info);
extern void RNGCDECL cla_porfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, int colequ, float *c, complex *b, rng_int_t ldb, complex *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern float RNGCDECL cla_porpvgrw(char uplo, rng_int_t ncols, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf);
extern void RNGCDECL cla_syamv(rng_int_t uplo, rng_int_t n, float *alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, float *beta, float *y, rng_int_t incy);
extern float RNGCDECL cla_syrcond_c(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *c, int capply, rng_int_t *info);
extern float RNGCDECL cla_syrcond_x(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info);
extern void RNGCDECL cla_syrfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, float *c, complex *b, rng_int_t ldb, complex *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern float RNGCDECL cla_syrpvgrw(char uplo, rng_int_t n, rng_int_t *info, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv);
extern void RNGCDECL cla_wwaddw(rng_int_t n, complex *x, complex *y, complex *w);
extern float RNGCDECL clanhf(char norm, char transr, char uplo, rng_int_t n, complex *a);
extern void RNGCDECL clapmr(int forwrd, rng_int_t m, rng_int_t n, complex *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL clarfgp(rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *tau);
extern void RNGCDECL clarscl2(rng_int_t m, rng_int_t n, float *d, complex *x, rng_int_t ldx);
extern void RNGCDECL clascl2(rng_int_t m, rng_int_t n, float *d, complex *x, rng_int_t ldx);
extern void RNGCDECL cpbcon(char uplo, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cpbequ(char uplo, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL cpbrfs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cpbstf(char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL cpbsv(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cpbsvx(char fact, char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, char equed, float *scale, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cpbtrf(char uplo, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cpbtrs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cpftrf(char transr, char uplo, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL cpftri(char transr, char uplo, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL cpftrs(char transr, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cpocon(char uplo, rng_int_t n, complex *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cpoequ(rng_int_t n, complex *a, rng_int_t lda, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL cpoequb(rng_int_t n, complex *a, rng_int_t lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL cporfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cporfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cposv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cposvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, char equed, float *scale, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cposvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, char equed, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL cpotrf(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cpotri(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cpotrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cppcon(char uplo, rng_int_t n, complex *a, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cppequ(char uplo, rng_int_t n, complex *a, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL cpprfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cppsv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cppsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, char equed, float *scale, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cpptrf(char uplo, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL cpptri(char uplo, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL cpptrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cpstf2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, float tol, rng_int_t *info);
extern void RNGCDECL cpstrf(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, float tol, rng_int_t *info);
extern void RNGCDECL cptcon(rng_int_t n, float *diag, complex *offd, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL cpteqr(char compz, rng_int_t n, float *d, float *e, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL cptrfs(char uplo, rng_int_t n, rng_int_t nrhs, float *diag, complex *offd, float *diagf, complex *offdf, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cptsv(rng_int_t n, rng_int_t nrhs, float *diag, complex *sub, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cptsvx(char fact, rng_int_t n, rng_int_t nrhs, float *diag, complex *sub, float *diagf, complex *subf, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cpttrf(rng_int_t n, float *diag, complex *offd, rng_int_t *info);
extern void RNGCDECL cpttrs(char uplo, rng_int_t n, rng_int_t nrhs, float *diag, complex *offd, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cspcon(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL csprfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL cspsv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cspsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, complex *af, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL csptrf(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csptri(char uplo, rng_int_t n, complex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csptrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL cstedc(char compz, rng_int_t n, float *d, float *e, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL cstegr(char jobz, char range, rng_int_t n, float *d, float *e, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, complex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL cstein(rng_int_t n, float *d, float *e, rng_int_t m, float *w, rng_int_t *iblock, rng_int_t *isplit, complex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL csteqr(char compz, rng_int_t n, float *d, float *e, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL csycon(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL csyconv(char uplo, char way, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csyequb(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL csyrfs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL csyrfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL csysv(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL csysvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL csysvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *s, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL csyswapr(char uplo, rng_int_t n, complex *a, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL csytrf(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csytri(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csytri2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL csytri2x(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL csytrs(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL csytrs2(char uplo, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ctbcon(char norm, char uplo, char diag, rng_int_t n, rng_int_t ndiag, complex *a, rng_int_t lda, float *rcond, rng_int_t *info);
extern void RNGCDECL ctbrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ctbtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ctfsm(char transr, char side, char uplo, char trans, char diag, rng_int_t m, rng_int_t n, complex alpha, complex *a, complex *b, rng_int_t ldb);
extern void RNGCDECL ctftri(char transr, char uplo, char diag, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL ctfttp(char transr, char uplo, rng_int_t n, complex *arf, complex *ap, rng_int_t *info);
extern void RNGCDECL ctfttr(char transr, char uplo, rng_int_t n, complex *arf, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ctgevc(char side, char howmny, rng_int_t *select, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ctgexc(rng_int_t wantq, rng_int_t wantz, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *q, rng_int_t ldq, complex *z, rng_int_t ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL ctgsen(rng_int_t ijob, rng_int_t wantq, rng_int_t wantz, rng_int_t *select, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *alpha, complex *beta, complex *q, rng_int_t ldq, complex *z, rng_int_t ldz, rng_int_t *m, float *pl, float *pr, float *dif, rng_int_t *info);
extern void RNGCDECL ctgsja(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, rng_int_t k, rng_int_t l, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, float tola, float tolb, float *alpha, float *beta, complex *u, rng_int_t ldu, complex *v, rng_int_t ldv, complex *q, rng_int_t ldq, rng_int_t *ncycle, rng_int_t *info);
extern void RNGCDECL ctgsna(char job, char howmnt, rng_int_t *select, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, float *s, float *dif, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ctgsyl(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *c, rng_int_t ldc, complex *d, rng_int_t ldd, complex *e, rng_int_t lde, complex *f, rng_int_t ldf, float *scale, float *dif, rng_int_t *info);
extern void RNGCDECL ctpcon(char norm, char uplo, char diag, rng_int_t n, complex *a, float *rcond, rng_int_t *info);
extern void RNGCDECL ctpmqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, rng_int_t nb, complex *v, rng_int_t ldv, complex *t, rng_int_t ldt, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ctpqrt(rng_int_t m, rng_int_t n, rng_int_t l, rng_int_t nb, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL ctpqrt2(rng_int_t m, rng_int_t n, rng_int_t l, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL ctprfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, complex *v, rng_int_t ldv, complex *t, rng_int_t ldt, complex *a, rng_int_t lda, complex *b, rng_int_t ldb);
extern void RNGCDECL ctprfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, complex *a, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ctptri(char uplo, char diag, rng_int_t n, complex *a, rng_int_t *info);
extern void RNGCDECL ctptrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, complex *a, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ctpttf(char transr, char uplo, rng_int_t n, complex *ap, complex *arf, rng_int_t *info);
extern void RNGCDECL ctpttr(char uplo, rng_int_t n, complex *ap, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ctrcon(char norm, char uplo, char diag, rng_int_t n, complex *a, rng_int_t lda, float *rcond, rng_int_t *info);
extern void RNGCDECL ctrevc(char side, char howmny, rng_int_t *select, rng_int_t n, complex *t, rng_int_t ldt, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ctrexc(char compq, rng_int_t n, complex *t, rng_int_t ldt, complex *q, rng_int_t ldq, rng_int_t ifst, rng_int_t ilst, rng_int_t *info);
extern void RNGCDECL ctrrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ctrsen(char job, char compq, rng_int_t *select, rng_int_t n, complex *t, rng_int_t ldt, complex *q, rng_int_t ldq, complex *w, rng_int_t *m, float *s, float *sep, rng_int_t *info);
extern void RNGCDECL ctrsna(char job, char howmny, rng_int_t *select, rng_int_t n, complex *t, rng_int_t ldt, complex *vl, rng_int_t ldvl, complex *vr, rng_int_t ldvr, float *s, float *sep, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ctrsyl(char trana, char tranb, rng_int_t isgn, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *c, rng_int_t ldc, float *scale, rng_int_t *info);
extern void RNGCDECL ctrtri(char uplo, char diag, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ctrtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ctrttf(char transr, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *arf, rng_int_t *info);
extern void RNGCDECL ctrttp(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *ap, rng_int_t *info);
extern void RNGCDECL ctzrqf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL ctzrzf(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cunbdb(char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, complex *x11, rng_int_t ldx11, complex *x12, rng_int_t ldx12, complex *x21, rng_int_t ldx21, complex *x22, rng_int_t ldx22, float *theta, float *phi, complex *taup1, complex *taup2, complex *tauq1, complex *tauq2, rng_int_t *info);
extern void RNGCDECL cuncsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, complex *x11, rng_int_t ldx11, complex *x12, rng_int_t ldx12, complex *x21, rng_int_t ldx21, complex *x22, rng_int_t ldx22, float *theta, complex *u1, rng_int_t ldu1, complex *u2, rng_int_t ldu2, complex *v1t, rng_int_t ldv1t, complex *v2t, rng_int_t ldv2t, rng_int_t *info);
extern void RNGCDECL cungbr(char vect, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cunghr(rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cunglq(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungql(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungqr(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungrq(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungtr(char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cunmbr(char vect, char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmhr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmlq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmql(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmqr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmrq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmrz(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cupgtr(char uplo, rng_int_t n, complex *ap, complex *tau, complex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL cupmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, complex *ap, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dbbcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, rng_int_t m, rng_int_t p, rng_int_t q, double *theta, double *phi, double *u1, rng_int_t ldu1, double *u2, rng_int_t ldu2, double *v1t, rng_int_t ldv1t, double *v2t, rng_int_t ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, rng_int_t *info);
extern void RNGCDECL dbdsdc(char uplo, char compq, rng_int_t n, double *d, double *e, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, double *q, rng_int_t *iq, rng_int_t *info);
extern void RNGCDECL dbdsqr(char uplo, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, double *d, double *e, double *vt, rng_int_t ldvt, double *u, rng_int_t ldu, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL ddisna(char job, rng_int_t m, rng_int_t n, double *d, double *sep, rng_int_t *info);
extern void RNGCDECL dgbbrd(char vect, rng_int_t m, rng_int_t n, rng_int_t ncc, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab, double *d, double *e, double *q, rng_int_t ldq, double *pt, rng_int_t ldpt, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dgbcon(char norm, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, double *a, rng_int_t lda, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dgbequ(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, double *a, rng_int_t lda, double *rowsc, double *colsc, double *rowcn, double *colcn, double *amax, rng_int_t *info);
extern void RNGCDECL dgbequb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGCDECL dgbrfs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dgbrfsx(char trans, char equed, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, double *ab, rng_int_t ldab, double *afb, rng_int_t ldafb, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dgbsv(rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);

/* N.B. In this C interface to dgbsvx, rpvgrw returns what is returned in
   the first element of WORK by the FORTRAN interface */
extern void RNGCDECL dgbsvx(char fact, char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *rowsc, double *colsc, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, double *rpvgrw, rng_int_t *info);

extern void RNGCDECL dgbsvxx(char fact, char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, double *ab, rng_int_t ldab, double *afb, rng_int_t ldafb, rng_int_t *ipiv, char equed, double *r, double *c, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dgbtrf(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgbtrs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dgebak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *scale, rng_int_t m, double *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL dgebal(char job, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info);
extern void RNGCDECL dgebrd(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *d, double *e, double *tauq, double *taup, rng_int_t *info);
extern void RNGCDECL dgecon(char norm, rng_int_t n, double *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dgeequ(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *rowsc, double *colsc, double *rowcn, double *colcn, double *amax, rng_int_t *info);
extern void RNGCDECL dgeequb(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGCDECL dgees(char jobz, char sortev, RNG_DGEES_SELECT select, rng_int_t n, double *a, rng_int_t lda, rng_int_t *nout, double *wr, double *wi, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dgeesx(char jobz, char sortev, RNG_DGEESX_SELECT select, char sense, rng_int_t n, double *a, rng_int_t lda, rng_int_t *nout, double *wr, double *wi, double *z, rng_int_t ldz, double *srcone, double *rconv, rng_int_t *info);
extern void RNGCDECL dgeev(char jobvl, char jobvr, rng_int_t n, double *a, rng_int_t lda, double *wr, double *wi, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL dgeevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, double *a, rng_int_t lda, double *wr, double *wi, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rcone, double *rconv, rng_int_t *info);
extern void RNGCDECL dgegs(char jobvsl, char jobvsr, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t ldvsl, double *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL dgegv(char jobvl, char jobvr, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL dgehrd(rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgejsv(char joba, char jobu, char jobv, char jobr, char jobt, char jobp, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *sva, double *u, rng_int_t ldu, double *v, rng_int_t ldv, double *work, rng_int_t lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGCDECL dgelqf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgels(char trans, rng_int_t m, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dgelsd(rng_int_t m, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *s, double rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL dgelss(rng_int_t m, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *sing, double rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL dgelsx(rng_int_t m, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *jpivot, double rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL dgelsy(rng_int_t m, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *jpvt, double rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL dgemqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t nb, double *v, rng_int_t ldv, double *t, rng_int_t ldt, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dgeqlf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqp3(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, rng_int_t *jpvt, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqpf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, rng_int_t *jpivot, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqr2p(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqrf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqrfp(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqrt(rng_int_t m, rng_int_t n, rng_int_t nb, double *a, rng_int_t lda, double *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL dgeqrt2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL dgeqrt3(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL dgerfs(char transa, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dgerfsx(char trans, char equed, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dgerqf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgesdd(char jobz, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *s, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL dgesv(rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dgesvd(char jobu, char jobvt, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *sing, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL dgesvj(char joba, char jobu, char jobv, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *sva, rng_int_t mv, double *v, rng_int_t ldv, double *work, rng_int_t lwork, rng_int_t *info);

/* N.B. In this C interface to dgesvx, rpvgrw returns what is returned in
   the first element of WORK by the FORTRAN interface */
extern void RNGCDECL dgesvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *rowsc, double *colsc, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, double *rpvgrw, rng_int_t *info);

extern void RNGCDECL dgesvxx(char fact, char trans, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *r, double *c, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dgsvj0(char jobv, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *d, double *sva, rng_int_t mv, double *v, rng_int_t ldv, double eps, double sfmin, double tol, rng_int_t nsweep, rng_int_t *info);
extern void RNGCDECL dgsvj1(char jobv, rng_int_t m, rng_int_t n, rng_int_t n1, double *a, rng_int_t lda, double *d, double *sva, rng_int_t mv, double *v, rng_int_t ldv, double eps, double sfmin, double tol, rng_int_t nsweep, rng_int_t *info);
extern void RNGCDECL dgetrf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgetri(rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgetrs(char transa, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dggbak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *lscale, double *rscale, rng_int_t m, double *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL dggbal(char job, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *info);
extern void RNGCDECL dgges(char jobvsl, char jobvsr, char sort, RNG_DGGES_DELCTG delctg, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t ldvsl, double *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL dggesx(char jobvsl, char jobvsr, char sort, RNG_DGGESX_DELCTG delctg, char sense, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t ldvsl, double *vsr, rng_int_t ldvsr, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL dggev(char jobvl, char jobvr, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL dggevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL dggglm(rng_int_t n, rng_int_t m, rng_int_t p, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *d, double *x, double *y, rng_int_t *info);
extern void RNGCDECL dgghrd(char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *q, rng_int_t ldq, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dgglse(rng_int_t m, rng_int_t n, rng_int_t p, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *c, double *d, double *x, rng_int_t *info);
extern void RNGCDECL dggqrf(rng_int_t n, rng_int_t m, rng_int_t p, double *a, rng_int_t lda, double *taua, double *b, rng_int_t ldb, double *taub, rng_int_t *info);
extern void RNGCDECL dggrqf(rng_int_t m, rng_int_t p, rng_int_t n, double *a, rng_int_t lda, double *taua, double *b, rng_int_t ldb, double *taub, rng_int_t *info);
extern void RNGCDECL dggsvd(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t n, rng_int_t p, rng_int_t *k, rng_int_t *l, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alpha, double *beta, double *u, rng_int_t ldu, double *v, rng_int_t ldv, double *q, rng_int_t ldq, rng_int_t *iwork3, rng_int_t *info);
extern void RNGCDECL dggsvp(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double tola, double tolb, rng_int_t *k, rng_int_t *l, double *u, rng_int_t ldu, double *v, rng_int_t ldv, double *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL dgtcon(char norm, rng_int_t n, double *low, double *diag, double *up1, double *up2, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dgtrfs(char transa, rng_int_t n, rng_int_t nrhs, double *low, double *diag, double *up, double *lowf, double *diagf, double *upf1, double *upf2, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dgtsv(rng_int_t n, rng_int_t nrhs, double *low, double *diag, double *up, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dgtsvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, double *low, double *diag, double *up, double *lowf, double *diagf, double *upf1, double *upf2, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dgttrf(rng_int_t n, double *low, double *diag, double *up1, double *up2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgttrs(char transa, rng_int_t n, rng_int_t nrhs, double *low, double *diag, double *up1, double *up2, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dhgeqz(char job, char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t ldq, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dhsein(char side, char eigsrc, char initv, rng_int_t *select, rng_int_t n, double *h, rng_int_t ldh, double *wr, double *wi, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGCDECL dhseqr(char job, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *h, rng_int_t ldh, double *wr, double *wi, double *z, rng_int_t ldz, rng_int_t *info);
extern rng_int_t RNGCDECL disnan(double *din);
extern double RNGCDECL dla_gbrcond(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab, double *afb, rng_int_t ldafb, rng_int_t *ipiv, rng_int_t cmode, double *c, rng_int_t *info);
extern double RNGCDECL dla_gbrpvgrw(rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t ncols, double *ab, rng_int_t ldab, double *afb, rng_int_t ldafb);
extern double RNGCDECL dla_gercond(char trans, rng_int_t n, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, rng_int_t cmode, double *c, rng_int_t *info);
extern double RNGCDECL dla_gerpvgrw(rng_int_t n, rng_int_t ncols, double *a, rng_int_t lda, double *af, rng_int_t ldaf);
extern double RNGCDECL dla_porcond(char uplo, rng_int_t n, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t cmode, double *c, rng_int_t *info);
extern double RNGCDECL dla_porpvgrw(char uplo, rng_int_t ncols, double *a, rng_int_t lda, double *af, rng_int_t ldaf);
extern double RNGCDECL dla_syrcond(char uplo, rng_int_t n, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, rng_int_t cmode, double *c, rng_int_t *info);
extern double RNGCDECL dla_syrpvgrw(char uplo, rng_int_t n, rng_int_t *info, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv);
extern double RNGCDECL dlamch(char cmach);
extern double RNGCDECL dlansf(char norm, char transr, char uplo, rng_int_t n, double *a);
extern void RNGCDECL dla_gbamv(rng_int_t trans, rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, double alpha, double *ab, rng_int_t ldab, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dla_gbrfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, double *ab, rng_int_t ldab, double *afb, rng_int_t ldafb, rng_int_t *ipiv, int colequ, double *c, double *b, rng_int_t ldb, double *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL dla_geamv(rng_int_t trans, rng_int_t m, rng_int_t n, double alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern void RNGCDECL dla_gerfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, double *c, double *b, rng_int_t ldb, double *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *errs_n, double *errs_c, double *res, double *ayb, double *dy, double *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL dla_lin_berr(rng_int_t n, rng_int_t nz, rng_int_t nrhs, double *res, double *ayb, double *berr);
extern void RNGCDECL dla_porfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, int colequ, double *c, double *b, rng_int_t ldb, double *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL dla_syamv(rng_int_t uplo, rng_int_t n, double *alpha, double *a, rng_int_t lda, double *x, rng_int_t incx, double *beta, double *y, rng_int_t incy);
extern void RNGCDECL dla_syrfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, double *c, double *b, rng_int_t ldb, double *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL dla_wwaddw(rng_int_t n, double *x, double *y, double *w);
extern void RNGCDECL dlapmr(int forwrd, rng_int_t m, rng_int_t n, double *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL dlarfgp(rng_int_t n, double *alpha, double *x, rng_int_t incx, double *tau);
extern void RNGCDECL dlarft(char direct, char storev, rng_int_t n, rng_int_t k, double *v, rng_int_t ldv, double *tau, double *t, rng_int_t ldt);
extern void RNGCDECL dlarscl2(rng_int_t m, rng_int_t n, double *d, double *x, rng_int_t ldx);
extern void RNGCDECL dlartgp(double f, double g, double *cs, double *sn, double *r);
extern void RNGCDECL dlartgs(double x, double y, double sigma, double *cs, double *sn);
extern void RNGCDECL dlascl2(rng_int_t m, rng_int_t n, double *d, double *x, rng_int_t ldx);
extern void RNGCDECL dlasrt(char id, rng_int_t n, double *d, rng_int_t *info);
extern void RNGCDECL dlassq(rng_int_t n, double *x, rng_int_t incx, double *scale, double *sumsq);
extern void RNGCDECL dlat2s(char uplo, rng_int_t n, double *a, rng_int_t lda, float *sa, rng_int_t ldsa, rng_int_t *info);
extern void RNGCDECL dopgtr(char uplo, rng_int_t n, double *ap, double *tau, double *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL dopmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, double *ap, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dorbdb(char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, double *x11, rng_int_t ldx11, double *x12, rng_int_t ldx12, double *x21, rng_int_t ldx21, double *x22, rng_int_t ldx22, double *theta, double *phi, double *taup1, double *taup2, double *tauq1, double *tauq2, rng_int_t *info);
extern void RNGCDECL dorcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, double *x11, rng_int_t ldx11, double *x12, rng_int_t ldx12, double *x21, rng_int_t ldx21, double *x22, rng_int_t ldx22, double *theta, double *u1, rng_int_t ldu1, double *u2, rng_int_t ldu2, double *v1t, rng_int_t ldv1t, double *v2t, rng_int_t ldv2t, rng_int_t *info);
extern void RNGCDECL dorgbr(char vect, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorghr(rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorglq(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgql(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgqr(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgrq(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgtr(char uplo, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dormbr(char vect, char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormhr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormlq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormql(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormqr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormr3(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormrq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormrz(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dpbcon(char uplo, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dpbequ(char uplo, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL dpbrfs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dpbstf(char uplo, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL dpbsv(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dpbsvx(char fact, char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, char equed, double *scale, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dpbtrf(char uplo, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dpbtrs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dpftrf(char transr, char uplo, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dpftri(char transr, char uplo, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dpftrs(char transr, char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dpocon(char uplo, rng_int_t n, double *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dpoequ(rng_int_t n, double *a, rng_int_t lda, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL dpoequb(rng_int_t n, double *a, rng_int_t lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL dporfs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dporfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, double *s, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dposv(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dposvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, char equed, double *scale, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dposvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, char equed, double *s, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dpotrf(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dpotri(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dpotrs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dppcon(char uplo, rng_int_t n, double *a, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dppequ(char uplo, rng_int_t n, double *a, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL dpprfs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *af, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dppsv(char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dppsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *af, char equed, double *scale, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dpptrf(char uplo, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dpptri(char uplo, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dpptrs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dpstf2(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, double tol, rng_int_t *info);
extern void RNGCDECL dpstrf(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, double tol, rng_int_t *info);
extern void RNGCDECL dptcon(rng_int_t n, double *diag, double *offd, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dpteqr(char compz, rng_int_t n, double *d, double *e, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dptrfs(rng_int_t n, rng_int_t nrhs, double *diag, double *offd, double *diagf, double *offdf, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dptsv(rng_int_t n, rng_int_t nrhs, double *diag, double *sub, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dptsvx(char fact, rng_int_t n, rng_int_t nrhs, double *diag, double *sub, double *diagf, double *subf, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dpttrf(rng_int_t n, double *diag, double *offd, rng_int_t *info);
extern void RNGCDECL dpttrs(rng_int_t n, rng_int_t nrhs, double *diag, double *offd, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dsbev(char jobz, char uplo, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dsbevd(char jobz, char uplo, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dsbevx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *q, rng_int_t ldq, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsbgst(char vect, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, double *ab, rng_int_t ldab, double *bb, rng_int_t ldbb, double *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL dsbgv(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, double *ab, rng_int_t ldab, double *bb, rng_int_t ldbb, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dsbgvd(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, double *ab, rng_int_t ldab, double *bb, rng_int_t ldbb, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dsbgvx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, double *ab, rng_int_t ldab, double *bb, rng_int_t ldbb, double *q, rng_int_t ldq, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsbtrd(char vect, char uplo, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, double *d, double *e, double *q, rng_int_t ldq, rng_int_t *info);
extern double RNGCDECL dsecnd(void);
extern void RNGCDECL dsfrk(char transr, char uplo, char trans, rng_int_t n, rng_int_t k, double alpha, double *a, rng_int_t lda, double beta, double *c);
extern void RNGCDECL dsgesv(rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGCDECL dspcon(char uplo, rng_int_t n, double *a, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dspev(char jobz, char uplo, rng_int_t n, double *a, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dspevd(char jobz, char uplo, rng_int_t n, double *ap, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dspevx(char jobz, char range, char uplo, rng_int_t n, double *a, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dspgst(rng_int_t itype, char uplo, rng_int_t n, double *ap, double *bp, rng_int_t *info);
extern void RNGCDECL dspgv(rng_int_t itype, char jobz, char uplo, rng_int_t n, double *a, double *b, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dspgvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, double *ap, double *bp, double *w, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dspgvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, double *ap, double *bp, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsposv(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *x, rng_int_t ldx, rng_int_t *iter, rng_int_t *info);
extern void RNGCDECL dsprfs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *af, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dspsv(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dspsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, double *af, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dsptrd(char uplo, rng_int_t n, double *ap, double *d, double *e, double *tau, rng_int_t *info);
extern void RNGCDECL dsptrf(char uplo, rng_int_t n, double *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsptri(char uplo, rng_int_t n, double *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsptrs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dstebz(char range, char order, rng_int_t n, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, double *d, double *e, rng_int_t *m, rng_int_t *nsplit, double *w, rng_int_t *iblock, rng_int_t *isplit, rng_int_t *info);
extern void RNGCDECL dstedc(char compz, rng_int_t n, double *d, double *e, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dstegr(char jobz, char range, rng_int_t n, double *d, double *e, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL dstein(rng_int_t n, double *d, double *e, rng_int_t m, double *w, rng_int_t *iblock, rng_int_t *isplit, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dstemr(char jobz, char range, rng_int_t n, double *d, double *e, double vl, double vu, rng_int_t il, rng_int_t iu, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, rng_int_t *info);
extern void RNGCDECL dsteqr(char compz, rng_int_t n, double *d, double *e, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dsterf(rng_int_t n, double *d, double *e, rng_int_t *info);
extern void RNGCDECL dstev(char jobz, rng_int_t n, double *diag, double *offd, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dstevd(char jobz, rng_int_t n, double *d, double *e, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dstevr(char jobz, char range, rng_int_t n, double *d, double *e, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL dstevx(char jobz, char range, rng_int_t n, double *diag, double *offd, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsycon(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL dsyconv(char uplo, char way, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsyequb(char uplo, rng_int_t n, double *a, rng_int_t lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL dsyev(char jobz, char uplo, rng_int_t n, double *a, rng_int_t lda, double *w, rng_int_t *info);
extern void RNGCDECL dsyevd(char jobz, char uplo, rng_int_t n, double *a, rng_int_t lda, double *w, rng_int_t *info);
extern void RNGCDECL dsyevr(char jobz, char range, char uplo, rng_int_t n, double *a, rng_int_t lda, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL dsyevx(char jobz, char range, char uplo, rng_int_t n, double *a, rng_int_t lda, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsygst(rng_int_t itype, char uplo, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dsygv(rng_int_t itype, char jobz, char uplo, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *w, rng_int_t *info);
extern void RNGCDECL dsygvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *w, rng_int_t *info);
extern void RNGCDECL dsygvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, double *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL dsyrfs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dsyrfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *s, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dsysv(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dsysvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dsysvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *s, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL dsyswapr(char uplo, rng_int_t n, double *a, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL dsytrd(char uplo, rng_int_t n, double *a, rng_int_t lda, double *d, double *e, double *tau, rng_int_t *info);
extern void RNGCDECL dsytrf(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsytri(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsytri2(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dsytri2x(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL dsytrs(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dsytrs2(char uplo, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, rng_int_t *ipiv, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dtbcon(char norm, char uplo, char diag, rng_int_t n, rng_int_t ndiag, double *a, rng_int_t lda, double *rcond, rng_int_t *info);
extern void RNGCDECL dtbrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dtbtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dtfsm(char transr, char side, char uplo, char trans, char diag, rng_int_t m, rng_int_t n, double alpha, double *a, double *b, rng_int_t ldb);
extern void RNGCDECL dtftri(char transr, char uplo, char diag, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dtfttp(char transr, char uplo, rng_int_t n, double *arf, double *ap, rng_int_t *info);
extern void RNGCDECL dtfttr(char transr, char uplo, rng_int_t n, double *arf, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dtgevc(char side, char howmny, rng_int_t *select, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL dtgexc(rng_int_t wantq, rng_int_t wantz, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *q, rng_int_t ldq, double *z, rng_int_t ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL dtgsen(rng_int_t ijob, rng_int_t wantq, rng_int_t wantz, rng_int_t *select, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t ldq, double *z, rng_int_t ldz, rng_int_t *m, double *pl, double *pr, double *dif, rng_int_t *info);
extern void RNGCDECL dtgsja(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, rng_int_t k, rng_int_t l, double *a, rng_int_t lda, double *b, rng_int_t ldb, double tola, double tolb, double *alpha, double *beta, double *u, rng_int_t ldu, double *v, rng_int_t ldv, double *q, rng_int_t ldq, rng_int_t *ncycle, rng_int_t *info);
extern void RNGCDECL dtgsna(char job, char howmnt, rng_int_t *select, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, double *s, double *dif, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL dtgsyl(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *c, rng_int_t ldc, double *d, rng_int_t ldd, double *e, rng_int_t lde, double *f, rng_int_t ldf, double *scale, double *dif, rng_int_t *info);
extern void RNGCDECL dtpcon(char norm, char uplo, char diag, rng_int_t n, double *a, double *rcond, rng_int_t *info);
extern void RNGCDECL dtpmqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, rng_int_t nb, double *v, rng_int_t ldv, double *t, rng_int_t ldt, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dtpqrt(rng_int_t m, rng_int_t n, rng_int_t l, rng_int_t nb, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL dtpqrt2(rng_int_t m, rng_int_t n, rng_int_t l, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL dtprfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, double *v, rng_int_t ldv, double *t, rng_int_t ldt, double *a, rng_int_t lda, double *b, rng_int_t ldb);
extern void RNGCDECL dtprfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, double *a, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dtptri(char uplo, char diag, rng_int_t n, double *a, rng_int_t *info);
extern void RNGCDECL dtptrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, double *a, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dtpttf(char transr, char uplo, rng_int_t n, double *ap, double *arf, rng_int_t *info);
extern void RNGCDECL dtpttr(char uplo, rng_int_t n, double *ap, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dtrcon(char norm, char uplo, char diag, rng_int_t n, double *a, rng_int_t lda, double *rcond, rng_int_t *info);
extern void RNGCDECL dtrevc(char side, char howmny, rng_int_t *select, rng_int_t n, double *t, rng_int_t ldt, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL dtrexc(char compq, rng_int_t n, double *t, rng_int_t ldt, double *q, rng_int_t ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL dtrrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL dtrsen(char job, char compq, rng_int_t *select, rng_int_t n, double *t, rng_int_t ldt, double *q, rng_int_t ldq, double *wr, double *wi, rng_int_t *m, double *s, double *sep, rng_int_t *info);
extern void RNGCDECL dtrsna(char job, char howmny, rng_int_t *select, rng_int_t n, double *t, rng_int_t ldt, double *vl, rng_int_t ldvl, double *vr, rng_int_t ldvr, double *s, double *sep, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL dtrsyl(char trana, char tranb, rng_int_t isgn, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *c, rng_int_t ldc, double *scale, rng_int_t *info);
extern void RNGCDECL dtrtri(char uplo, char diag, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dtrtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dtrttf(char transr, char uplo, rng_int_t n, double *a, rng_int_t lda, double *arf, rng_int_t *info);
extern void RNGCDECL dtrttp(char uplo, rng_int_t n, double *a, rng_int_t lda, double *ap, rng_int_t *info);
extern void RNGCDECL dtzrqf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dtzrzf(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern rng_int_t RNGCDECL ilaclc(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda);
extern rng_int_t RNGCDECL ilaclr(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda);
extern rng_int_t RNGCDECL iladiag(char diag);
extern rng_int_t RNGCDECL iladlc(rng_int_t m, rng_int_t n, double *a, rng_int_t lda);
extern rng_int_t RNGCDECL iladlr(rng_int_t m, rng_int_t n, double *a, rng_int_t lda);
extern rng_int_t RNGCDECL ilaenv(rng_int_t ispec, const char *name, const char *opts, rng_int_t n1, rng_int_t n2, rng_int_t n3, rng_int_t n4);
extern rng_int_t RNGCDECL ilaprec(char prec);
extern rng_int_t RNGCDECL ilaslc(rng_int_t m, rng_int_t n, float *a, rng_int_t lda);
extern rng_int_t RNGCDECL ilaslr(rng_int_t m, rng_int_t n, float *a, rng_int_t lda);
extern rng_int_t RNGCDECL ilatrans(char trans);
extern rng_int_t RNGCDECL ilauplo(char uplo);
extern rng_int_t RNGCDECL ilazlc(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern rng_int_t RNGCDECL ilazlr(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL ilaenvset(rng_int_t ispec, const char *name, const char *opts, rng_int_t n1, rng_int_t n2, rng_int_t n3, rng_int_t n4, rng_int_t nvalue, rng_int_t *info);
extern void RNGCDECL ilaver(rng_int_t *vers_major, rng_int_t *vers_minor, rng_int_t *vers_patch);
extern float RNGCDECL second(void);
extern void RNGCDECL sbbcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, rng_int_t m, rng_int_t p, rng_int_t q, float *theta, float *phi, float *u1, rng_int_t ldu1, float *u2, rng_int_t ldu2, float *v1t, rng_int_t ldv1t, float *v2t, rng_int_t ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, rng_int_t *info);
extern void RNGCDECL sbdsdc(char uplo, char compq, rng_int_t n, float *d, float *e, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, float *q, rng_int_t *iq, rng_int_t *info);
extern void RNGCDECL sbdsqr(char uplo, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, float *d, float *e, float *vt, rng_int_t ldvt, float *u, rng_int_t ldu, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sdisna(char job, rng_int_t m, rng_int_t n, float *d, float *sep, rng_int_t *info);
extern void RNGCDECL sgbbrd(char vect, rng_int_t m, rng_int_t n, rng_int_t ncc, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab, float *d, float *e, float *q, rng_int_t ldq, float *pt, rng_int_t ldpt, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sgbcon(char norm, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, float *a, rng_int_t lda, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL sgbequ(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, float *a, rng_int_t lda, float *rowsc, float *colsc, float *rowcn, float *colcn, float *amax, rng_int_t *info);
extern void RNGCDECL sgbequb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL sgbrfs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sgbrfsx(char trans, char equed, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, float *ab, rng_int_t ldab, float *afb, rng_int_t ldafb, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL sgbsv(rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);

/* N.B. In this C interface to sgbsvx, rpvgrw returns what is returned in
   the first element of WORK by the FORTRAN interface */
extern void RNGCDECL sgbsvx(char fact, char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *rowsc, float *colsc, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, float *rpvgrw, rng_int_t *info);

extern void RNGCDECL sgbsvxx(char fact, char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, float *ab, rng_int_t ldab, float *afb, rng_int_t ldafb, rng_int_t *ipiv, char equed, float *r, float *c, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL sgbtrf(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgbtrs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sgebak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *scale, rng_int_t m, float *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL sgebal(char job, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info);
extern void RNGCDECL sgebrd(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *d, float *e, float *tauq, float *taup, rng_int_t *info);
extern void RNGCDECL sgecon(char norm, rng_int_t n, float *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL sgeequ(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *rowsc, float *colsc, float *rowcn, float *colcn, float *amax, rng_int_t *info);
extern void RNGCDECL sgeequb(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGCDECL sgees(char jobz, char sortev, RNG_SGEES_SELECT select, rng_int_t n, float *a, rng_int_t lda, rng_int_t *nout, float *wr, float *wi, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sgeesx(char jobz, char sortev, RNG_SGEESX_SELECT select, char sense, rng_int_t n, float *a, rng_int_t lda, rng_int_t *nout, float *wr, float *wi, float *z, rng_int_t ldz, float *srcone, float *rconv, rng_int_t *info);
extern void RNGCDECL sgeev(char jobvl, char jobvr, rng_int_t n, float *a, rng_int_t lda, float *wr, float *wi, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL sgeevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, float *a, rng_int_t lda, float *wr, float *wi, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rcone, float *rconv, rng_int_t *info);
extern void RNGCDECL sgegs(char jobvsl, char jobvsr, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t ldvsl, float *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL sgegv(char jobvl, char jobvr, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL sgehrd(rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgejsv(char joba, char jobu, char jobv, char jobr, char jobt, char jobp, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *sva, float *u, rng_int_t ldu, float *v, rng_int_t ldv, float *work, rng_int_t lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGCDECL sgelqf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgels(char trans, rng_int_t m, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sgelsd(rng_int_t m, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *s, float rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL sgelss(rng_int_t m, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *sing, float rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL sgelsx(rng_int_t m, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *jpivot, float rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL sgelsy(rng_int_t m, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *jpvt, float rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL sgemqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t nb, float *v, rng_int_t ldv, float *t, rng_int_t ldt, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sgeqlf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqp3(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, rng_int_t *jpvt, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqpf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, rng_int_t *jpivot, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqr2p(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqrf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqrfp(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqrt(rng_int_t m, rng_int_t n, rng_int_t nb, float *a, rng_int_t lda, float *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL sgeqrt2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL sgeqrt3(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL sgerfs(char transa, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sgerfsx(char trans, char equed, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL sgerqf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgesdd(char jobz, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *s, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL sgesv(rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sgesvd(char jobu, char jobvt, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *sing, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL sgesvj(char joba, char jobu, char jobv, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *sva, rng_int_t mv, float *v, rng_int_t ldv, float *work, rng_int_t lwork, rng_int_t *info);

/* N.B. In this C interface to sgesvx, rpvgrw returns what is returned in
   the first element of WORK by the FORTRAN interface */
extern void RNGCDECL sgesvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *rowsc, float *colsc, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, float *rpvgrw, rng_int_t *info);

extern void RNGCDECL sgesvxx(char fact, char trans, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *r, float *c, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL sgetrf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgetri(rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgetrs(char transa, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sggbak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *lscale, float *rscale, rng_int_t m, float *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL sggbal(char job, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *info);
extern void RNGCDECL sgges(char jobvsl, char jobvsr, char sort, RNG_SGGES_SELCTG selctg, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t ldvsl, float *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL sggesx(char jobvsl, char jobvsr, char sort, RNG_SGGESX_SELCTG selctg, char sense, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t ldvsl, float *vsr, rng_int_t ldvsr, float *rconde, float *rcondv, rng_int_t *info);
extern void RNGCDECL sggev(char jobvl, char jobvr, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL sggevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, rng_int_t *info);
extern void RNGCDECL sggglm(rng_int_t n, rng_int_t m, rng_int_t p, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *d, float *x, float *y, rng_int_t *info);
extern void RNGCDECL sgghrd(char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *q, rng_int_t ldq, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sgglse(rng_int_t m, rng_int_t n, rng_int_t p, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *c, float *d, float *x, rng_int_t *info);
extern void RNGCDECL sggqrf(rng_int_t n, rng_int_t m, rng_int_t p, float *a, rng_int_t lda, float *taua, float *b, rng_int_t ldb, float *taub, rng_int_t *info);
extern void RNGCDECL sggrqf(rng_int_t m, rng_int_t p, rng_int_t n, float *a, rng_int_t lda, float *taua, float *b, rng_int_t ldb, float *taub, rng_int_t *info);
extern void RNGCDECL sggsvd(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t n, rng_int_t p, rng_int_t *k, rng_int_t *l, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alpha, float *beta, float *u, rng_int_t ldu, float *v, rng_int_t ldv, float *q, rng_int_t ldq, rng_int_t *iwork3, rng_int_t *info);
extern void RNGCDECL sggsvp(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float tola, float tolb, rng_int_t *k, rng_int_t *l, float *u, rng_int_t ldu, float *v, rng_int_t ldv, float *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL sgsvj0(char jobv, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *d, float *sva, rng_int_t mv, float *v, rng_int_t ldv, float eps, float sfmin, float tol, rng_int_t nsweep, rng_int_t *info);
extern void RNGCDECL sgsvj1(char jobv, rng_int_t m, rng_int_t n, rng_int_t n1, float *a, rng_int_t lda, float *d, float *sva, rng_int_t mv, float *v, rng_int_t ldv, float eps, float sfmin, float tol, rng_int_t nsweep, rng_int_t *info);
extern void RNGCDECL sgtcon(char norm, rng_int_t n, float *low, float *diag, float *up1, float *up2, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL sgtrfs(char transa, rng_int_t n, rng_int_t nrhs, float *low, float *diag, float *up, float *lowf, float *diagf, float *upf1, float *upf2, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sgtsv(rng_int_t n, rng_int_t nrhs, float *low, float *diag, float *up, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sgtsvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, float *low, float *diag, float *up, float *lowf, float *diagf, float *upf1, float *upf2, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sgttrf(rng_int_t n, float *low, float *diag, float *up1, float *up2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgttrs(char transa, rng_int_t n, rng_int_t nrhs, float *low, float *diag, float *up1, float *up2, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL shgeqz(char job, char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t ldq, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL shsein(char side, char eigsrc, char initv, rng_int_t *select, rng_int_t n, float *h, rng_int_t ldh, float *wr, float *wi, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGCDECL shseqr(char job, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *h, rng_int_t ldh, float *wr, float *wi, float *z, rng_int_t ldz, rng_int_t *info);
extern rng_int_t RNGCDECL sisnan(float *sin);
extern float RNGCDECL sla_gbrcond(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab, float *afb, rng_int_t ldafb, rng_int_t *ipiv, rng_int_t cmode, float *c, rng_int_t *info);
extern float RNGCDECL sla_gbrpvgrw(rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t ncols, float *ab, rng_int_t ldab, float *afb, rng_int_t ldafb);
extern float RNGCDECL sla_gercond(char trans, rng_int_t n, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, rng_int_t cmode, float *c, rng_int_t *info);
extern float RNGCDECL sla_gerpvgrw(rng_int_t n, rng_int_t ncols, float *a, rng_int_t lda, float *af, rng_int_t ldaf);
extern float RNGCDECL sla_porcond(char uplo, rng_int_t n, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t cmode, float *c, rng_int_t *info);
extern float RNGCDECL sla_porpvgrw(char uplo, rng_int_t ncols, float *a, rng_int_t lda, float *af, rng_int_t ldaf);
extern float RNGCDECL sla_syrcond(char uplo, rng_int_t n, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, rng_int_t cmode, float *c, rng_int_t *info);
extern float RNGCDECL sla_syrpvgrw(char uplo, rng_int_t n, rng_int_t *info, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv);
extern float RNGCDECL slansf(char norm, char transr, char uplo, rng_int_t n, float *a);
extern float RNGCDECL slamch(char cmach);
extern void RNGCDECL sla_gbamv(rng_int_t trans, rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, float alpha, float *ab, rng_int_t ldab, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sla_gbrfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, float *ab, rng_int_t ldab, float *afb, rng_int_t ldafb, rng_int_t *ipiv, int colequ, float *c, float *b, rng_int_t ldb, float *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL sla_geamv(rng_int_t trans, rng_int_t m, rng_int_t n, float alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float beta, float *y, rng_int_t incy);
extern void RNGCDECL sla_gerfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, float *c, float *b, rng_int_t ldb, float *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL sla_lin_berr(rng_int_t n, rng_int_t nz, rng_int_t nrhs, float *res, float *ayb, float *berr);
extern void RNGCDECL sla_porfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, int colequ, float *c, float *b, rng_int_t ldb, float *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL sla_syamv(rng_int_t uplo, rng_int_t n, float *alpha, float *a, rng_int_t lda, float *x, rng_int_t incx, float *beta, float *y, rng_int_t incy);
extern void RNGCDECL sla_syrfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, float *c, float *b, rng_int_t ldb, float *y, rng_int_t ldy, float *berr_out, rng_int_t n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float rcond, rng_int_t ithresh, float rthresh, float dz_ub, int ignore_cwise, rng_int_t *info);
extern void RNGCDECL sla_wwaddw(rng_int_t n, float *x, float *y, float *w);
extern void RNGCDECL slapmr(int forwrd, rng_int_t m, rng_int_t n, float *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL slarfgp(rng_int_t n, float *alpha, float *x, rng_int_t incx, float *tau);
extern void RNGCDECL slarft(char direct, char storev, rng_int_t n, rng_int_t k, float *v, rng_int_t ldv, float *tau, float *t, rng_int_t ldt);
extern void RNGCDECL slarscl2(rng_int_t m, rng_int_t n, float *d, float *x, rng_int_t ldx);
extern void RNGCDECL slartgp(float f, float g, float *cs, float *sn, float *r);
extern void RNGCDECL slartgs(float x, float y, float sigma, float *cs, float *sn);
extern void RNGCDECL slascl2(rng_int_t m, rng_int_t n, float *d, float *x, rng_int_t ldx);
extern void RNGCDECL slasrt(char id, rng_int_t n, float *d, rng_int_t *info);
extern void RNGCDECL slassq(rng_int_t n, float *x, rng_int_t incx, float *scale, float *sumsq);
extern void RNGCDECL sopgtr(char uplo, rng_int_t n, float *ap, float *tau, float *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL sopmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, float *ap, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sorbdb(char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, float *x11, rng_int_t ldx11, float *x12, rng_int_t ldx12, float *x21, rng_int_t ldx21, float *x22, rng_int_t ldx22, float *theta, float *phi, float *taup1, float *taup2, float *tauq1, float *tauq2, rng_int_t *info);
extern void RNGCDECL sorcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, float *x11, rng_int_t ldx11, float *x12, rng_int_t ldx12, float *x21, rng_int_t ldx21, float *x22, rng_int_t ldx22, float *theta, float *u1, rng_int_t ldu1, float *u2, rng_int_t ldu2, float *v1t, rng_int_t ldv1t, float *v2t, rng_int_t ldv2t, rng_int_t *info);
extern void RNGCDECL sorgbr(char vect, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorghr(rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorglq(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgql(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgqr(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgrq(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgtr(char uplo, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sormbr(char vect, char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormhr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormlq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormql(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormqr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormr3(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormrq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormrz(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL spbcon(char uplo, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL spbequ(char uplo, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL spbrfs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL spbstf(char uplo, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL spbsv(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL spbsvx(char fact, char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, char equed, float *scale, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL spbtrf(char uplo, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL spbtrs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL spftrf(char transr, char uplo, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL spftri(char transr, char uplo, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL spftrs(char transr, char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL spocon(char uplo, rng_int_t n, float *a, rng_int_t lda, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL spoequ(rng_int_t n, float *a, rng_int_t lda, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL spoequb(rng_int_t n, float *a, rng_int_t lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL sporfs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sporfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, float *s, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL sposv(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sposvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, char equed, float *scale, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sposvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, char equed, float *s, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL spotrf(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL spotri(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL spotrs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sppcon(char uplo, rng_int_t n, float *a, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL sppequ(char uplo, rng_int_t n, float *a, float *scale, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL spprfs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *af, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sppsv(char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sppsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *af, char equed, float *scale, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL spptrf(char uplo, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL spptri(char uplo, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL spptrs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL spstf2(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, float tol, rng_int_t *info);
extern void RNGCDECL spstrf(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, float tol, rng_int_t *info);
extern void RNGCDECL sptcon(rng_int_t n, float *diag, float *offd, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL spteqr(char compz, rng_int_t n, float *d, float *e, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sptrfs(rng_int_t n, rng_int_t nrhs, float *diag, float *offd, float *diagf, float *offdf, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sptsv(rng_int_t n, rng_int_t nrhs, float *diag, float *sub, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sptsvx(char fact, rng_int_t n, rng_int_t nrhs, float *diag, float *sub, float *diagf, float *subf, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL spttrf(rng_int_t n, float *diag, float *offd, rng_int_t *info);
extern void RNGCDECL spttrs(rng_int_t n, rng_int_t nrhs, float *diag, float *offd, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ssbev(char jobz, char uplo, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL ssbevd(char jobz, char uplo, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL ssbevx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *q, rng_int_t ldq, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssbgst(char vect, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, float *ab, rng_int_t ldab, float *bb, rng_int_t ldbb, float *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL ssbgv(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, float *ab, rng_int_t ldab, float *bb, rng_int_t ldbb, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL ssbgvd(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, float *ab, rng_int_t ldab, float *bb, rng_int_t ldbb, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL ssbgvx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, float *ab, rng_int_t ldab, float *bb, rng_int_t ldbb, float *q, rng_int_t ldq, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssbtrd(char vect, char uplo, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, float *d, float *e, float *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL ssfrk(char transr, char uplo, char trans, rng_int_t n, rng_int_t k, float alpha, float *a, rng_int_t lda, float beta, float *c);
extern void RNGCDECL sspcon(char uplo, rng_int_t n, float *a, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL sspev(char jobz, char uplo, rng_int_t n, float *a, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sspevd(char jobz, char uplo, rng_int_t n, float *ap, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sspevx(char jobz, char range, char uplo, rng_int_t n, float *a, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL sspgst(rng_int_t itype, char uplo, rng_int_t n, float *ap, float *bp, rng_int_t *info);
extern void RNGCDECL sspgv(rng_int_t itype, char jobz, char uplo, rng_int_t n, float *a, float *b, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sspgvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, float *ap, float *bp, float *w, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sspgvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, float *ap, float *bp, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssprfs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *af, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL sspsv(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sspsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, float *af, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ssptrd(char uplo, rng_int_t n, float *ap, float *d, float *e, float *tau, rng_int_t *info);
extern void RNGCDECL ssptrf(char uplo, rng_int_t n, float *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssptri(char uplo, rng_int_t n, float *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssptrs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL sstebz(char range, char order, rng_int_t n, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, float *d, float *e, rng_int_t *m, rng_int_t *nsplit, float *w, rng_int_t *iblock, rng_int_t *isplit, rng_int_t *info);
extern void RNGCDECL sstedc(char compz, rng_int_t n, float *d, float *e, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sstegr(char jobz, char range, rng_int_t n, float *d, float *e, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL sstein(rng_int_t n, float *d, float *e, rng_int_t m, float *w, rng_int_t *iblock, rng_int_t *isplit, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssteqr(char compz, rng_int_t n, float *d, float *e, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL ssterf(rng_int_t n, float *d, float *e, rng_int_t *info);
extern void RNGCDECL sstev(char jobz, rng_int_t n, float *diag, float *offd, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sstevd(char jobz, rng_int_t n, float *d, float *e, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL sstevr(char jobz, char range, rng_int_t n, float *d, float *e, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL sstevx(char jobz, char range, rng_int_t n, float *diag, float *offd, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssycon(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, float anorm, float *rcond, rng_int_t *info);
extern void RNGCDECL ssyconv(char uplo, char way, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssyequb(char uplo, rng_int_t n, float *a, rng_int_t lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGCDECL ssyev(char jobz, char uplo, rng_int_t n, float *a, rng_int_t lda, float *w, rng_int_t *info);
extern void RNGCDECL ssyevd(char jobz, char uplo, rng_int_t n, float *a, rng_int_t lda, float *w, rng_int_t *info);
extern void RNGCDECL ssyevr(char jobz, char range, char uplo, rng_int_t n, float *a, rng_int_t lda, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL ssyevx(char jobz, char range, char uplo, rng_int_t n, float *a, rng_int_t lda, float vl, float vu, rng_int_t il, rng_int_t iu, float abtol, rng_int_t *nfound, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssygst(rng_int_t itype, char uplo, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ssygv(rng_int_t itype, char jobz, char uplo, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *w, rng_int_t *info);
extern void RNGCDECL ssygvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *w, rng_int_t *info);
extern void RNGCDECL ssygvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float vl, float vu, rng_int_t il, rng_int_t iu, float abstol, rng_int_t *m, float *w, float *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL ssyrfs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ssyrfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *s, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL ssysv(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ssysvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL ssysvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, float *s, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t nparams, float *params, rng_int_t *info);
extern void RNGCDECL ssyswapr(char uplo, rng_int_t n, float *a, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL ssytrd(char uplo, rng_int_t n, float *a, rng_int_t lda, float *d, float *e, float *tau, rng_int_t *info);
extern void RNGCDECL ssytrf(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssytri(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssytri2(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ssytri2x(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL ssytrs(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ssytrs2(char uplo, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, rng_int_t *ipiv, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL stbcon(char norm, char uplo, char diag, rng_int_t n, rng_int_t ndiag, float *a, rng_int_t lda, float *rcond, rng_int_t *info);
extern void RNGCDECL stbrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL stbtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL stfsm(char transr, char side, char uplo, char trans, char diag, rng_int_t m, rng_int_t n, float alpha, float *a, float *b, rng_int_t ldb);
extern void RNGCDECL stftri(char transr, char uplo, char diag, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL stfttp(char transr, char uplo, rng_int_t n, float *arf, float *ap, rng_int_t *info);
extern void RNGCDECL stfttr(char transr, char uplo, rng_int_t n, float *arf, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL stgevc(char side, char howmny, rng_int_t *select, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL stgexc(rng_int_t wantq, rng_int_t wantz, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *q, rng_int_t ldq, float *z, rng_int_t ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL stgsen(rng_int_t ijob, rng_int_t wantq, rng_int_t wantz, rng_int_t *select, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t ldq, float *z, rng_int_t ldz, rng_int_t *m, float *pl, float *pr, float *dif, rng_int_t *info);
extern void RNGCDECL stgsja(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, rng_int_t k, rng_int_t l, float *a, rng_int_t lda, float *b, rng_int_t ldb, float tola, float tolb, float *alpha, float *beta, float *u, rng_int_t ldu, float *v, rng_int_t ldv, float *q, rng_int_t ldq, rng_int_t *ncycle, rng_int_t *info);
extern void RNGCDECL stgsna(char job, char howmnt, rng_int_t *select, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, float *s, float *dif, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL stgsyl(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *c, rng_int_t ldc, float *d, rng_int_t ldd, float *e, rng_int_t lde, float *f, rng_int_t ldf, float *scale, float *dif, rng_int_t *info);
extern void RNGCDECL stpcon(char norm, char uplo, char diag, rng_int_t n, float *a, float *rcond, rng_int_t *info);
extern void RNGCDECL stpmqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, rng_int_t nb, float *v, rng_int_t ldv, float *t, rng_int_t ldt, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL stpqrt(rng_int_t m, rng_int_t n, rng_int_t l, rng_int_t nb, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL stpqrt2(rng_int_t m, rng_int_t n, rng_int_t l, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL stprfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, float *v, rng_int_t ldv, float *t, rng_int_t ldt, float *a, rng_int_t lda, float *b, rng_int_t ldb);
extern void RNGCDECL stprfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, float *a, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL stptri(char uplo, char diag, rng_int_t n, float *a, rng_int_t *info);
extern void RNGCDECL stptrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, float *a, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL stpttf(char transr, char uplo, rng_int_t n, float *ap, float *arf, rng_int_t *info);
extern void RNGCDECL stpttr(char uplo, rng_int_t n, float *ap, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL strcon(char norm, char uplo, char diag, rng_int_t n, float *a, rng_int_t lda, float *rcond, rng_int_t *info);
extern void RNGCDECL strevc(char side, char howmny, rng_int_t *select, rng_int_t n, float *t, rng_int_t ldt, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL strexc(char compq, rng_int_t n, float *t, rng_int_t ldt, float *q, rng_int_t ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL strrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *x, rng_int_t ldx, float *ferr, float *berr, rng_int_t *info);
extern void RNGCDECL strsen(char job, char compq, rng_int_t *select, rng_int_t n, float *t, rng_int_t ldt, float *q, rng_int_t ldq, float *wr, float *wi, rng_int_t *m, float *s, float *sep, rng_int_t *info);
extern void RNGCDECL strsna(char job, char howmny, rng_int_t *select, rng_int_t n, float *t, rng_int_t ldt, float *vl, rng_int_t ldvl, float *vr, rng_int_t ldvr, float *s, float *sep, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL strsyl(char trana, char tranb, rng_int_t isgn, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *c, rng_int_t ldc, float *scale, rng_int_t *info);
extern void RNGCDECL strtri(char uplo, char diag, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL strtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL strttf(char transr, char uplo, rng_int_t n, float *a, rng_int_t lda, float *arf, rng_int_t *info);
extern void RNGCDECL strttp(char uplo, rng_int_t n, float *a, rng_int_t lda, float *ap, rng_int_t *info);
extern void RNGCDECL stzrqf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL stzrzf(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL xerbla_array(char srname_array, rng_int_t srname_len, rng_int_t *info);

/* N.B. In this C interface to zgbsvx, rpvgrw returns what is returned in
   the first element of RWORK by the FORTRAN interface */
extern void RNGCDECL zgbsvx(char fact, char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *rowsc, double *colsc, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, double *rpvgrw, rng_int_t *info);

extern void RNGCDECL zbbcsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, rng_int_t m, rng_int_t p, rng_int_t q, double *theta, double *phi, doublecomplex *u1, rng_int_t ldu1, doublecomplex *u2, rng_int_t ldu2, doublecomplex *v1t, rng_int_t ldv1t, doublecomplex *v2t, rng_int_t ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, rng_int_t *info);
extern void RNGCDECL zbdsqr(char uplo, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, double *d, double *e, doublecomplex *vt, rng_int_t ldvt, doublecomplex *u, rng_int_t ldu, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zcgesv(rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, doublecomplex *work, complex *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGCDECL zcposv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, rng_int_t *iter, rng_int_t *info);
extern void RNGCDECL zgbbrd(char vect, rng_int_t m, rng_int_t n, rng_int_t ncc, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, double *d, double *e, doublecomplex *q, rng_int_t ldq, doublecomplex *pt, rng_int_t ldpt, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zgbcon(char norm, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zgbequ(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, doublecomplex *a, rng_int_t lda, double *rowsc, double *colsc, double *rowcn, double *colcn, double *amax, rng_int_t *info);
extern void RNGCDECL zgbequb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGCDECL zgbrfs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zgbrfsx(char trans, char equed, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zgbsv(rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zgbsvxx(char fact, char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb, rng_int_t *ipiv, char equed, double *r, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zgbtrf(rng_int_t m, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgbtrs(char transa, rng_int_t n, rng_int_t nsub, rng_int_t nsuper, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zgebak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *scale, rng_int_t m, doublecomplex *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL zgebal(char job, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info);
extern void RNGCDECL zgebrd(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, rng_int_t *info);
extern void RNGCDECL zgecon(char norm, rng_int_t n, doublecomplex *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zgeequ(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *rowsc, double *colsc, double *rowcn, double *colcn, double *amax, rng_int_t *info);
extern void RNGCDECL zgeequb(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGCDECL zgees(char jobvs, char sort, RNG_ZGEES_SELECT select, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t ldvs, rng_int_t *info);
extern void RNGCDECL zgeesx(char jobvs, char sort, RNG_ZGEESX_SELECT select, char sense, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t ldvs, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL zgeev(char jobvl, char jobvr, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *w, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL zgeevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *w, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL zgegs(char jobvsl, char jobvsr, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t ldvsl, doublecomplex *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL zgegv(char jobvl, char jobvr, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL zgehrd(rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgelqf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgels(char trans, rng_int_t m, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zgelsd(rng_int_t m, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double *s, double rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL zgelss(rng_int_t m, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double *sing, double rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL zgelsx(rng_int_t m, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *jpivot, double rcond, rng_int_t *irank, rng_int_t *info);
extern void RNGCDECL zgelsy(rng_int_t m, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *jpvt, double rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL zgemqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t nb, doublecomplex *v, rng_int_t ldv, doublecomplex *t, rng_int_t ldt, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zgeqlf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqp3(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *jpvt, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqpf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *jpvt, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqr2p(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqrf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqrfp(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqrt(rng_int_t m, rng_int_t n, rng_int_t nb, doublecomplex *a, rng_int_t lda, doublecomplex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL zgeqrt2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL zgeqrt3(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL zgerfs(char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zgerfsx(char trans, char equed, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zgerqf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgesdd(char jobz, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, doublecomplex *u, rng_int_t ldu, doublecomplex *vt, rng_int_t ldvt, rng_int_t *info);
extern void RNGCDECL zgesv(rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zgesvd(char jobu, char jobvt, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *sing, doublecomplex *u, rng_int_t ldu, doublecomplex *vt, rng_int_t ldvt, rng_int_t *info);

/* N.B. In this C interface to zgesvx, rpvgrw returns what is returned in
   the first element of RWORK by the FORTRAN interface */
extern void RNGCDECL zgesvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *rowsc, double *colsc, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, double *rpvgrw, rng_int_t *info);

extern void RNGCDECL zgesvxx(char fact, char trans, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *r, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zgetrf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgetri(rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgetrs(char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zggbak(char job, char side, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *lscale, double *rscale, rng_int_t m, doublecomplex *v, rng_int_t ldv, rng_int_t *info);
extern void RNGCDECL zggbal(char job, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *info);
extern void RNGCDECL zgges(char jobvsl, char jobvsr, char sort, RNG_ZGGES_DELCTG delctg, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t ldvsl, doublecomplex *vsr, rng_int_t ldvsr, rng_int_t *info);
extern void RNGCDECL zggesx(char jobvsl, char jobvsr, char sort, RNG_ZGGESX_DELCTG delctg, char sense, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t ldvsl, doublecomplex *vsr, rng_int_t ldvsr, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL zggev(char jobvl, char jobvr, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t *info);
extern void RNGCDECL zggevx(char balanc, char jobvl, char jobvr, char sense, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, rng_int_t *info);
extern void RNGCDECL zggglm(rng_int_t n, rng_int_t m, rng_int_t p, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *d, doublecomplex *x, doublecomplex *y, rng_int_t *info);
extern void RNGCDECL zgghrd(char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *q, rng_int_t ldq, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zgglse(rng_int_t m, rng_int_t n, rng_int_t p, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *c, doublecomplex *d, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zggqrf(rng_int_t n, rng_int_t m, rng_int_t p, doublecomplex *a, rng_int_t lda, doublecomplex *taua, doublecomplex *b, rng_int_t ldb, doublecomplex *taub, rng_int_t *info);
extern void RNGCDECL zggrqf(rng_int_t m, rng_int_t p, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *taua, doublecomplex *b, rng_int_t ldb, doublecomplex *taub, rng_int_t *info);
extern void RNGCDECL zggsvd(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t n, rng_int_t p, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double *alpha, double *beta, doublecomplex *u, rng_int_t ldu, doublecomplex *v, rng_int_t ldv, doublecomplex *q, rng_int_t ldq, rng_int_t *iwork3, rng_int_t *info);
extern void RNGCDECL zggsvp(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double tola, double tolb, rng_int_t *k, rng_int_t *l, doublecomplex *u, rng_int_t ldu, doublecomplex *v, rng_int_t ldv, doublecomplex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL zgtcon(char norm, rng_int_t n, doublecomplex *low, doublecomplex *diag, doublecomplex *up1, doublecomplex *up2, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zgtrfs(char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *low, doublecomplex *diag, doublecomplex *up, doublecomplex *lowf, doublecomplex *diagf, doublecomplex *upf1, doublecomplex *upf2, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zgtsv(rng_int_t n, rng_int_t nrhs, doublecomplex *low, doublecomplex *diag, doublecomplex *up, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zgtsvx(char fact, char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *low, doublecomplex *diag, doublecomplex *up, doublecomplex *lowf, doublecomplex *diagf, doublecomplex *upf1, doublecomplex *upf2, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zgttrf(rng_int_t n, doublecomplex *low, doublecomplex *diag, doublecomplex *up1, doublecomplex *up2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgttrs(char transa, rng_int_t n, rng_int_t nrhs, doublecomplex *low, doublecomplex *diag, doublecomplex *up1, doublecomplex *up2, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhbev(char jobz, char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhbevd(char jobz, char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhbevx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, doublecomplex *q, rng_int_t ldq, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zhbgst(char vect, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, doublecomplex *ab, rng_int_t ldab, doublecomplex *bb, rng_int_t ldbb, doublecomplex *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL zhbgv(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, doublecomplex *ab, rng_int_t ldab, doublecomplex *bb, rng_int_t ldbb, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhbgvd(char jobz, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, doublecomplex *ab, rng_int_t ldab, doublecomplex *bb, rng_int_t ldbb, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhbgvx(char jobz, char range, char uplo, rng_int_t n, rng_int_t ka, rng_int_t kb, doublecomplex *ab, rng_int_t ldab, doublecomplex *bb, rng_int_t ldbb, doublecomplex *q, rng_int_t ldq, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zhbtrd(char vect, char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, double *d, double *e, doublecomplex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL zhecon(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zheequb(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zheev(char jobz, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *w, rng_int_t *info);
extern void RNGCDECL zheevd(char jobz, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *w, rng_int_t *info);
extern void RNGCDECL zheevr(char jobz, char range, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL zheevx(char jobz, char range, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zhegst(rng_int_t itype, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhegv(rng_int_t itype, char jobz, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double *w, rng_int_t *info);
extern void RNGCDECL zhegvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double *w, rng_int_t *info);
extern void RNGCDECL zhegvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zherfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zherfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zhesv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhesvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zhesvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zheswapr(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL zhetrd(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *d, double *e, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zhetrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zhetri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zhetri2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zhetri2x(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL zhetrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhetrs2(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhfrk(char transr, char uplo, char trans, rng_int_t n, rng_int_t k, double alpha, doublecomplex *a, rng_int_t lda, double beta, doublecomplex *c);
extern void RNGCDECL zhgeqz(char job, char compq, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t ldq, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhpcon(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zhpev(char jobz, char uplo, rng_int_t n, doublecomplex *a, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhpevd(char jobz, char uplo, rng_int_t n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhpevx(char jobz, char range, char uplo, rng_int_t n, doublecomplex *a, double vl, double vu, rng_int_t il, rng_int_t iu, double abtol, rng_int_t *nfound, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zhpgst(rng_int_t itype, char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *bp, rng_int_t *info);
extern void RNGCDECL zhpgv(rng_int_t itype, char jobz, char uplo, rng_int_t n, doublecomplex *a, doublecomplex *b, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhpgvd(rng_int_t itype, char jobz, char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zhpgvx(rng_int_t itype, char jobz, char range, char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *bp, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zhprfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zhpsv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhpsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zhptrd(char uplo, rng_int_t n, doublecomplex *ap, double *d, double *e, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zhptrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zhptri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zhptrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhsein(char side, char eigsrc, char initv, rng_int_t *select, rng_int_t n, doublecomplex *h, rng_int_t ldh, doublecomplex *w, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGCDECL zhseqr(char job, char compz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *h, rng_int_t ldh, doublecomplex *w, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zla_gbamv(rng_int_t trans, rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, double alpha, doublecomplex *ab, rng_int_t ldab, doublecomplex *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern double RNGCDECL zla_gbrcond_c(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb, rng_int_t *ipiv, double *c, int capply, rng_int_t *info);
extern double RNGCDECL zla_gbrcond_x(char trans, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zla_gbrfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t nrhs, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb, rng_int_t *ipiv, int colequ, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern double RNGCDECL zla_gbrpvgrw(rng_int_t n, rng_int_t kl, rng_int_t ku, rng_int_t ncols, doublecomplex *ab, rng_int_t ldab, doublecomplex *afb, rng_int_t ldafb);
extern void RNGCDECL zla_geamv(rng_int_t trans, rng_int_t m, rng_int_t n, double alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, double beta, double *y, rng_int_t incy);
extern double RNGCDECL zla_gercond_c(char trans, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *c, int capply, rng_int_t *info);
extern double RNGCDECL zla_gercond_x(char trans, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zla_gerfsx_extended(rng_int_t prec_type, rng_int_t trans_type, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *errs_n, double *errs_c, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern double RNGCDECL zla_gerpvgrw(rng_int_t n, rng_int_t ncols, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf);
extern void RNGCDECL zla_heamv(rng_int_t uplo, rng_int_t n, double *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, double *beta, double *y, rng_int_t incy);
extern double RNGCDECL zla_hercond_c(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *c, int capply, rng_int_t *info);
extern double RNGCDECL zla_hercond_x(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zla_herfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern double RNGCDECL zla_herpvgrw(char uplo, rng_int_t n, rng_int_t *info, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv);
extern void RNGCDECL zla_lin_berr(rng_int_t n, rng_int_t nz, rng_int_t nrhs, doublecomplex *res, double *ayb, double *berr);
extern double RNGCDECL zla_porcond_c(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, double *c, int capply, rng_int_t *info);
extern double RNGCDECL zla_porcond_x(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zla_porfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, int colequ, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern double RNGCDECL zla_porpvgrw(char uplo, rng_int_t ncols, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf);
extern void RNGCDECL zla_syamv(rng_int_t uplo, rng_int_t n, double *alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, double *beta, double *y, rng_int_t incy);
extern double RNGCDECL zla_syrcond_c(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *c, int capply, rng_int_t *info);
extern double RNGCDECL zla_syrcond_x(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info);
extern void RNGCDECL zla_syrfsx_extended(rng_int_t prec_type, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, int colequ, double *c, doublecomplex *b, rng_int_t ldb, doublecomplex *y, rng_int_t ldy, double *berr_out, rng_int_t n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double rcond, rng_int_t ithresh, double rthresh, double dz_ub, int ignore_cwise, rng_int_t *info);
extern double RNGCDECL zla_syrpvgrw(char uplo, rng_int_t n, rng_int_t *info, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv);
extern void RNGCDECL zla_wwaddw(rng_int_t n, doublecomplex *x, doublecomplex *y, doublecomplex *w);
extern double RNGCDECL zlanhf(char norm, char transr, char uplo, rng_int_t n, doublecomplex *a);
extern void RNGCDECL zlapmr(int forwrd, rng_int_t m, rng_int_t n, doublecomplex *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL zlarfgp(rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *tau);
extern void RNGCDECL zlarscl2(rng_int_t m, rng_int_t n, double *d, doublecomplex *x, rng_int_t ldx);
extern void RNGCDECL zlascl2(rng_int_t m, rng_int_t n, double *d, doublecomplex *x, rng_int_t ldx);
extern void RNGCDECL zlat2c(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, complex *sa, rng_int_t ldsa, rng_int_t *info);
extern void RNGCDECL zpbcon(char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zpbequ(char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zpbrfs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zpbstf(char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL zpbsv(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zpbsvx(char fact, char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, char equed, double *scale, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zpbtrf(char uplo, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zpbtrs(char uplo, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zpftrf(char transr, char uplo, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL zpftri(char transr, char uplo, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL zpftrs(char transr, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zpocon(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zpoequ(rng_int_t n, doublecomplex *a, rng_int_t lda, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zpoequb(rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zporfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zporfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zposv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zposvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, char equed, double *scale, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zposvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, char equed, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zpotrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zpotri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zpotrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zppcon(char uplo, rng_int_t n, doublecomplex *a, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zppequ(char uplo, rng_int_t n, doublecomplex *a, double *scale, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zpprfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zppsv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zppsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, char equed, double *scale, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zpptrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL zpptri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL zpptrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zpstf2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, double tol, rng_int_t *info);
extern void RNGCDECL zpstrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *piv, rng_int_t *rank, double tol, rng_int_t *info);
extern void RNGCDECL zptcon(rng_int_t n, double *diag, doublecomplex *offd, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zpteqr(char compz, rng_int_t n, double *d, double *e, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zptrfs(char uplo, rng_int_t n, rng_int_t nrhs, double *diag, doublecomplex *offd, double *diagf, doublecomplex *offdf, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zptsv(rng_int_t n, rng_int_t nrhs, double *diag, doublecomplex *sub, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zptsvx(char fact, rng_int_t n, rng_int_t nrhs, double *diag, doublecomplex *sub, double *diagf, doublecomplex *subf, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zpttrf(rng_int_t n, double *diag, doublecomplex *offd, rng_int_t *info);
extern void RNGCDECL zpttrs(char uplo, rng_int_t n, rng_int_t nrhs, double *diag, doublecomplex *offd, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zspcon(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zsprfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zspsv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zspsvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *af, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zsptrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsptri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsptrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zstedc(char compz, rng_int_t n, double *d, double *e, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zstegr(char jobz, char range, rng_int_t n, double *d, double *e, double vl, double vu, rng_int_t il, rng_int_t iu, double abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL zstein(rng_int_t n, double *d, double *e, rng_int_t m, double *w, rng_int_t *iblock, rng_int_t *isplit, doublecomplex *z, rng_int_t ldz, rng_int_t *ifail, rng_int_t *info);
extern void RNGCDECL zsteqr(char compz, rng_int_t n, double *d, double *e, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zsycon(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, double anorm, double *rcond, rng_int_t *info);
extern void RNGCDECL zsyconv(char uplo, char way, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsyequb(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGCDECL zsyrfs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zsyrfsx(char uplo, char equed, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zsysv(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zsysvx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL zsysvxx(char fact, char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *af, rng_int_t ldaf, rng_int_t *ipiv, char equed, double *s, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t nparams, double *params, rng_int_t *info);
extern void RNGCDECL zsyswapr(char uplo, rng_int_t n, doublecomplex *a, rng_int_t i1, rng_int_t i2);
extern void RNGCDECL zsytrf(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsytri(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsytri2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zsytri2x(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t nb, rng_int_t *info);
extern void RNGCDECL zsytrs(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zsytrs2(char uplo, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ztbcon(char norm, char uplo, char diag, rng_int_t n, rng_int_t ndiag, doublecomplex *a, rng_int_t lda, double *rcond, rng_int_t *info);
extern void RNGCDECL ztbrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL ztbtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t ndiag, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ztfsm(char transr, char side, char uplo, char trans, char diag, rng_int_t m, rng_int_t n, doublecomplex alpha, doublecomplex *a, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL ztftri(char transr, char uplo, char diag, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL ztfttp(char transr, char uplo, rng_int_t n, doublecomplex *arf, doublecomplex *ap, rng_int_t *info);
extern void RNGCDECL ztfttr(char transr, char uplo, rng_int_t n, doublecomplex *arf, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ztgevc(char side, char howmny, rng_int_t *select, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ztgexc(rng_int_t wantq, rng_int_t wantz, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *q, rng_int_t ldq, doublecomplex *z, rng_int_t ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGCDECL ztgsen(rng_int_t ijob, rng_int_t wantq, rng_int_t wantz, rng_int_t *select, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t ldq, doublecomplex *z, rng_int_t ldz, rng_int_t *m, double *pl, double *pr, double *dif, rng_int_t *info);
extern void RNGCDECL ztgsja(char jobu, char jobv, char jobq, rng_int_t m, rng_int_t p, rng_int_t n, rng_int_t k, rng_int_t l, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, double tola, double tolb, double *alpha, double *beta, doublecomplex *u, rng_int_t ldu, doublecomplex *v, rng_int_t ldv, doublecomplex *q, rng_int_t ldq, rng_int_t *ncycle, rng_int_t *info);
extern void RNGCDECL ztgsna(char job, char howmnt, rng_int_t *select, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, double *s, double *dif, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ztgsyl(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *c, rng_int_t ldc, doublecomplex *d, rng_int_t ldd, doublecomplex *e, rng_int_t lde, doublecomplex *f, rng_int_t ldf, double *scale, double *dif, rng_int_t *info);
extern void RNGCDECL ztpcon(char norm, char uplo, char diag, rng_int_t n, doublecomplex *a, double *rcond, rng_int_t *info);
extern void RNGCDECL ztpmqrt(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, rng_int_t nb, doublecomplex *v, rng_int_t ldv, doublecomplex *t, rng_int_t ldt, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ztpqrt(rng_int_t m, rng_int_t n, rng_int_t l, rng_int_t nb, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL ztpqrt2(rng_int_t m, rng_int_t n, rng_int_t l, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *t, rng_int_t ldt, rng_int_t *info);
extern void RNGCDECL ztprfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, doublecomplex *v, rng_int_t ldv, doublecomplex *t, rng_int_t ldt, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL ztprfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL ztptri(char uplo, char diag, rng_int_t n, doublecomplex *a, rng_int_t *info);
extern void RNGCDECL ztptrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, doublecomplex *a, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ztpttf(char transr, char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *arf, rng_int_t *info);
extern void RNGCDECL ztpttr(char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ztrcon(char norm, char uplo, char diag, rng_int_t n, doublecomplex *a, rng_int_t lda, double *rcond, rng_int_t *info);
extern void RNGCDECL ztrevc(char side, char howmny, rng_int_t *select, rng_int_t n, doublecomplex *t, rng_int_t ldt, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ztrexc(char compq, rng_int_t n, doublecomplex *t, rng_int_t ldt, doublecomplex *q, rng_int_t ldq, rng_int_t ifst, rng_int_t ilst, rng_int_t *info);
extern void RNGCDECL ztrrfs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *x, rng_int_t ldx, double *ferr, double *berr, rng_int_t *info);
extern void RNGCDECL ztrsen(char job, char compq, rng_int_t *select, rng_int_t n, doublecomplex *t, rng_int_t ldt, doublecomplex *q, rng_int_t ldq, doublecomplex *w, rng_int_t *m, double *s, double *sep, rng_int_t *info);
extern void RNGCDECL ztrsna(char job, char howmny, rng_int_t *select, rng_int_t n, doublecomplex *t, rng_int_t ldt, doublecomplex *vl, rng_int_t ldvl, doublecomplex *vr, rng_int_t ldvr, double *s, double *sep, rng_int_t mm, rng_int_t *m, rng_int_t *info);
extern void RNGCDECL ztrsyl(char trana, char tranb, rng_int_t isgn, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *c, rng_int_t ldc, double *scale, rng_int_t *info);
extern void RNGCDECL ztrtri(char uplo, char diag, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL ztrtrs(char uplo, char transa, char diag, rng_int_t n, rng_int_t nrhs, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ztrttf(char transr, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *arf, rng_int_t *info);
extern void RNGCDECL ztrttp(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *ap, rng_int_t *info);
extern void RNGCDECL ztzrqf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL ztzrzf(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zunbdb(char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, doublecomplex *x11, rng_int_t ldx11, doublecomplex *x12, rng_int_t ldx12, doublecomplex *x21, rng_int_t ldx21, doublecomplex *x22, rng_int_t ldx22, double *theta, double *phi, doublecomplex *taup1, doublecomplex *taup2, doublecomplex *tauq1, doublecomplex *tauq2, rng_int_t *info);
extern void RNGCDECL zuncsd(char jobu1, char jobu2, char jobv1t, char jobv2t, char trans, char signs, rng_int_t m, rng_int_t p, rng_int_t q, doublecomplex *x11, rng_int_t ldx11, doublecomplex *x12, rng_int_t ldx12, doublecomplex *x21, rng_int_t ldx21, doublecomplex *x22, rng_int_t ldx22, double *theta, doublecomplex *u1, rng_int_t ldu1, doublecomplex *u2, rng_int_t ldu2, doublecomplex *v1t, rng_int_t ldv1t, doublecomplex *v2t, rng_int_t ldv2t, rng_int_t *info);
extern void RNGCDECL zungbr(char vect, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zunghr(rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zunglq(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungql(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungqr(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungrq(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungtr(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zunmbr(char vect, char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmhr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmlq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmql(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmqr(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmrq(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmrz(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zupgtr(char uplo, rng_int_t n, doublecomplex *ap, doublecomplex *tau, doublecomplex *q, rng_int_t ldq, rng_int_t *info);
extern void RNGCDECL zupmtr(char side, char uplo, char trans, rng_int_t m, rng_int_t n, doublecomplex *ap, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);

/* LAPACK auxiliary C interfaces */
extern void RNGCDECL cgbtf2(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgebd2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *d, float *e, complex *tauq, complex *taup, rng_int_t *info);
extern void RNGCDECL cgehd2(rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgelq2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeql2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgeqr2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgerq2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cgesc2(rng_int_t n, complex *a, rng_int_t lda, complex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGCDECL cgetc2(rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGCDECL cgetf2(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL cgtts2(rng_int_t itrans, rng_int_t n, rng_int_t nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t ldb);
extern void RNGCDECL chegs2(rng_int_t itype, char uplo, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL chetd2(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *d, float *e, complex *tau, rng_int_t *info);
extern void RNGCDECL chetf2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL clabrd(rng_int_t m, rng_int_t n, rng_int_t nb, complex *a, rng_int_t lda, float *d, float *e, complex *tauq, complex *taup, complex *x, rng_int_t ldx, complex *y, rng_int_t ldy);
extern void RNGCDECL clacgv(rng_int_t n, complex *x, rng_int_t incx);
extern void RNGCDECL clacn2(rng_int_t n, complex *v, complex *x, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGCDECL clacon(rng_int_t n, complex *v, complex *x, float *est, rng_int_t *kase);
extern void RNGCDECL clacp2(char uplo, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, complex *b, rng_int_t ldb);
extern void RNGCDECL clacpy(char uplo, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb);
extern void RNGCDECL clacrm(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *b, rng_int_t ldb, complex *c, rng_int_t ldc);
extern void RNGCDECL clacrt(rng_int_t n, complex *cx, rng_int_t incx, complex *cy, rng_int_t incy, complex c, complex s);
extern complex RNGCDECL cladiv(complex x, complex y);
extern void RNGCDECL claed0(rng_int_t qsiz, rng_int_t n, float *d, float *e, complex *q, rng_int_t ldq, complex *qstore, rng_int_t ldqs, rng_int_t *info);
extern void RNGCDECL claed7(rng_int_t n, rng_int_t cutpnt, rng_int_t qsiz, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, float *d, complex *q, rng_int_t ldq, float rho, rng_int_t *indxq, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void RNGCDECL claed8(rng_int_t *k, rng_int_t n, rng_int_t qsiz, complex *q, rng_int_t ldq, float *d, float *rho, rng_int_t cutpnt, float *z, float *dlamda, complex *q2, rng_int_t ldq2, float *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void RNGCDECL claein(rng_int_t rightv, rng_int_t noinit, rng_int_t n, complex *h, rng_int_t ldh, complex w, complex *v, complex *b, rng_int_t ldb, float eps3, float smlnum, rng_int_t *info);
extern void RNGCDECL claesy(complex a, complex b, complex c, complex *rt1, complex *rt2, complex *evscal, complex *cs1, complex *sn1);
extern void RNGCDECL claev2(complex a, complex b, complex c, float *rt1, float *rt2, float *cs1, complex *sn1);
extern void RNGCDECL clag2z(rng_int_t m, rng_int_t n, complex *sa, rng_int_t ldsa, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL clags2(rng_int_t upper, float a1, complex a2, float a3, float b1, complex b2, float b3, float *csu, complex *snu, float *csv, complex *snv, float *csq, complex *snq);
extern void RNGCDECL clagtm(char trans, rng_int_t n, rng_int_t nrhs, float alpha, complex *dl, complex *d, complex *du, complex *x, rng_int_t ldx, float beta, complex *b, rng_int_t ldb);
extern void RNGCDECL clahef(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL clahqr(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *h, rng_int_t ldh, complex *w, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL clahr2(rng_int_t n, rng_int_t k, rng_int_t nb, complex *a, rng_int_t lda, complex *tau, complex *t, rng_int_t ldt, complex *y, rng_int_t ldy);
extern void RNGCDECL clahrd(rng_int_t n, rng_int_t k, rng_int_t nb, complex *a, rng_int_t lda, complex *tau, complex *t, rng_int_t ldt, complex *y, rng_int_t ldy);
extern void RNGCDECL claic1(rng_int_t job, rng_int_t j, complex *x, float sest, complex *w, complex gamma, float *sestpr, complex *s, complex *c);
extern void RNGCDECL clals0(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t nrhs, complex *b, rng_int_t ldb, complex *bx, rng_int_t ldbx, rng_int_t *perm, rng_int_t givptr, rng_int_t *givcol, rng_int_t ldgcol, float *givnum, rng_int_t ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t k, float c, float s, rng_int_t *info);
extern void RNGCDECL clalsa(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, complex *b, rng_int_t ldb, complex *bx, rng_int_t ldbx, float *u, rng_int_t ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, rng_int_t *info);
extern void RNGCDECL clalsd(char uplo, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, float *d, float *e, complex *b, rng_int_t ldb, float rcond, rng_int_t *rank, rng_int_t *info);
extern float RNGCDECL clangb(char norm, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab);
extern float RNGCDECL clange(char norm, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda);
extern float RNGCDECL clangt(char norm, rng_int_t n, complex *dl, complex *d, complex *du);
extern float RNGCDECL clanhb(char norm, char uplo, rng_int_t n, rng_int_t k, complex *ab, rng_int_t ldab);
extern float RNGCDECL clanhe(char norm, char uplo, rng_int_t n, complex *a, rng_int_t lda);
extern float RNGCDECL clanhp(char norm, char uplo, rng_int_t n, complex *ap);
extern float RNGCDECL clanhs(char norm, rng_int_t n, complex *a, rng_int_t lda);
extern float RNGCDECL clanht(char norm, rng_int_t n, float *d, complex *e);
extern float RNGCDECL clansb(char norm, char uplo, rng_int_t n, rng_int_t k, complex *ab, rng_int_t ldab);
extern float RNGCDECL clansp(char norm, char uplo, rng_int_t n, complex *ap);
extern float RNGCDECL clansy(char norm, char uplo, rng_int_t n, complex *a, rng_int_t lda);
extern float RNGCDECL clantb(char norm, char uplo, char diag, rng_int_t n, rng_int_t k, complex *ab, rng_int_t ldab);
extern float RNGCDECL clantp(char norm, char uplo, char diag, rng_int_t n, complex *ap);
extern float RNGCDECL clantr(char norm, char uplo, char diag, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda);
extern void RNGCDECL clapll(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy, float *ssmin);
extern void RNGCDECL clapmt(rng_int_t forwrd, rng_int_t m, rng_int_t n, complex *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL claqgb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, complex *ab, rng_int_t ldab, float *r, float *c, float rowcnd, float colcnd, float amax, char *equed);
extern void RNGCDECL claqge(rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, float *r, float *c, float rowcnd, float colcnd, float amax, char *equed);
extern void RNGCDECL claqhb(char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, float *s, float scond, float amax, char *equed);
extern void RNGCDECL claqhe(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *s, float scond, float amax, char *equed);
extern void RNGCDECL claqhp(char uplo, rng_int_t n, complex *ap, float *s, float scond, float amax, char *equed);
extern void RNGCDECL claqp2(rng_int_t m, rng_int_t n, rng_int_t offset, complex *a, rng_int_t lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2);
extern void RNGCDECL claqps(rng_int_t m, rng_int_t n, rng_int_t offset, rng_int_t nb, rng_int_t *kb, complex *a, rng_int_t lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *auxv, complex *f, rng_int_t ldf);
extern void RNGCDECL claqr0(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *h, rng_int_t ldh, complex *w, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL claqr1(rng_int_t n, complex *h, rng_int_t ldh, complex s1, complex s2, complex *v);
extern void RNGCDECL claqr2(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, complex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t ldv, rng_int_t nh, complex *t, rng_int_t ldt, rng_int_t nv, complex *wv, rng_int_t ldwv);
extern void RNGCDECL claqr3(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, complex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t ldv, rng_int_t nh, complex *t, rng_int_t ldt, rng_int_t nv, complex *wv, rng_int_t ldwv);
extern void RNGCDECL claqr4(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, complex *h, rng_int_t ldh, complex *w, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL claqr5(rng_int_t wantt, rng_int_t wantz, rng_int_t kacc22, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nshfts, complex *s, complex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, complex *z, rng_int_t ldz, complex *v, rng_int_t ldv, complex *u, rng_int_t ldu, rng_int_t nv, complex *wv, rng_int_t ldwv, rng_int_t nh, complex *wh, rng_int_t ldwh);
extern void RNGCDECL claqsb(char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, float *s, float scond, float amax, char *equed);
extern void RNGCDECL claqsp(char uplo, rng_int_t n, complex *ap, float *s, float scond, float amax, char *equed);
extern void RNGCDECL claqsy(char uplo, rng_int_t n, complex *a, rng_int_t lda, float *s, float scond, float amax, char *equed);
extern void RNGCDECL clar1v(rng_int_t n, rng_int_t b1, rng_int_t bn, float lambda, float *d, float *l, float *ld, float *lld, float pivmin, float gaptol, complex *z, rng_int_t wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr);
extern void RNGCDECL clar2v(rng_int_t n, complex *x, complex *y, complex *z, rng_int_t incx, float *c, complex *s, rng_int_t incc);
extern void RNGCDECL clarcm(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *c, rng_int_t ldc);
extern void RNGCDECL clarfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, complex *v, rng_int_t ldv, complex *t, rng_int_t ldt, complex *c, rng_int_t ldc);
extern void RNGCDECL clarf(char side, rng_int_t m, rng_int_t n, complex *v, rng_int_t incv, complex tau, complex *c, rng_int_t ldc);
extern void RNGCDECL clarfg(rng_int_t n, complex *alpha, complex *x, rng_int_t incx, complex *tau);
extern void RNGCDECL clarft(char direct, char storev, rng_int_t n, rng_int_t k, complex *v, rng_int_t ldv, complex *tau, complex *t, rng_int_t ldt);
extern void RNGCDECL clarfx(char side, rng_int_t m, rng_int_t n, complex *v, complex tau, complex *c, rng_int_t ldc);
extern void RNGCDECL clargv(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy, float *c, rng_int_t incc);
extern void RNGCDECL clarnv(rng_int_t idist, rng_int_t *iseed, rng_int_t n, complex *x);
extern void RNGCDECL clarrv(rng_int_t n, float vl, float vu, float *d, float *l, float pivmin, rng_int_t *isplit, rng_int_t m, rng_int_t dol, rng_int_t dou, float minrgp, float rtol1, float rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, complex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL clartg(complex f, complex g, float *cs, complex *sn, complex *r);
extern void RNGCDECL clartv(rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy, float *c, complex *s, rng_int_t incc);
extern void RNGCDECL clarzb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, complex *v, rng_int_t ldv, complex *t, rng_int_t ldt, complex *c, rng_int_t ldc);
extern void RNGCDECL clarz(char side, rng_int_t m, rng_int_t n, rng_int_t l, complex *v, rng_int_t incv, complex tau, complex *c, rng_int_t ldc);
extern void RNGCDECL clarzt(char direct, char storev, rng_int_t n, rng_int_t k, complex *v, rng_int_t ldv, complex *tau, complex *t, rng_int_t ldt);
extern void RNGCDECL clascl(char type, rng_int_t kl, rng_int_t ku, float cfrom, float cto, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL claset(char uplo, rng_int_t m, rng_int_t n, complex alpha, complex beta, complex *a, rng_int_t lda);
extern void RNGCDECL clasr(char side, char pivot, char direct, rng_int_t m, rng_int_t n, float *c, float *s, complex *a, rng_int_t lda);
extern void RNGCDECL claswp(rng_int_t n, complex *a, rng_int_t lda, rng_int_t k1, rng_int_t k2, rng_int_t *ipiv, rng_int_t incx);
extern void RNGCDECL clasyf(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, complex *a, rng_int_t lda, rng_int_t *ipiv, complex *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL clatbs(char uplo, char trans, char diag, char normin, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL clatdf(rng_int_t ijob, rng_int_t n, complex *z, rng_int_t ldz, complex *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGCDECL clatps(char uplo, char trans, char diag, char normin, rng_int_t n, complex *ap, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL clatrd(char uplo, rng_int_t n, rng_int_t nb, complex *a, rng_int_t lda, float *e, complex *tau, complex *w, rng_int_t ldw);
extern void RNGCDECL clatrs(char uplo, char trans, char diag, char normin, rng_int_t n, complex *a, rng_int_t lda, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL clatrz(rng_int_t m, rng_int_t n, rng_int_t l, complex *a, rng_int_t lda, complex *tau);
extern void RNGCDECL clatzm(char side, rng_int_t m, rng_int_t n, complex *v, rng_int_t incv, complex tau, complex *c1, complex *c2, rng_int_t ldc);
extern void RNGCDECL clauu2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL clauum(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cpbtf2(char uplo, rng_int_t n, rng_int_t kd, complex *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL cpotf2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cptts2(rng_int_t iuplo, rng_int_t n, rng_int_t nrhs, float *d, complex *e, complex *b, rng_int_t ldb);
extern void RNGCDECL crot(rng_int_t n, complex *cx, rng_int_t incx, complex *cy, rng_int_t incy, float c, complex s);
extern void RNGCDECL cspmv(char uplo, rng_int_t n, complex alpha, complex *ap, complex *x, rng_int_t incx, complex beta, complex *y, rng_int_t incy);
extern void RNGCDECL cspr(char uplo, rng_int_t n, complex alpha, complex *x, rng_int_t incx, complex *ap);
extern void RNGCDECL csrscl(rng_int_t n, float sa, complex *sx, rng_int_t incx);
extern void RNGCDECL csymv(char uplo, rng_int_t n, complex alpha, complex *a, rng_int_t lda, complex *x, rng_int_t incx, complex beta, complex *y, rng_int_t incy);
extern void RNGCDECL csyr(char uplo, rng_int_t n, complex alpha, complex *x, rng_int_t incx, complex *a, rng_int_t lda);
extern void RNGCDECL csytf2(char uplo, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ctgex2(rng_int_t wantq, rng_int_t wantz, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *q, rng_int_t ldq, complex *z, rng_int_t ldz, rng_int_t j1, rng_int_t *info);
extern void RNGCDECL ctgsy2(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, complex *a, rng_int_t lda, complex *b, rng_int_t ldb, complex *c, rng_int_t ldc, complex *d, rng_int_t ldd, complex *e, rng_int_t lde, complex *f, rng_int_t ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *info);
extern void RNGCDECL ctrti2(char uplo, char diag, rng_int_t n, complex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL cung2l(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cung2r(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungl2(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cungr2(rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, rng_int_t *info);
extern void RNGCDECL cunm2l(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunm2r(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunml2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmr2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL cunmr3(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, complex *a, rng_int_t lda, complex *tau, complex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dgbtf2(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgebd2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *d, double *e, double *tauq, double *taup, rng_int_t *info);
extern void RNGCDECL dgehd2(rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgelq2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeql2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgeqr2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgerq2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dgesc2(rng_int_t n, double *a, rng_int_t lda, double *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGCDECL dgetc2(rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGCDECL dgetf2(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dgtts2(rng_int_t itrans, rng_int_t n, rng_int_t nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t ldb);
extern void RNGCDECL dlabad(double *small, double *large);
extern void RNGCDECL dlabrd(rng_int_t m, rng_int_t n, rng_int_t nb, double *a, rng_int_t lda, double *d, double *e, double *tauq, double *taup, double *x, rng_int_t ldx, double *y, rng_int_t ldy);
extern void RNGCDECL dlacn2(rng_int_t n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGCDECL dlacon(rng_int_t n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase);
extern void RNGCDECL dlacpy(char uplo, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb);
extern void RNGCDECL dladiv(double a, double b, double c, double d, double *p, double *q);
extern void RNGCDECL dlae2(double a, double b, double c, double *rt1, double *rt2);
extern void RNGCDECL dlaebz(rng_int_t ijob, rng_int_t nitmax, rng_int_t n, rng_int_t mmax, rng_int_t minp, rng_int_t nbmin, double abstol, double reltol, double pivmin, double *d, double *e, double *e2, rng_int_t *nval, double *ab, double *c, rng_int_t *mout, rng_int_t *nab, rng_int_t *info);
extern void RNGCDECL dlaed0(rng_int_t icompq, rng_int_t qsiz, rng_int_t n, double *d, double *e, double *q, rng_int_t ldq, double *qstore, rng_int_t ldqs, rng_int_t *info);
extern void RNGCDECL dlaed1(rng_int_t n, double *d, double *q, rng_int_t ldq, rng_int_t *indxq, double rho, rng_int_t cutpnt, rng_int_t *info);
extern void RNGCDECL dlaed2(rng_int_t *k, rng_int_t n, rng_int_t n1, double *d, double *q, rng_int_t ldq, rng_int_t *indxq, double *rho, double *z, double *dlamda, double *w, double *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGCDECL dlaed3(rng_int_t k, rng_int_t n, rng_int_t n1, double *d, double *q, rng_int_t ldq, double rho, double *dlamda, double *q2, rng_int_t *indx, rng_int_t *ctot, double *w, double *s, rng_int_t *info);
extern void RNGCDECL dlaed4(rng_int_t n, rng_int_t i, double *d, double *z, double *delta, double rho, double *dlam, rng_int_t *info);
extern void RNGCDECL dlaed5(rng_int_t i, double *d, double *z, double *delta, double rho, double *dlam);
extern void RNGCDECL dlaed6(rng_int_t kniter, rng_int_t orgati, double rho, double *d, double *z, double finit, double *tau, rng_int_t *info);
extern void RNGCDECL dlaed7(rng_int_t icompq, rng_int_t n, rng_int_t qsiz, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, double *d, double *q, rng_int_t ldq, rng_int_t *indxq, double rho, rng_int_t cutpnt, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void RNGCDECL dlaed8(rng_int_t icompq, rng_int_t *k, rng_int_t n, rng_int_t qsiz, double *d, double *q, rng_int_t ldq, rng_int_t *indxq, double *rho, rng_int_t cutpnt, double *z, double *dlamda, double *q2, rng_int_t ldq2, double *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGCDECL dlaed9(rng_int_t k, rng_int_t kstart, rng_int_t kstop, rng_int_t n, double *d, double *q, rng_int_t ldq, double rho, double *dlamda, double *w, double *s, rng_int_t lds, rng_int_t *info);
extern void RNGCDECL dlaeda(rng_int_t n, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *q, rng_int_t *qptr, double *z, double *ztemp, rng_int_t *info);
extern void RNGCDECL dlaein(rng_int_t rightv, rng_int_t noinit, rng_int_t n, double *h, rng_int_t ldh, double wr, double wi, double *vr, double *vi, double *b, rng_int_t ldb, double eps3, double smlnum, double bignum, rng_int_t *info);
extern void RNGCDECL dlaev2(double a, double b, double c, double *rt1, double *rt2, double *cs1, double *sn1);
extern void RNGCDECL dlaexc(rng_int_t wantq, rng_int_t n, double *t, rng_int_t ldt, double *q, rng_int_t ldq, rng_int_t j1, rng_int_t n1, rng_int_t n2, rng_int_t *info);
extern void RNGCDECL dlag2(double *a, rng_int_t lda, double *b, rng_int_t ldb, double safmin, double *scale1, double *scale2, double *wr1, double *wr2, double *wi);
extern void RNGCDECL dlag2s(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, float *sa, rng_int_t ldsa, rng_int_t *info);
extern void RNGCDECL dlags2(rng_int_t upper, double a1, double a2, double a3, double b1, double b2, double b3, double *csu, double *snu, double *csv, double *snv, double *csq, double *snq);
extern void RNGCDECL dlagtf(rng_int_t n, double *a, double lambda, double *b, double *c, double tol, double *d, rng_int_t *in, rng_int_t *info);
extern void RNGCDECL dlagtm(char trans, rng_int_t n, rng_int_t nrhs, double alpha, double *dl, double *d, double *du, double *x, rng_int_t ldx, double beta, double *b, rng_int_t ldb);
extern void RNGCDECL dlagts(rng_int_t job, rng_int_t n, double *a, double *b, double *c, double *d, rng_int_t *in, double *y, double *tol, rng_int_t *info);
extern void RNGCDECL dlagv2(double *a, rng_int_t lda, double *b, rng_int_t ldb, double *alphar, double *alphai, double *beta, double *csl, double *snl, double *csr, double *snr);
extern void RNGCDECL dlahqr(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *h, rng_int_t ldh, double *wr, double *wi, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dlahr2(rng_int_t n, rng_int_t k, rng_int_t nb, double *a, rng_int_t lda, double *tau, double *t, rng_int_t ldt, double *y, rng_int_t ldy);
extern void RNGCDECL dlahrd(rng_int_t n, rng_int_t k, rng_int_t nb, double *a, rng_int_t lda, double *tau, double *t, rng_int_t ldt, double *y, rng_int_t ldy);
extern void RNGCDECL dlaic1(rng_int_t job, rng_int_t j, double *x, double sest, double *w, double gamma, double *sestpr, double *s, double *c);
extern rng_int_t RNGCDECL dlaisnan(double din1, double din2);
extern void RNGCDECL dlaln2(rng_int_t ltrans, rng_int_t na, rng_int_t nw, double smin, double ca, double *a, rng_int_t lda, double d1, double d2, double *b, rng_int_t ldb, double wr, double wi, double *x, rng_int_t ldx, double *scale, double *xnorm, rng_int_t *info);
extern void RNGCDECL dlals0(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t nrhs, double *b, rng_int_t ldb, double *bx, rng_int_t ldbx, rng_int_t *perm, rng_int_t givptr, rng_int_t *givcol, rng_int_t ldgcol, double *givnum, rng_int_t ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t k, double c, double s, rng_int_t *info);
extern void RNGCDECL dlalsa(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, double *b, rng_int_t ldb, double *bx, rng_int_t ldbx, double *u, rng_int_t ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, rng_int_t *info);
extern void RNGCDECL dlalsd(char uplo, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, double *d, double *e, double *b, rng_int_t ldb, double rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL dlamrg(rng_int_t n1, rng_int_t n2, double *a, rng_int_t dtrd1, rng_int_t dtrd2, rng_int_t *index);
extern rng_int_t RNGCDECL dlaneg(rng_int_t n, double *d, double *lld, double sigma, double pivmin, rng_int_t r);
extern double RNGCDECL dlangb(char norm, rng_int_t n, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab);
extern double RNGCDECL dlange(char norm, rng_int_t m, rng_int_t n, double *a, rng_int_t lda);
extern double RNGCDECL dlangt(char norm, rng_int_t n, double *dl, double *d, double *du);
extern double RNGCDECL dlanhs(char norm, rng_int_t n, double *a, rng_int_t lda);
extern double RNGCDECL dlansb(char norm, char uplo, rng_int_t n, rng_int_t k, double *ab, rng_int_t ldab);
extern double RNGCDECL dlansp(char norm, char uplo, rng_int_t n, double *ap);
extern double RNGCDECL dlanst(char norm, rng_int_t n, double *d, double *e);
extern double RNGCDECL dlansy(char norm, char uplo, rng_int_t n, double *a, rng_int_t lda);
extern double RNGCDECL dlantb(char norm, char uplo, char diag, rng_int_t n, rng_int_t k, double *ab, rng_int_t ldab);
extern double RNGCDECL dlantp(char norm, char uplo, char diag, rng_int_t n, double *ap);
extern double RNGCDECL dlantr(char norm, char uplo, char diag, rng_int_t m, rng_int_t n, double *a, rng_int_t lda);
extern void RNGCDECL dlanv2(double *a, double *b, double *c, double *d, double *rt1r, double *rt1i, double *rt2r, double *rt2i, double *cs, double *sn);
extern void RNGCDECL dlapll(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy, double *ssmin);
extern void RNGCDECL dlapmt(rng_int_t forwrd, rng_int_t m, rng_int_t n, double *x, rng_int_t ldx, rng_int_t *k);
extern double RNGCDECL dlapy2(double x, double y);
extern double RNGCDECL dlapy3(double x, double y, double z);
extern void RNGCDECL dlaqgb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, double *ab, rng_int_t ldab, double *r, double *c, double rowcnd, double colcnd, double amax, char *equed);
extern void RNGCDECL dlaqge(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *r, double *c, double rowcnd, double colcnd, double amax, char *equed);
extern void RNGCDECL dlaqp2(rng_int_t m, rng_int_t n, rng_int_t offset, double *a, rng_int_t lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2);
extern void RNGCDECL dlaqps(rng_int_t m, rng_int_t n, rng_int_t offset, rng_int_t nb, rng_int_t *kb, double *a, rng_int_t lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *auxv, double *f, rng_int_t ldf);
extern void RNGCDECL dlaqr0(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *h, rng_int_t ldh, double *wr, double *wi, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dlaqr1(rng_int_t n, double *h, rng_int_t ldh, double sr1, double si1, double sr2, double si2, double *v);
extern void RNGCDECL dlaqr2(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, double *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double *v, rng_int_t ldv, rng_int_t nh, double *t, rng_int_t ldt, rng_int_t nv, double *wv, rng_int_t ldwv);
extern void RNGCDECL dlaqr3(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, double *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double *v, rng_int_t ldv, rng_int_t nh, double *t, rng_int_t ldt, rng_int_t nv, double *wv, rng_int_t ldwv);
extern void RNGCDECL dlaqr4(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, double *h, rng_int_t ldh, double *wr, double *wi, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL dlaqr5(rng_int_t wantt, rng_int_t wantz, rng_int_t kacc22, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nshfts, double *sr, double *si, double *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, double *z, rng_int_t ldz, double *v, rng_int_t ldv, double *u, rng_int_t ldu, rng_int_t nv, double *wv, rng_int_t ldwv, rng_int_t nh, double *wh, rng_int_t ldwh);
extern void RNGCDECL dlaqsb(char uplo, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, double *s, double scond, double amax, char *equed);
extern void RNGCDECL dlaqsp(char uplo, rng_int_t n, double *ap, double *s, double scond, double amax, char *equed);
extern void RNGCDECL dlaqsy(char uplo, rng_int_t n, double *a, rng_int_t lda, double *s, double scond, double amax, char *equed);
extern void RNGCDECL dlaqtr(rng_int_t ltran, rng_int_t lreal, rng_int_t n, double *t, rng_int_t ldt, double *b, double w, double *scale, double *x, rng_int_t *info);
extern void RNGCDECL dlar1v(rng_int_t n, rng_int_t b1, rng_int_t bn, double lambda, double *d, double *l, double *ld, double *lld, double pivmin, double gaptol, double *z, rng_int_t wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr);
extern void RNGCDECL dlar2v(rng_int_t n, double *x, double *y, double *z, rng_int_t incx, double *c, double *s, rng_int_t incc);
extern void RNGCDECL dlarfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, double *v, rng_int_t ldv, double *t, rng_int_t ldt, double *c, rng_int_t ldc);
extern void RNGCDECL dlarf(char side, rng_int_t m, rng_int_t n, double *v, rng_int_t incv, double tau, double *c, rng_int_t ldc);
extern void RNGCDECL dlarfg(rng_int_t n, double *alpha, double *x, rng_int_t incx, double *tau);
extern void RNGCDECL dlarfx(char side, rng_int_t m, rng_int_t n, double *v, double tau, double *c, rng_int_t ldc);
extern void RNGCDECL dlargv(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy, double *c, rng_int_t incc);
extern void RNGCDECL dlarnv(rng_int_t idist, rng_int_t *iseed, rng_int_t n, double *x);
extern void RNGCDECL dlarra(rng_int_t n, double *d, double *e, double *e2, double spltol, double tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGCDECL dlarrb(rng_int_t n, double *d, double *lld, rng_int_t ifirst, rng_int_t ilast, double rtol1, double rtol2, rng_int_t offset, double *w, double *wgap, double *werr, double pivmin, double spdiam, rng_int_t twist, rng_int_t *info);
extern void RNGCDECL dlarrc(char jobt, rng_int_t n, double vl, double vu, double *d, double *e, double pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info);
extern void RNGCDECL dlarrd(char range, char order, rng_int_t n, double vl, double vu, rng_int_t il, rng_int_t iu, double *gers, double reltol, double *d, double *e, double *e2, double pivmin, rng_int_t nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wl, double *wu, rng_int_t *iblock, rng_int_t *indexw, rng_int_t *info);
extern void RNGCDECL dlarre(char range, rng_int_t n, double *vl, double *vu, rng_int_t il, rng_int_t iu, double *d, double *e, double *e2, double rtol1, double rtol2, double spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *pivmin, rng_int_t *info);
extern void RNGCDECL dlarrf(rng_int_t n, double *d, double *l, double *ld, rng_int_t clstrt, rng_int_t clend, double *w, double *wgap, double *werr, double spdiam, double clgapl, double clgapr, double pivmin, double *sigma, double *dplus, double *lplus, rng_int_t *info);
extern void RNGCDECL dlarrj(rng_int_t n, double *d, double *e2, rng_int_t ifirst, rng_int_t ilast, double rtol, rng_int_t offset, double *w, double *werr, double pivmin, double spdiam, rng_int_t *info);
extern void RNGCDECL dlarrk(rng_int_t n, rng_int_t iw, double gl, double gu, double *d, double *e2, double pivmin, double reltol, double *w, double *werr, rng_int_t *info);
extern void RNGCDECL dlarrr(rng_int_t n, double *d, double *e, rng_int_t *info);
extern void RNGCDECL dlarrv(rng_int_t n, double vl, double vu, double *d, double *l, double pivmin, rng_int_t *isplit, rng_int_t m, rng_int_t dol, rng_int_t dou, double minrgp, double rtol1, double rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL dlartg(double f, double g, double *cs, double *sn, double *r);
extern void RNGCDECL dlartv(rng_int_t n, double *x, rng_int_t incx, double *y, rng_int_t incy, double *c, double *s, rng_int_t incc);
extern void RNGCDECL dlaruv(rng_int_t *iseed, rng_int_t n, double *x);
extern void RNGCDECL dlarzb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, double *v, rng_int_t ldv, double *t, rng_int_t ldt, double *c, rng_int_t ldc);
extern void RNGCDECL dlarz(char side, rng_int_t m, rng_int_t n, rng_int_t l, double *v, rng_int_t incv, double tau, double *c, rng_int_t ldc);
extern void RNGCDECL dlarzt(char direct, char storev, rng_int_t n, rng_int_t k, double *v, rng_int_t ldv, double *tau, double *t, rng_int_t ldt);
extern void RNGCDECL dlas2(double f, double g, double h, double *ssmin, double *ssmax);
extern void RNGCDECL dlascl(char type, rng_int_t kl, rng_int_t ku, double cfrom, double cto, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dlasd0(rng_int_t n, rng_int_t sqre, double *d, double *e, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, rng_int_t smlsiz, rng_int_t *info);
extern void RNGCDECL dlasd1(rng_int_t nl, rng_int_t nr, rng_int_t sqre, double *d, double *alpha, double *beta, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, rng_int_t *idxq, rng_int_t *info);
extern void RNGCDECL dlasd2(rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t *k, double *d, double *z, double alpha, double beta, double *u, rng_int_t ldu, double *vt, rng_int_t ldvt, double *dsigma, double *u2, rng_int_t ldu2, double *vt2, rng_int_t ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGCDECL dlasd3(rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t k, double *d, double *q, rng_int_t ldq, double *dsigma, double *u, rng_int_t ldu, double *u2, rng_int_t ldu2, double *vt, rng_int_t ldvt, double *vt2, rng_int_t ldvt2, rng_int_t *idxc, rng_int_t *ctot, double *z, rng_int_t *info);
extern void RNGCDECL dlasd4(rng_int_t n, rng_int_t i, double *d, double *z, double *delta, double rho, double *sigma, rng_int_t *info);
extern void RNGCDECL dlasd5(rng_int_t i, double *d, double *z, double *delta, double rho, double *dsigma);
extern void RNGCDECL dlasd6(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, double *d, double *vf, double *vl, double *alpha, double *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, double *givnum, rng_int_t ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, rng_int_t *info);
extern void RNGCDECL dlasd7(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t *k, double *d, double *z, double *zw, double *vf, double *vfw, double *vl, double *vlw, double alpha, double beta, double *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, double *givnum, rng_int_t ldgnum, double *c, double *s, rng_int_t *info);
extern void RNGCDECL dlasd8(rng_int_t icompq, rng_int_t k, double *d, double *z, double *vf, double *vl, double *difl, double *difr, rng_int_t lddifr, double *dsigma, rng_int_t *info);
extern void RNGCDECL dlasda(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t sqre, double *d, double *e, double *u, rng_int_t ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, rng_int_t *info);
extern void RNGCDECL dlasdq(char uplo, rng_int_t sqre, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, double *d, double *e, double *vt, rng_int_t ldvt, double *u, rng_int_t ldu, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dlasdt(rng_int_t n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t msub);
extern void RNGCDECL dlaset(char uplo, rng_int_t m, rng_int_t n, double alpha, double beta, double *a, rng_int_t lda);
extern void RNGCDECL dlasq1(rng_int_t n, double *d, double *e, rng_int_t *info);
extern void RNGCDECL dlasq2(rng_int_t n, double *z, rng_int_t *info);
extern void RNGCDECL dlasq3(rng_int_t i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *sigma, double *desig, double qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t ieee, rng_int_t *ttype, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *g, double *tau);
extern void RNGCDECL dlasq4(rng_int_t i0, rng_int_t n0, double *z, rng_int_t pp, rng_int_t n0in, double dmin, double dmin1, double dmin2, double dn, double dn1, double dn2, double *tau, rng_int_t *ttype, double *g);
extern void RNGCDECL dlasq5(rng_int_t i0, rng_int_t n0, double *z, rng_int_t pp, double tau, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2, rng_int_t ieee);
extern void RNGCDECL dlasq6(rng_int_t i0, rng_int_t n0, double *z, rng_int_t pp, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2);
extern void RNGCDECL dlasr(char side, char pivot, char direct, rng_int_t m, rng_int_t n, double *c, double *s, double *a, rng_int_t lda);
extern void RNGCDECL dlasv2(double f, double g, double h, double *ssmin, double *ssmax, double *snr, double *csr, double *snl, double *csl);
extern void RNGCDECL dlaswp(rng_int_t n, double *a, rng_int_t lda, rng_int_t k1, rng_int_t k2, rng_int_t *ipiv, rng_int_t incx);
extern void RNGCDECL dlasy2(rng_int_t ltranl, rng_int_t ltranr, rng_int_t isgn, rng_int_t n1, rng_int_t n2, double *tl, rng_int_t ldtl, double *tr, rng_int_t ldtr, double *b, rng_int_t ldb, double *scale, double *x, rng_int_t ldx, double *xnorm, rng_int_t *info);
extern void RNGCDECL dlasyf(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, double *a, rng_int_t lda, rng_int_t *ipiv, double *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL dlatbs(char uplo, char trans, char diag, char normin, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL dlatdf(rng_int_t ijob, rng_int_t n, double *z, rng_int_t ldz, double *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGCDECL dlatps(char uplo, char trans, char diag, char normin, rng_int_t n, double *ap, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL dlatrd(char uplo, rng_int_t n, rng_int_t nb, double *a, rng_int_t lda, double *e, double *tau, double *w, rng_int_t ldw);
extern void RNGCDECL dlatrs(char uplo, char trans, char diag, char normin, rng_int_t n, double *a, rng_int_t lda, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL dlatrz(rng_int_t m, rng_int_t n, rng_int_t l, double *a, rng_int_t lda, double *tau);
extern void RNGCDECL dlatzm(char side, rng_int_t m, rng_int_t n, double *v, rng_int_t incv, double tau, double *c1, double *c2, rng_int_t ldc);
extern void RNGCDECL dlauu2(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dlauum(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dorg2l(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorg2r(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgl2(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorgr2(rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, rng_int_t *info);
extern void RNGCDECL dorm2l(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dorm2r(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dorml2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dormr2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, double *a, rng_int_t lda, double *tau, double *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL dpbtf2(char uplo, rng_int_t n, rng_int_t kd, double *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL dpotf2(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL dptts2(rng_int_t n, rng_int_t nrhs, double *d, double *e, double *b, rng_int_t ldb);
extern void RNGCDECL drscl(rng_int_t n, double sa, double *sx, rng_int_t incx);
extern void RNGCDECL dsygs2(rng_int_t itype, char uplo, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL dsytd2(char uplo, rng_int_t n, double *a, rng_int_t lda, double *d, double *e, double *tau, rng_int_t *info);
extern void RNGCDECL dsytf2(char uplo, rng_int_t n, double *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL dtgex2(rng_int_t wantq, rng_int_t wantz, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *q, rng_int_t ldq, double *z, rng_int_t ldz, rng_int_t j1, rng_int_t n1, rng_int_t n2, rng_int_t *info);
extern void RNGCDECL dtgsy2(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, double *b, rng_int_t ldb, double *c, rng_int_t ldc, double *d, rng_int_t ldd, double *e, rng_int_t lde, double *f, rng_int_t ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *pq, rng_int_t *info);
extern void RNGCDECL dtrti2(char uplo, char diag, rng_int_t n, double *a, rng_int_t lda, rng_int_t *info);
extern double RNGCDECL dzsum1(rng_int_t n, doublecomplex *cx, rng_int_t incx);
extern rng_int_t RNGCDECL icmax1(rng_int_t n, complex *cx, rng_int_t incx);
extern rng_int_t RNGCDECL ieeeck(rng_int_t ispec, float zero, float one);
extern rng_int_t RNGCDECL iparmq(rng_int_t ispec, char *name, char *opts, rng_int_t n, rng_int_t ilo, rng_int_t ihi, rng_int_t lwork);
extern rng_int_t RNGCDECL izmax1(rng_int_t n, doublecomplex *cx, rng_int_t incx);
extern rng_int_t RNGCDECL lsamen(rng_int_t n, char *ca, char *cb);
extern float RNGCDECL scsum1(rng_int_t n, complex *cx, rng_int_t incx);
extern void RNGCDECL sgbtf2(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgebd2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *d, float *e, float *tauq, float *taup, rng_int_t *info);
extern void RNGCDECL sgehd2(rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgelq2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeql2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgeqr2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgerq2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sgesc2(rng_int_t n, float *a, rng_int_t lda, float *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGCDECL sgetc2(rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGCDECL sgetf2(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL sgtts2(rng_int_t itrans, rng_int_t n, rng_int_t nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t ldb);
extern void RNGCDECL slabad(float *small, float *large);
extern void RNGCDECL slabrd(rng_int_t m, rng_int_t n, rng_int_t nb, float *a, rng_int_t lda, float *d, float *e, float *tauq, float *taup, float *x, rng_int_t ldx, float *y, rng_int_t ldy);
extern void RNGCDECL slacn2(rng_int_t n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGCDECL slacon(rng_int_t n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase);
extern void RNGCDECL slacpy(char uplo, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb);
extern void RNGCDECL sladiv(float a, float b, float c, float d, float *p, float *q);
extern void RNGCDECL slae2(float a, float b, float c, float *rt1, float *rt2);
extern void RNGCDECL slaebz(rng_int_t ijob, rng_int_t nitmax, rng_int_t n, rng_int_t mmax, rng_int_t minp, rng_int_t nbmin, float abstol, float reltol, float pivmin, float *d, float *e, float *e2, rng_int_t *nval, float *ab, float *c, rng_int_t *mout, rng_int_t *nab, rng_int_t *info);
extern void RNGCDECL slaed0(rng_int_t icompq, rng_int_t qsiz, rng_int_t n, float *d, float *e, float *q, rng_int_t ldq, float *qstore, rng_int_t ldqs, rng_int_t *info);
extern void RNGCDECL slaed1(rng_int_t n, float *d, float *q, rng_int_t ldq, rng_int_t *indxq, float rho, rng_int_t cutpnt, rng_int_t *info);
extern void RNGCDECL slaed2(rng_int_t *k, rng_int_t n, rng_int_t n1, float *d, float *q, rng_int_t ldq, rng_int_t *indxq, float *rho, float *z, float *dlamda, float *w, float *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGCDECL slaed3(rng_int_t k, rng_int_t n, rng_int_t n1, float *d, float *q, rng_int_t ldq, float rho, float *dlamda, float *q2, rng_int_t *indx, rng_int_t *ctot, float *w, float *s, rng_int_t *info);
extern void RNGCDECL slaed4(rng_int_t n, rng_int_t i, float *d, float *z, float *delta, float rho, float *dlam, rng_int_t *info);
extern void RNGCDECL slaed5(rng_int_t i, float *d, float *z, float *delta, float rho, float *dlam);
extern void RNGCDECL slaed6(rng_int_t kniter, rng_int_t orgati, float rho, float *d, float *z, float finit, float *tau, rng_int_t *info);
extern void RNGCDECL slaed7(rng_int_t icompq, rng_int_t n, rng_int_t qsiz, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, float *d, float *q, rng_int_t ldq, rng_int_t *indxq, float rho, rng_int_t cutpnt, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void RNGCDECL slaed8(rng_int_t icompq, rng_int_t *k, rng_int_t n, rng_int_t qsiz, float *d, float *q, rng_int_t ldq, rng_int_t *indxq, float *rho, rng_int_t cutpnt, float *z, float *dlamda, float *q2, rng_int_t ldq2, float *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGCDECL slaed9(rng_int_t k, rng_int_t kstart, rng_int_t kstop, rng_int_t n, float *d, float *q, rng_int_t ldq, float rho, float *dlamda, float *w, float *s, rng_int_t lds, rng_int_t *info);
extern void RNGCDECL slaeda(rng_int_t n, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *q, rng_int_t *qptr, float *z, float *ztemp, rng_int_t *info);
extern void RNGCDECL slaein(rng_int_t rightv, rng_int_t noinit, rng_int_t n, float *h, rng_int_t ldh, float wr, float wi, float *vr, float *vi, float *b, rng_int_t ldb, float eps3, float smlnum, float bignum, rng_int_t *info);
extern void RNGCDECL slaev2(float a, float b, float c, float *rt1, float *rt2, float *cs1, float *sn1);
extern void RNGCDECL slaexc(rng_int_t wantq, rng_int_t n, float *t, rng_int_t ldt, float *q, rng_int_t ldq, rng_int_t j1, rng_int_t n1, rng_int_t n2, rng_int_t *info);
extern void RNGCDECL slag2d(rng_int_t m, rng_int_t n, float *sa, rng_int_t ldsa, double *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL slag2(float *a, rng_int_t lda, float *b, rng_int_t ldb, float safmin, float *scale1, float *scale2, float *wr1, float *wr2, float *wi);
extern void RNGCDECL slags2(rng_int_t upper, float a1, float a2, float a3, float b1, float b2, float b3, float *csu, float *snu, float *csv, float *snv, float *csq, float *snq);
extern void RNGCDECL slagtf(rng_int_t n, float *a, float lambda, float *b, float *c, float tol, float *d, rng_int_t *in, rng_int_t *info);
extern void RNGCDECL slagtm(char trans, rng_int_t n, rng_int_t nrhs, float alpha, float *dl, float *d, float *du, float *x, rng_int_t ldx, float beta, float *b, rng_int_t ldb);
extern void RNGCDECL slagts(rng_int_t job, rng_int_t n, float *a, float *b, float *c, float *d, rng_int_t *in, float *y, float *tol, rng_int_t *info);
extern void RNGCDECL slagv2(float *a, rng_int_t lda, float *b, rng_int_t ldb, float *alphar, float *alphai, float *beta, float *csl, float *snl, float *csr, float *snr);
extern void RNGCDECL slahqr(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *h, rng_int_t ldh, float *wr, float *wi, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL slahr2(rng_int_t n, rng_int_t k, rng_int_t nb, float *a, rng_int_t lda, float *tau, float *t, rng_int_t ldt, float *y, rng_int_t ldy);
extern void RNGCDECL slahrd(rng_int_t n, rng_int_t k, rng_int_t nb, float *a, rng_int_t lda, float *tau, float *t, rng_int_t ldt, float *y, rng_int_t ldy);
extern void RNGCDECL slaic1(rng_int_t job, rng_int_t j, float *x, float sest, float *w, float gamma, float *sestpr, float *s, float *c);
extern rng_int_t RNGCDECL slaisnan(float sin1, float sin2);
extern void RNGCDECL slaln2(rng_int_t ltrans, rng_int_t na, rng_int_t nw, float smin, float ca, float *a, rng_int_t lda, float d1, float d2, float *b, rng_int_t ldb, float wr, float wi, float *x, rng_int_t ldx, float *scale, float *xnorm, rng_int_t *info);
extern void RNGCDECL slals0(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t nrhs, float *b, rng_int_t ldb, float *bx, rng_int_t ldbx, rng_int_t *perm, rng_int_t givptr, rng_int_t *givcol, rng_int_t ldgcol, float *givnum, rng_int_t ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t k, float c, float s, rng_int_t *info);
extern void RNGCDECL slalsa(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, float *b, rng_int_t ldb, float *bx, rng_int_t ldbx, float *u, rng_int_t ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, rng_int_t *info);
extern void RNGCDECL slalsd(char uplo, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, float *d, float *e, float *b, rng_int_t ldb, float rcond, rng_int_t *rank, rng_int_t *info);
extern void RNGCDECL slamrg(rng_int_t n1, rng_int_t n2, float *a, rng_int_t strd1, rng_int_t strd2, rng_int_t *index);
extern rng_int_t RNGCDECL slaneg(rng_int_t n, float d, float lld, float sigma, float pivmin, rng_int_t r);
extern float RNGCDECL slangb(char norm, rng_int_t n, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab);
extern float RNGCDECL slange(char norm, rng_int_t m, rng_int_t n, float *a, rng_int_t lda);
extern float RNGCDECL slangt(char norm, rng_int_t n, float *dl, float *d, float *du);
extern float RNGCDECL slanhs(char norm, rng_int_t n, float *a, rng_int_t lda);
extern float RNGCDECL slansb(char norm, char uplo, rng_int_t n, rng_int_t k, float *ab, rng_int_t ldab);
extern float RNGCDECL slansp(char norm, char uplo, rng_int_t n, float *ap);
extern float RNGCDECL slanst(char norm, rng_int_t n, float *d, float *e);
extern float RNGCDECL slansy(char norm, char uplo, rng_int_t n, float *a, rng_int_t lda);
extern float RNGCDECL slantb(char norm, char uplo, char diag, rng_int_t n, rng_int_t k, float *ab, rng_int_t ldab);
extern float RNGCDECL slantp(char norm, char uplo, char diag, rng_int_t n, float *ap);
extern float RNGCDECL slantr(char norm, char uplo, char diag, rng_int_t m, rng_int_t n, float *a, rng_int_t lda);
extern void RNGCDECL slanv2(float *a, float *b, float *c, float *d, float *rt1r, float *rt1i, float *rt2r, float *rt2i, float *cs, float *sn);
extern void RNGCDECL slapll(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy, float *ssmin);
extern void RNGCDECL slapmt(rng_int_t forwrd, rng_int_t m, rng_int_t n, float *x, rng_int_t ldx, rng_int_t *k);
extern float RNGCDECL slapy2(float x, float y);
extern float RNGCDECL slapy3(float x, float y, float z);
extern void RNGCDECL slaqgb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, float *ab, rng_int_t ldab, float *r, float *c, float rowcnd, float colcnd, float amax, char *equed);
extern void RNGCDECL slaqge(rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *r, float *c, float rowcnd, float colcnd, float amax, char *equed);
extern void RNGCDECL slaqp2(rng_int_t m, rng_int_t n, rng_int_t offset, float *a, rng_int_t lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2);
extern void RNGCDECL slaqps(rng_int_t m, rng_int_t n, rng_int_t offset, rng_int_t nb, rng_int_t *kb, float *a, rng_int_t lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *auxv, float *f, rng_int_t ldf);
extern void RNGCDECL slaqr0(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *h, rng_int_t ldh, float *wr, float *wi, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL slaqr1(rng_int_t n, float *h, rng_int_t ldh, float sr1, float si1, float sr2, float si2, float *v);
extern void RNGCDECL slaqr2(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, float *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t ldv, rng_int_t nh, float *t, rng_int_t ldt, rng_int_t nv, float *wv, rng_int_t ldwv);
extern void RNGCDECL slaqr3(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, float *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t ldv, rng_int_t nh, float *t, rng_int_t ldt, rng_int_t nv, float *wv, rng_int_t ldwv);
extern void RNGCDECL slaqr4(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, float *h, rng_int_t ldh, float *wr, float *wi, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL slaqr5(rng_int_t wantt, rng_int_t wantz, rng_int_t kacc22, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nshfts, float *sr, float *si, float *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, float *z, rng_int_t ldz, float *v, rng_int_t ldv, float *u, rng_int_t ldu, rng_int_t nv, float *wv, rng_int_t ldwv, rng_int_t nh, float *wh, rng_int_t ldwh);
extern void RNGCDECL slaqsb(char uplo, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, float *s, float scond, float amax, char *equed);
extern void RNGCDECL slaqsp(char uplo, rng_int_t n, float *ap, float *s, float scond, float amax, char *equed);
extern void RNGCDECL slaqsy(char uplo, rng_int_t n, float *a, rng_int_t lda, float *s, float scond, float amax, char *equed);
extern void RNGCDECL slaqtr(rng_int_t ltran, rng_int_t lreal, rng_int_t n, float *t, rng_int_t ldt, float *b, float w, float *scale, float *x, rng_int_t *info);
extern void RNGCDECL slar1v(rng_int_t n, rng_int_t b1, rng_int_t bn, float lambda, float d, float l, float ld, float lld, float pivmin, float gaptol, float *z, rng_int_t wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr);
extern void RNGCDECL slar2v(rng_int_t n, float *x, float *y, float *z, rng_int_t incx, float *c, float *s, rng_int_t incc);
extern void RNGCDECL slarfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, float *v, rng_int_t ldv, float *t, rng_int_t ldt, float *c, rng_int_t ldc);
extern void RNGCDECL slarf(char side, rng_int_t m, rng_int_t n, float *v, rng_int_t incv, float tau, float *c, rng_int_t ldc);
extern void RNGCDECL slarfg(rng_int_t n, float *alpha, float *x, rng_int_t incx, float *tau);
extern void RNGCDECL slarfx(char side, rng_int_t m, rng_int_t n, float *v, float tau, float *c, rng_int_t ldc);
extern void RNGCDECL slargv(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy, float *c, rng_int_t incc);
extern void RNGCDECL slarnv(rng_int_t idist, rng_int_t *iseed, rng_int_t n, float *x);
extern void RNGCDECL slarra(rng_int_t n, float d, float *e, float *e2, float spltol, float tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGCDECL slarrb(rng_int_t n, float d, float lld, rng_int_t ifirst, rng_int_t ilast, float rtol1, float rtol2, rng_int_t offset, float *w, float *wgap, float *werr, float pivmin, float spdiam, rng_int_t twist, rng_int_t *info);
extern void RNGCDECL slarrc(char jobt, rng_int_t n, float vl, float vu, float *d, float *e, float pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info);
extern void RNGCDECL slarrd(char range, char order, rng_int_t n, float vl, float vu, rng_int_t il, rng_int_t iu, float gers, float reltol, float d, float e, float e2, float pivmin, rng_int_t nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wl, float *wu, rng_int_t *iblock, rng_int_t *indexw, rng_int_t *info);
extern void RNGCDECL slarre(char range, rng_int_t n, float *vl, float *vu, rng_int_t il, rng_int_t iu, float *d, float *e, float *e2, float rtol1, float rtol2, float spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *pivmin, rng_int_t *info);
extern void RNGCDECL slarrf(rng_int_t n, float *d, float *l, float *ld, rng_int_t clstrt, rng_int_t clend, float *w, float *wgap, float *werr, float spdiam, float clgapl, float clgapr, float pivmin, float *sigma, float *dplus, float *lplus, rng_int_t *info);
extern void RNGCDECL slarrj(rng_int_t n, float d, float e2, rng_int_t ifirst, rng_int_t ilast, float rtol, rng_int_t offset, float *w, float *werr, float pivmin, float spdiam, rng_int_t *info);
extern void RNGCDECL slarrk(rng_int_t n, rng_int_t iw, float gl, float gu, float d, float e2, float pivmin, float reltol, float *w, float *werr, rng_int_t *info);
extern void RNGCDECL slarrr(rng_int_t n, float d, float *e, rng_int_t *info);
extern void RNGCDECL slarrv(rng_int_t n, float vl, float vu, float *d, float *l, float pivmin, rng_int_t *isplit, rng_int_t m, rng_int_t dol, rng_int_t dou, float minrgp, float rtol1, float rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL slartg(float f, float g, float *cs, float *sn, float *r);
extern void RNGCDECL slartv(rng_int_t n, float *x, rng_int_t incx, float *y, rng_int_t incy, float *c, float *s, rng_int_t incc);
extern void RNGCDECL slaruv(rng_int_t *iseed, rng_int_t n, float *x);
extern void RNGCDECL slarzb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, float *v, rng_int_t ldv, float *t, rng_int_t ldt, float *c, rng_int_t ldc);
extern void RNGCDECL slarz(char side, rng_int_t m, rng_int_t n, rng_int_t l, float *v, rng_int_t incv, float tau, float *c, rng_int_t ldc);
extern void RNGCDECL slarzt(char direct, char storev, rng_int_t n, rng_int_t k, float *v, rng_int_t ldv, float *tau, float *t, rng_int_t ldt);
extern void RNGCDECL slas2(float f, float g, float h, float *ssmin, float *ssmax);
extern void RNGCDECL slascl(char type, rng_int_t kl, rng_int_t ku, float cfrom, float cto, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL slasd0(rng_int_t n, rng_int_t sqre, float *d, float *e, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, rng_int_t smlsiz, rng_int_t *info);
extern void RNGCDECL slasd1(rng_int_t nl, rng_int_t nr, rng_int_t sqre, float *d, float *alpha, float *beta, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, rng_int_t *idxq, rng_int_t *info);
extern void RNGCDECL slasd2(rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t *k, float *d, float *z, float alpha, float beta, float *u, rng_int_t ldu, float *vt, rng_int_t ldvt, float *dsigma, float *u2, rng_int_t ldu2, float *vt2, rng_int_t ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGCDECL slasd3(rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t k, float *d, float *q, rng_int_t ldq, float *dsigma, float *u, rng_int_t ldu, float *u2, rng_int_t ldu2, float *vt, rng_int_t ldvt, float *vt2, rng_int_t ldvt2, rng_int_t *idxc, rng_int_t *ctot, float *z, rng_int_t *info);
extern void RNGCDECL slasd4(rng_int_t n, rng_int_t i, float *d, float *z, float *delta, float rho, float *sigma, rng_int_t *info);
extern void RNGCDECL slasd5(rng_int_t i, float *d, float *z, float *delta, float rho, float *dsigma);
extern void RNGCDECL slasd6(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, float *d, float *vf, float *vl, float *alpha, float *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, float *givnum, rng_int_t ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, rng_int_t *info);
extern void RNGCDECL slasd7(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t *k, float *d, float *z, float *zw, float *vf, float *vfw, float *vl, float *vlw, float alpha, float beta, float *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, float *givnum, rng_int_t ldgnum, float *c, float *s, rng_int_t *info);
extern void RNGCDECL slasd8(rng_int_t icompq, rng_int_t k, float *d, float *z, float *vf, float *vl, float *difl, float *difr, rng_int_t lddifr, float *dsigma, rng_int_t *info);
extern void RNGCDECL slasda(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t sqre, float *d, float *e, float *u, rng_int_t ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, rng_int_t *info);
extern void RNGCDECL slasdq(char uplo, rng_int_t sqre, rng_int_t n, rng_int_t ncvt, rng_int_t nru, rng_int_t ncc, float *d, float *e, float *vt, rng_int_t ldvt, float *u, rng_int_t ldu, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL slasdt(rng_int_t n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t msub);
extern void RNGCDECL slaset(char uplo, rng_int_t m, rng_int_t n, float alpha, float beta, float *a, rng_int_t lda);
extern void RNGCDECL slasq1(rng_int_t n, float *d, float *e, rng_int_t *info);
extern void RNGCDECL slasq2(rng_int_t n, float *z, rng_int_t *info);
extern void RNGCDECL slasq3(rng_int_t i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *sigma, float *desig, float qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t ieee, rng_int_t *ttype, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *g, float *tau);
extern void RNGCDECL slasq4(rng_int_t i0, rng_int_t n0, float *z, rng_int_t pp, rng_int_t n0in, float dmin, float dmin1, float dmin2, float dn, float dn1, float dn2, float *tau, rng_int_t *ttype, float *g);
extern void RNGCDECL slasq5(rng_int_t i0, rng_int_t n0, float *z, rng_int_t pp, float tau, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2, rng_int_t ieee);
extern void RNGCDECL slasq6(rng_int_t i0, rng_int_t n0, float *z, rng_int_t pp, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2);
extern void RNGCDECL slasr(char side, char pivot, char direct, rng_int_t m, rng_int_t n, float *c, float *s, float *a, rng_int_t lda);
extern void RNGCDECL slasv2(float f, float g, float h, float *ssmin, float *ssmax, float *snr, float *csr, float *snl, float *csl);
extern void RNGCDECL slaswp(rng_int_t n, float *a, rng_int_t lda, rng_int_t k1, rng_int_t k2, rng_int_t *ipiv, rng_int_t incx);
extern void RNGCDECL slasy2(rng_int_t ltranl, rng_int_t ltranr, rng_int_t isgn, rng_int_t n1, rng_int_t n2, float *tl, rng_int_t ldtl, float *tr, rng_int_t ldtr, float *b, rng_int_t ldb, float *scale, float *x, rng_int_t ldx, float *xnorm, rng_int_t *info);
extern void RNGCDECL slasyf(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, float *a, rng_int_t lda, rng_int_t *ipiv, float *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL slatbs(char uplo, char trans, char diag, char normin, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL slatdf(rng_int_t ijob, rng_int_t n, float *z, rng_int_t ldz, float *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGCDECL slatps(char uplo, char trans, char diag, char normin, rng_int_t n, float *ap, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL slatrd(char uplo, rng_int_t n, rng_int_t nb, float *a, rng_int_t lda, float *e, float *tau, float *w, rng_int_t ldw);
extern void RNGCDECL slatrs(char uplo, char trans, char diag, char normin, rng_int_t n, float *a, rng_int_t lda, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGCDECL slatrz(rng_int_t m, rng_int_t n, rng_int_t l, float *a, rng_int_t lda, float *tau);
extern void RNGCDECL slatzm(char side, rng_int_t m, rng_int_t n, float *v, rng_int_t incv, float tau, float *c1, float *c2, rng_int_t ldc);
extern void RNGCDECL slauu2(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL slauum(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL sorg2l(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorg2r(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgl2(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorgr2(rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, rng_int_t *info);
extern void RNGCDECL sorm2l(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sorm2r(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sorml2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL sormr2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, float *a, rng_int_t lda, float *tau, float *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL spbtf2(char uplo, rng_int_t n, rng_int_t kd, float *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL spotf2(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL sptts2(rng_int_t n, rng_int_t nrhs, float *d, float *e, float *b, rng_int_t ldb);
extern void RNGCDECL srscl(rng_int_t n, float sa, float *sx, rng_int_t incx);
extern void RNGCDECL ssygs2(rng_int_t itype, char uplo, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL ssytd2(char uplo, rng_int_t n, float *a, rng_int_t lda, float *d, float *e, float *tau, rng_int_t *info);
extern void RNGCDECL ssytf2(char uplo, rng_int_t n, float *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL stgex2(rng_int_t wantq, rng_int_t wantz, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *q, rng_int_t ldq, float *z, rng_int_t ldz, rng_int_t j1, rng_int_t n1, rng_int_t n2, rng_int_t *info);
extern void RNGCDECL stgsy2(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, float *a, rng_int_t lda, float *b, rng_int_t ldb, float *c, rng_int_t ldc, float *d, rng_int_t ldd, float *e, rng_int_t lde, float *f, rng_int_t ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *pq, rng_int_t *info);
extern void RNGCDECL strti2(char uplo, char diag, rng_int_t n, float *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zdrscl(rng_int_t n, double sa, doublecomplex *sx, rng_int_t incx);
extern void RNGCDECL zgbtf2(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgebd2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, rng_int_t *info);
extern void RNGCDECL zgehd2(rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgelq2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeql2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgeqr2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgerq2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zgesc2(rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGCDECL zgetc2(rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGCDECL zgetf2(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zgtts2(rng_int_t itrans, rng_int_t n, rng_int_t nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL zhegs2(rng_int_t itype, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, rng_int_t *info);
extern void RNGCDECL zhetd2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *d, double *e, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zhetf2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL zlabrd(rng_int_t m, rng_int_t n, rng_int_t nb, doublecomplex *a, rng_int_t lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *x, rng_int_t ldx, doublecomplex *y, rng_int_t ldy);
extern void RNGCDECL zlacgv(rng_int_t n, doublecomplex *x, rng_int_t incx);
extern void RNGCDECL zlacn2(rng_int_t n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGCDECL zlacon(rng_int_t n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase);
extern void RNGCDECL zlacp2(char uplo, rng_int_t m, rng_int_t n, double *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL zlacpy(char uplo, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL zlacrm(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *b, rng_int_t ldb, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlacrt(rng_int_t n, doublecomplex *cx, rng_int_t incx, doublecomplex *cy, rng_int_t incy, doublecomplex c, doublecomplex s);
extern doublecomplex RNGCDECL zladiv(doublecomplex x, doublecomplex y);
extern void RNGCDECL zlaed0(rng_int_t qsiz, rng_int_t n, double *d, double *e, doublecomplex *q, rng_int_t ldq, doublecomplex *qstore, rng_int_t ldqs, rng_int_t *info);
extern void RNGCDECL zlaed7(rng_int_t n, rng_int_t cutpnt, rng_int_t qsiz, rng_int_t tlvls, rng_int_t curlvl, rng_int_t curpbm, double *d, doublecomplex *q, rng_int_t ldq, double rho, rng_int_t *indxq, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void RNGCDECL zlaed8(rng_int_t *k, rng_int_t n, rng_int_t qsiz, doublecomplex *q, rng_int_t ldq, double *d, double *rho, rng_int_t cutpnt, double *z, double *dlamda, doublecomplex *q2, rng_int_t ldq2, double *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void RNGCDECL zlaein(rng_int_t rightv, rng_int_t noinit, rng_int_t n, doublecomplex *h, rng_int_t ldh, doublecomplex w, doublecomplex *v, doublecomplex *b, rng_int_t ldb, double eps3, double smlnum, rng_int_t *info);
extern void RNGCDECL zlaesy(doublecomplex a, doublecomplex b, doublecomplex c, doublecomplex *rt1, doublecomplex *rt2, doublecomplex *evscal, doublecomplex *cs1, doublecomplex *sn1);
extern void RNGCDECL zlaev2(doublecomplex a, doublecomplex b, doublecomplex c, double *rt1, double *rt2, double *cs1, doublecomplex *sn1);
extern void RNGCDECL zlag2c(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, complex *sa, rng_int_t ldsa, rng_int_t *info);
extern void RNGCDECL zlags2(rng_int_t upper, double a1, doublecomplex a2, double a3, double b1, doublecomplex b2, double b3, double *csu, doublecomplex *snu, double *csv, doublecomplex *snv, double *csq, doublecomplex *snq);
extern void RNGCDECL zlagtm(char trans, rng_int_t n, rng_int_t nrhs, double alpha, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *x, rng_int_t ldx, double beta, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL zlahef(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL zlahqr(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *h, rng_int_t ldh, doublecomplex *w, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zlahr2(rng_int_t n, rng_int_t k, rng_int_t nb, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *t, rng_int_t ldt, doublecomplex *y, rng_int_t ldy);
extern void RNGCDECL zlahrd(rng_int_t n, rng_int_t k, rng_int_t nb, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *t, rng_int_t ldt, doublecomplex *y, rng_int_t ldy);
extern void RNGCDECL zlaic1(rng_int_t job, rng_int_t j, doublecomplex *x, double sest, doublecomplex *w, doublecomplex gamma, double *sestpr, doublecomplex *s, doublecomplex *c);
extern void RNGCDECL zlals0(rng_int_t icompq, rng_int_t nl, rng_int_t nr, rng_int_t sqre, rng_int_t nrhs, doublecomplex *b, rng_int_t ldb, doublecomplex *bx, rng_int_t ldbx, rng_int_t *perm, rng_int_t givptr, rng_int_t *givcol, rng_int_t ldgcol, double *givnum, rng_int_t ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t k, double c, double s, rng_int_t *info);
extern void RNGCDECL zlalsa(rng_int_t icompq, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, doublecomplex *b, rng_int_t ldb, doublecomplex *bx, rng_int_t ldbx, double *u, rng_int_t ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, rng_int_t *info);
extern void RNGCDECL zlalsd(char uplo, rng_int_t smlsiz, rng_int_t n, rng_int_t nrhs, double *d, double *e, doublecomplex *b, rng_int_t ldb, double rcond, rng_int_t *rank, rng_int_t *info);
extern double RNGCDECL zlangb(char norm, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab);
extern double RNGCDECL zlange(char norm, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern double RNGCDECL zlangt(char norm, rng_int_t n, doublecomplex *dl, doublecomplex *d, doublecomplex *du);
extern double RNGCDECL zlanhb(char norm, char uplo, rng_int_t n, rng_int_t k, doublecomplex *ab, rng_int_t ldab);
extern double RNGCDECL zlanhe(char norm, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern double RNGCDECL zlanhp(char norm, char uplo, rng_int_t n, doublecomplex *ap);
extern double RNGCDECL zlanhs(char norm, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern double RNGCDECL zlanht(char norm, rng_int_t n, double *d, doublecomplex *e);
extern double RNGCDECL zlansb(char norm, char uplo, rng_int_t n, rng_int_t k, doublecomplex *ab, rng_int_t ldab);
extern double RNGCDECL zlansp(char norm, char uplo, rng_int_t n, doublecomplex *ap);
extern double RNGCDECL zlansy(char norm, char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern double RNGCDECL zlantb(char norm, char uplo, char diag, rng_int_t n, rng_int_t k, doublecomplex *ab, rng_int_t ldab);
extern double RNGCDECL zlantp(char norm, char uplo, char diag, rng_int_t n, doublecomplex *ap);
extern double RNGCDECL zlantr(char norm, char uplo, char diag, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zlapll(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, double *ssmin);
extern void RNGCDECL zlapmt(rng_int_t forwrd, rng_int_t m, rng_int_t n, doublecomplex *x, rng_int_t ldx, rng_int_t *k);
extern void RNGCDECL zlaqgb(rng_int_t m, rng_int_t n, rng_int_t kl, rng_int_t ku, doublecomplex *ab, rng_int_t ldab, double *r, double *c, double rowcnd, double colcnd, double amax, char *equed);
extern void RNGCDECL zlaqge(rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, double *r, double *c, double rowcnd, double colcnd, double amax, char *equed);
extern void RNGCDECL zlaqhb(char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlaqhe(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlaqhp(char uplo, rng_int_t n, doublecomplex *ap, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlaqp2(rng_int_t m, rng_int_t n, rng_int_t offset, doublecomplex *a, rng_int_t lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2);
extern void RNGCDECL zlaqps(rng_int_t m, rng_int_t n, rng_int_t offset, rng_int_t nb, rng_int_t *kb, doublecomplex *a, rng_int_t lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *auxv, doublecomplex *f, rng_int_t ldf);
extern void RNGCDECL zlaqr0(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *h, rng_int_t ldh, doublecomplex *w, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zlaqr1(rng_int_t n, doublecomplex *h, rng_int_t ldh, doublecomplex s1, doublecomplex s2, doublecomplex *v);
extern void RNGCDECL zlaqr2(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, doublecomplex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t ldv, rng_int_t nh, doublecomplex *t, rng_int_t ldt, rng_int_t nv, doublecomplex *wv, rng_int_t ldwv);
extern void RNGCDECL zlaqr3(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nw, doublecomplex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t ldv, rng_int_t nh, doublecomplex *t, rng_int_t ldt, rng_int_t nv, doublecomplex *wv, rng_int_t ldwv);
extern void RNGCDECL zlaqr4(rng_int_t wantt, rng_int_t wantz, rng_int_t n, rng_int_t ilo, rng_int_t ihi, doublecomplex *h, rng_int_t ldh, doublecomplex *w, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, rng_int_t *info);
extern void RNGCDECL zlaqr5(rng_int_t wantt, rng_int_t wantz, rng_int_t kacc22, rng_int_t n, rng_int_t ktop, rng_int_t kbot, rng_int_t nshfts, doublecomplex *s, doublecomplex *h, rng_int_t ldh, rng_int_t iloz, rng_int_t ihiz, doublecomplex *z, rng_int_t ldz, doublecomplex *v, rng_int_t ldv, doublecomplex *u, rng_int_t ldu, rng_int_t nv, doublecomplex *wv, rng_int_t ldwv, rng_int_t nh, doublecomplex *wh, rng_int_t ldwh);
extern void RNGCDECL zlaqsb(char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlaqsp(char uplo, rng_int_t n, doublecomplex *ap, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlaqsy(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, double *s, double scond, double amax, char *equed);
extern void RNGCDECL zlar1v(rng_int_t n, rng_int_t b1, rng_int_t bn, double lambda, double *d, double *l, double *ld, double *lld, double pivmin, double gaptol, doublecomplex *z, rng_int_t wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr);
extern void RNGCDECL zlar2v(rng_int_t n, doublecomplex *x, doublecomplex *y, doublecomplex *z, rng_int_t incx, double *c, doublecomplex *s, rng_int_t incc);
extern void RNGCDECL zlarcm(rng_int_t m, rng_int_t n, double *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlarfb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *v, rng_int_t ldv, doublecomplex *t, rng_int_t ldt, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlarf(char side, rng_int_t m, rng_int_t n, doublecomplex *v, rng_int_t incv, doublecomplex tau, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlarfg(rng_int_t n, doublecomplex *alpha, doublecomplex *x, rng_int_t incx, doublecomplex *tau);
extern void RNGCDECL zlarft(char direct, char storev, rng_int_t n, rng_int_t k, doublecomplex *v, rng_int_t ldv, doublecomplex *tau, doublecomplex *t, rng_int_t ldt);
extern void RNGCDECL zlarfx(char side, rng_int_t m, rng_int_t n, doublecomplex *v, doublecomplex tau, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlargv(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, double *c, rng_int_t incc);
extern void RNGCDECL zlarnv(rng_int_t idist, rng_int_t *iseed, rng_int_t n, doublecomplex *x);
extern void RNGCDECL zlarrv(rng_int_t n, double vl, double vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t m, rng_int_t dol, rng_int_t dou, double minrgp, double rtol1, double rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, doublecomplex *z, rng_int_t ldz, rng_int_t *isuppz, rng_int_t *info);
extern void RNGCDECL zlartg(doublecomplex f, doublecomplex g, double *cs, doublecomplex *sn, doublecomplex *r);
extern void RNGCDECL zlartv(rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, double *c, doublecomplex *s, rng_int_t incc);
extern void RNGCDECL zlarzb(char side, char trans, char direct, char storev, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, doublecomplex *v, rng_int_t ldv, doublecomplex *t, rng_int_t ldt, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlarz(char side, rng_int_t m, rng_int_t n, rng_int_t l, doublecomplex *v, rng_int_t incv, doublecomplex tau, doublecomplex *c, rng_int_t ldc);
extern void RNGCDECL zlarzt(char direct, char storev, rng_int_t n, rng_int_t k, doublecomplex *v, rng_int_t ldv, doublecomplex *tau, doublecomplex *t, rng_int_t ldt);
extern void RNGCDECL zlascl(char type, rng_int_t kl, rng_int_t ku, double cfrom, double cto, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zlaset(char uplo, rng_int_t m, rng_int_t n, doublecomplex alpha, doublecomplex beta, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zlasr(char side, char pivot, char direct, rng_int_t m, rng_int_t n, double *c, double *s, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zlaswp(rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t k1, rng_int_t k2, rng_int_t *ipiv, rng_int_t incx);
extern void RNGCDECL zlasyf(char uplo, rng_int_t n, rng_int_t nb, rng_int_t *kb, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t ldw, rng_int_t *info);
extern void RNGCDECL zlatbs(char uplo, char trans, char diag, char normin, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL zlatdf(rng_int_t ijob, rng_int_t n, doublecomplex *z, rng_int_t ldz, doublecomplex *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGCDECL zlatps(char uplo, char trans, char diag, char normin, rng_int_t n, doublecomplex *ap, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL zlatrd(char uplo, rng_int_t n, rng_int_t nb, doublecomplex *a, rng_int_t lda, double *e, doublecomplex *tau, doublecomplex *w, rng_int_t ldw);
extern void RNGCDECL zlatrs(char uplo, char trans, char diag, char normin, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGCDECL zlatrz(rng_int_t m, rng_int_t n, rng_int_t l, doublecomplex *a, rng_int_t lda, doublecomplex *tau);
extern void RNGCDECL zlatzm(char side, rng_int_t m, rng_int_t n, doublecomplex *v, rng_int_t incv, doublecomplex tau, doublecomplex *c1, doublecomplex *c2, rng_int_t ldc);
extern void RNGCDECL zlauu2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zlauum(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zpbtf2(char uplo, rng_int_t n, rng_int_t kd, doublecomplex *ab, rng_int_t ldab, rng_int_t *info);
extern void RNGCDECL zpotf2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zptts2(rng_int_t iuplo, rng_int_t n, rng_int_t nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t ldb);
extern void RNGCDECL zrot(rng_int_t n, doublecomplex *cx, rng_int_t incx, doublecomplex *cy, rng_int_t incy, double c, doublecomplex s);
extern void RNGCDECL zspmv(char uplo, rng_int_t n, doublecomplex alpha, doublecomplex *ap, doublecomplex *x, rng_int_t incx, doublecomplex beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zspr(char uplo, rng_int_t n, doublecomplex alpha, doublecomplex *x, rng_int_t incx, doublecomplex *ap);
extern void RNGCDECL zsymv(char uplo, rng_int_t n, doublecomplex alpha, doublecomplex *a, rng_int_t lda, doublecomplex *x, rng_int_t incx, doublecomplex beta, doublecomplex *y, rng_int_t incy);
extern void RNGCDECL zsyr(char uplo, rng_int_t n, doublecomplex alpha, doublecomplex *x, rng_int_t incx, doublecomplex *a, rng_int_t lda);
extern void RNGCDECL zsytf2(char uplo, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGCDECL ztgex2(rng_int_t wantq, rng_int_t wantz, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *q, rng_int_t ldq, doublecomplex *z, rng_int_t ldz, rng_int_t j1, rng_int_t *info);
extern void RNGCDECL ztgsy2(char trans, rng_int_t ijob, rng_int_t m, rng_int_t n, doublecomplex *a, rng_int_t lda, doublecomplex *b, rng_int_t ldb, doublecomplex *c, rng_int_t ldc, doublecomplex *d, rng_int_t ldd, doublecomplex *e, rng_int_t lde, doublecomplex *f, rng_int_t ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *info);
extern void RNGCDECL ztrti2(char uplo, char diag, rng_int_t n, doublecomplex *a, rng_int_t lda, rng_int_t *info);
extern void RNGCDECL zung2l(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zung2r(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungl2(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zungr2(rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, rng_int_t *info);
extern void RNGCDECL zunm2l(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunm2r(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunml2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmr2(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);
extern void RNGCDECL zunmr3(char side, char trans, rng_int_t m, rng_int_t n, rng_int_t k, rng_int_t l, doublecomplex *a, rng_int_t lda, doublecomplex *tau, doublecomplex *c, rng_int_t ldc, rng_int_t *info);

/* FFT C interfaces */
extern void RNGCDECL cfft1d(rng_int_t mode, rng_int_t n, complex *x, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft1dx(rng_int_t mode, float scale, rng_int_t inpl, rng_int_t n, complex *x, rng_int_t incx, complex *y, rng_int_t incy, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft1m(rng_int_t mode, rng_int_t nseq, rng_int_t n, complex *x, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft1mx(rng_int_t mode, float scale, rng_int_t inpl, rng_int_t nseq, rng_int_t n, complex *x, rng_int_t incx1, rng_int_t incx2, complex *y, rng_int_t incy1, rng_int_t incy2, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, complex *x, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft2dx(rng_int_t mode, float scale, rng_int_t ltrans, rng_int_t inpl, rng_int_t m, rng_int_t n, complex *x, rng_int_t incx1, rng_int_t incx2, complex *y, rng_int_t incy1, rng_int_t incy2, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, complex *x, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft3dx(rng_int_t mode, float scale, rng_int_t ltrans, rng_int_t inpl, rng_int_t l, rng_int_t m, rng_int_t n, complex *x, complex *y, complex *comm, rng_int_t *info);
extern void RNGCDECL cfft3dy(rng_int_t mode, float scale, rng_int_t inpl, rng_int_t l, rng_int_t m, rng_int_t n, complex *x, rng_int_t incx1, rng_int_t incx2, rng_int_t incx3, complex *y, rng_int_t incy1, rng_int_t incy2, rng_int_t incy3, complex *comm, rng_int_t lcomm, rng_int_t *info);
extern void RNGCDECL csfft(rng_int_t mode, rng_int_t n, float *x, float *comm, rng_int_t *info);
extern void RNGCDECL csfft1d(rng_int_t mode, rng_int_t n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGCDECL csfft1m(rng_int_t mode, rng_int_t m, rng_int_t n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGCDECL csfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGCDECL csfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGCDECL csfftm(rng_int_t nseq, rng_int_t n, float *x, float *comm, rng_int_t *info);
extern void RNGCDECL dzfft(rng_int_t mode, rng_int_t n, double *x, double *comm, rng_int_t *info);
extern void RNGCDECL dzfft1d(rng_int_t mode, rng_int_t n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGCDECL dzfft1m(rng_int_t mode, rng_int_t m, rng_int_t n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGCDECL dzfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGCDECL dzfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGCDECL dzfftm(rng_int_t nseq, rng_int_t n, double *x, double *comm, rng_int_t *info);
extern void RNGCDECL scfft(rng_int_t mode, rng_int_t n, float *x, float *comm, rng_int_t *info);
extern void RNGCDECL scfft1d(rng_int_t mode, rng_int_t n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGCDECL scfft1m(rng_int_t mode, rng_int_t m, rng_int_t n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGCDECL scfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGCDECL scfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGCDECL scfftm(rng_int_t nseq, rng_int_t n, float *x, float *comm, rng_int_t *info);
extern void RNGCDECL zdfft(rng_int_t mode, rng_int_t n, double *x, double *comm, rng_int_t *info);
extern void RNGCDECL zdfft1d(rng_int_t mode, rng_int_t n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGCDECL zdfft1m(rng_int_t mode, rng_int_t m, rng_int_t n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGCDECL zdfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGCDECL zdfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGCDECL zdfftm(rng_int_t nseq, rng_int_t n, double *x, double *comm, rng_int_t *info);
extern void RNGCDECL zfft1d(rng_int_t mode, rng_int_t n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft1dx(rng_int_t mode, double scale, rng_int_t inpl, rng_int_t n, doublecomplex *x, rng_int_t incx, doublecomplex *y, rng_int_t incy, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft1m(rng_int_t mode, rng_int_t nseq, rng_int_t n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft1mx(rng_int_t mode, double scale, rng_int_t inpl, rng_int_t nseq, rng_int_t n, doublecomplex *x, rng_int_t incx1, rng_int_t incx2, doublecomplex *y, rng_int_t incy1, rng_int_t incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft2d(rng_int_t mode, rng_int_t m, rng_int_t n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft2dx(rng_int_t mode, double scale, rng_int_t ltrans, rng_int_t inpl, rng_int_t m, rng_int_t n, doublecomplex *x, rng_int_t incx1, rng_int_t incx2, doublecomplex *y, rng_int_t incy1, rng_int_t incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft3d(rng_int_t mode, rng_int_t l, rng_int_t m, rng_int_t n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft3dx(rng_int_t mode, double scale, rng_int_t ltrans, rng_int_t inpl, rng_int_t l, rng_int_t m, rng_int_t n, doublecomplex *x, doublecomplex *y, doublecomplex *comm, rng_int_t *info);
extern void RNGCDECL zfft3dy(rng_int_t mode, double scale, rng_int_t inpl, rng_int_t l, rng_int_t m, rng_int_t n, doublecomplex *x, rng_int_t incx1, rng_int_t incx2, rng_int_t incx3, doublecomplex *y, rng_int_t incy1, rng_int_t incy2, rng_int_t incy3, doublecomplex *comm, rng_int_t lcomm, rng_int_t *info);

/* Sparse BLAS interfaces */
extern void RNGCDECL caxpyi(rng_int_t nz, complex a, complex *x, rng_int_t *indx, complex *y);
extern complex RNGCDECL cdotci(rng_int_t nz, complex *x, rng_int_t *indx, complex *y);
extern complex RNGCDECL cdotui(rng_int_t nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGCDECL cgthr(rng_int_t nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGCDECL cgthrz(rng_int_t nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGCDECL csctr(rng_int_t nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGCDECL daxpyi(rng_int_t nz, double a, double *x, rng_int_t *indx, double *y);
extern double RNGCDECL ddoti(rng_int_t nz, double *x, rng_int_t *indx, double *y);
extern void RNGCDECL dgthr(rng_int_t nz, double *y, double *x, rng_int_t *indx);
extern void RNGCDECL dgthrz(rng_int_t nz, double *y, double *x, rng_int_t *indx);
extern void RNGCDECL droti(rng_int_t nz, double *x, rng_int_t *indx, double *y, double c, double s);
extern void RNGCDECL dsctr(rng_int_t nz, double *x, rng_int_t *indx, double *y);
extern void RNGCDECL saxpyi(rng_int_t nz, float a, float *x, rng_int_t *indx, float *y);
extern float RNGCDECL sdoti(rng_int_t nz, float *x, rng_int_t *indx, float *y);
extern void RNGCDECL sgthr(rng_int_t nz, float *y, float *x, rng_int_t *indx);
extern void RNGCDECL sgthrz(rng_int_t nz, float *y, float *x, rng_int_t *indx);
extern void RNGCDECL sroti(rng_int_t nz, float *x, rng_int_t *indx, float *y, float c, float s);
extern void RNGCDECL ssctr(rng_int_t nz, float *x, rng_int_t *indx, float *y);
extern void RNGCDECL zaxpyi(rng_int_t nz, doublecomplex a, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGCDECL zdotci(rng_int_t nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGCDECL zdotui(rng_int_t nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGCDECL zgthr(rng_int_t nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGCDECL zgthrz(rng_int_t nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGCDECL zsctr(rng_int_t nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);

/* Random number generators */
extern void RNGCDECL drandbeta(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandbinomial(rng_int_t n, rng_int_t m, double p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandbinomialreference(rng_int_t m, double p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandblumblumshub(rng_int_t n, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandcauchy(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandchisquared(rng_int_t n, rng_int_t df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL dranddiscreteuniform(rng_int_t n, rng_int_t a, rng_int_t b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandexponential(rng_int_t n, double a, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandf(rng_int_t n, rng_int_t df1, rng_int_t df2, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandgamma(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandgaussian(rng_int_t n, double xmu, double var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandgeneraldiscrete(rng_int_t n, double *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandgeometric(rng_int_t n, double p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandgeometricreference(double p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandhypergeometric(rng_int_t n, rng_int_t np, rng_int_t ns, rng_int_t m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandhypergeometricreference(rng_int_t np, rng_int_t ns, rng_int_t m, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandinitialize(rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL drandinitialize_secrng(rng_int_t genid, rng_int_t subid, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL drandinitializebbs(rng_int_t nbits, rng_int_t lp, rng_int_t *p, rng_int_t lq, rng_int_t *q, rng_int_t ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL drandinitializeuser(RNG_DRANDINITIALIZEUSER_UINI uini, RNG_DRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL drandleapfrog(rng_int_t n, rng_int_t k, rng_int_t *state, rng_int_t *info);
extern void RNGCDECL drandlogistic(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandlognormal(rng_int_t n, double xmu, double var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandmultinomial(rng_int_t n, rng_int_t m, double *p, rng_int_t k, rng_int_t *state, rng_int_t *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL drandmultinormalreference(rng_int_t m, double *xmu, double *c, rng_int_t ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandmultinormalr(rng_int_t n, double *ref, rng_int_t *state, double *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL drandmultistudentstreference(rng_int_t m, rng_int_t df, double *xmu, double *c, rng_int_t ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandmultistudentstr(rng_int_t n, double *ref, rng_int_t *state, double *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL drandnegativebinomial(rng_int_t n, rng_int_t m, double p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandnegativebinomialreference(rng_int_t m, double p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandpoisson(rng_int_t n, double lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL drandpoissonreference(double lambda, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL drandskipahead(rng_int_t n, rng_int_t *state, rng_int_t *info);
extern void RNGCDECL drandstudentst(rng_int_t n, rng_int_t df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandtriangular(rng_int_t n, double xmin, double xmed, double xmax, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL dranduniform(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandvonmises(rng_int_t n, double vk, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandweibull(rng_int_t n, double a, double b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGCDECL drandmultinormal(rng_int_t n, rng_int_t m, double *xmu, double *c, rng_int_t ldc, rng_int_t *state, double *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL drandmultistudentst(rng_int_t n, rng_int_t m, rng_int_t df, double *xmu, double *c, rng_int_t ldc, rng_int_t *state, double *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL srandbeta(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandblumblumshub(rng_int_t n, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandbinomial(rng_int_t n, rng_int_t m, float p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandbinomialreference(rng_int_t m, float p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandcauchy(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandchisquared(rng_int_t n, rng_int_t df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL sranddiscreteuniform(rng_int_t n, rng_int_t a, rng_int_t b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandexponential(rng_int_t n, float a, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandf(rng_int_t n, rng_int_t df1, rng_int_t df2, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandgamma(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandgaussian(rng_int_t n, float xmu, float var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandgeneraldiscrete(rng_int_t n, float *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandgeometric(rng_int_t n, float p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandgeometricreference(float p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandhypergeometric(rng_int_t n, rng_int_t np, rng_int_t ns, rng_int_t m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandhypergeometricreference(rng_int_t np, rng_int_t ns, rng_int_t m, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandinitialize(rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL srandinitializebbs(rng_int_t nbits, rng_int_t lp, rng_int_t *p, rng_int_t lq, rng_int_t *q, rng_int_t ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL srandinitializeuser(RNG_SRANDINITIALIZEUSER_UINI uini, RNG_SRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGCDECL srandleapfrog(rng_int_t n, rng_int_t k, rng_int_t *state, rng_int_t *info);
extern void RNGCDECL srandlogistic(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandlognormal(rng_int_t n, float xmu, float var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandmultinomial(rng_int_t n, rng_int_t m, float *p, rng_int_t k, rng_int_t *state, rng_int_t *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL srandmultinormalreference(rng_int_t m, float *xmu, float *c, rng_int_t ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandmultinormalr(rng_int_t n, float *ref, rng_int_t *state, float *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL srandmultistudentstreference(rng_int_t m, rng_int_t df, float *xmu, float *c, rng_int_t ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandmultistudentstr(rng_int_t n, float *ref, rng_int_t *state, float *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL srandnegativebinomial(rng_int_t n, rng_int_t m, float p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandnegativebinomialreference(rng_int_t m, float p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandpoisson(rng_int_t n, float lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGCDECL srandpoissonreference(float lambda, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGCDECL srandskipahead(rng_int_t n, rng_int_t *state, rng_int_t *info);
extern void RNGCDECL srandstudentst(rng_int_t n, rng_int_t df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandtriangular(rng_int_t n, float xmin, float xmed, float xmax, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL sranduniform(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandvonmises(rng_int_t n, float vk, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandweibull(rng_int_t n, float a, float b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGCDECL srandmultinormal(rng_int_t n, rng_int_t m, float *xmu, float *c, rng_int_t ldc, rng_int_t *state, float *x, rng_int_t ldx, rng_int_t *info);
extern void RNGCDECL srandmultistudentst(rng_int_t n, rng_int_t m, rng_int_t df, float *xmu, float *c, rng_int_t ldc, rng_int_t *state, float *x, rng_int_t ldx, rng_int_t *info);

/* RNG version information */
extern void RNGCDECL rngversion(rng_int_t *major, rng_int_t *minor, rng_int_t *patch, rng_int_t *build);
extern void RNGCDECL rnginfo(void);

/* OMP interfaces */
extern rng_int_t RNGCDECL rnggetmaxthreads(void);
extern rng_int_t RNGCDECL rnggetnumthreads(void);
extern void RNGCDECL rngsetnumthreads(rng_int_t numthreads);
extern rng_int_t RNGCDECL rnggetnumprocs(void);

/* Basic complex arithmetic routines for C */
extern complex RNGCDECL compose_complex(float x, float y);
extern float RNGCDECL complex_real(complex z);
extern float RNGCDECL complex_imag(complex z);
extern complex RNGCDECL complex_negate(complex z);
extern complex RNGCDECL complex_conjugate(complex z);
extern complex RNGCDECL complex_add(complex z1, complex z2);
extern complex RNGCDECL complex_subtract(complex z1, complex z2);
extern complex RNGCDECL complex_multiply(complex z1, complex z2);
extern complex RNGCDECL complex_divide(complex z1, complex z2);
extern rng_int_t RNGCDECL complex_equal(complex z1, complex z2);
extern rng_int_t RNGCDECL complex_notequal(complex z1, complex z2);
extern float RNGCDECL complex_abs(complex z);

extern doublecomplex RNGCDECL compose_doublecomplex(double x, double y);
extern double RNGCDECL doublecomplex_real(doublecomplex z);
extern double RNGCDECL doublecomplex_imag(doublecomplex z);
extern doublecomplex RNGCDECL doublecomplex_negate(doublecomplex z);
extern doublecomplex RNGCDECL doublecomplex_conjugate(doublecomplex z);
extern doublecomplex RNGCDECL doublecomplex_add(doublecomplex z1, doublecomplex z2);
extern doublecomplex RNGCDECL doublecomplex_subtract(doublecomplex z1, doublecomplex z2);
extern doublecomplex RNGCDECL doublecomplex_multiply(doublecomplex z1, doublecomplex z2);
extern doublecomplex RNGCDECL doublecomplex_divide(doublecomplex z1, doublecomplex z2);
extern rng_int_t RNGCDECL doublecomplex_equal(doublecomplex z1, doublecomplex z2);
extern rng_int_t RNGCDECL doublecomplex_notequal(doublecomplex z1, doublecomplex z2);
extern double RNGCDECL doublecomplex_abs(doublecomplex z);

/* minmax utilities */
extern rng_int_t RNGCDECL rng_imax2(rng_int_t a, rng_int_t b);
extern rng_int_t RNGCDECL rng_imin2(rng_int_t a, rng_int_t b);
extern rng_int_t RNGCDECL rng_imax3(rng_int_t a, rng_int_t b, rng_int_t c);
extern rng_int_t RNGCDECL rng_imin3(rng_int_t a, rng_int_t b, rng_int_t c);
extern float RNGCDECL rng_fmax2(float a, float b);
extern float RNGCDECL rng_fmin2(float a, float b);
extern float RNGCDECL rng_fmax3(float a, float b, float c);
extern float RNGCDECL rng_fmin3(float a, float b, float c);
extern double RNGCDECL rng_dmax2(double a, double b);
extern double RNGCDECL rng_dmin2(double a, double b);
extern double RNGCDECL rng_dmax3(double a, double b, double c);
extern double RNGCDECL rng_dmin3(double a, double b, double c);

/* ------------------------------------------------------------------ */
/* Below are prototypes for the FORTRAN interfaces to RNG routines */

#if defined(WIN32_VF)
/* BLAS routines */
extern void RNGSTDCALL CAXPY(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CCOPY(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex RNGSTDCALL CDOTC(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CDOTCSUB(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex RNGSTDCALL CDOTU(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CDOTUSUB(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CGBMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CGEMM(char *transa, rng_strlen_t transa_len, char *transb, rng_strlen_t transb_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CGEMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CGERC(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CGERU(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CHBMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CHEMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CHEMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CHER(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CHER2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CHER2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CHERK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CHPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *a, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CHPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a);
extern void RNGSTDCALL CHPR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a);
extern void RNGSTDCALL CLASSQ(rng_int_t *n, complex *x, rng_int_t *incx, float *scale, float *sumsq);
extern void RNGSTDCALL CROTG(complex *a, complex *b, float *c, complex *s);
extern void RNGSTDCALL CSCAL(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CSROT(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, float *s);
extern void RNGSTDCALL CSSCAL(rng_int_t *n, float *alpha, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CSTEMR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CSWAP(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CSYMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CSYR2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CSYRK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *beta, complex *c, rng_int_t *ldc);
extern void RNGSTDCALL CTBMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CTBSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CTPMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CTPSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CTRMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CTRMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CTRSM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CTRSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx);
extern double RNGSTDCALL DASUM(rng_int_t *n, double *x, rng_int_t *incx);
extern void RNGSTDCALL DAXPY(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double RNGSTDCALL DCABS1(doublecomplex *z);
extern void RNGSTDCALL DCOPY(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double RNGSTDCALL DDOT(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void RNGSTDCALL DGBMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern void RNGSTDCALL DGEMM(char *transa, rng_strlen_t transa_len, char *transb, rng_strlen_t transb_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc);
extern void RNGSTDCALL DGEMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern void RNGSTDCALL DGER(rng_int_t *m, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda);
extern double RNGSTDCALL DNRM2(rng_int_t *n, double *x, rng_int_t *incx);
extern void RNGSTDCALL DROT(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s);
extern void RNGSTDCALL DROTG(double *a, double *b, double *c, double *s);
extern void RNGSTDCALL DROTM(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *param);
extern void RNGSTDCALL DROTMG(double *d1, double *d2, double *b1, double *b2, double *param);
extern void RNGSTDCALL DSBMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern void RNGSTDCALL DSCAL(rng_int_t *n, double *alpha, double *x, rng_int_t *incx);
extern double RNGSTDCALL DSDOT(rng_int_t *n, float *sx, rng_int_t *incx, float *sy, rng_int_t *incy);
extern void RNGSTDCALL DSPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *ap, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern void RNGSTDCALL DSPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *ap);
extern void RNGSTDCALL DSPR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ap);
extern void RNGSTDCALL DSWAP(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void RNGSTDCALL DSYMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc);
extern void RNGSTDCALL DSYMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern void RNGSTDCALL DSYR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *a, rng_int_t *lda);
extern void RNGSTDCALL DSYR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda);
extern void RNGSTDCALL DSYR2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc);
extern void RNGSTDCALL DSYRK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c, rng_int_t *ldc);
extern void RNGSTDCALL DTBMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx);
extern void RNGSTDCALL DTBSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx);
extern void RNGSTDCALL DTPMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *ap, double *x, rng_int_t *incx);
extern void RNGSTDCALL DTPSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *ap, double *x, rng_int_t *incx);
extern void RNGSTDCALL DTRMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DTRMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx);
extern void RNGSTDCALL DTRSM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DTRSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx);
extern double RNGSTDCALL DZASUM(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern double RNGSTDCALL DZNRM2(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ICAMAX(rng_int_t *n, complex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IDAMAX(rng_int_t *n, double *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ISAMAX(rng_int_t *n, float *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IZAMAX(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL LSAME(char *ca, rng_strlen_t ca_len, char *cb, rng_strlen_t cb_len);
extern float RNGSTDCALL SASUM(rng_int_t *n, float *x, rng_int_t *incx);
extern void RNGSTDCALL SAXPY(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SCASUM(rng_int_t *n, complex *x, rng_int_t *incx);
extern float RNGSTDCALL SCNRM2(rng_int_t *n, complex *x, rng_int_t *incx);
extern void RNGSTDCALL SCOPY(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SDOT(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SDSDOT(rng_int_t *n, float *b, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void RNGSTDCALL SGBMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern void RNGSTDCALL SGEMM(char *transa, rng_strlen_t transa_len, char *transb, rng_strlen_t transb_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc);
extern void RNGSTDCALL SGEMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern void RNGSTDCALL SGER(rng_int_t *m, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda);
extern float RNGSTDCALL SNRM2(rng_int_t *n, float *x, rng_int_t *incx);
extern void RNGSTDCALL SROT(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s);
extern void RNGSTDCALL SROTG(float *a, float *b, float *c, float *s);
extern void RNGSTDCALL SROTM(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *param);
extern void RNGSTDCALL SROTMG(float *d1, float *d2, float *b1, float *b2, float *param);
extern void RNGSTDCALL SSBMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern void RNGSTDCALL SSCAL(rng_int_t *n, float *alpha, float *x, rng_int_t *incx);
extern void RNGSTDCALL SSPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *ap, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern void RNGSTDCALL SSPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *ap);
extern void RNGSTDCALL SSPR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ap);
extern void RNGSTDCALL SSTEMR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSWAP(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void RNGSTDCALL SSYMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc);
extern void RNGSTDCALL SSYMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern void RNGSTDCALL SSYR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *a, rng_int_t *lda);
extern void RNGSTDCALL SSYR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda);
extern void RNGSTDCALL SSYR2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc);
extern void RNGSTDCALL SSYRK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c, rng_int_t *ldc);
extern void RNGSTDCALL STBMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx);
extern void RNGSTDCALL STBSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx);
extern void RNGSTDCALL STPMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *ap, float *x, rng_int_t *incx);
extern void RNGSTDCALL STPSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *ap, float *x, rng_int_t *incx);
extern void RNGSTDCALL STRMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb);
extern void RNGSTDCALL STRMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx);
extern void RNGSTDCALL STRSM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb);
extern void RNGSTDCALL STRSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx);
extern void RNGSTDCALL XERBLA(const char *srname, rng_strlen_t srname_len, rng_int_t *info);
extern void RNGSTDCALL ZAXPY(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZCOPY(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex RNGSTDCALL ZDOTC(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDOTCSUB(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex RNGSTDCALL ZDOTU(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDOTUSUB(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDROT(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, double *s);
extern void RNGSTDCALL ZDSCAL(rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZGBMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZGEMM(char *transa, rng_strlen_t transa_len, char *transb, rng_strlen_t transb_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZGEMV(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZGERC(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZGERU(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZHBMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZHEMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZHEMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZHER(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZHER2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZHER2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZHERK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZHPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZHPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a);
extern void RNGSTDCALL ZHPR2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a);
extern void RNGSTDCALL ZLASSQ(rng_int_t *n, doublecomplex *x, rng_int_t *incx, double *scale, double *sumsq);
extern void RNGSTDCALL ZROTG(doublecomplex *a, doublecomplex *b, double *c, doublecomplex *s);
extern void RNGSTDCALL ZSCAL(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZSTEMR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZSWAP(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZSYMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZSYR2K(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZSYRK(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc);
extern void RNGSTDCALL ZTBMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZTBSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZTPMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZTPSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZTRMM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZTRMV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZTRSM(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *transa, rng_strlen_t transa_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZTRSV(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx);

/* LAPACK routines */
extern void RNGSTDCALL CBBCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *rwork, rng_int_t *lrwork, rng_int_t *info);
extern void RNGSTDCALL CBDSQR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, complex *vt, rng_int_t *ldvt, complex *u, rng_int_t *ldu, complex *c, rng_int_t *ldc, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBBRD(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *pt, rng_int_t *ldpt, complex *c, rng_int_t *ldc, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGBRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBRFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGBSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBSVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGBTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGEBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL CGEBAL(char *job, rng_strlen_t job_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info);
extern void RNGSTDCALL CGEBRD(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGECON(char *norm, rng_strlen_t norm_len, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEEQU(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGEEQUB(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGEES(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_CGEES_SELECT select, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL CGEESX(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_CGEESX_SELECT select, char *sense, rng_strlen_t sense_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL CGEEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEGS(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEGV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGELQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGELS(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQLF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQP3(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEQPF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEQR2P(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQRF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQRFP(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQRT2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CGEQRT3(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CGERFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGERFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGERQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGESDD(char *jobz, rng_strlen_t jobz_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CGESV(rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGESVD(char *jobu, rng_strlen_t jobu_len, char *jobvt, rng_strlen_t jobvt_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGESVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGESVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGETRF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGETRI(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGETRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGGBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL CGGBAL(char *job, rng_strlen_t job_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info);
extern void RNGSTDCALL CGGES(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_CGGES_SELCTG selctg, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL CGGESX(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_CGGESX_SELCTG selctg, char *sense, rng_strlen_t sense_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL CGGEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGGEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL CGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *d, complex *x, complex *y, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGHRD(char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL CGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, complex *d, complex *x, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGSVD(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CGGSVP(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, rng_int_t *iwork, float *rwork, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGTCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGTRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGTSV(rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGTSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGTTRF(rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGTTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHBEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHBEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHBEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHBGST(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *x, rng_int_t *ldx, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHBGV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHBGVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHBGVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHBTRD(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHECON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHEEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHEEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHEEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHEEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHEEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHEGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHEGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHEGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHEGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHERFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHERFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHESV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CHESVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHESVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHESWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL CHETRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CHETRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CHETRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHETRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CHETRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL CHETRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHETRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHFRK(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c);
extern void RNGSTDCALL CHGEQZ(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHLA_TRANSTYPE(char *ret_val, rng_strlen_t ret_val_len, rng_int_t *trans);
extern void RNGSTDCALL CHPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHPEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHPEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHPEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHPGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *bp, rng_int_t *info);
extern void RNGSTDCALL CHPGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHPGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CHPGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CHPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CHPTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *d, float *e, complex *tau, rng_int_t *info);
extern void RNGSTDCALL CHPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CHPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info);
extern void RNGSTDCALL CHPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHSEIN(char *side, rng_strlen_t side_len, char *eigsrc, rng_strlen_t eigsrc_len, char *initv, rng_strlen_t initv_len, rng_int_t *select, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGSTDCALL CHSEQR(char *job, rng_strlen_t job_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, complex *ab, rng_int_t *ldab, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_GBRCOND_C(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork);
extern float RNGSTDCALL CLA_GBRCOND_X(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork);
extern void RNGSTDCALL CLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb);
extern void RNGSTDCALL CLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_GERCOND_C(char *trans, rng_strlen_t trans_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork);
extern float RNGSTDCALL CLA_GERCOND_X(char *trans, rng_strlen_t trans_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork);
extern void RNGSTDCALL CLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *errs_n, float *errs_c, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf);
extern void RNGSTDCALL CLA_HEAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_HERCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork);
extern float RNGSTDCALL CLA_HERCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork);
extern void RNGSTDCALL CLA_HERFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_HERPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work);
extern void RNGSTDCALL CLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, complex *res, float *ayb, float *berr);
extern float RNGSTDCALL CLA_PORCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *c, int *capply, rng_int_t *info, complex *work, float *rwork);
extern float RNGSTDCALL CLA_PORCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *x, rng_int_t *info, complex *work, float *rwork);
extern void RNGSTDCALL CLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_PORPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *work);
extern void RNGSTDCALL CLA_SYAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_SYRCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork);
extern float RNGSTDCALL CLA_SYRCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork);
extern void RNGSTDCALL CLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_SYRPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work);
extern void RNGSTDCALL CLA_WWADDW(rng_int_t *n, complex *x, complex *y, complex *w);
extern float RNGSTDCALL CLANHF(char *norm, rng_strlen_t norm_len, char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, float *work);
extern void RNGSTDCALL CLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL CLARFGP(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void RNGSTDCALL CLARSCL2(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void RNGSTDCALL CLASCL2(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void RNGSTDCALL CPBCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPBEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPBRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPBSTF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL CPBSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPBSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPBTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL CPBTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPFTRF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *info);
extern void RNGSTDCALL CPFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *info);
extern void RNGSTDCALL CPFTRS(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPOCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPOEQU(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPOEQUB(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPORFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPORFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPOSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPOSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPOTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CPOTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CPOTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPPEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *info);
extern void RNGSTDCALL CPPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *info);
extern void RNGSTDCALL CPPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPSTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info);
extern void RNGSTDCALL CPSTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info);
extern void RNGSTDCALL CPTCON(rng_int_t *n, float *d, complex *e, float *anorm, float *rcond, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL CPTRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPTSV(rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPTSVX(char *fact, rng_strlen_t fact_len, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPTTRF(rng_int_t *n, float *d, complex *e, rng_int_t *info);
extern void RNGSTDCALL CPTTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CSPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CSPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CSPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CSTEDC(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CSTEGR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CSTEIN(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, complex *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CSTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL CSYCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSYCONV(char *uplo, rng_strlen_t uplo_len, char *way, rng_strlen_t way_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSYEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSYRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSYRFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSYSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CSYSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSYSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CSYSWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL CSYTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CSYTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info);
extern void RNGSTDCALL CSYTRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CSYTRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL CSYTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CSYTRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info);
extern void RNGSTDCALL CTBCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTBRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTBTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CTFSM(char *transr, rng_strlen_t transr_len, char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CTFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *info);
extern void RNGSTDCALL CTFTTP(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *arf, complex *ap, rng_int_t *info);
extern void RNGSTDCALL CTFTTR(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *arf, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CTGEVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL CTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CTGSJA(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, rng_int_t *ncycle, rng_int_t *info);
extern void RNGSTDCALL CTGSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CTGSYL(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CTPCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *ap, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTPMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info);
extern void RNGSTDCALL CTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void RNGSTDCALL CTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CTPRFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *ldwork);
extern void RNGSTDCALL CTPRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTPTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *ap, rng_int_t *info);
extern void RNGSTDCALL CTPTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CTPTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *arf, rng_int_t *info);
extern void RNGSTDCALL CTPTTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CTRCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *lda, float *rcond, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTREVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTREXC(char *compq, rng_strlen_t compq_len, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL CTRRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTRSEN(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, complex *w, rng_int_t *m, float *s, float *sep, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CTRSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *ldwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CTRSYL(char *trana, rng_strlen_t trana_len, char *tranb, rng_strlen_t tranb_len, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *scale, rng_int_t *info);
extern void RNGSTDCALL CTRTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CTRTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CTRTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *arf, rng_int_t *info);
extern void RNGSTDCALL CTRTTP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *ap, rng_int_t *info);
extern void RNGSTDCALL CTZRQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, rng_int_t *info);
extern void RNGSTDCALL CTZRZF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNBDB(char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, float *phi, complex *taup1, complex *taup2, complex *tauq1, complex *tauq2, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CUNGBR(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMBR(char *vect, rng_strlen_t vect_len, char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMHR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMLQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMQL(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMQR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNMRQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMRZ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUPGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, complex *tau, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUPMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, complex *ap, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL DBBCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DBDSDC(char *uplo, rng_strlen_t uplo_len, char *compq, rng_strlen_t compq_len, rng_int_t *n, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *q, rng_int_t *iq, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DBDSQR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DDISNA(char *job, rng_strlen_t job_len, rng_int_t *m, rng_int_t *n, double *d, double *sep, rng_int_t *info);
extern void RNGSTDCALL DGBBRD(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *pt, rng_int_t *ldpt, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DGBCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGBRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGBRFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGBSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGBSVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGBTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGEBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL DGEBAL(char *job, rng_strlen_t job_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info);
extern void RNGSTDCALL DGEBRD(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGECON(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGEEQU(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGEEQUB(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGEES(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_DGEES_SELECT select, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL DGEESX(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_DGEESX_SELECT select, char *sense, rng_strlen_t sense_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL DGEEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGEGS(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEGV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEJSV(char *joba, rng_strlen_t joba_len, char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobr, rng_strlen_t jobr_len, char *jobt, rng_strlen_t jobt_len, char *jobp, rng_strlen_t jobp_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGELQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGELS(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *info);
extern void RNGSTDCALL DGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQRT2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DGEQRT3(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQLF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQP3(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQPF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQR2P(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQRF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQRFP(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGERFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGERFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGERQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGESDD(char *jobz, rng_strlen_t jobz_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGESV(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGESVD(char *jobu, rng_strlen_t jobu_len, char *jobvt, rng_strlen_t jobvt_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGESVJ(char *joba, rng_strlen_t joba_len, char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGESVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGESVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGETRF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGETRI(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGETRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGGBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL DGGBAL(char *job, rng_strlen_t job_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info);
extern void RNGSTDCALL DGGES(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_DGGES_DELCTG delctg, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL DGGESX(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_DGGESX_DELCTG delctg, char *sense, rng_strlen_t sense_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL DGGEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL DGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *d, double *x, double *y, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGHRD(char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL DGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, double *d, double *x, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGSVD(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGGSVP(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, rng_int_t *iwork, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGSVJ0(char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGSVJ1(char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, rng_int_t *n1, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGTCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGTRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGTSV(rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGTSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGTTRF(rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGTTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DHGEQZ(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DHSEIN(char *side, rng_strlen_t side_len, char *eigsrc, rng_strlen_t eigsrc_len, char *initv, rng_strlen_t initv_len, rng_int_t *select, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGSTDCALL DHSEQR(char *job, rng_strlen_t job_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern rng_int_t RNGSTDCALL DISNAN(double *din);
extern void RNGSTDCALL DLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *ab, rng_int_t *ldab, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_GBRCOND(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork);
extern void RNGSTDCALL DLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb);
extern void RNGSTDCALL DLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_GERCOND(char *trans, rng_strlen_t trans_len, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork);
extern void RNGSTDCALL DLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf);
extern void RNGSTDCALL DLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, double *res, double *ayb, double *berr);
extern double RNGSTDCALL DLA_PORCOND(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork);
extern void RNGSTDCALL DLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_PORPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *work);
extern void RNGSTDCALL DLA_SYAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_SYRCOND(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork);
extern void RNGSTDCALL DLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_SYRPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work);
extern void RNGSTDCALL DLA_WWADDW(rng_int_t *n, double *x, double *y, double *w);
extern double RNGSTDCALL DLAMCH(char *cmach, rng_strlen_t cmach_len);
extern double RNGSTDCALL DLANSF(char *norm, rng_strlen_t norm_len, char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, double *work);
extern void RNGSTDCALL DLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL DLARFGP(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void RNGSTDCALL DLARSCL2(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void RNGSTDCALL DLARTGP(double *f, double *g, double *cs, double *sn, double *r_);
extern void RNGSTDCALL DLARTGS(double *x, double *y, double *sigma, double *cs, double *sn);
extern void RNGSTDCALL DLASCL2(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void RNGSTDCALL DLAT2S(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL DLARFT(char *direct, rng_strlen_t direct_len, char *storev,   rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt);
extern void RNGSTDCALL DLASRT(char *id, rng_strlen_t id_len, rng_int_t *n, double *d, rng_int_t *info);
extern void RNGSTDCALL DLASSQ(rng_int_t *n, double *x, rng_int_t *incx, double *scale, double *sumsq);
extern void RNGSTDCALL DOPGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *tau, double *q, rng_int_t *ldq, double *work, rng_int_t *info);
extern void RNGSTDCALL DOPMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, double *ap, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DORBDB(char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *phi, double *taup1, double *taup2, double *tauq1, double *tauq2, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DORGBR(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMBR(char *vect, rng_strlen_t vect_len, char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMHR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMLQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMQL(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMQR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DORMRQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMRZ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DPBCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPBEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPBRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPBSTF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL DPBSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPBSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, char *equed, rng_strlen_t equed_len, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPBTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL DPBTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPFTRF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *info);
extern void RNGSTDCALL DPFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *info);
extern void RNGSTDCALL DPFTRS(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPOCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPOEQU(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPOEQUB(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPORFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPORFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPOSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPOSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPOTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DPOTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DPOTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPPEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, char *equed, rng_strlen_t equed_len, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DPPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, rng_int_t *info);
extern void RNGSTDCALL DPPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, rng_int_t *info);
extern void RNGSTDCALL DPPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPSTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info);
extern void RNGSTDCALL DPSTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTCON(rng_int_t *n, double *d, double *e, double *anorm, double *rcond, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTRFS(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTSV(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPTSVX(char *fact, rng_strlen_t fact_len, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTTRF(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DPTTRS(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSBEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSBEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSBEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSBGST(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *x, rng_int_t *ldx, double *work, rng_int_t *info);
extern void RNGSTDCALL DSBGV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSBGVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSBGVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSBTRD(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *work, rng_int_t *info);
extern double RNGSTDCALL DSECND(void);
extern void RNGSTDCALL DSFRK(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c);
extern void RNGSTDCALL DSGESV(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL DSPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSPEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSPEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSPEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSPGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *bp, rng_int_t *info);
extern void RNGSTDCALL DSPGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSPGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSPGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL DSPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSPTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *d, double *e, double *tau, rng_int_t *info);
extern void RNGSTDCALL DSPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DSPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, rng_int_t *ipiv, double *work, rng_int_t *info);
extern void RNGSTDCALL DSPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSTEBZ(char *range, rng_strlen_t range_len, char *order, rng_strlen_t order_len, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, double *d, double *e, rng_int_t *m, rng_int_t *nsplit, double *w, rng_int_t *iblock, rng_int_t *isplit, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSTEDC(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSTEGR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSTEIN(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSTEMR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSTERF(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DSTEV(char *jobz, rng_strlen_t jobz_len, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL DSTEVD(char *jobz, rng_strlen_t jobz_len, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSTEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSTEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSYCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSYCONV(char *uplo, rng_strlen_t uplo_len, char *way, rng_strlen_t way_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info);
extern void RNGSTDCALL DSYEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, double *work, rng_int_t *info);
extern void RNGSTDCALL DSYEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSYEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSYEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSYGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSYGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DSYGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSYRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSYRFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSYSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSYSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DSYSWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL DSYTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info);
extern void RNGSTDCALL DSYTRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DSYTRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL DSYTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSYTRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *info);
extern void RNGSTDCALL DTBCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTBRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTBTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DTFSM(char *transr, rng_strlen_t transr_len, char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, double *alpha, double *a, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DTFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *info);
extern void RNGSTDCALL DTFTTP(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *arf, double *ap, rng_int_t *info);
extern void RNGSTDCALL DTFTTR(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *arf, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DTGEVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info);
extern void RNGSTDCALL DTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DTGSJA(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *ncycle, rng_int_t *info);
extern void RNGSTDCALL DTGSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTGSYL(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTPCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *ap, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTPMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *info);
extern void RNGSTDCALL DTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void RNGSTDCALL DTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DTPRFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *ldwork);
extern void RNGSTDCALL DTPRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTPTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *ap, rng_int_t *info);
extern void RNGSTDCALL DTPTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DTPTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *arf, rng_int_t *info);
extern void RNGSTDCALL DTPTTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DTRCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *lda, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTREVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info);
extern void RNGSTDCALL DTREXC(char *compq, rng_strlen_t compq_len, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *info);
extern void RNGSTDCALL DTRRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTRSEN(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, double *wr, double *wi, rng_int_t *m, double *s, double *sep, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DTRSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DTRSYL(char *trana, rng_strlen_t trana_len, char *tranb, rng_strlen_t tranb_len, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *scale, rng_int_t *info);
extern void RNGSTDCALL DTRTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DTRTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DTRTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *arf, rng_int_t *info);
extern void RNGSTDCALL DTRTTP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *ap, rng_int_t *info);
extern void RNGSTDCALL DTZRQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, rng_int_t *info);
extern void RNGSTDCALL DTZRZF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern rng_int_t RNGSTDCALL ILAENV(rng_int_t *ispec, const char *name, rng_strlen_t name_len, const char *opts, rng_strlen_t opts_len, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4);
extern void RNGSTDCALL ILAENVSET(rng_int_t *ispec, const char *name, rng_strlen_t name_len, const char *opts, rng_strlen_t opts_len, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4, rng_int_t *nvalue, rng_int_t *info);
extern void RNGSTDCALL ILAVER(rng_int_t *vers_major, rng_int_t *vers_minor, rng_int_t *vers_patch);
extern rng_int_t RNGSTDCALL ILACLC(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILACLR(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILADIAG(char *diag, rng_strlen_t diag_len);
extern rng_int_t RNGSTDCALL ILADLC(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILADLR(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILAPREC(char *prec, rng_strlen_t prec_len);
extern rng_int_t RNGSTDCALL ILASLC(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILASLR(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILATRANS(char *trans, rng_strlen_t trans_len);
extern rng_int_t RNGSTDCALL ILAUPLO(char *uplo, rng_strlen_t uplo_len);
extern rng_int_t RNGSTDCALL ILAZLC(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILAZLR(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL SBBCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SBDSDC(char *uplo, rng_strlen_t uplo_len, char *compq, rng_strlen_t compq_len, rng_int_t *n, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *q, rng_int_t *iq, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SBDSQR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SDISNA(char *job, rng_strlen_t job_len, rng_int_t *m, rng_int_t *n, float *d, float *sep, rng_int_t *info);
extern float RNGSTDCALL SECOND(void);
extern void RNGSTDCALL SGBBRD(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *pt, rng_int_t *ldpt, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SGBCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGBRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGBRFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGBSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGBSVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGBTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGEBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL SGEBAL(char *job, rng_strlen_t job_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info);
extern void RNGSTDCALL SGEBRD(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGECON(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGEEQU(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGEEQUB(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGEES(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_SGEES_SELECT select, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL SGEESX(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_SGEESX_SELECT select, char *sense, rng_strlen_t sense_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL SGEEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGEGS(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEGV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEJSV(char *joba, rng_strlen_t joba_len, char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobr, rng_strlen_t jobr_len, char *jobt, rng_strlen_t jobt_len, char *jobp, rng_strlen_t jobp_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGELQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGELS(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *info);
extern void RNGSTDCALL SGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQLF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQP3(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQPF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQR2P(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQRF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQRFP(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQRT2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL SGEQRT3(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL SGERFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGERFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGERQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGESDD(char *jobz, rng_strlen_t jobz_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGESV(rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGESVD(char *jobu, rng_strlen_t jobu_len, char *jobvt, rng_strlen_t jobvt_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGESVJ(char *joba, rng_strlen_t joba_len, char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGESVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGESVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGETRF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGETRI(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGETRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGGBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL SGGBAL(char *job, rng_strlen_t job_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info);
extern void RNGSTDCALL SGGES(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_SGGES_SELCTG selctg, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL SGGESX(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_SGGESX_SELCTG selctg, char *sense, rng_strlen_t sense_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL SGGEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL SGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *d, float *x, float *y, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGHRD(char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL SGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, float *d, float *x, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGSVD(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGGSVP(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, rng_int_t *iwork, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGSVJ0(char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGSVJ1(char *jobv, rng_strlen_t jobv_len, rng_int_t *m, rng_int_t *n, rng_int_t *n1, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGTCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGTRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGTSV(rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGTSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGTTRF(rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGTTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SHGEQZ(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SHSEIN(char *side, rng_strlen_t side_len, char *eigsrc, rng_strlen_t eigsrc_len, char *initv, rng_strlen_t initv_len, rng_int_t *select, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGSTDCALL SHSEQR(char *job, rng_strlen_t job_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern rng_int_t RNGSTDCALL SISNAN(float *sin);
extern void RNGSTDCALL SLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *ab, rng_int_t *ldab, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_GBRCOND(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork);
extern void RNGSTDCALL SLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL SLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb);
extern void RNGSTDCALL SLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_GERCOND(char *trans, rng_strlen_t trans_len, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork);
extern void RNGSTDCALL SLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL SLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf);
extern void RNGSTDCALL SLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, float *res, float *ayb, float *berr);
extern double RNGSTDCALL SLA_PORCOND(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork);
extern void RNGSTDCALL SLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL SLA_PORPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *work);
extern void RNGSTDCALL SLA_SYAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_SYRCOND(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork);
extern void RNGSTDCALL SLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL SLA_SYRPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work);
extern void RNGSTDCALL SLA_WWADDW(rng_int_t *n, float *x, float *y, float *w);
extern float RNGSTDCALL SLAMCH(char *cmach, rng_strlen_t cmach_len);
extern float RNGSTDCALL SLANSF(char *norm, rng_strlen_t norm_len, char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, float *work);
extern void RNGSTDCALL SLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL SLARFGP(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void RNGSTDCALL SLARFT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt);
extern void RNGSTDCALL SLARSCL2(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void RNGSTDCALL SLARTGP(float *f, float *g, float *cs, float *sn, float *r_);
extern void RNGSTDCALL SLARTGS(float *x, float *y, float *sigma, float *cs, float *sn);
extern void RNGSTDCALL SLASCL2(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void RNGSTDCALL SLASRT(char *id, rng_strlen_t id_len, rng_int_t *n, float *d, rng_int_t *info);
extern void RNGSTDCALL SLASSQ(rng_int_t *n, float *x, rng_int_t *incx, float *scale, float *sumsq);
extern void RNGSTDCALL SOPGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *tau, float *q, rng_int_t *ldq, float *work, rng_int_t *info);
extern void RNGSTDCALL SOPMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, float *ap, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SORBDB(char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *phi, float *taup1, float *taup2, float *tauq1, float *tauq2, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SORGBR(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMBR(char *vect, rng_strlen_t vect_len, char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMHR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMLQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMQL(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMQR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SORMRQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMRZ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SPBCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPBEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPBRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPBSTF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL SPBSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPBSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, char *equed, rng_strlen_t equed_len, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPBTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL SPBTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPFTRF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *info);
extern void RNGSTDCALL SPFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *info);
extern void RNGSTDCALL SPFTRS(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPOCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPOEQU(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPOEQUB(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPORFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPORFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPOSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPOSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPOTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SPOTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SPOTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPPEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, char *equed, rng_strlen_t equed_len, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SPPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, rng_int_t *info);
extern void RNGSTDCALL SPPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, rng_int_t *info);
extern void RNGSTDCALL SPPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPSTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info);
extern void RNGSTDCALL SPSTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTCON(rng_int_t *n, float *d, float *e, float *anorm, float *rcond, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTRFS(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTSV(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPTSVX(char *fact, rng_strlen_t fact_len, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTTRF(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SPTTRS(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSBEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSBEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSBEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSBGST(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *x, rng_int_t *ldx, float *work, rng_int_t *info);
extern void RNGSTDCALL SSBGV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSBGVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSBGVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSBTRD(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *work, rng_int_t *info);
extern void RNGSTDCALL SSFRK(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c);
extern void RNGSTDCALL SSPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSPEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSPEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSPEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSPGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *bp, rng_int_t *info);
extern void RNGSTDCALL SSPGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSPGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSPGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSPTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *d, float *e, float *tau, rng_int_t *info);
extern void RNGSTDCALL SSPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SSPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, rng_int_t *ipiv, float *work, rng_int_t *info);
extern void RNGSTDCALL SSPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSTEBZ(char *range, rng_strlen_t range_len, char *order, rng_strlen_t order_len, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, float *d, float *e, rng_int_t *m, rng_int_t *nsplit, float *w, rng_int_t *iblock, rng_int_t *isplit, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSTEDC(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSTEGR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSTEIN(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSTERF(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SSTEV(char *jobz, rng_strlen_t jobz_len, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info);
extern void RNGSTDCALL SSTEVD(char *jobz, rng_strlen_t jobz_len, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSTEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSTEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSYCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSYCONV(char *uplo, rng_strlen_t uplo_len, char *way, rng_strlen_t way_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info);
extern void RNGSTDCALL SSYEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, float *work, rng_int_t *info);
extern void RNGSTDCALL SSYEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSYEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSYEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSYGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSYGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL SSYGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSYRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSYRFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSYSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSYSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SSYSWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL SSYTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info);
extern void RNGSTDCALL SSYTRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SSYTRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL SSYTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSYTRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *info);
extern void RNGSTDCALL STBCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STBRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STBTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL STFSM(char *transr, rng_strlen_t transr_len, char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, float *alpha, float *a, float *b, rng_int_t *ldb);
extern void RNGSTDCALL STFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *info);
extern void RNGSTDCALL STFTTP(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *arf, float *ap, rng_int_t *info);
extern void RNGSTDCALL STFTTR(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *arf, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL STGEVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info);
extern void RNGSTDCALL STGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL STGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL STGSJA(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *ncycle, rng_int_t *info);
extern void RNGSTDCALL STGSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STGSYL(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STPCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *ap, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STPMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *info);
extern void RNGSTDCALL STPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void RNGSTDCALL STPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL STPRFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *ldwork);
extern void RNGSTDCALL STPRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STPTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *ap, rng_int_t *info);
extern void RNGSTDCALL STPTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL STPTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *arf, rng_int_t *info);
extern void RNGSTDCALL STPTTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL STRCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *lda, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STREVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info);
extern void RNGSTDCALL STREXC(char *compq, rng_strlen_t compq_len, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *info);
extern void RNGSTDCALL STRRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STRSEN(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, float *wr, float *wi, rng_int_t *m, float *s, float *sep, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL STRSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL STRSYL(char *trana, rng_strlen_t trana_len, char *tranb, rng_strlen_t tranb_len, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *scale, rng_int_t *info);
extern void RNGSTDCALL STRTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL STRTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL STRTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *arf, rng_int_t *info);
extern void RNGSTDCALL STRTTP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *ap, rng_int_t *info);
extern void RNGSTDCALL STZRQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, rng_int_t *info);
extern void RNGSTDCALL STZRZF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL XERBLA_ARRAY(char *srname_array, rng_strlen_t srname_array_len, rng_int_t *srname_len, rng_int_t *info);
extern void RNGSTDCALL ZBBCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *rwork, rng_int_t *lrwork, rng_int_t *info);
extern void RNGSTDCALL ZBDSQR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *u, rng_int_t *ldu, doublecomplex *c, rng_int_t *ldc, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZCGESV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL ZCPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, double *rwork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL ZGBBRD(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *pt, rng_int_t *ldpt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGBRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBRFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGBSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBSVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGBTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGEBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL ZGEBAL(char *job, rng_strlen_t job_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info);
extern void RNGSTDCALL ZGEBRD(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGECON(char *norm, rng_strlen_t norm_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEEQU(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGEEQUB(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGEES(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_ZGEES_SELECT select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL ZGEESX(char *jobvs, rng_strlen_t jobvs_len, char *sort, rng_strlen_t sort_len, RNG_ZGEESX_SELECT select, char *sense, rng_strlen_t sense_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL ZGEEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEGS(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEGV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGELQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGELS(char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQLF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQP3(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQPF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQR2P(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQRF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQRFP(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT3(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZGERFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGERFSX(char *trans, rng_strlen_t trans_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGERQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGESDD(char *jobz, rng_strlen_t jobz_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZGESV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGESVD(char *jobu, rng_strlen_t jobu_len, char *jobvt, rng_strlen_t jobvt_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGESVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGESVXX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGETRF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGETRI(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGETRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGGBAK(char *job, rng_strlen_t job_len, char *side, rng_strlen_t side_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info);
extern void RNGSTDCALL ZGGBAL(char *job, rng_strlen_t job_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info);
extern void RNGSTDCALL ZGGES(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_ZGGES_DELCTG delctg, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL ZGGESX(char *jobvsl, rng_strlen_t jobvsl_len, char *jobvsr, rng_strlen_t jobvsr_len, char *sort, rng_strlen_t sort_len, RNG_ZGGESX_DELCTG delctg, char *sense, rng_strlen_t sense_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL ZGGEV(char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGGEVX(char *balanc, rng_strlen_t balanc_len, char *jobvl, rng_strlen_t jobvl_len, char *jobvr, rng_strlen_t jobvr_len, char *sense, rng_strlen_t sense_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info);
extern void RNGSTDCALL ZGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *d, doublecomplex *x, doublecomplex *y, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGHRD(char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL ZGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, doublecomplex *d, doublecomplex *x, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGSVD(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZGGSVP(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, rng_int_t *iwork, double *rwork, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGTCON(char *norm, rng_strlen_t norm_len, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGTRFS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGTSV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGTSVX(char *fact, rng_strlen_t fact_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGTTRF(rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGTTRS(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHBEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHBEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHBEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHBGST(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHBGV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHBGVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHBGVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHBTRD(char *vect, rng_strlen_t vect_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHECON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHEEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHEEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHEEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHEEVR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHEEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHEGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHEGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHEGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHEGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHERFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHERFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHESV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZHESVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHESVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHESWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL ZHETRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZHETRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZHETRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHETRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZHETRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL ZHETRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHETRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHFRK(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c);
extern void RNGSTDCALL ZHGEQZ(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHPEV(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHPEVD(char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHPEVX(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHPGST(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, rng_int_t *info);
extern void RNGSTDCALL ZHPGV(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHPGVD(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZHPGVX(rng_int_t *itype, char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZHPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZHPTRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *d, double *e, doublecomplex *tau, rng_int_t *info);
extern void RNGSTDCALL ZHPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZHPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZHPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHSEIN(char *side, rng_strlen_t side_len, char *eigsrc, rng_strlen_t eigsrc_len, char *initv, rng_strlen_t initv_len, rng_int_t *select, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info);
extern void RNGSTDCALL ZHSEQR(char *job, rng_strlen_t job_len, char *compz, rng_strlen_t compz_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_GBRCOND_C(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork);
extern double RNGSTDCALL ZLA_GBRCOND_X(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork);
extern void RNGSTDCALL ZLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb);
extern void RNGSTDCALL ZLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_GERCOND_C(char *trans, rng_strlen_t trans_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork);
extern double RNGSTDCALL ZLA_GERCOND_X(char *trans, rng_strlen_t trans_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork);
extern void RNGSTDCALL ZLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf);
extern void RNGSTDCALL ZLA_HEAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_HERCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork);
extern double RNGSTDCALL ZLA_HERCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork);
extern void RNGSTDCALL ZLA_HERFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_HERPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work);
extern void RNGSTDCALL ZLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, doublecomplex *res, double *ayb, double *berr);
extern double RNGSTDCALL ZLA_PORCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork);
extern double RNGSTDCALL ZLA_PORCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork);
extern void RNGSTDCALL ZLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_PORPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *work);
extern void RNGSTDCALL ZLA_SYAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_SYRCOND_C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork);
extern double RNGSTDCALL ZLA_SYRCOND_X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork);
extern void RNGSTDCALL ZLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_SYRPVGRW(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work);
extern void RNGSTDCALL ZLA_WWADDW(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *w);
extern double RNGSTDCALL ZLANHF(char *norm, rng_strlen_t norm_len, char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, double *work);
extern void RNGSTDCALL ZLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL ZLARFGP(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void RNGSTDCALL ZLARSCL2(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void RNGSTDCALL ZLASCL2(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void RNGSTDCALL ZLAT2C(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL ZPBCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPBEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPBRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPBSTF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL ZPBSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPBSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPBTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL ZPBTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPFTRF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *info);
extern void RNGSTDCALL ZPFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *info);
extern void RNGSTDCALL ZPFTRS(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPOCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPOEQU(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPOEQUB(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPORFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPORFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPOSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPOSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPOSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPOTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZPOTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZPOTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPPEQU(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *info);
extern void RNGSTDCALL ZPPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *info);
extern void RNGSTDCALL ZPPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPSTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info);
extern void RNGSTDCALL ZPSTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info);
extern void RNGSTDCALL ZPTCON(rng_int_t *n, double *d, doublecomplex *e, double *anorm, double *rcond, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL ZPTRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPTSV(rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPTSVX(char *fact, rng_strlen_t fact_len, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPTTRF(rng_int_t *n, double *d, doublecomplex *e, rng_int_t *info);
extern void RNGSTDCALL ZPTTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZSPCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSPRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSPSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZSPSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSPTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZSPTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSPTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZSTEDC(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZSTEGR(char *jobz, rng_strlen_t jobz_len, char *range, rng_strlen_t range_len, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZSTEIN(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZSTEQR(char *compz, rng_strlen_t compz_len, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info);
extern void RNGSTDCALL ZSYCON(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSYCONV(char *uplo, rng_strlen_t uplo_len, char *way, rng_strlen_t way_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSYEQUB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSYRFS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSYRFSX(char *uplo, rng_strlen_t uplo_len, char *equed, rng_strlen_t equed_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSYSV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZSYSVX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSYSVXX(char *fact, rng_strlen_t fact_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, rng_strlen_t equed_len, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZSYSWAPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *i1, rng_int_t *i2);
extern void RNGSTDCALL ZSYTRF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZSYTRI(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZSYTRI2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZSYTRI2X(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info);
extern void RNGSTDCALL ZSYTRS(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZSYTRS2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZTBCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTBRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTBTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZTFSM(char *transr, rng_strlen_t transr_len, char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZTFTRI(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *info);
extern void RNGSTDCALL ZTFTTP(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *arf, doublecomplex *ap, rng_int_t *info);
extern void RNGSTDCALL ZTFTTR(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *arf, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZTGEVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL ZTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZTGSJA(char *jobu, rng_strlen_t jobu_len, char *jobv, rng_strlen_t jobv_len, char *jobq, rng_strlen_t jobq_len, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *ncycle, rng_int_t *info);
extern void RNGSTDCALL ZTGSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZTGSYL(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZTPCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *ap, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTPMQRT(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZTPRFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *ldwork);
extern void RNGSTDCALL ZTPRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTPTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *ap, rng_int_t *info);
extern void RNGSTDCALL ZTPTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZTPTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *arf, rng_int_t *info);
extern void RNGSTDCALL ZTPTTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZTRCON(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTREVC(char *side, rng_strlen_t side_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTREXC(char *compq, rng_strlen_t compq_len, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL ZTRRFS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTRSEN(char *job, rng_strlen_t job_len, char *compq, rng_strlen_t compq_len, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, doublecomplex *w, rng_int_t *m, double *s, double *sep, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZTRSNA(char *job, rng_strlen_t job_len, char *howmny, rng_strlen_t howmny_len, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *ldwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZTRSYL(char *trana, rng_strlen_t trana_len, char *tranb, rng_strlen_t tranb_len, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *scale, rng_int_t *info);
extern void RNGSTDCALL ZTRTRI(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZTRTRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZTRTTF(char *transr, rng_strlen_t transr_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *arf, rng_int_t *info);
extern void RNGSTDCALL ZTRTTP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *ap, rng_int_t *info);
extern void RNGSTDCALL ZTZRQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, rng_int_t *info);
extern void RNGSTDCALL ZTZRZF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNBDB(char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, double *phi, doublecomplex *taup1, doublecomplex *taup2, doublecomplex *tauq1, doublecomplex *tauq2, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNCSD(char *jobu1, rng_strlen_t jobu1_len, char *jobu2, rng_strlen_t jobu2_len, char *jobv1t, rng_strlen_t jobv1t_len, char *jobv2t, rng_strlen_t jobv2t_len, char *trans, rng_strlen_t trans_len, char *signs, rng_strlen_t signs_len, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGBR(char *vect, rng_strlen_t vect_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMBR(char *vect, rng_strlen_t vect_len, char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMHR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMLQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMQL(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMQR(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNMRQ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMRZ(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUPGTR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUPMTR(char *side, rng_strlen_t side_len, char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);

/* LAPACK auxiliary routines */
extern void RNGSTDCALL CGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGEBD2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGELQ2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQL2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQR2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGERQ2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGESC2(rng_int_t *n, complex *a, rng_int_t *lda, complex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGSTDCALL CGETC2(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL CGETF2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CHEGS2(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CHETD2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, rng_int_t *info);
extern void RNGSTDCALL CHETF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *x, rng_int_t *ldx, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLACGV(rng_int_t *n, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CLACN2(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL CLACON(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase);
extern void RNGSTDCALL CLACP2(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CLACPY(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CLACRM(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void RNGSTDCALL CLACRT(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, complex *c, complex *s);
extern complex RNGSTDCALL CLADIV(complex *ret_val, complex *x, complex *y);

extern void RNGSTDCALL CLAED0(rng_int_t *qsiz, rng_int_t *n, float *d, float *e, complex *q, rng_int_t *ldq, complex *qstore, rng_int_t *ldqs, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLAED7(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, complex *q, rng_int_t *ldq, float *rho, rng_int_t *indxq, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLAED8(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, complex *q, rng_int_t *ldq, float *d, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, complex *q2, rng_int_t *ldq2, float *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void RNGSTDCALL CLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *v, complex *b, rng_int_t *ldb, float *rwork, float *eps3, float *smlnum, rng_int_t *info);
extern void RNGSTDCALL CLAESY(complex *a, complex *b, complex *c, complex *rt1, complex *rt2, complex *evscal, complex *cs1, complex *sn1);
extern void RNGSTDCALL CLAEV2(complex *a, complex *b, complex *c, float *rt1, float *rt2, float *cs1, complex *sn1);
extern void RNGSTDCALL CLAG2Z(rng_int_t *m, rng_int_t *n, complex *sa, rng_int_t *ldsa, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CLAGS2(rng_int_t *upper, float *a1, complex *a2, float *a3, float *b1, complex *b2, float *b3, float *csu, complex *snu, float *csv, complex *snv, float *csq, complex *snq);
extern void RNGSTDCALL CLAGTM(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *alpha, complex *dl, complex *d, complex *du, complex *x, rng_int_t *ldx, float *beta, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CLAHEF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL CLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL CLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLAIC1(rng_int_t *job, rng_int_t *j, complex *x, float *sest, complex *w, complex *gamma, float *sestpr, complex *s, complex *c);
extern void RNGSTDCALL CLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLALSD(char *uplo, rng_strlen_t uplo_len, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, complex *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern float RNGSTDCALL CLANGB(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL CLANGE(char *norm, rng_strlen_t norm_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL CLANGT(char *norm, rng_strlen_t norm_len, rng_int_t *n, complex *dl, complex *d, complex *du);
extern float RNGSTDCALL CLANHB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL CLANHE(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL CLANHP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *work);
extern float RNGSTDCALL CLANHS(char *norm, rng_strlen_t norm_len, rng_int_t *n, complex *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL CLANHT(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *d, complex *e);
extern float RNGSTDCALL CLANSB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL CLANSP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *work);
extern float RNGSTDCALL CLANSY(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL CLANTB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL CLANTP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *ap, float *work);
extern float RNGSTDCALL CLANTR(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work);
extern void RNGSTDCALL CLAPLL(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *ssmin);
extern void RNGSTDCALL CLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL CLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQGE(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHE(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *work);
extern void RNGSTDCALL CLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *auxv, complex *f, rng_int_t *ldf);
extern void RNGSTDCALL CLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CLAQR1(rng_int_t *n, complex *h, rng_int_t *ldh, complex *s1, complex *s2, complex *v);
extern void RNGSTDCALL CLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void RNGSTDCALL CLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void RNGSTDCALL CLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, complex *s, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *v, rng_int_t *ldv, complex *u, rng_int_t *ldu, rng_int_t *nv, complex *wv, rng_int_t *ldwv, rng_int_t *nh, complex *wh, rng_int_t *ldwh);
extern void RNGSTDCALL CLAQSB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQSP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQSY(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, complex *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void RNGSTDCALL CLAR2V(rng_int_t *n, complex *x, complex *y, complex *z, rng_int_t *incx, float *c, complex *s, rng_int_t *incc);
extern void RNGSTDCALL CLARCM(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void RNGSTDCALL CLARFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork);
extern void RNGSTDCALL CLARF(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work);
extern void RNGSTDCALL CLARFG(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void RNGSTDCALL CLARFT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt);
extern void RNGSTDCALL CLARFX(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, complex *v, complex *tau, complex *c, rng_int_t *ldc, complex *work);
extern void RNGSTDCALL CLARGV(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void RNGSTDCALL CLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, complex *x);
extern void RNGSTDCALL CLARRV(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLARTG(complex *f, complex *g, float *cs, complex *sn, complex *r);
extern void RNGSTDCALL CLARTV(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, complex *s, rng_int_t *incc);
extern void RNGSTDCALL CLARZB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork);
extern void RNGSTDCALL CLARZ(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work);
extern void RNGSTDCALL CLARZT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt);
extern void RNGSTDCALL CLASCL(char *type, rng_strlen_t type_len, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CLASET(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, complex *alpha, complex *beta, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CLASR(char *side, rng_strlen_t side_len, char *pivot, rng_strlen_t pivot_len, char *direct, rng_strlen_t direct_len, rng_int_t *m, rng_int_t *n, float *c, float *s, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CLASWP(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL CLASYF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL CLATBS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL CLATDF(rng_int_t *ijob, rng_int_t *n, complex *z, rng_int_t *ldz, complex *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL CLATPS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, complex *ap, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL CLATRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *e, complex *tau, complex *w, rng_int_t *ldw);
extern void RNGSTDCALL CLATRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL CLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *work);
extern void RNGSTDCALL CLATZM(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c1, complex *c2, rng_int_t *ldc, complex *work);
extern void RNGSTDCALL CLAUU2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CLAUUM(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CPBTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL CPOTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CPTTS2(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CROT(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, float *c, complex *s);
extern void RNGSTDCALL CSPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *ap, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CSPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *ap);
extern void RNGSTDCALL CSRSCL(rng_int_t *n, float *sa, complex *sx, rng_int_t *incx);
extern void RNGSTDCALL CSYMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CSYR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CSYTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void RNGSTDCALL CTGSY2(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *info);
extern void RNGSTDCALL CTRTI2(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CUNG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNM2L(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNM2R(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNML2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNMR2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info);
extern void RNGSTDCALL DGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGEBD2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGELQ2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQL2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQR2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGERQ2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGESC2(rng_int_t *n, double *a, rng_int_t *lda, double *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGSTDCALL DGETC2(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL DGETF2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DLABAD(double *small, double *large);
extern void RNGSTDCALL DLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *x, rng_int_t *ldx, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLACN2(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL DLACON(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase);
extern void RNGSTDCALL DLACPY(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DLADIV(double *a, double *b, double *c, double *d, double *p, double *q);
extern void RNGSTDCALL DLAE2(double *a, double *b, double *c, double *rt1, double *rt2);
extern void RNGSTDCALL DLAEBZ(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, double *abstol, double *reltol, double *pivmin, double *d, double *e, double *e2, rng_int_t *nval, double *ab, double *c, rng_int_t *mout, rng_int_t *nab, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED0(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, double *d, double *e, double *q, rng_int_t *ldq, double *qstore, rng_int_t *ldqs, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED1(rng_int_t *n, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED2(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, double *z, double *dlamda, double *w, double *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL DLAED3(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *q2, rng_int_t *indx, rng_int_t *ctot, double *w, double *s, rng_int_t *info);
extern void RNGSTDCALL DLAED4(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam, rng_int_t *info);
extern void RNGSTDCALL DLAED5(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam);
extern void RNGSTDCALL DLAED6(rng_int_t *kniter, rng_int_t *orgati, double *rho, double *d, double *z, double *finit, double *tau, rng_int_t *info);
extern void RNGSTDCALL DLAED7(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED8(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, double *q2, rng_int_t *ldq2, double *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGSTDCALL DLAED9(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *w, double *s, rng_int_t *lds, rng_int_t *info);
extern void RNGSTDCALL DLAEDA(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *q, rng_int_t *qptr, double *z, double *ztemp, rng_int_t *info);
extern void RNGSTDCALL DLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vr, double *vi, double *b, rng_int_t *ldb, double *work, double *eps3, double *smlnum, double *bignum, rng_int_t *info);
extern void RNGSTDCALL DLAEV2(double *a, double *b, double *c, double *rt1, double *rt2, double *cs1, double *sn1);
extern void RNGSTDCALL DLAEXC(rng_int_t *wantq, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *info);
extern void RNGSTDCALL DLAG2(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *safmin, double *scale1, double *scale2, double *wr1, double *wr2, double *wi);
extern void RNGSTDCALL DLAG2S(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL DLAGS2(rng_int_t *upper, double *a1, double *a2, double *a3, double *b1, double *b2, double *b3, double *csu, double *snu, double *csv, double *snv, double *csq, double *snq);
extern void RNGSTDCALL DLAGTF(rng_int_t *n, double *a, double *lambda, double *b, double *c, double *tol, double *d, rng_int_t *in, rng_int_t *info);
extern void RNGSTDCALL DLAGTM(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *alpha, double *dl, double *d, double *du, double *x, rng_int_t *ldx, double *beta, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DLAGTS(rng_int_t *job, rng_int_t *n, double *a, double *b, double *c, double *d, rng_int_t *in, double *y, double *tol, rng_int_t *info);
extern void RNGSTDCALL DLAGV2(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *csl, double *snl, double *csr, double *snr);
extern void RNGSTDCALL DLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL DLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLAIC1(rng_int_t *job, rng_int_t *j, double *x, double *sest, double *w, double *gamma, double *sestpr, double *s, double *c);
extern rng_int_t RNGSTDCALL DLAISNAN(double *din1, double *din2);
extern void RNGSTDCALL DLALN2(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, double *smin, double *ca, double *a, rng_int_t *lda, double *d1, double *d2, double *b, rng_int_t *ldb, double *wr, double *wi, double *x, rng_int_t *ldx, double *scale, double *xnorm, rng_int_t *info);
extern void RNGSTDCALL DLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *info);
extern void RNGSTDCALL DLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLALSD(char *uplo, rng_strlen_t uplo_len, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAMRG(rng_int_t *n1, rng_int_t *n2, double *a, rng_int_t *dtrd1, rng_int_t *dtrd2, rng_int_t *index);
extern rng_int_t RNGSTDCALL DLANEG(rng_int_t *n, double *d, double *lld, double *sigma, double *pivmin, rng_int_t *r);
extern double RNGSTDCALL DLANGB(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL DLANGE(char *norm, rng_strlen_t norm_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL DLANGT(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *dl, double *d, double *du);
extern double RNGSTDCALL DLANHS(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL DLANSB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL DLANSP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *work);
extern double RNGSTDCALL DLANST(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *d, double *e);
extern double RNGSTDCALL DLANSY(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL DLANTB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL DLANTP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *ap, double *work);
extern double RNGSTDCALL DLANTR(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work);
extern void RNGSTDCALL DLANV2(double *a, double *b, double *c, double *d, double *rt1r, double *rt1i, double *rt2r, double *rt2i, double *cs, double *sn);
extern void RNGSTDCALL DLAPLL(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ssmin);
extern void RNGSTDCALL DLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern double RNGSTDCALL DLAPY2(double *x, double *y);
extern double RNGSTDCALL DLAPY3(double *x, double *y, double *z);
extern void RNGSTDCALL DLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQGE(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *work);
extern void RNGSTDCALL DLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *auxv, double *f, rng_int_t *ldf);
extern void RNGSTDCALL DLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DLAQR1(rng_int_t *n, double *h, rng_int_t *ldh, double *sr1, double *si1, double *sr2, double *si2, double *v);
extern void RNGSTDCALL DLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double *v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t *nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void RNGSTDCALL DLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t * ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double * v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t * nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void RNGSTDCALL DLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, double *sr, double *si, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *v, rng_int_t *ldv, double *u, rng_int_t *ldu, rng_int_t *nv, double *wv, rng_int_t *ldwv, rng_int_t *nh, double *wh, rng_int_t *ldwh);
extern void RNGSTDCALL DLAQSB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQSP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQSY(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQTR(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, double *t, rng_int_t *ldt, double *b, double *w, double *scale, double *x, double *work, rng_int_t *info);
extern void RNGSTDCALL DLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, double *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void RNGSTDCALL DLAR2V(rng_int_t *n, double *x, double *y, double *z, rng_int_t *incx, double *c, double *s, rng_int_t *incc);
extern void RNGSTDCALL DLARFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork);
extern void RNGSTDCALL DLARF(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work);
extern void RNGSTDCALL DLARFG(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void RNGSTDCALL DLARFX(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, double *v, double *tau, double *c, rng_int_t *ldc, double *work);
extern void RNGSTDCALL DLARGV(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void RNGSTDCALL DLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, double *x);
extern void RNGSTDCALL DLARRA(rng_int_t *n, double *d, double *e, double *e2, double *spltol, double *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGSTDCALL DLARRB(rng_int_t *n, double *d, double *lld, rng_int_t *ifirst, rng_int_t *ilast, double *rtol1, double *rtol2, rng_int_t *offset, double *w, double *wgap, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *twist, rng_int_t *info);
extern void RNGSTDCALL DLARRC(char *jobt, rng_strlen_t jobt_len, rng_int_t *n, double *vl, double *vu, double *d, double *e, double *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info);
extern void RNGSTDCALL DLARRD(char *range, rng_strlen_t range_len, char *order, rng_strlen_t order_len, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *gers, double *reltol, double *d, double *e, double *e2, double *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wl, double *wu, rng_int_t *iblock, rng_int_t *indexw, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLARRE(char *range, rng_strlen_t range_len, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *d, double *e, double *e2, double *rtol1, double *rtol2, double *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *pivmin, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLARRF(rng_int_t *n, double *d, double *l, double *ld, rng_int_t *clstrt, rng_int_t *clend, double *w, double *wgap, double *werr, double *spdiam, double *clgapl, double *clgapr, double *pivmin, double *sigma, double *dplus, double *lplus, double *work, rng_int_t *info);
extern void RNGSTDCALL DLARRJ(rng_int_t *n, double *d, double *e2, rng_int_t *ifirst, rng_int_t *ilast, double *rtol, rng_int_t *offset, double *w, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *info);
extern void RNGSTDCALL DLARRK(rng_int_t *n, rng_int_t *iw, double *gl, double *gu, double *d, double *e2, double *pivmin, double *reltol, double *w, double *werr, rng_int_t *info);
extern void RNGSTDCALL DLARRR(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DLARRV(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLARTG(double *f, double *g, double *cs, double *sn, double *r);
extern void RNGSTDCALL DLARTV(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s, rng_int_t *incc);
extern void RNGSTDCALL DLARUV(rng_int_t *iseed, rng_int_t *n, double *x);
extern void RNGSTDCALL DLARZB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork);
extern void RNGSTDCALL DLARZ(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, rng_int_t *l, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work);
extern void RNGSTDCALL DLARZT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt);
extern void RNGSTDCALL DLAS2(double *f, double *g, double *h, double *ssmin, double *ssmax);
extern void RNGSTDCALL DLASCL(char *type, rng_strlen_t type_len, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DLASD0(rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD1(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD2(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *dsigma, double *u2, rng_int_t *ldu2, double *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL DLASD3(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *q, rng_int_t *ldq, double *dsigma, double *u, rng_int_t *ldu, double *u2, rng_int_t *ldu2, double *vt, rng_int_t *ldvt, double *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, double *z, rng_int_t *info);
extern void RNGSTDCALL DLASD4(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *sigma, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD5(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dsigma, double *work);
extern void RNGSTDCALL DLASD6(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *vf, double *vl, double *alpha, double *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLASD7(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *zw, double *vf, double *vfw, double *vl, double *vlw, double *alpha, double *beta, double *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *c, double *s, rng_int_t *info);
extern void RNGSTDCALL DLASD8(rng_int_t *icompq, rng_int_t *k, double *d, double *z, double *vf, double *vl, double *difl, double *difr, rng_int_t *lddifr, double *dsigma, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASDA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLASDQ(char *uplo, rng_strlen_t uplo_len, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASDT(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void RNGSTDCALL DLASET(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, double *alpha, double *beta, double *a, rng_int_t *lda);
extern void RNGSTDCALL DLASQ1(rng_int_t *n, double *d, double *e, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASQ2(rng_int_t *n, double *z, rng_int_t *info);
extern void RNGSTDCALL DLASQ3(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *sigma, double *desig, double *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *g, double *tau);
extern void RNGSTDCALL DLASQ4(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, rng_int_t *n0in, double *dmin, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *tau, rng_int_t *ttype, double *g);
extern void RNGSTDCALL DLASQ5(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *tau, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2, rng_int_t *ieee);
extern void RNGSTDCALL DLASQ6(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2);
extern void RNGSTDCALL DLASR(char *side, rng_strlen_t side_len, char *pivot, rng_strlen_t pivot_len, char *direct, rng_strlen_t direct_len, rng_int_t *m, rng_int_t *n, double *c, double *s, double *a, rng_int_t *lda);
extern void RNGSTDCALL DLASV2(double *f, double *g, double *h, double *ssmin, double *ssmax, double *snr, double *csr, double *snl, double *csl);
extern void RNGSTDCALL DLASWP(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL DLASY2(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, double *tl, rng_int_t *ldtl, double *tr, rng_int_t *ldtr, double *b, rng_int_t *ldb, double *scale, double *x, rng_int_t *ldx, double *xnorm, rng_int_t *info);
extern void RNGSTDCALL DLASYF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *ipiv, double *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL DLATBS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL DLATDF(rng_int_t *ijob, rng_int_t *n, double *z, rng_int_t *ldz, double *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL DLATPS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, double *ap, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL DLATRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *e, double *tau, double *w, rng_int_t *ldw);
extern void RNGSTDCALL DLATRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, double *a, rng_int_t *lda, double *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL DLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *work);
extern void RNGSTDCALL DLATZM(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c1, double *c2, rng_int_t *ldc, double *work);
extern void RNGSTDCALL DLAUU2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DLAUUM(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DORG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORM2L(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DORM2R(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DORML2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DORMR2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info);
extern void RNGSTDCALL DPBTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL DPOTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL DPTTS2(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DRSCL(rng_int_t *n, double *sa, double *sx, rng_int_t *incx);
extern void RNGSTDCALL DSYGS2(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSYTD2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, rng_int_t *info);
extern void RNGSTDCALL DSYTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DTGSY2(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info);
extern void RNGSTDCALL DTRTI2(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info);
extern double RNGSTDCALL DZSUM1(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ICMAX1(rng_int_t *n, complex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IEEECK(rng_int_t *ispec, float *zero, float *one);
extern rng_int_t RNGSTDCALL IPARMQ(rng_int_t *ispec, char *name, rng_strlen_t name_len, char *opts, rng_strlen_t opts_len, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, rng_int_t *lwork);
extern rng_int_t RNGSTDCALL IZMAX1(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL LSAMEN(rng_int_t *n, char *ca, rng_strlen_t ca_len, char *cb, rng_strlen_t cb_len);
extern float RNGSTDCALL SCSUM1(rng_int_t *n, complex *cx, rng_int_t *incx);
extern void RNGSTDCALL SGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGEBD2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGELQ2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQL2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQR2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGERQ2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGESC2(rng_int_t *n, float *a, rng_int_t *lda, float *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGSTDCALL SGETC2(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL SGETF2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SLABAD(float *small, float *large);
extern void RNGSTDCALL SLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *x, rng_int_t *ldx, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLACN2(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL SLACON(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase);
extern void RNGSTDCALL SLACPY(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SLADIV(float *a, float *b, float *c, float *d, float *p, float *q);
extern void RNGSTDCALL SLAE2(float *a, float *b, float *c, float *rt1, float *rt2);
extern void RNGSTDCALL SLAEBZ(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, float *abstol, float *reltol, float *pivmin, float *d, float *e, float *e2, rng_int_t *nval, float *ab, float *c, rng_int_t *mout, rng_int_t *nab, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED0(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, float *d, float *e, float *q, rng_int_t *ldq, float *qstore, rng_int_t *ldqs, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED1(rng_int_t *n, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *work, rng_int_t * iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED2(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, float *z, float *dlamda, float *w, float *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL SLAED3(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *q2, rng_int_t *indx, rng_int_t *ctot, float *w, float *s, rng_int_t *info);
extern void RNGSTDCALL SLAED4(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam, rng_int_t *info);
extern void RNGSTDCALL SLAED5(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam);
extern void RNGSTDCALL SLAED6(rng_int_t *kniter, rng_int_t *orgati, float *rho, float *d, float *z, float *finit, float *tau, rng_int_t *info);
extern void RNGSTDCALL SLAED7(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED8(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, float *q2, rng_int_t *ldq2, float *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGSTDCALL SLAED9(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *w, float *s, rng_int_t *lds, rng_int_t *info);
extern void RNGSTDCALL SLAEDA(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *q, rng_int_t *qptr, float *z, float *ztemp, rng_int_t *info);
extern void RNGSTDCALL SLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vr, float *vi, float *b, rng_int_t *ldb, float *work, float *eps3, float *smlnum, float *bignum, rng_int_t *info);
extern void RNGSTDCALL SLAEV2(float *a, float *b, float *c, float *rt1, float *rt2, float *cs1, float *sn1);
extern void RNGSTDCALL SLAEXC(rng_int_t *wantq, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *info);
extern void RNGSTDCALL SLAG2D(rng_int_t *m, rng_int_t *n, float *sa, rng_int_t *ldsa, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SLAG2(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *safmin, float *scale1, float *scale2, float *wr1, float *wr2, float *wi);
extern void RNGSTDCALL SLAGS2(rng_int_t *upper, float *a1, float *a2, float *a3, float *b1, float *b2, float *b3, float *csu, float *snu, float *csv, float *snv, float *csq, float *snq);
extern void RNGSTDCALL SLAGTF(rng_int_t *n, float *a, float *lambda, float *b, float *c, float *tol, float *d, rng_int_t *in, rng_int_t *info);
extern void RNGSTDCALL SLAGTM(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, float *alpha, float *dl, float *d, float *du, float *x, rng_int_t *ldx, float *beta, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SLAGTS(rng_int_t *job, rng_int_t *n, float *a, float *b, float *c, float *d, rng_int_t *in, float *y, float *tol, rng_int_t *info);
extern void RNGSTDCALL SLAGV2(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *csl, float *snl, float *csr, float *snr);
extern void RNGSTDCALL SLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL SLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLAIC1(rng_int_t *job, rng_int_t *j, float *x, float *sest, float *w, float *gamma, float *sestpr, float *s, float *c);
extern rng_int_t RNGSTDCALL SLAISNAN(float *sin1, float *sin2);
extern void RNGSTDCALL SLALN2(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, float *smin, float *ca, float *a, rng_int_t *lda, float *d1, float *d2, float *b, rng_int_t *ldb, float *wr, float *wi, float *x, rng_int_t *ldx, float *scale, float *xnorm, rng_int_t *info);
extern void RNGSTDCALL SLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *info);
extern void RNGSTDCALL SLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLALSD(char *uplo, rng_strlen_t uplo_len, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAMRG(rng_int_t *n1, rng_int_t *n2, float *a, rng_int_t *strd1, rng_int_t *strd2, rng_int_t *index);
extern rng_int_t RNGSTDCALL SLANEG(rng_int_t *n, float *d, float *lld, float *sigma, float *pivmin, rng_int_t *r);
extern float RNGSTDCALL SLANGB(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL SLANGE(char *norm, rng_strlen_t norm_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL SLANGT(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *dl, float *d, float *du);
extern float RNGSTDCALL SLANHS(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL SLANSB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL SLANSP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *work);
extern float RNGSTDCALL SLANST(char *norm, rng_strlen_t norm_len, rng_int_t *n, float *d, float *e);
extern float RNGSTDCALL SLANSY(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *work);
extern float RNGSTDCALL SLANTB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work);
extern float RNGSTDCALL SLANTP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *ap, float *work);
extern float RNGSTDCALL SLANTR(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work);
extern void RNGSTDCALL SLANV2(float *a, float *b, float *c, float *d, float *rt1r, float *rt1i, float *rt2r, float *rt2i, float *cs, float *sn);
extern void RNGSTDCALL SLAPLL(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ssmin);
extern void RNGSTDCALL SLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern float RNGSTDCALL SLAPY2(float *x, float *y);
extern float RNGSTDCALL SLAPY3(float *x, float *y, float *z);
extern void RNGSTDCALL SLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQGE(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *work);
extern void RNGSTDCALL SLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *auxv, float *f, rng_int_t *ldf);
extern void RNGSTDCALL SLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SLAQR1(rng_int_t *n, float *h, rng_int_t *ldh, float *sr1, float *si1, float *sr2, float *si2, float *v);
extern void RNGSTDCALL SLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float *work, rng_int_t *lwork);
extern void RNGSTDCALL SLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float * work, rng_int_t *lwork);
extern void RNGSTDCALL SLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, float *sr, float *si, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *v, rng_int_t *ldv, float *u, rng_int_t *ldu, rng_int_t *nv, float *wv, rng_int_t *ldwv, rng_int_t *nh, float *wh, rng_int_t *ldwh);
extern void RNGSTDCALL SLAQSB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQSP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQSY(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQTR(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, float *t, rng_int_t *ldt, float *b, float *w, float *scale, float *x, float *work, rng_int_t *info);
extern void RNGSTDCALL SLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, float *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void RNGSTDCALL SLAR2V(rng_int_t *n, float *x, float *y, float *z, rng_int_t *incx, float *c, float *s, rng_int_t *incc);
extern void RNGSTDCALL SLARFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork);
extern void RNGSTDCALL SLARF(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work);
extern void RNGSTDCALL SLARFG(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void RNGSTDCALL SLARFX(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, float *v, float *tau, float *c, rng_int_t *ldc, float *work);
extern void RNGSTDCALL SLARGV(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void RNGSTDCALL SLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, float *x);
extern void RNGSTDCALL SLARRA(rng_int_t *n, float *d, float *e, float *e2, float *spltol, float *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGSTDCALL SLARRB(rng_int_t *n, float *d, float *lld, rng_int_t *ifirst, rng_int_t *ilast, float *rtol1, float *rtol2, rng_int_t *offset, float *w, float *wgap, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *twist, rng_int_t *info);
extern void RNGSTDCALL SLARRC(char *jobt, rng_strlen_t jobt_len, rng_int_t *n, float *vl, float *vu, float *d, float *e, float *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info);
extern void RNGSTDCALL SLARRD(char *range, rng_strlen_t range_len, char *order, rng_strlen_t order_len, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *gers, float *reltol, float *d, float *e, float *e2, float *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wl, float *wu, rng_int_t *iblock, rng_int_t *indexw, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLARRE(char *range, rng_strlen_t range_len, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *d, float *e, float *e2, float *rtol1, float *rtol2, float *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *pivmin, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLARRF(rng_int_t *n, float *d, float *l, float *ld, rng_int_t *clstrt, rng_int_t *clend, float *w, float *wgap, float *werr, float *spdiam, float *clgapl, float *clgapr, float *pivmin, float *sigma, float *dplus, float *lplus, float *work, rng_int_t *info);
extern void RNGSTDCALL SLARRJ(rng_int_t *n, float *d, float *e2, rng_int_t *ifirst, rng_int_t *ilast, float *rtol, rng_int_t *offset, float *w, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *info);
extern void RNGSTDCALL SLARRK(rng_int_t *n, rng_int_t *iw, float *gl, float *gu, float *d, float *e2, float *pivmin, float *reltol, float *w, float *werr, rng_int_t *info);
extern void RNGSTDCALL SLARRR(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SLARRV(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLARTG(float *f, float *g, float *cs, float *sn, float *r);
extern void RNGSTDCALL SLARTV(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s, rng_int_t *incc);
extern void RNGSTDCALL SLARUV(rng_int_t *iseed, rng_int_t *n, float *x);
extern void RNGSTDCALL SLARZB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork);
extern void RNGSTDCALL SLARZ(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, rng_int_t *l, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work);
extern void RNGSTDCALL SLARZT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt);
extern void RNGSTDCALL SLAS2(float *f, float *g, float *h, float *ssmin, float *ssmax);
extern void RNGSTDCALL SLASCL(char *type, rng_strlen_t type_len, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SLASD0(rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD1(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD2(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *dsigma, float *u2, rng_int_t *ldu2, float *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL SLASD3(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *q, rng_int_t *ldq, float *dsigma, float *u, rng_int_t *ldu, float *u2, rng_int_t *ldu2, float *vt, rng_int_t *ldvt, float *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, float *z, rng_int_t *info);
extern void RNGSTDCALL SLASD4(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *sigma, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD5(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dsigma, float *work);
extern void RNGSTDCALL SLASD6(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *vf, float *vl, float *alpha, float *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLASD7(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *zw, float *vf, float *vfw, float *vl, float *vlw, float *alpha, float *beta, float *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *c, float *s, rng_int_t *info);
extern void RNGSTDCALL SLASD8(rng_int_t *icompq, rng_int_t *k, float *d, float *z, float *vf, float *vl, float *difl, float *difr, rng_int_t *lddifr, float *dsigma, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASDA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLASDQ(char *uplo, rng_strlen_t uplo_len, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASDT(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void RNGSTDCALL SLASET(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, float *alpha, float *beta, float *a, rng_int_t *lda);
extern void RNGSTDCALL SLASQ1(rng_int_t *n, float *d, float *e, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASQ2(rng_int_t *n, float *z, rng_int_t *info);
extern void RNGSTDCALL SLASQ3(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *sigma, float *desig, float *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *g, float *tau);
extern void RNGSTDCALL SLASQ4(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, rng_int_t *n0in, float *dmin, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *tau, rng_int_t *ttype, float *g);
extern void RNGSTDCALL SLASQ5(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *tau, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2, rng_int_t *ieee);
extern void RNGSTDCALL SLASQ6(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2);
extern void RNGSTDCALL SLASR(char *side, rng_strlen_t side_len, char *pivot, rng_strlen_t pivot_len, char *direct, rng_strlen_t direct_len, rng_int_t *m, rng_int_t *n, float *c, float *s, float *a, rng_int_t *lda);
extern void RNGSTDCALL SLASV2(float *f, float *g, float *h, float *ssmin, float *ssmax, float *snr, float *csr, float *snl, float *csl);
extern void RNGSTDCALL SLASWP(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL SLASY2(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, float *tl, rng_int_t *ldtl, float *tr, rng_int_t *ldtr, float *b, rng_int_t *ldb, float *scale, float *x, rng_int_t *ldx, float *xnorm, rng_int_t *info);
extern void RNGSTDCALL SLASYF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *ipiv, float *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL SLATBS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL SLATDF(rng_int_t *ijob, rng_int_t *n, float *z, rng_int_t *ldz, float *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL SLATPS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, float *ap, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL SLATRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *e, float *tau, float *w, rng_int_t *ldw);
extern void RNGSTDCALL SLATRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, float *a, rng_int_t *lda, float *x, float *scale, float *cnorm, rng_int_t *info);
extern void RNGSTDCALL SLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *work);
extern void RNGSTDCALL SLATZM(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c1, float *c2, rng_int_t *ldc, float *work);
extern void RNGSTDCALL SLAUU2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SLAUUM(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SORG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORM2L(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SORM2R(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SORML2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SORMR2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info);
extern void RNGSTDCALL SPBTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL SPOTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SPTTS2(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SRSCL(rng_int_t *n, float *sa, float *sx, rng_int_t *incx);
extern void RNGSTDCALL SSYGS2(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSYTD2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, rng_int_t *info);
extern void RNGSTDCALL SSYTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL STGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL STGSY2(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info);
extern void RNGSTDCALL STRTI2(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZDRSCL(rng_int_t *n, double *sa, doublecomplex *sx, rng_int_t *incx);
extern void RNGSTDCALL ZGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGEBD2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGELQ2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQL2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQR2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGERQ2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGESC2(rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGSTDCALL ZGETC2(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL ZGETF2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZHEGS2(rng_int_t *itype, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZHETD2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, rng_int_t *info);
extern void RNGSTDCALL ZHETF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *x, rng_int_t *ldx, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLACGV(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZLACN2(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL ZLACON(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase);
extern void RNGSTDCALL ZLACP2(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZLACPY(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZLACRM(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void RNGSTDCALL ZLACRT(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, doublecomplex *c, doublecomplex *s);
extern doublecomplex RNGSTDCALL ZLADIV(doublecomplex *ret_val, doublecomplex *x, doublecomplex *y);

extern void RNGSTDCALL ZLAED0(rng_int_t *qsiz, rng_int_t *n, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *qstore, rng_int_t *ldqs, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLAED7(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, doublecomplex *q, rng_int_t *ldq, double *rho, rng_int_t *indxq, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLAED8(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, doublecomplex *q, rng_int_t *ldq, double *d, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, doublecomplex *q2, rng_int_t *ldq2, double *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void RNGSTDCALL ZLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *v, doublecomplex *b, rng_int_t *ldb, double *rwork, double *eps3, double *smlnum, rng_int_t *info);
extern void RNGSTDCALL ZLAESY(doublecomplex *a, doublecomplex *b, doublecomplex *c, doublecomplex *rt1, doublecomplex *rt2, doublecomplex *evscal, doublecomplex *cs1, doublecomplex *sn1);
extern void RNGSTDCALL ZLAEV2(doublecomplex *a, doublecomplex *b, doublecomplex *c, double *rt1, double *rt2, double *cs1, doublecomplex *sn1);
extern void RNGSTDCALL ZLAG2C(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL ZLAGS2(rng_int_t *upper, double *a1, doublecomplex * a2, double *a3, double *b1, doublecomplex *b2, double *b3, double *csu, doublecomplex *snu, double *csv, doublecomplex * snv, double *csq, doublecomplex *snq);
extern void RNGSTDCALL ZLAGTM(char *trans, rng_strlen_t trans_len, rng_int_t *n, rng_int_t *nrhs, double *alpha, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *x, rng_int_t *ldx, double *beta, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZLAHEF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL ZLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL ZLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLAIC1(rng_int_t *job, rng_int_t *j, doublecomplex *x, double *sest, doublecomplex *w, doublecomplex *gamma, double *sestpr, doublecomplex *s, doublecomplex *c);
extern void RNGSTDCALL ZLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLALSD(char *uplo, rng_strlen_t uplo_len, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, doublecomplex *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern double RNGSTDCALL ZLANGB(char *norm, rng_strlen_t norm_len, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL ZLANGE(char *norm, rng_strlen_t norm_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL ZLANGT(char *norm, rng_strlen_t norm_len, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du);
extern double RNGSTDCALL ZLANHB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL ZLANHE(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL ZLANHP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *work);
extern double RNGSTDCALL ZLANHS(char *norm, rng_strlen_t norm_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL ZLANHT(char *norm, rng_strlen_t norm_len, rng_int_t *n, double *d, doublecomplex *e);
extern double RNGSTDCALL ZLANSB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL ZLANSP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *work);
extern double RNGSTDCALL ZLANSY(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work);
extern double RNGSTDCALL ZLANTB(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work);
extern double RNGSTDCALL ZLANTP(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *ap, double *work);
extern double RNGSTDCALL ZLANTR(char *norm, rng_strlen_t norm_len, char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work);
extern void RNGSTDCALL ZLAPLL(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *ssmin);
extern void RNGSTDCALL ZLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL ZLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQGE(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHE(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *work);
extern void RNGSTDCALL ZLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *auxv, doublecomplex *f, rng_int_t *ldf);
extern void RNGSTDCALL ZLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZLAQR1(rng_int_t *n, doublecomplex *h, rng_int_t*ldh, doublecomplex *s1, doublecomplex *s2, doublecomplex *v);
extern void RNGSTDCALL ZLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void RNGSTDCALL ZLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void RNGSTDCALL ZLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, doublecomplex *s, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *v, rng_int_t *ldv, doublecomplex *u, rng_int_t *ldu, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, rng_int_t *nh, doublecomplex *wh, rng_int_t *ldwh);
extern void RNGSTDCALL ZLAQSB(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQSP(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQSY(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, doublecomplex *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void RNGSTDCALL ZLAR2V(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *z, rng_int_t *incx, double *c, doublecomplex *s, rng_int_t *incc);
extern void RNGSTDCALL ZLARCM(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void RNGSTDCALL ZLARFB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork);
extern void RNGSTDCALL ZLARF(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work);
extern void RNGSTDCALL ZLARFG(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void RNGSTDCALL ZLARFT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt);
extern void RNGSTDCALL ZLARFX(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, doublecomplex *v, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work);
extern void RNGSTDCALL ZLARGV(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void RNGSTDCALL ZLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, doublecomplex *x);
extern void RNGSTDCALL ZLARRV(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLARTG(doublecomplex *f, doublecomplex *g, double *cs, doublecomplex *sn, doublecomplex *r);
extern void RNGSTDCALL ZLARTV(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, doublecomplex *s, rng_int_t *incc);
extern void RNGSTDCALL ZLARZB(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork);
extern void RNGSTDCALL ZLARZ(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work);
extern void RNGSTDCALL ZLARZT(char *direct, rng_strlen_t direct_len, char *storev, rng_strlen_t storev_len, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt);
extern void RNGSTDCALL ZLASCL(char *type, rng_strlen_t type_len, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZLASET(char *uplo, rng_strlen_t uplo_len, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *beta, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZLASR(char *side, rng_strlen_t side_len, char *pivot, rng_strlen_t pivot_len, char *direct, rng_strlen_t direct_len, rng_int_t *m, rng_int_t *n, double *c, double *s, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZLASWP(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL ZLASYF(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info);
extern void RNGSTDCALL ZLATBS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL ZLATDF(rng_int_t *ijob, rng_int_t *n, doublecomplex *z, rng_int_t *ldz, doublecomplex *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL ZLATPS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, doublecomplex *ap, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL ZLATRD(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *e, doublecomplex *tau, doublecomplex *w, rng_int_t *ldw);
extern void RNGSTDCALL ZLATRS(char *uplo, rng_strlen_t uplo_len, char *trans, rng_strlen_t trans_len, char *diag, rng_strlen_t diag_len, char *normin, rng_strlen_t normin_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info);
extern void RNGSTDCALL ZLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work);
extern void RNGSTDCALL ZLATZM(char *side, rng_strlen_t side_len, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c1, doublecomplex *c2, rng_int_t *ldc, doublecomplex *work);
extern void RNGSTDCALL ZLAUU2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZLAUUM(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZPBTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info);
extern void RNGSTDCALL ZPOTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZPTTS2(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZROT(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, double *c, doublecomplex *s);
extern void RNGSTDCALL ZSPMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZSPR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *ap);
extern void RNGSTDCALL ZSYMV(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZSYR(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZSYTF2(char *uplo, rng_strlen_t uplo_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void RNGSTDCALL ZTGSY2(char *trans, rng_strlen_t trans_len, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *info);
extern void RNGSTDCALL ZTRTI2(char *uplo, rng_strlen_t uplo_len, char *diag, rng_strlen_t diag_len, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL ZUNG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNM2L(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNM2R(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNML2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNMR2(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNMR3(char *side, rng_strlen_t side_len, char *trans, rng_strlen_t trans_len, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info);

/* FFT routines */
extern void RNGSTDCALL CFFT1D(rng_int_t *mode, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1DX(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1M(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1MX(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT2DX(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3DX(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *y, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3DY(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, complex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, complex *comm, rng_int_t *lcomm, rng_int_t *info);
extern void RNGSTDCALL CSFFT(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT1D(rng_int_t *mode, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex * x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex * x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFTM(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT1D(rng_int_t *mode, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFTM(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT1D(rng_int_t *mode, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFTM(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT1D(rng_int_t *mode, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFTM(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1D(rng_int_t *mode, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1DX(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1M(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1MX(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT2DX(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3DX(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3DY(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, doublecomplex *comm, rng_int_t *lcomm, rng_int_t *info);

/* Sparse BLAS routines */
extern void RNGSTDCALL CAXPYI(rng_int_t *nz, complex *a, complex *x, rng_int_t *indx, complex *y);
extern complex RNGSTDCALL CDOTCI(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CDOTCISUB(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern complex RNGSTDCALL CDOTUI(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CDOTUISUB(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CGTHR(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGSTDCALL CGTHRZ(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGSTDCALL CSCTR(rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL DAXPYI(rng_int_t *nz, double *a, double *x, rng_int_t *indx, double *y);
extern double RNGSTDCALL DDOTI(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void RNGSTDCALL DGTHR(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void RNGSTDCALL DGTHRZ(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void RNGSTDCALL DROTI(rng_int_t *nz, double *x, rng_int_t *indx, double *y, double *c, double *s);
extern void RNGSTDCALL DSCTR(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void RNGSTDCALL SAXPYI(rng_int_t *nz, float *a, float *x, rng_int_t *indx, float *y);
extern float RNGSTDCALL SDOTI(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void RNGSTDCALL SGTHR(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void RNGSTDCALL SGTHRZ(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void RNGSTDCALL SROTI(rng_int_t *nz, float *x, rng_int_t *indx, float *y, float *c, float *s);
extern void RNGSTDCALL SSCTR(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void RNGSTDCALL ZAXPYI(rng_int_t *nz, doublecomplex *a, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGSTDCALL ZDOTCI(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZDOTCISUB(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGSTDCALL ZDOTUI(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZDOTUISUB(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZGTHR(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGSTDCALL ZGTHRZ(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGSTDCALL ZSCTR(rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);

/* Random number generators */
extern void RNGSTDCALL DRANDBETA(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDBINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDBINOMIALREFERENCE(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDBLUMBLUMSHUB(rng_int_t *n, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDCAUCHY(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDCHISQUARED(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDDISCRETEUNIFORM(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDEXPONENTIAL(rng_int_t *n, double *a, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDF(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGAMMA(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGAUSSIAN(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGENERALDISCRETE(rng_int_t *n, double *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGEOMETRIC(rng_int_t *n, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGEOMETRICREFERENCE(double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDHYPERGEOMETRIC(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDHYPERGEOMETRICREFERENCE(rng_int_t *np, rng_int_t *ns, rng_int_t *m, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZE(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZEBBS(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZEUSER(RNG_DRANDINITIALIZEUSER_UINI uini, RNG_DRANDINITIALIZEUSER_UGEN ugen, rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDLEAPFROG(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL DRANDLOGISTIC(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDLOGNORMAL(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMALREFERENCE(rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMALR(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTSTREFERENCE(rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTSTR(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDNEGATIVEBINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDNEGATIVEBINOMIALREFERENCE(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDPOISSON(rng_int_t *n, double *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDPOISSONREFERENCE(double *lambda, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDSKIPAHEAD(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL DRANDSTUDENTST(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDTRIANGULAR(rng_int_t *n, double *xmin, double *xmed, double *xmax, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDUNIFORM(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDVONMISES(rng_int_t *n, double *vk, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDWEIBULL(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMAL(rng_int_t *n, rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTST(rng_int_t *n, rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDBETA(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBLUMBLUMSHUB(rng_int_t *n, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBINOMIALREFERENCE(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDCAUCHY(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDCHISQUARED(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDDISCRETEUNIFORM(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDEXPONENTIAL(rng_int_t *n, float *a, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDF(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGAMMA(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGAUSSIAN(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGENERALDISCRETE(rng_int_t *n, float *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGEOMETRIC(rng_int_t *n, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGEOMETRICREFERENCE(float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDHYPERGEOMETRIC(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDHYPERGEOMETRICREFERENCE(rng_int_t *np, rng_int_t *ns, rng_int_t *m, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZE(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZEBBS(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZEUSER(RNG_SRANDINITIALIZEUSER_UINI uini, RNG_SRANDINITIALIZEUSER_UGEN ugen, rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDLEAPFROG(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL SRANDLOGISTIC(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDLOGNORMAL(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMALREFERENCE(rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMALR(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTSTREFERENCE(rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTSTR(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDNEGATIVEBINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDNEGATIVEBINOMIALREFERENCE(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDPOISSON(rng_int_t *n, float *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDPOISSONREFERENCE(float *lambda, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDSKIPAHEAD(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL SRANDSTUDENTST(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDTRIANGULAR(rng_int_t *n, float *xmin, float *xmed, float *xmax, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDUNIFORM(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDVONMISES(rng_int_t *n, float *vk, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDWEIBULL(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMAL(rng_int_t *n, rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTST(rng_int_t *n, rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);

/* RNG version information */
extern void RNGSTDCALL RNGVERSION(rng_int_t *major, rng_int_t *minor, rng_int_t *patch, rng_int_t *build);
extern void RNGSTDCALL RNGINFO(void);

/* OMP interfaces */
extern rng_int_t RNGSTDCALL RNGGETMAXTHREADS(void);
extern rng_int_t RNGSTDCALL RNGGETNUMTHREADS(void);
extern void RNGSTDCALL RNGSETNUMTHREADS(rng_int_t *numthreads);
extern rng_int_t RNGSTDCALL RNGGETNUMPROCS(void);

/* Putenv and getenv and other utilities */
extern void RNGSTDCALL RNGPUTENV(char *name, rng_strlen_t name_len, char *value, rng_strlen_t value_len);
extern void RNGSTDCALL RNGGETENV(char *name, rng_strlen_t name_len, char *value, rng_strlen_t value_len);
extern void RNGSTDCALL RNGLOCATION(char *message, rng_strlen_t message_len, void *arg);
extern void RNGSTDCALL RNGLOCATIONSTRING(char *message, rng_strlen_t message_len, void *arg, char *string, rng_strlen_t string_len);

#elif defined(WIN_IFORT) /* ! WIN32_VF */
/* BLAS routines */
extern void RNGSTDCALL CAXPY(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CCOPY(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex RNGSTDCALL CDOTC(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CDOTCSUB(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex RNGSTDCALL CDOTU(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CDOTUSUB(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CGBMV(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL CGEMM(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void RNGSTDCALL CGEMV(char *trans, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL CGERC(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CGERU(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void RNGSTDCALL CHBMV(char *uplo, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEMV(char *uplo, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHER(char *uplo, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHER2(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHER2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CHERK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CHPMV(char *uplo, rng_int_t *n, complex *alpha, complex *a, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPR(char *uplo, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPR2(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLASSQ(rng_int_t *n, complex *x, rng_int_t *incx, float *scale, float *sumsq);
extern void RNGSTDCALL CROTG(complex *a, complex *b, float *c, complex *s);
extern void RNGSTDCALL CSCAL(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CSROT(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, float *s);
extern void RNGSTDCALL CSSCAL(rng_int_t *n, float *alpha, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CSTEMR(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL CSWAP(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void RNGSTDCALL CSYMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYR2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CSYRK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CTBMV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTBSV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPMV(char *uplo, char *trans, char *diag, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPSV(char *uplo, char *trans, char *diag, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRMM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRMV(char *uplo, char *trans, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRSM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRSV(char *uplo, char *trans, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern double RNGSTDCALL DASUM(rng_int_t *n, double *x, rng_int_t *incx);
extern void RNGSTDCALL DAXPY(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double RNGSTDCALL DCABS1(doublecomplex *z);
extern void RNGSTDCALL DCOPY(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double RNGSTDCALL DDOT(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void RNGSTDCALL DGBMV(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL DGEMM(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void RNGSTDCALL DGEMV(char *trans, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL DGER(rng_int_t *m, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda);
extern double RNGSTDCALL DNRM2(rng_int_t *n, double *x, rng_int_t *incx);
extern void RNGSTDCALL DROT(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s);
extern void RNGSTDCALL DROTG(double *a, double *b, double *c, double *s);
extern void RNGSTDCALL DROTM(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *param);
extern void RNGSTDCALL DROTMG(double *d1, double *d2, double *b1, double *b2, double *param);
extern void RNGSTDCALL DSBMV(char *uplo, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSCAL(rng_int_t *n, double *alpha, double *x, rng_int_t *incx);
extern double RNGSTDCALL DSDOT(rng_int_t *n, float *sx, rng_int_t *incx, float *sy, rng_int_t *incy);
extern void RNGSTDCALL DSPMV(char *uplo, rng_int_t *n, double *alpha, double *ap, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPR(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPR2(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSWAP(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void RNGSTDCALL DSYMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYMV(char *uplo, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYR(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYR2(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYR2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DSYRK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DTBMV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTBSV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPMV(char *uplo, char *trans, char *diag, rng_int_t *n, double *ap, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPSV(char *uplo, char *trans, char *diag, rng_int_t *n, double *ap, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRMM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRMV(char *uplo, char *trans, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRSM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRSV(char *uplo, char *trans, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern double RNGSTDCALL DZASUM(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern double RNGSTDCALL DZNRM2(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ICAMAX(rng_int_t *n, complex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IDAMAX(rng_int_t *n, double *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ISAMAX(rng_int_t *n, float *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IZAMAX(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t RNGSTDCALL LSAME(char *ca, char *cb, rng_strlen_t ca_len, rng_strlen_t cb_len);
extern float RNGSTDCALL SASUM(rng_int_t *n, float *x, rng_int_t *incx);
extern void RNGSTDCALL SAXPY(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SCASUM(rng_int_t *n, complex *x, rng_int_t *incx);
extern float RNGSTDCALL SCNRM2(rng_int_t *n, complex *x, rng_int_t *incx);
extern void RNGSTDCALL SCOPY(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SDOT(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float RNGSTDCALL SDSDOT(rng_int_t *n, float *b, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void RNGSTDCALL SGBMV(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL SGEMM(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void RNGSTDCALL SGEMV(char *trans, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL SGER(rng_int_t *m, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda);
extern float RNGSTDCALL SNRM2(rng_int_t *n, float *x, rng_int_t *incx);
extern void RNGSTDCALL SROT(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s);
extern void RNGSTDCALL SROTG(float *a, float *b, float *c, float *s);
extern void RNGSTDCALL SROTM(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *param);
extern void RNGSTDCALL SROTMG(float *d1, float *d2, float *b1, float *b2, float *param);
extern void RNGSTDCALL SSBMV(char *uplo, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSCAL(rng_int_t *n, float *alpha, float *x, rng_int_t *incx);
extern void RNGSTDCALL SSPMV(char *uplo, rng_int_t *n, float *alpha, float *ap, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPR(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPR2(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSTEMR(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL SSWAP(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void RNGSTDCALL SSYMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYMV(char *uplo, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYR(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYR2(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYR2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SSYRK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL STBMV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STBSV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPMV(char *uplo, char *trans, char *diag, rng_int_t *n, float *ap, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPSV(char *uplo, char *trans, char *diag, rng_int_t *n, float *ap, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRMM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRMV(char *uplo, char *trans, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRSM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRSV(char *uplo, char *trans, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL XERBLA(const char *srname, rng_int_t *info, rng_strlen_t srname_len);
extern void RNGSTDCALL ZAXPY(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZCOPY(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex RNGSTDCALL ZDOTC(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDOTCSUB(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex RNGSTDCALL ZDOTU(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDOTUSUB(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZDROT(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, double *s);
extern void RNGSTDCALL ZDSCAL(rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZGBMV(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGEMM(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void RNGSTDCALL ZGEMV(char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGERC(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZGERU(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL ZHBMV(char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEMV(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHER(char *uplo, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHER2(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHER2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZHERK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZHPMV(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPR(char *uplo, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPR2(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLASSQ(rng_int_t *n, doublecomplex *x, rng_int_t *incx, double *scale, double *sumsq);
extern void RNGSTDCALL ZROTG(doublecomplex *a, doublecomplex *b, double *c, doublecomplex *s);
extern void RNGSTDCALL ZSCAL(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZSTEMR(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL ZSWAP(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void RNGSTDCALL ZSYMM(char *side, char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYR2K(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZSYRK(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZTBMV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTBSV(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPMV(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPSV(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRMM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRMV(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRSM(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRSV(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);

/* LAPACK routines */
extern void RNGSTDCALL CBBCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *rwork, rng_int_t *lrwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CBDSQR(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, complex *vt, rng_int_t *ldvt, complex *u, rng_int_t *ldu, complex *c, rng_int_t *ldc, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CGBBRD(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *pt, rng_int_t *ldpt, complex *c, rng_int_t *ldc, complex *work, float *rwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL CGBCON(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL CGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGBRFS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGBRFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGBSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGBSVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGBTRS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGEBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL CGEBAL(char *job, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL CGEBRD(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGECON(char *norm, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL CGEEQU(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGEEQUB(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL CGEES(char *jobvs, char *sort, RNG_CGEES_SELECT select, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void RNGSTDCALL CGEESX(char *jobvs, char *sort, RNG_CGEESX_SELECT select, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL CGEEV(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL CGEEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL CGEGS(char *jobvsl, char *jobvsr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void RNGSTDCALL CGEGV(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL CGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGELQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGELS(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CGEQLF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQP3(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEQPF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CGEQR2P(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQRF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQRFP(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQRT2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CGEQRT3(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CGERFS(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGERFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGERQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGESDD(char *jobz, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL CGESV(rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGESVD(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void RNGSTDCALL CGESVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGESVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CGETRF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGETRI(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGETRS(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGGBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL CGGBAL(char *job, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL CGGES(char *jobvsl, char *jobvsr, char *sort, RNG_CGGES_SELCTG selctg, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void RNGSTDCALL CGGESX(char *jobvsl, char *jobvsr, char *sort, RNG_CGGESX_SELCTG selctg, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL CGGEV(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL CGGEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL CGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *d, complex *x, complex *y, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGHRD(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL CGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, complex *d, complex *x, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CGGSVD(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL CGGSVP(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, rng_int_t *iwork, float *rwork, complex *tau, complex *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL CGTCON(char *norm, rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL CGTRFS(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CGTSV(rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CGTSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CGTTRF(rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGTTRS(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CHBEV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBEVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBEVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBGST(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *x, rng_int_t *ldx, complex *work, float *rwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBGV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBGVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBGVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHBTRD(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHECON(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEEQUB(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEEV(char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEEVD(char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEEVR(char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEEVX(char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEGST(rng_int_t *itype, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHEGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHERFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHERFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CHESV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHESVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHESVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CHESWAPR(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRD(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRF(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRI(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRI2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRI2X(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHFRK(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CHGEQZ(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL CHLA_TRANSTYPE(char *ret_val, rng_strlen_t ret_val_len, rng_int_t *trans);
extern void RNGSTDCALL CHPCON(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPEV(char *jobz, char *uplo, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPEVD(char *jobz, char *uplo, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPEVX(char *jobz, char *range, char *uplo, rng_int_t *n, complex *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPGST(rng_int_t *itype, char *uplo, rng_int_t *n, complex *ap, complex *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPTRD(char *uplo, rng_int_t *n, complex *ap, float *d, float *e, complex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPTRF(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPTRI(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHSEIN(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void RNGSTDCALL CHSEQR(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern void RNGSTDCALL CLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, complex *ab, rng_int_t *ldab, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_GBRCOND_C(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern float RNGSTDCALL CLA_GBRCOND_X(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern void RNGSTDCALL CLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb);
extern void RNGSTDCALL CLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_GERCOND_C(char *trans, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern float RNGSTDCALL CLA_GERCOND_X(char *trans, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern void RNGSTDCALL CLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *errs_n, float *errs_c, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL CLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf);
extern void RNGSTDCALL CLA_HEAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_HERCOND_C(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_HERCOND_X(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_HERFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_HERPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, complex *res, float *ayb, float *berr);
extern float RNGSTDCALL CLA_PORCOND_C(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_PORCOND_X(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_PORPVGRW(char *uplo, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_SYAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float RNGSTDCALL CLA_SYRCOND_C(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_SYRCOND_X(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLA_SYRPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLA_WWADDW(rng_int_t *n, complex *x, complex *y, complex *w);
extern float RNGSTDCALL CLANHF(char *norm, char *transr, char *uplo, rng_int_t *n, complex *a, float *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL CLARFGP(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void RNGSTDCALL CLARSCL2(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void RNGSTDCALL CLASCL2(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void RNGSTDCALL CPBCON(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBEQU(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBRFS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBSTF(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBSV(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CPBTRF(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBTRS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPFTRF(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPFTRI(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPFTRS(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOCON(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOEQU(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPOEQUB(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL CPORFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPORFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CPOSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CPOTRF(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOTRI(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPCON(char *uplo, rng_int_t *n, complex *ap, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPEQU(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CPPTRF(char *uplo, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPTRI(char *uplo, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPSTF2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPSTRF(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPTCON(rng_int_t *n, float *d, complex *e, float *anorm, float *rcond, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CPTEQR(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL CPTRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPTSV(rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL CPTSVX(char *fact, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len);
extern void RNGSTDCALL CPTTRF(rng_int_t *n, float *d, complex *e, rng_int_t *info);
extern void RNGSTDCALL CPTTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPCON(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPTRF(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPTRI(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSTEDC(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL CSTEGR(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL CSTEIN(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, complex *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL CSTEQR(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL CSYCON(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYCONV(char *uplo, char *way, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void RNGSTDCALL CSYEQUB(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYRFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CSYSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CSYSWAPR(char *uplo, rng_int_t *n, complex *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRF(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRI(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRI2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRI2X(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTBCON(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTBRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTBTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTFSM(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, complex *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTFTRI(char *transr, char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTFTTP(char *transr, char *uplo, rng_int_t *n, complex *arf, complex *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTFTTR(char *transr, char *uplo, rng_int_t *n, complex *arf, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTGEVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL CTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL CTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL CTGSJA(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL CTGSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL CTGSYL(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CTPCON(char *norm, char *uplo, char *diag, rng_int_t *n, complex *ap, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void RNGSTDCALL CTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL CTPRFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL CTPRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPTRI(char *uplo, char *diag, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTPTTF(char *transr, char *uplo, rng_int_t *n, complex *ap, complex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTPTTR(char *uplo, rng_int_t *n, complex *ap, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTRCON(char *norm, char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTREVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL CTREXC(char *compq, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info, rng_strlen_t compq_len);
extern void RNGSTDCALL CTRRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRSEN(char *job, char *compq, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, complex *w, rng_int_t *m, float *s, float *sep, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void RNGSTDCALL CTRSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *ldwork, float *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL CTRSYL(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void RNGSTDCALL CTRTRI(char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CTRTTF(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTRTTP(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTZRQF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, rng_int_t *info);
extern void RNGSTDCALL CTZRZF(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNBDB(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, float *phi, complex *taup1, complex *taup2, complex *tauq1, complex *tauq2, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL CUNCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL CUNGBR(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL CUNGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CUNGTR(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CUNMBR(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMHR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMLQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMQL(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMQR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMRQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMRZ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUPGTR(char *uplo, rng_int_t *n, complex *ap, complex *tau, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CUPMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, complex *ap, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DBBCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DBDSDC(char *uplo, char *compq, rng_int_t *n, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *q, rng_int_t *iq, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t compq_len);
extern void RNGSTDCALL DBDSQR(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DDISNA(char *job, rng_int_t *m, rng_int_t *n, double *d, double *sep, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL DGBBRD(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *pt, rng_int_t *ldpt, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL DGBCON(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL DGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGBRFS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGBRFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGBSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGBSVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGBTRS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGEBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL DGEBAL(char *job, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL DGEBRD(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGECON(char *norm, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL DGEEQU(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGEEQUB(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL DGEES(char *jobvs, char *sort, RNG_DGEES_SELECT select, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void RNGSTDCALL DGEESX(char *jobvs, char *sort, RNG_DGEESX_SELECT select, char *sense, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL DGEEV(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL DGEEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL DGEGS(char *jobvsl, char *jobvsr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void RNGSTDCALL DGEGV(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL DGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEJSV(char *joba, char *jobu, char *jobv, char *jobr, char *jobt, char *jobp, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobr_len, rng_strlen_t jobt_len, rng_strlen_t jobp_len);
extern void RNGSTDCALL DGELQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGELS(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *info);
extern void RNGSTDCALL DGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DGEQLF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQP3(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQPF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQR2P(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQRF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQRFP(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQRT2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DGEQRT3(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DGERFS(char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGERFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGERQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGESDD(char *jobz, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL DGESV(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGESVD(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void RNGSTDCALL DGESVJ(char *joba, char *jobu, char *jobv, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len);
extern void RNGSTDCALL DGESVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGESVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DGETRF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGETRI(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGETRS(char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGGBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL DGGBAL(char *job, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL DGGES(char *jobvsl, char *jobvsr, char *sort, RNG_DGGES_DELCTG delctg, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void RNGSTDCALL DGGESX(char *jobvsl, char *jobvsr, char *sort, RNG_DGGESX_DELCTG delctg, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL DGGEV(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL DGGEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL DGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *d, double *x, double *y, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGHRD(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL DGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, double *d, double *x, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DGGSVD(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL DGGSVP(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, rng_int_t *iwork, double *tau, double *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL DGSVJ0(char *jobv, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void RNGSTDCALL DGSVJ1(char *jobv, rng_int_t *m, rng_int_t *n, rng_int_t *n1, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void RNGSTDCALL DGTCON(char *norm, rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL DGTRFS(char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DGTSV(rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DGTSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DGTTRF(rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGTTRS(char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DHGEQZ(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL DHSEIN(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void RNGSTDCALL DHSEQR(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern rng_int_t RNGSTDCALL DISNAN(double *din);
extern void RNGSTDCALL DLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *ab, rng_int_t *ldab, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_GBRCOND(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void RNGSTDCALL DLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb);
extern void RNGSTDCALL DLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_GERCOND(char *trans, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void RNGSTDCALL DLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL DLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf);
extern void RNGSTDCALL DLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, double *res, double *ayb, double *berr);
extern double RNGSTDCALL DLA_PORCOND(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL DLA_PORPVGRW(char *uplo, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLA_SYAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL DLA_SYRCOND(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL DLA_SYRPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLA_WWADDW(rng_int_t *n, double *x, double *y, double *w);
extern double RNGSTDCALL DLAMCH(char *cmach, rng_strlen_t cmach_len);
extern double RNGSTDCALL DLANSF(char *norm, char *transr, char *uplo, rng_int_t *n, double *a, double *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL DLARFGP(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void RNGSTDCALL DLARFT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt,  rng_strlen_t direct_len,  rng_strlen_t storev_len);
extern void RNGSTDCALL DLARSCL2(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void RNGSTDCALL DLARTGP(double *f, double *g, double *cs, double *sn, double *r_);
extern void RNGSTDCALL DLARTGS(double *x, double *y, double *sigma, double *cs, double *sn);
extern void RNGSTDCALL DLASCL2(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void RNGSTDCALL DLASRT(char *id, rng_int_t *n, double *d, rng_int_t *info, rng_strlen_t id_len);
extern void RNGSTDCALL DLASSQ(rng_int_t *n, double *x, rng_int_t *incx, double *scale, double *sumsq);
extern void RNGSTDCALL DLAT2S(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DOPGTR(char *uplo, rng_int_t *n, double *ap, double *tau, double *q, rng_int_t *ldq, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DOPMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, double *ap, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORBDB(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *phi, double *taup1, double *taup2, double *tauq1, double *tauq2, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL DORCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL DORGBR(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL DORGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DORGTR(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DORMBR(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMHR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMLQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMQL(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMQR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMRQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMRZ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DPBCON(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBEQU(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBRFS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBSTF(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBSV(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DPBTRF(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPBTRS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPFTRF(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPFTRI(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPFTRS(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOCON(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOEQU(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPOEQUB(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL DPORFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPORFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DPOSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DPOTRF(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOTRI(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPCON(char *uplo, rng_int_t *n, double *ap, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPEQU(char *uplo, rng_int_t *n, double *ap, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DPPTRF(char *uplo, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPTRI(char *uplo, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPSTF2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPSTRF(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPTCON(rng_int_t *n, double *d, double *e, double *anorm, double *rcond, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTEQR(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL DPTRFS(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *info);
extern void RNGSTDCALL DPTSV(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DPTSVX(char *fact, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *info, rng_strlen_t fact_len);
extern void RNGSTDCALL DPTTRF(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DPTTRS(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL DSBEV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBEVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBEVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBGST(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *x, rng_int_t *ldx, double *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBGV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBGVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBGVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSBTRD(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL DSECND(void);
extern void RNGSTDCALL DSFRK(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DSGESV(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL DSPCON(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPEV(char *jobz, char *uplo, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPEVD(char *jobz, char *uplo, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPEVX(char *jobz, char *range, char *uplo, rng_int_t *n, double *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPGST(rng_int_t *itype, char *uplo, rng_int_t *n, double *ap, double *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, double *ap, double *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPTRD(char *uplo, rng_int_t *n, double *ap, double *d, double *e, double *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPTRF(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPTRI(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSTEBZ(char *range, char *order, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, double *d, double *e, rng_int_t *m, rng_int_t *nsplit, double *w, rng_int_t *iblock, rng_int_t *isplit, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void RNGSTDCALL DSTEDC(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL DSTEGR(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL DSTEIN(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL DSTEMR(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL DSTEQR(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL DSTERF(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DSTEV(char *jobz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL DSTEVD(char *jobz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL DSTEVR(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL DSTEVX(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL DSYCON(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYCONV(char *uplo, char *way, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void RNGSTDCALL DSYEQUB(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYEV(char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYEVD(char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYEVR(char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYEVX(char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYGST(rng_int_t *itype, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYRFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DSYSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DSYSWAPR(char *uplo, rng_int_t *n, double *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRD(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRF(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRI(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRI2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRI2X(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTBCON(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTBRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTBTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTFSM(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, double *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTFTRI(char *transr, char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTFTTP(char *transr, char *uplo, rng_int_t *n, double *arf, double *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTFTTR(char *transr, char *uplo, rng_int_t *n, double *arf, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTGEVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL DTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL DTGSJA(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL DTGSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL DTGSYL(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DTPCON(char *norm, char *uplo, char *diag, rng_int_t *n, double *ap, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void RNGSTDCALL DTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL DTPRFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL DTPRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPTRI(char *uplo, char *diag, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTPTTF(char *transr, char *uplo, rng_int_t *n, double *ap, double *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTPTTR(char *uplo, rng_int_t *n, double *ap, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTRCON(char *norm, char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTREVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL DTREXC(char *compq, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *info, rng_strlen_t compq_len);
extern void RNGSTDCALL DTRRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRSEN(char *job, char *compq, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, double *wr, double *wi, rng_int_t *m, double *s, double *sep, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void RNGSTDCALL DTRSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL DTRSYL(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void RNGSTDCALL DTRTRI(char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DTRTTF(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTRTTP(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTZRQF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, rng_int_t *info);
extern void RNGSTDCALL DTZRZF(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern rng_int_t RNGSTDCALL ILAENV(rng_int_t *ispec, const char *name, const char *opts, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4, rng_strlen_t name_len, rng_strlen_t opts_len);
extern void RNGSTDCALL ILAENVSET(rng_int_t *ispec, const char *name, const char *opts, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4, rng_int_t *nvalue, rng_int_t *info, rng_strlen_t name_len, rng_strlen_t opts_len);
extern void RNGSTDCALL ILAVER(rng_int_t *vers_major, rng_int_t *vers_minor, rng_int_t *vers_patch);
extern rng_int_t RNGSTDCALL ILACLC(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILACLR(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILADIAG(char *diag, rng_strlen_t diag_len);
extern rng_int_t RNGSTDCALL ILADLC(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILADLR(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILAPREC(char *prec, rng_strlen_t prec_len);
extern rng_int_t RNGSTDCALL ILASLC(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILASLR(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILATRANS(char *trans, rng_strlen_t trans_len);
extern rng_int_t RNGSTDCALL ILAUPLO(char *uplo, rng_strlen_t uplo_len);
extern rng_int_t RNGSTDCALL ILAZLC(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern rng_int_t RNGSTDCALL ILAZLR(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern void RNGSTDCALL SBBCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SBDSDC(char *uplo, char *compq, rng_int_t *n, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *q, rng_int_t *iq, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t compq_len);
extern void RNGSTDCALL SBDSQR(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SDISNA(char *job, rng_int_t *m, rng_int_t *n, float *d, float *sep, rng_int_t *info, rng_strlen_t job_len);
extern float RNGSTDCALL SECOND(void);
extern void RNGSTDCALL SGBBRD(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *pt, rng_int_t *ldpt, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL SGBCON(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL SGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGBRFS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGBRFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGBSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGBSVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGBTRS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGEBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL SGEBAL(char *job, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL SGEBRD(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGECON(char *norm, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL SGEEQU(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGEEQUB(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void RNGSTDCALL SGEES(char *jobvs, char *sort, RNG_SGEES_SELECT select, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void RNGSTDCALL SGEESX(char *jobvs, char *sort, RNG_SGEESX_SELECT select, char *sense, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL SGEEV(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL SGEEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL SGEGS(char *jobvsl, char *jobvsr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void RNGSTDCALL SGEGV(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL SGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEJSV(char *joba, char *jobu, char *jobv, char *jobr, char *jobt, char *jobp, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobr_len, rng_strlen_t jobt_len, rng_strlen_t jobp_len);
extern void RNGSTDCALL SGELQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGELS(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *info);
extern void RNGSTDCALL SGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SGEQLF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQP3(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQPF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQR2P(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQRF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQRFP(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQRT2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL SGEQRT3(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL SGERFS(char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGERFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGERQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGESDD(char *jobz, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL SGESV(rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGESVD(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void RNGSTDCALL SGESVJ(char *joba, char *jobu, char *jobv, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len);
extern void RNGSTDCALL SGESVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGESVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SGETRF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGETRI(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGETRS(char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGGBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL SGGBAL(char *job, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL SGGES(char *jobvsl, char *jobvsr, char *sort, RNG_SGGES_SELCTG selctg, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void RNGSTDCALL SGGESX(char *jobvsl, char *jobvsr, char *sort, RNG_SGGESX_SELCTG selctg, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL SGGEV(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL SGGEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL SGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *d, float *x, float *y, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGHRD(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL SGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, float *d, float *x, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SGGSVD(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL SGGSVP(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, rng_int_t *iwork, float *tau, float *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL SGSVJ0(char *jobv, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void RNGSTDCALL SGSVJ1(char *jobv, rng_int_t *m, rng_int_t *n, rng_int_t *n1, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void RNGSTDCALL SGTCON(char *norm, rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL SGTRFS(char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SGTSV(rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SGTSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SGTTRF(rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGTTRS(char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL SHGEQZ(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL SHSEIN(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void RNGSTDCALL SHSEQR(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern rng_int_t RNGSTDCALL SISNAN(float *sin);
extern void RNGSTDCALL SLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *ab, rng_int_t *ldab, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_GBRCOND(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void RNGSTDCALL SLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL SLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb);
extern void RNGSTDCALL SLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_GERCOND(char *trans, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void RNGSTDCALL SLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float RNGSTDCALL SLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf);
extern void RNGSTDCALL SLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, float *res, float *ayb, float *berr);
extern double RNGSTDCALL SLA_PORCOND(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL SLA_PORPVGRW(char *uplo, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLA_SYAMV(rng_int_t *uplo, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double RNGSTDCALL SLA_SYRCOND(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL SLA_SYRPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLA_WWADDW(rng_int_t *n, float *x, float *y, float *w);
extern float RNGSTDCALL SLAMCH(char *cmach, rng_strlen_t cmach_len);
extern float RNGSTDCALL SLANSF(char *norm, char *transr, char *uplo, rng_int_t *n, float *a, float *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL SLARFGP(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void RNGSTDCALL SLARFT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt,  rng_strlen_t direct_len,  rng_strlen_t storev_len);
extern void RNGSTDCALL SLARSCL2(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void RNGSTDCALL SLARTGP(float *f, float *g, float *cs, float *sn, float *r_);
extern void RNGSTDCALL SLARTGS(float *x, float *y, float *sigma, float *cs, float *sn);
extern void RNGSTDCALL SLASCL2(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void RNGSTDCALL SLASRT(char *id, rng_int_t *n, float *d, rng_int_t *info, rng_strlen_t id_len);
extern void RNGSTDCALL SLASSQ(rng_int_t *n, float *x, rng_int_t *incx, float *scale, float *sumsq);
extern void RNGSTDCALL SOPGTR(char *uplo, rng_int_t *n, float *ap, float *tau, float *q, rng_int_t *ldq, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SOPMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, float *ap, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORBDB(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *phi, float *taup1, float *taup2, float *tauq1, float *tauq2, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL SORCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL SORGBR(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL SORGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SORGTR(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SORMBR(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMHR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMLQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMQL(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMQR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMRQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMRZ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SPBCON(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBEQU(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBRFS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBSTF(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBSV(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SPBTRF(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPBTRS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPFTRF(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPFTRI(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPFTRS(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOCON(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOEQU(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPOEQUB(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void RNGSTDCALL SPORFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPORFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SPOSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SPOTRF(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOTRI(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPCON(char *uplo, rng_int_t *n, float *ap, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPEQU(char *uplo, rng_int_t *n, float *ap, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SPPTRF(char *uplo, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPTRI(char *uplo, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPSTF2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPSTRF(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPTCON(rng_int_t *n, float *d, float *e, float *anorm, float *rcond, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTEQR(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL SPTRFS(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *info);
extern void RNGSTDCALL SPTSV(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SPTSVX(char *fact, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *info, rng_strlen_t fact_len);
extern void RNGSTDCALL SPTTRF(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SPTTRS(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL SSBEV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBEVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBEVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBGST(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *x, rng_int_t *ldx, float *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBGV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBGVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBGVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSBTRD(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSFRK(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SSPCON(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPEV(char *jobz, char *uplo, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPEVD(char *jobz, char *uplo, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPEVX(char *jobz, char *range, char *uplo, rng_int_t *n, float *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPGST(rng_int_t *itype, char *uplo, rng_int_t *n, float *ap, float *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, float *ap, float *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPTRD(char *uplo, rng_int_t *n, float *ap, float *d, float *e, float *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPTRF(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPTRI(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSTEBZ(char *range, char *order, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, float *d, float *e, rng_int_t *m, rng_int_t *nsplit, float *w, rng_int_t *iblock, rng_int_t *isplit, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void RNGSTDCALL SSTEDC(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL SSTEGR(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL SSTEIN(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL SSTEQR(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL SSTERF(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SSTEV(char *jobz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL SSTEVD(char *jobz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL SSTEVR(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL SSTEVX(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL SSYCON(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYCONV(char *uplo, char *way, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void RNGSTDCALL SSYEQUB(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYEV(char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYEVD(char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYEVR(char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYEVX(char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYGST(rng_int_t *itype, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYRFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SSYSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SSYSWAPR(char *uplo, rng_int_t *n, float *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRD(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRF(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRI(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRI2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRI2X(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL STBCON(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STBRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STBTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STFSM(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, float *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STFTRI(char *transr, char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STFTTP(char *transr, char *uplo, rng_int_t *n, float *arf, float *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL STFTTR(char *transr, char *uplo, rng_int_t *n, float *arf, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL STGEVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL STGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL STGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL STGSJA(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL STGSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL STGSYL(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL STPCON(char *norm, char *uplo, char *diag, rng_int_t *n, float *ap, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL STPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void RNGSTDCALL STPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL STPRFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL STPRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPTRI(char *uplo, char *diag, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STPTTF(char *transr, char *uplo, rng_int_t *n, float *ap, float *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL STPTTR(char *uplo, rng_int_t *n, float *ap, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL STRCON(char *norm, char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STREVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL STREXC(char *compq, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *info, rng_strlen_t compq_len);
extern void RNGSTDCALL STRRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRSEN(char *job, char *compq, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, float *wr, float *wi, rng_int_t *m, float *s, float *sep, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void RNGSTDCALL STRSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL STRSYL(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void RNGSTDCALL STRTRI(char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL STRTTF(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL STRTTP(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL STZRQF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, rng_int_t *info);
extern void RNGSTDCALL STZRZF(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL XERBLA_ARRAY(char *srname_array, rng_int_t *srname_len, rng_int_t *info, rng_strlen_t srname_array_len);
extern void RNGSTDCALL ZBBCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *rwork, rng_int_t *lrwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZBDSQR(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *u, rng_int_t *ldu, doublecomplex *c, rng_int_t *ldc, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZCGESV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, rng_int_t *iter, rng_int_t *info);
extern void RNGSTDCALL ZCPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, double *rwork, rng_int_t *iter, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZGBBRD(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *pt, rng_int_t *ldpt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL ZGBCON(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL ZGBEQU(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGBEQUB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGBRFS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGBRFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGBSV(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGBSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGBSVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGBTRF(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGBTRS(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGEBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL ZGEBAL(char *job, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL ZGEBRD(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGECON(char *norm, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL ZGEEQU(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGEEQUB(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZGEES(char *jobvs, char *sort, RNG_ZGEES_SELECT select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void RNGSTDCALL ZGEESX(char *jobvs, char *sort, RNG_ZGEESX_SELECT select, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL ZGEEV(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL ZGEEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL ZGEGS(char *jobvsl, char *jobvsr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void RNGSTDCALL ZGEGV(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL ZGEHRD(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGELQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGELS(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGELSD(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSS(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSX(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGELSY(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGEQLF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQP3(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQPF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQR2P(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQRF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQRFP(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZGEQRT3(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZGERFS(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGERFSX(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGERQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGESDD(char *jobz, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void RNGSTDCALL ZGESV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGESVD(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void RNGSTDCALL ZGESVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGESVXX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZGETRF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGETRI(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGETRS(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGGBAK(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void RNGSTDCALL ZGGBAL(char *job, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info, rng_strlen_t job_len);
extern void RNGSTDCALL ZGGES(char *jobvsl, char *jobvsr, char *sort, RNG_ZGGES_DELCTG delctg, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void RNGSTDCALL ZGGESX(char *jobvsl, char *jobvsr, char *sort, RNG_ZGGESX_DELCTG delctg, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void RNGSTDCALL ZGGEV(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void RNGSTDCALL ZGGEVX(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void RNGSTDCALL ZGGGLM(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *d, doublecomplex *x, doublecomplex *y, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGHRD(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL ZGGLSE(rng_int_t *m, rng_int_t *n, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, doublecomplex *d, doublecomplex *x, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGQRF(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGRQF(rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZGGSVD(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL ZGGSVP(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, rng_int_t *iwork, double *rwork, doublecomplex *tau, doublecomplex *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL ZGTCON(char *norm, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t norm_len);
extern void RNGSTDCALL ZGTRFS(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGTSV(rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZGTSVX(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZGTTRF(rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGTTRS(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZHBEV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBEVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBEVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBGST(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBGV(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBGVD(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBGVX(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHBTRD(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHECON(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEEQUB(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEEV(char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEEVD(char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEEVR(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEEVX(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEGST(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHEGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHERFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHERFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZHESV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHESVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHESVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZHESWAPR(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRD(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRF(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRI(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRI2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRI2X(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHFRK(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZHGEQZ(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void RNGSTDCALL ZHPCON(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPEV(char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPEVD(char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPEVX(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPGST(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPGV(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPGVD(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPGVX(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPTRD(char *uplo, rng_int_t *n, doublecomplex *ap, double *d, double *e, doublecomplex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPTRF(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPTRI(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHSEIN(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void RNGSTDCALL ZHSEQR(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern void RNGSTDCALL ZLA_GBAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_GBRCOND_C(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern double RNGSTDCALL ZLA_GBRCOND_X(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern void RNGSTDCALL ZLA_GBRFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_GBRPVGRW(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb);
extern void RNGSTDCALL ZLA_GEAMV(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_GERCOND_C(char *trans, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern double RNGSTDCALL ZLA_GERCOND_X(char *trans, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern void RNGSTDCALL ZLA_GERFSX_EXTENDED(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double RNGSTDCALL ZLA_GERPVGRW(rng_int_t *n, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf);
extern void RNGSTDCALL ZLA_HEAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_HERCOND_C(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_HERCOND_X(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_HERFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_HERPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_LIN_BERR(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, doublecomplex *res, double *ayb, double *berr);
extern double RNGSTDCALL ZLA_PORCOND_C(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_PORCOND_X(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_PORFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_PORPVGRW(char *uplo, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_SYAMV(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double RNGSTDCALL ZLA_SYRCOND_C(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_SYRCOND_X(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_SYRFSX_EXTENDED(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLA_SYRPVGRW(char *uplo, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLA_WWADDW(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *w);
extern double RNGSTDCALL ZLANHF(char *norm, char *transr, char *uplo, rng_int_t *n, doublecomplex *a, double *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLAPMR(int *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL ZLARFGP(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void RNGSTDCALL ZLARSCL2(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void RNGSTDCALL ZLASCL2(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void RNGSTDCALL ZLAT2C(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBCON(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBEQU(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBRFS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBSTF(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBSV(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZPBTRF(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBTRS(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPFTRF(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPFTRI(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPFTRS(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOCON(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOEQU(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPOEQUB(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void RNGSTDCALL ZPORFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPORFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZPOSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZPOSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZPOTRF(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOTRI(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPCON(char *uplo, rng_int_t *n, doublecomplex *ap, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPEQU(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZPPTRF(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPTRI(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPSTF2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPSTRF(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPTCON(rng_int_t *n, double *d, doublecomplex *e, double *anorm, double *rcond, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZPTEQR(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL ZPTRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPTSV(rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void RNGSTDCALL ZPTSVX(char *fact, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len);
extern void RNGSTDCALL ZPTTRF(rng_int_t *n, double *d, doublecomplex *e, rng_int_t *info);
extern void RNGSTDCALL ZPTTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPCON(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPTRF(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPTRI(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSTEDC(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL ZSTEGR(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void RNGSTDCALL ZSTEIN(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void RNGSTDCALL ZSTEQR(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void RNGSTDCALL ZSYCON(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYCONV(char *uplo, char *way, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void RNGSTDCALL ZSYEQUB(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYRFS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYRFSX(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZSYSV(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYSVX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYSVXX(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZSYSWAPR(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRF(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRI(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRI2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRI2X(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRS(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTRS2(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTBCON(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTBRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTBTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTFSM(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTFTRI(char *transr, char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTFTTP(char *transr, char *uplo, rng_int_t *n, doublecomplex *arf, doublecomplex *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTFTTR(char *transr, char *uplo, rng_int_t *n, doublecomplex *arf, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTGEVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL ZTGEXC(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void RNGSTDCALL ZTGSEN(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void RNGSTDCALL ZTGSJA(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void RNGSTDCALL ZTGSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL ZTGSYL(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZTPCON(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPMQRT(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZTPQRT(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZTPQRT2(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void RNGSTDCALL ZTPRFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL ZTPRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPTRI(char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTPTTF(char *transr, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTPTTR(char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTRCON(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTREVC(char *side, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL ZTREXC(char *compq, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info, rng_strlen_t compq_len);
extern void RNGSTDCALL ZTRRFS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRSEN(char *job, char *compq, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, doublecomplex *w, rng_int_t *m, double *s, double *sep, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void RNGSTDCALL ZTRSNA(char *job, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *ldwork, double *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void RNGSTDCALL ZTRSYL(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void RNGSTDCALL ZTRTRI(char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRTRS(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZTRTTF(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTRTTP(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTZRQF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, rng_int_t *info);
extern void RNGSTDCALL ZTZRZF(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNBDB(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, double *phi, doublecomplex *taup1, doublecomplex *taup2, doublecomplex *tauq1, doublecomplex *tauq2, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL ZUNCSD(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void RNGSTDCALL ZUNGBR(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void RNGSTDCALL ZUNGHR(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGLQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGQL(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGQR(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGRQ(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZUNGTR(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZUNMBR(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMHR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMLQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMQL(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMQR(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMRQ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMRZ(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUPGTR(char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZUPMTR(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);

/* LAPACK auxiliaries */
extern void RNGSTDCALL CGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGEBD2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGELQ2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQL2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGEQR2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGERQ2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CGESC2(rng_int_t *n, complex *a, rng_int_t *lda, complex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGSTDCALL CGETC2(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL CGETF2(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL CGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CHEGS2(rng_int_t *itype, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETD2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CHETF2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *x, rng_int_t *ldx, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLACGV(rng_int_t *n, complex *x, rng_int_t *incx);
extern void RNGSTDCALL CLACN2(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL CLACON(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase);
extern void RNGSTDCALL CLACP2(char *uplo, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLACPY(char *uplo, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLACRM(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void RNGSTDCALL CLACRT(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, complex *c, complex *s);
extern complex RNGSTDCALL CLADIV(complex *ret_val, complex *x, complex *y);

extern void RNGSTDCALL CLAED0(rng_int_t *qsiz, rng_int_t *n, float *d, float *e, complex *q, rng_int_t *ldq, complex *qstore, rng_int_t *ldqs, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLAED7(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, complex *q, rng_int_t *ldq, float *rho, rng_int_t *indxq, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLAED8(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, complex *q, rng_int_t *ldq, float *d, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, complex *q2, rng_int_t *ldq2, float *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void RNGSTDCALL CLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *v, complex *b, rng_int_t *ldb, float *rwork, float *eps3, float *smlnum, rng_int_t *info);
extern void RNGSTDCALL CLAESY(complex *a, complex *b, complex *c, complex *rt1, complex *rt2, complex *evscal, complex *cs1, complex *sn1);
extern void RNGSTDCALL CLAEV2(complex *a, complex *b, complex *c, float *rt1, float *rt2, float *cs1, complex *sn1);
extern void RNGSTDCALL CLAG2Z(rng_int_t *m, rng_int_t *n, complex *sa, rng_int_t *ldsa, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL CLAGS2(rng_int_t *upper, float *a1, complex *a2, float *a3, float *b1, complex *b2, float *b3, float *csu, complex *snu, float *csv, complex *snv, float *csq, complex *snq);
extern void RNGSTDCALL CLAGTM(char *trans, rng_int_t *n, rng_int_t *nrhs, float *alpha, complex *dl, complex *d, complex *du, complex *x, rng_int_t *ldx, float *beta, complex *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void RNGSTDCALL CLAHEF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL CLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void RNGSTDCALL CLAIC1(rng_int_t *job, rng_int_t *j, complex *x, float *sest, complex *w, complex *gamma, float *sestpr, complex *s, complex *c);
extern void RNGSTDCALL CLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *rwork, rng_int_t *info);
extern void RNGSTDCALL CLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLALSD(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, complex *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANGB(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL CLANGE(char *norm, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL CLANGT(char *norm, rng_int_t *n, complex *dl, complex *d, complex *du, rng_strlen_t norm_len);
extern float RNGSTDCALL CLANHB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANHE(char *norm, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANHP(char *norm, char *uplo, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANHS(char *norm, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL CLANHT(char *norm, rng_int_t *n, float *d, complex *e, rng_strlen_t norm_len);
extern float RNGSTDCALL CLANSB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANSP(char *norm, char *uplo, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANSY(char *norm, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL CLANTB(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float RNGSTDCALL CLANTP(char *norm, char *uplo, char *diag, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float RNGSTDCALL CLANTR(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CLAPLL(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *ssmin);
extern void RNGSTDCALL CLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL CLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQGE(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHB(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHE(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQHP(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *work);
extern void RNGSTDCALL CLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *auxv, complex *f, rng_int_t *ldf);
extern void RNGSTDCALL CLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CLAQR1(rng_int_t *n, complex *h, rng_int_t *ldh, complex *s1, complex *s2, complex *v);
extern void RNGSTDCALL CLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void RNGSTDCALL CLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void RNGSTDCALL CLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL CLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, complex *s, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *v, rng_int_t *ldv, complex *u, rng_int_t *ldu, rng_int_t *nv, complex *wv, rng_int_t *ldwv, rng_int_t *nh, complex *wh, rng_int_t *ldwh);
extern void RNGSTDCALL CLAQSB(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQSP(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAQSY(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL CLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, complex *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void RNGSTDCALL CLAR2V(rng_int_t *n, complex *x, complex *y, complex *z, rng_int_t *incx, float *c, complex *s, rng_int_t *incc);
extern void RNGSTDCALL CLARCM(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void RNGSTDCALL CLARFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL CLARF(char *side, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void RNGSTDCALL CLARFG(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void RNGSTDCALL CLARFT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL CLARFX(char *side, rng_int_t *m, rng_int_t *n, complex *v, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void RNGSTDCALL CLARGV(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void RNGSTDCALL CLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, complex *x);
extern void RNGSTDCALL CLARRV(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL CLARTG(complex *f, complex *g, float *cs, complex *sn, complex *r);
extern void RNGSTDCALL CLARTV(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, complex *s, rng_int_t *incc);
extern void RNGSTDCALL CLARZB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL CLARZ(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void RNGSTDCALL CLARZT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL CLASCL(char *type, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void RNGSTDCALL CLASET(char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *beta, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLASR(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, float *c, float *s, complex *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void RNGSTDCALL CLASWP(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL CLASYF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLATBS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL CLATDF(rng_int_t *ijob, rng_int_t *n, complex *z, rng_int_t *ldz, complex *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL CLATPS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, complex *ap, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL CLATRD(char *uplo, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *e, complex *tau, complex *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLATRS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL CLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *work);
extern void RNGSTDCALL CLATZM(char *side, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c1, complex *c2, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void RNGSTDCALL CLAUU2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CLAUUM(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPBTF2(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPOTF2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CPTTS2(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb);
extern void RNGSTDCALL CROT(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, float *c, complex *s);
extern void RNGSTDCALL CSPMV(char *uplo, rng_int_t *n, complex *alpha, complex *ap, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSPR(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSRSCL(rng_int_t *n, float *sa, complex *sx, rng_int_t *incx);
extern void RNGSTDCALL CSYMV(char *uplo, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYR(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL CSYTF2(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL CTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void RNGSTDCALL CTGSY2(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL CTRTI2(char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL CUNG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void RNGSTDCALL CUNM2L(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNM2R(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNML2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMR2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL CUNMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGEBD2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGELQ2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQL2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGEQR2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGERQ2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DGESC2(rng_int_t *n, double *a, rng_int_t *lda, double *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGSTDCALL DGETC2(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL DGETF2(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL DGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DLABAD(double *small, double *large);
extern void RNGSTDCALL DLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *x, rng_int_t *ldx, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLACN2(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL DLACON(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase);
extern void RNGSTDCALL DLACPY(char *uplo, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLADIV(double *a, double *b, double *c, double *d, double *p, double *q);
extern void RNGSTDCALL DLAE2(double *a, double *b, double *c, double *rt1, double *rt2);
extern void RNGSTDCALL DLAEBZ(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, double *abstol, double *reltol, double *pivmin, double *d, double *e, double *e2, rng_int_t *nval, double *ab, double *c, rng_int_t *mout, rng_int_t *nab, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED0(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, double *d, double *e, double *q, rng_int_t *ldq, double *qstore, rng_int_t *ldqs, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED1(rng_int_t *n, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED2(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, double *z, double *dlamda, double *w, double *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL DLAED3(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *q2, rng_int_t *indx, rng_int_t *ctot, double *w, double *s, rng_int_t *info);
extern void RNGSTDCALL DLAED4(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam, rng_int_t *info);
extern void RNGSTDCALL DLAED5(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam);
extern void RNGSTDCALL DLAED6(rng_int_t *kniter, rng_int_t *orgati, double *rho, double *d, double *z, double *finit, double *tau, rng_int_t *info);
extern void RNGSTDCALL DLAED7(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLAED8(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, double *q2, rng_int_t *ldq2, double *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGSTDCALL DLAED9(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *w, double *s, rng_int_t *lds, rng_int_t *info);
extern void RNGSTDCALL DLAEDA(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *q, rng_int_t *qptr, double *z, double *ztemp, rng_int_t *info);
extern void RNGSTDCALL DLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vr, double *vi, double *b, rng_int_t *ldb, double *work, double *eps3, double *smlnum, double *bignum, rng_int_t *info);
extern void RNGSTDCALL DLAEV2(double *a, double *b, double *c, double *rt1, double *rt2, double *cs1, double *sn1);
extern void RNGSTDCALL DLAEXC(rng_int_t *wantq, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *info);
extern void RNGSTDCALL DLAG2(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *safmin, double *scale1, double *scale2, double *wr1, double *wr2, double *wi);
extern void RNGSTDCALL DLAG2S(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL DLAGS2(rng_int_t *upper, double *a1, double *a2, double *a3, double *b1, double *b2, double *b3, double *csu, double *snu, double *csv, double *snv, double *csq, double *snq);
extern void RNGSTDCALL DLAGTF(rng_int_t *n, double *a, double *lambda, double *b, double *c, double *tol, double *d, rng_int_t *in, rng_int_t *info);
extern void RNGSTDCALL DLAGTM(char *trans, rng_int_t *n, rng_int_t *nrhs, double *alpha, double *dl, double *d, double *du, double *x, rng_int_t *ldx, double *beta, double *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void RNGSTDCALL DLAGTS(rng_int_t *job, rng_int_t *n, double *a, double *b, double *c, double *d, rng_int_t *in, double *y, double *tol, rng_int_t *info);
extern void RNGSTDCALL DLAGV2(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *csl, double *snl, double *csr, double *snr);
extern void RNGSTDCALL DLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL DLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void RNGSTDCALL DLAIC1(rng_int_t *job, rng_int_t *j, double *x, double *sest, double *w, double *gamma, double *sestpr, double *s, double *c);
extern rng_int_t RNGSTDCALL DLAISNAN(double *din1, double *din2);
extern void RNGSTDCALL DLALN2(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, double *smin, double *ca, double *a, rng_int_t *lda, double *d1, double *d2, double *b, rng_int_t *ldb, double *wr, double *wi, double *x, rng_int_t *ldx, double *scale, double *xnorm, rng_int_t *info);
extern void RNGSTDCALL DLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *info);
extern void RNGSTDCALL DLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLALSD(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLAMRG(rng_int_t *n1, rng_int_t *n2, double *a, rng_int_t *dtrd1, rng_int_t *dtrd2, rng_int_t *index);
extern rng_int_t RNGSTDCALL DLANEG(rng_int_t *n, double *d, double *lld, double *sigma, double *pivmin, rng_int_t *r);
extern double RNGSTDCALL DLANGB(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL DLANGE(char *norm, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL DLANGT(char *norm, rng_int_t *n, double *dl, double *d, double *du, rng_strlen_t norm_len);
extern double RNGSTDCALL DLANHS(char *norm, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL DLANSB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL DLANSP(char *norm, char *uplo, rng_int_t *n, double *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL DLANST(char *norm, rng_int_t *n, double *d, double *e, rng_strlen_t norm_len);
extern double RNGSTDCALL DLANSY(char *norm, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL DLANTB(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double RNGSTDCALL DLANTP(char *norm, char *uplo, char *diag, rng_int_t *n, double *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double RNGSTDCALL DLANTR(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL DLANV2(double *a, double *b, double *c, double *d, double *rt1r, double *rt1i, double *rt2r, double *rt2i, double *cs, double *sn);
extern void RNGSTDCALL DLAPLL(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ssmin);
extern void RNGSTDCALL DLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern double RNGSTDCALL DLAPY2(double *x, double *y);
extern double RNGSTDCALL DLAPY3(double *x, double *y, double *z);
extern void RNGSTDCALL DLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQGE(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *work);
extern void RNGSTDCALL DLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *auxv, double *f, rng_int_t *ldf);
extern void RNGSTDCALL DLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DLAQR1(rng_int_t *n, double *h, rng_int_t *ldh, double *sr1, double *si1, double *sr2, double *si2, double *v);
extern void RNGSTDCALL DLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double *v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t *nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void RNGSTDCALL DLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t * ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double * v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t * nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void RNGSTDCALL DLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, double *sr, double *si, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *v, rng_int_t *ldv, double *u, rng_int_t *ldu, rng_int_t *nv, double *wv, rng_int_t *ldwv, rng_int_t *nh, double *wh, rng_int_t *ldwh);
extern void RNGSTDCALL DLAQSB(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQSP(char *uplo, rng_int_t *n, double *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQSY(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL DLAQTR(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, double *t, rng_int_t *ldt, double *b, double *w, double *scale, double *x, double *work, rng_int_t *info);
extern void RNGSTDCALL DLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, double *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void RNGSTDCALL DLAR2V(rng_int_t *n, double *x, double *y, double *z, rng_int_t *incx, double *c, double *s, rng_int_t *incc);
extern void RNGSTDCALL DLARFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL DLARF(char *side, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void RNGSTDCALL DLARFG(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void RNGSTDCALL DLARFX(char *side, rng_int_t *m, rng_int_t *n, double *v, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void RNGSTDCALL DLARGV(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void RNGSTDCALL DLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, double *x);
extern void RNGSTDCALL DLARRA(rng_int_t *n, double *d, double *e, double *e2, double *spltol, double *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGSTDCALL DLARRB(rng_int_t *n, double *d, double *lld, rng_int_t *ifirst, rng_int_t *ilast, double *rtol1, double *rtol2, rng_int_t *offset, double *w, double *wgap, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *twist, rng_int_t *info);
extern void RNGSTDCALL DLARRC(char *jobt, rng_int_t *n, double *vl, double *vu, double *d, double *e, double *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info, rng_strlen_t jobt_len);
extern void RNGSTDCALL DLARRD(char *range, char *order, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *gers, double *reltol, double *d, double *e, double *e2, double *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wl, double *wu, rng_int_t *iblock, rng_int_t *indexw, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void RNGSTDCALL DLARRE(char *range, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *d, double *e, double *e2, double *rtol1, double *rtol2, double *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *pivmin, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len);
extern void RNGSTDCALL DLARRF(rng_int_t *n, double *d, double *l, double *ld, rng_int_t *clstrt, rng_int_t *clend, double *w, double *wgap, double *werr, double *spdiam, double *clgapl, double *clgapr, double *pivmin, double *sigma, double *dplus, double *lplus, double *work, rng_int_t *info);
extern void RNGSTDCALL DLARRJ(rng_int_t *n, double *d, double *e2, rng_int_t *ifirst, rng_int_t *ilast, double *rtol, rng_int_t *offset, double *w, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *info);
extern void RNGSTDCALL DLARRK(rng_int_t *n, rng_int_t *iw, double *gl, double *gu, double *d, double *e2, double *pivmin, double *reltol, double *w, double *werr, rng_int_t *info);
extern void RNGSTDCALL DLARRR(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void RNGSTDCALL DLARRV(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLARTG(double *f, double *g, double *cs, double *sn, double *r);
extern void RNGSTDCALL DLARTV(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s, rng_int_t *incc);
extern void RNGSTDCALL DLARUV(rng_int_t *iseed, rng_int_t *n, double *x);
extern void RNGSTDCALL DLARZB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL DLARZ(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void RNGSTDCALL DLARZT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL DLAS2(double *f, double *g, double *h, double *ssmin, double *ssmax);
extern void RNGSTDCALL DLASCL(char *type, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void RNGSTDCALL DLASD0(rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD1(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD2(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *dsigma, double *u2, rng_int_t *ldu2, double *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL DLASD3(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *q, rng_int_t *ldq, double *dsigma, double *u, rng_int_t *ldu, double *u2, rng_int_t *ldu2, double *vt, rng_int_t *ldvt, double *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, double *z, rng_int_t *info);
extern void RNGSTDCALL DLASD4(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *sigma, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASD5(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dsigma, double *work);
extern void RNGSTDCALL DLASD6(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *vf, double *vl, double *alpha, double *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLASD7(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *zw, double *vf, double *vfw, double *vl, double *vlw, double *alpha, double *beta, double *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *c, double *s, rng_int_t *info);
extern void RNGSTDCALL DLASD8(rng_int_t *icompq, rng_int_t *k, double *d, double *z, double *vf, double *vl, double *difl, double *difr, rng_int_t *lddifr, double *dsigma, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASDA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL DLASDQ(char *uplo, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLASDT(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void RNGSTDCALL DLASET(char *uplo, rng_int_t *m, rng_int_t *n, double *alpha, double *beta, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLASQ1(rng_int_t *n, double *d, double *e, double *work, rng_int_t *info);
extern void RNGSTDCALL DLASQ2(rng_int_t *n, double *z, rng_int_t *info);
extern void RNGSTDCALL DLASQ3(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *sigma, double *desig, double *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *g, double *tau);
extern void RNGSTDCALL DLASQ4(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, rng_int_t *n0in, double *dmin, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *tau, rng_int_t *ttype, double *g);
extern void RNGSTDCALL DLASQ5(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *tau, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2, rng_int_t *ieee);
extern void RNGSTDCALL DLASQ6(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2);
extern void RNGSTDCALL DLASR(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, double *c, double *s, double *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void RNGSTDCALL DLASV2(double *f, double *g, double *h, double *ssmin, double *ssmax, double *snr, double *csr, double *snl, double *csl);
extern void RNGSTDCALL DLASWP(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL DLASY2(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, double *tl, rng_int_t *ldtl, double *tr, rng_int_t *ldtr, double *b, rng_int_t *ldb, double *scale, double *x, rng_int_t *ldx, double *xnorm, rng_int_t *info);
extern void RNGSTDCALL DLASYF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *ipiv, double *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLATBS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL DLATDF(rng_int_t *ijob, rng_int_t *n, double *z, rng_int_t *ldz, double *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL DLATPS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, double *ap, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL DLATRD(char *uplo, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *e, double *tau, double *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLATRS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, double *a, rng_int_t *lda, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL DLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *work);
extern void RNGSTDCALL DLATZM(char *side, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c1, double *c2, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void RNGSTDCALL DLAUU2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DLAUUM(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DORG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void RNGSTDCALL DORM2L(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORM2R(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORML2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DORMR2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL DPBTF2(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPOTF2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DPTTS2(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb);
extern void RNGSTDCALL DRSCL(rng_int_t *n, double *sa, double *sx, rng_int_t *incx);
extern void RNGSTDCALL DSYGS2(rng_int_t *itype, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTD2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DSYTF2(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL DTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL DTGSY2(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL DTRTI2(char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double RNGSTDCALL DZSUM1(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL ICMAX1(rng_int_t *n, complex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL IEEECK(rng_int_t *ispec, float *zero, float *one);
extern rng_int_t RNGSTDCALL IPARMQ(rng_int_t *ispec, char *name, char *opts, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, rng_int_t *lwork, rng_strlen_t name_len, rng_strlen_t opts_len);
extern rng_int_t RNGSTDCALL IZMAX1(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t RNGSTDCALL LSAMEN(rng_int_t *n, char *ca, char *cb, rng_strlen_t ca_len, rng_strlen_t cb_len);
extern float RNGSTDCALL SCSUM1(rng_int_t *n, complex *cx, rng_int_t *incx);
extern void RNGSTDCALL SGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGEBD2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGELQ2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQL2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGEQR2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGERQ2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SGESC2(rng_int_t *n, float *a, rng_int_t *lda, float *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void RNGSTDCALL SGETC2(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL SGETF2(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL SGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SLABAD(float *small, float *large);
extern void RNGSTDCALL SLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *x, rng_int_t *ldx, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLACN2(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL SLACON(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase);
extern void RNGSTDCALL SLACPY(char *uplo, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLADIV(float *a, float *b, float *c, float *d, float *p, float *q);
extern void RNGSTDCALL SLAE2(float *a, float *b, float *c, float *rt1, float *rt2);
extern void RNGSTDCALL SLAEBZ(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, float *abstol, float *reltol, float *pivmin, float *d, float *e, float *e2, rng_int_t *nval, float *ab, float *c, rng_int_t *mout, rng_int_t *nab, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED0(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, float *d, float *e, float *q, rng_int_t *ldq, float *qstore, rng_int_t *ldqs, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED1(rng_int_t *n, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *work, rng_int_t * iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED2(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, float *z, float *dlamda, float *w, float *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL SLAED3(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *q2, rng_int_t *indx, rng_int_t *ctot, float *w, float *s, rng_int_t *info);
extern void RNGSTDCALL SLAED4(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam, rng_int_t *info);
extern void RNGSTDCALL SLAED5(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam);
extern void RNGSTDCALL SLAED6(rng_int_t *kniter, rng_int_t *orgati, float *rho, float *d, float *z, float *finit, float *tau, rng_int_t *info);
extern void RNGSTDCALL SLAED7(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLAED8(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, float *q2, rng_int_t *ldq2, float *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void RNGSTDCALL SLAED9(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *w, float *s, rng_int_t *lds, rng_int_t *info);
extern void RNGSTDCALL SLAEDA(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *q, rng_int_t *qptr, float *z, float *ztemp, rng_int_t *info);
extern void RNGSTDCALL SLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vr, float *vi, float *b, rng_int_t *ldb, float *work, float *eps3, float *smlnum, float *bignum, rng_int_t *info);
extern void RNGSTDCALL SLAEV2(float *a, float *b, float *c, float *rt1, float *rt2, float *cs1, float *sn1);
extern void RNGSTDCALL SLAEXC(rng_int_t *wantq, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *info);
extern void RNGSTDCALL SLAG2D(rng_int_t *m, rng_int_t *n, float *sa, rng_int_t *ldsa, double *a, rng_int_t *lda, rng_int_t *info);
extern void RNGSTDCALL SLAG2(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *safmin, float *scale1, float *scale2, float *wr1, float *wr2, float *wi);
extern void RNGSTDCALL SLAGS2(rng_int_t *upper, float *a1, float *a2, float *a3, float *b1, float *b2, float *b3, float *csu, float *snu, float *csv, float *snv, float *csq, float *snq);
extern void RNGSTDCALL SLAGTF(rng_int_t *n, float *a, float *lambda, float *b, float *c, float *tol, float *d, rng_int_t *in, rng_int_t *info);
extern void RNGSTDCALL SLAGTM(char *trans, rng_int_t *n, rng_int_t *nrhs, float *alpha, float *dl, float *d, float *du, float *x, rng_int_t *ldx, float *beta, float *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void RNGSTDCALL SLAGTS(rng_int_t *job, rng_int_t *n, float *a, float *b, float *c, float *d, rng_int_t *in, float *y, float *tol, rng_int_t *info);
extern void RNGSTDCALL SLAGV2(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *csl, float *snl, float *csr, float *snr);
extern void RNGSTDCALL SLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL SLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void RNGSTDCALL SLAIC1(rng_int_t *job, rng_int_t *j, float *x, float *sest, float *w, float *gamma, float *sestpr, float *s, float *c);
extern rng_int_t RNGSTDCALL SLAISNAN(float *sin1, float *sin2);
extern void RNGSTDCALL SLALN2(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, float *smin, float *ca, float *a, rng_int_t *lda, float *d1, float *d2, float *b, rng_int_t *ldb, float *wr, float *wi, float *x, rng_int_t *ldx, float *scale, float *xnorm, rng_int_t *info);
extern void RNGSTDCALL SLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *info);
extern void RNGSTDCALL SLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLALSD(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLAMRG(rng_int_t *n1, rng_int_t *n2, float *a, rng_int_t *strd1, rng_int_t *strd2, rng_int_t *index);
extern rng_int_t RNGSTDCALL SLANEG(rng_int_t *n, float *d, float *lld, float *sigma, float *pivmin, rng_int_t *r);
extern float RNGSTDCALL SLANGB(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL SLANGE(char *norm, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL SLANGT(char *norm, rng_int_t *n, float *dl, float *d, float *du, rng_strlen_t norm_len);
extern float RNGSTDCALL SLANHS(char *norm, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float RNGSTDCALL SLANSB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL SLANSP(char *norm, char *uplo, rng_int_t *n, float *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL SLANST(char *norm, rng_int_t *n, float *d, float *e, rng_strlen_t norm_len);
extern float RNGSTDCALL SLANSY(char *norm, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float RNGSTDCALL SLANTB(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float RNGSTDCALL SLANTP(char *norm, char *uplo, char *diag, rng_int_t *n, float *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float RNGSTDCALL SLANTR(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL SLANV2(float *a, float *b, float *c, float *d, float *rt1r, float *rt1i, float *rt2r, float *rt2i, float *cs, float *sn);
extern void RNGSTDCALL SLAPLL(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ssmin);
extern void RNGSTDCALL SLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern float RNGSTDCALL SLAPY2(float *x, float *y);
extern float RNGSTDCALL SLAPY3(float *x, float *y, float *z);
extern void RNGSTDCALL SLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQGE(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *work);
extern void RNGSTDCALL SLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *auxv, float *f, rng_int_t *ldf);
extern void RNGSTDCALL SLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SLAQR1(rng_int_t *n, float *h, rng_int_t *ldh, float *sr1, float *si1, float *sr2, float *si2, float *v);
extern void RNGSTDCALL SLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float *work, rng_int_t *lwork);
extern void RNGSTDCALL SLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float * work, rng_int_t *lwork);
extern void RNGSTDCALL SLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL SLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, float *sr, float *si, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *v, rng_int_t *ldv, float *u, rng_int_t *ldu, rng_int_t *nv, float *wv, rng_int_t *ldwv, rng_int_t *nh, float *wh, rng_int_t *ldwh);
extern void RNGSTDCALL SLAQSB(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQSP(char *uplo, rng_int_t *n, float *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQSY(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL SLAQTR(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, float *t, rng_int_t *ldt, float *b, float *w, float *scale, float *x, float *work, rng_int_t *info);
extern void RNGSTDCALL SLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, float *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void RNGSTDCALL SLAR2V(rng_int_t *n, float *x, float *y, float *z, rng_int_t *incx, float *c, float *s, rng_int_t *incc);
extern void RNGSTDCALL SLARFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL SLARF(char *side, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void RNGSTDCALL SLARFG(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void RNGSTDCALL SLARFX(char *side, rng_int_t *m, rng_int_t *n, float *v, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void RNGSTDCALL SLARGV(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void RNGSTDCALL SLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, float *x);
extern void RNGSTDCALL SLARRA(rng_int_t *n, float *d, float *e, float *e2, float *spltol, float *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void RNGSTDCALL SLARRB(rng_int_t *n, float *d, float *lld, rng_int_t *ifirst, rng_int_t *ilast, float *rtol1, float *rtol2, rng_int_t *offset, float *w, float *wgap, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *twist, rng_int_t *info);
extern void RNGSTDCALL SLARRC(char *jobt, rng_int_t *n, float *vl, float *vu, float *d, float *e, float *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info, rng_strlen_t jobt_len);
extern void RNGSTDCALL SLARRD(char *range, char *order, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *gers, float *reltol, float *d, float *e, float *e2, float *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wl, float *wu, rng_int_t *iblock, rng_int_t *indexw, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void RNGSTDCALL SLARRE(char *range, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *d, float *e, float *e2, float *rtol1, float *rtol2, float *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *pivmin, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len);
extern void RNGSTDCALL SLARRF(rng_int_t *n, float *d, float *l, float *ld, rng_int_t *clstrt, rng_int_t *clend, float *w, float *wgap, float *werr, float *spdiam, float *clgapl, float *clgapr, float *pivmin, float *sigma, float *dplus, float *lplus, float *work, rng_int_t *info);
extern void RNGSTDCALL SLARRJ(rng_int_t *n, float *d, float *e2, rng_int_t *ifirst, rng_int_t *ilast, float *rtol, rng_int_t *offset, float *w, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *info);
extern void RNGSTDCALL SLARRK(rng_int_t *n, rng_int_t *iw, float *gl, float *gu, float *d, float *e2, float *pivmin, float *reltol, float *w, float *werr, rng_int_t *info);
extern void RNGSTDCALL SLARRR(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void RNGSTDCALL SLARRV(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLARTG(float *f, float *g, float *cs, float *sn, float *r);
extern void RNGSTDCALL SLARTV(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s, rng_int_t *incc);
extern void RNGSTDCALL SLARUV(rng_int_t *iseed, rng_int_t *n, float *x);
extern void RNGSTDCALL SLARZB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL SLARZ(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void RNGSTDCALL SLARZT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL SLAS2(float *f, float *g, float *h, float *ssmin, float *ssmax);
extern void RNGSTDCALL SLASCL(char *type, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void RNGSTDCALL SLASD0(rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD1(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD2(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *dsigma, float *u2, rng_int_t *ldu2, float *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void RNGSTDCALL SLASD3(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *q, rng_int_t *ldq, float *dsigma, float *u, rng_int_t *ldu, float *u2, rng_int_t *ldu2, float *vt, rng_int_t *ldvt, float *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, float *z, rng_int_t *info);
extern void RNGSTDCALL SLASD4(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *sigma, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASD5(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dsigma, float *work);
extern void RNGSTDCALL SLASD6(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *vf, float *vl, float *alpha, float *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLASD7(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *zw, float *vf, float *vfw, float *vl, float *vlw, float *alpha, float *beta, float *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *c, float *s, rng_int_t *info);
extern void RNGSTDCALL SLASD8(rng_int_t *icompq, rng_int_t *k, float *d, float *z, float *vf, float *vl, float *difl, float *difr, rng_int_t *lddifr, float *dsigma, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASDA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL SLASDQ(char *uplo, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLASDT(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void RNGSTDCALL SLASET(char *uplo, rng_int_t *m, rng_int_t *n, float *alpha, float *beta, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLASQ1(rng_int_t *n, float *d, float *e, float *work, rng_int_t *info);
extern void RNGSTDCALL SLASQ2(rng_int_t *n, float *z, rng_int_t *info);
extern void RNGSTDCALL SLASQ3(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *sigma, float *desig, float *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *g, float *tau);
extern void RNGSTDCALL SLASQ4(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, rng_int_t *n0in, float *dmin, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *tau, rng_int_t *ttype, float *g);
extern void RNGSTDCALL SLASQ5(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *tau, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2, rng_int_t *ieee);
extern void RNGSTDCALL SLASQ6(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2);
extern void RNGSTDCALL SLASR(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, float *c, float *s, float *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void RNGSTDCALL SLASV2(float *f, float *g, float *h, float *ssmin, float *ssmax, float *snr, float *csr, float *snl, float *csl);
extern void RNGSTDCALL SLASWP(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL SLASY2(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, float *tl, rng_int_t *ldtl, float *tr, rng_int_t *ldtr, float *b, rng_int_t *ldb, float *scale, float *x, rng_int_t *ldx, float *xnorm, rng_int_t *info);
extern void RNGSTDCALL SLASYF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *ipiv, float *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLATBS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL SLATDF(rng_int_t *ijob, rng_int_t *n, float *z, rng_int_t *ldz, float *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL SLATPS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, float *ap, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL SLATRD(char *uplo, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *e, float *tau, float *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLATRS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, float *a, rng_int_t *lda, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL SLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *work);
extern void RNGSTDCALL SLATZM(char *side, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c1, float *c2, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void RNGSTDCALL SLAUU2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SLAUUM(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SORG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void RNGSTDCALL SORM2L(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORM2R(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORML2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SORMR2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL SPBTF2(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPOTF2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SPTTS2(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb);
extern void RNGSTDCALL SRSCL(rng_int_t *n, float *sa, float *sx, rng_int_t *incx);
extern void RNGSTDCALL SSYGS2(rng_int_t *itype, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTD2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL SSYTF2(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL STGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL STGSY2(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL STRTI2(char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZDRSCL(rng_int_t *n, double *sa, doublecomplex *sx, rng_int_t *incx);
extern void RNGSTDCALL ZGBTF2(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGEBD2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEHD2(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGELQ2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQL2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGEQR2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGERQ2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZGESC2(rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void RNGSTDCALL ZGETC2(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void RNGSTDCALL ZGETF2(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void RNGSTDCALL ZGTTS2(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZHEGS2(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETD2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZHETF2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLABRD(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *x, rng_int_t *ldx, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLACGV(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern void RNGSTDCALL ZLACN2(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase, rng_int_t *isave);
extern void RNGSTDCALL ZLACON(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase);
extern void RNGSTDCALL ZLACP2(char *uplo, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLACPY(char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLACRM(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void RNGSTDCALL ZLACRT(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, doublecomplex *c, doublecomplex *s);
extern doublecomplex RNGSTDCALL ZLADIV(doublecomplex *ret_val, doublecomplex *x, doublecomplex *y);

extern void RNGSTDCALL ZLAED0(rng_int_t *qsiz, rng_int_t *n, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *qstore, rng_int_t *ldqs, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLAED7(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, doublecomplex *q, rng_int_t *ldq, double *rho, rng_int_t *indxq, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLAED8(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, doublecomplex *q, rng_int_t *ldq, double *d, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, doublecomplex *q2, rng_int_t *ldq2, double *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void RNGSTDCALL ZLAEIN(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *v, doublecomplex *b, rng_int_t *ldb, double *rwork, double *eps3, double *smlnum, rng_int_t *info);
extern void RNGSTDCALL ZLAESY(doublecomplex *a, doublecomplex *b, doublecomplex *c, doublecomplex *rt1, doublecomplex *rt2, doublecomplex *evscal, doublecomplex *cs1, doublecomplex *sn1);
extern void RNGSTDCALL ZLAEV2(doublecomplex *a, doublecomplex *b, doublecomplex *c, double *rt1, double *rt2, double *cs1, doublecomplex *sn1);
extern void RNGSTDCALL ZLAG2C(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info);
extern void RNGSTDCALL ZLAGS2(rng_int_t *upper, double *a1, doublecomplex * a2, double *a3, double *b1, doublecomplex *b2, double *b3, double *csu, doublecomplex *snu, double *csv, doublecomplex * snv, double *csq, doublecomplex *snq);
extern void RNGSTDCALL ZLAGTM(char *trans, rng_int_t *n, rng_int_t *nrhs, double *alpha, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *x, rng_int_t *ldx, double *beta, doublecomplex *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void RNGSTDCALL ZLAHEF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLAHQR(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *info);
extern void RNGSTDCALL ZLAHR2(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLAHRD(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void RNGSTDCALL ZLAIC1(rng_int_t *job, rng_int_t *j, doublecomplex *x, double *sest, doublecomplex *w, doublecomplex *gamma, double *sestpr, doublecomplex *s, doublecomplex *c);
extern void RNGSTDCALL ZLALS0(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *rwork, rng_int_t *info);
extern void RNGSTDCALL ZLALSA(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLALSD(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, doublecomplex *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANGB(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL ZLANGE(char *norm, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL ZLANGT(char *norm, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, rng_strlen_t norm_len);
extern double RNGSTDCALL ZLANHB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANHE(char *norm, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANHP(char *norm, char *uplo, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANHS(char *norm, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double RNGSTDCALL ZLANHT(char *norm, rng_int_t *n, double *d, doublecomplex *e, rng_strlen_t norm_len);
extern double RNGSTDCALL ZLANSB(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANSP(char *norm, char *uplo, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANSY(char *norm, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double RNGSTDCALL ZLANTB(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double RNGSTDCALL ZLANTP(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double RNGSTDCALL ZLANTR(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZLAPLL(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *ssmin);
extern void RNGSTDCALL ZLAPMT(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void RNGSTDCALL ZLAQGB(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQGE(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHB(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHE(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQHP(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQP2(rng_int_t *m, rng_int_t *n, rng_int_t *offset, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *work);
extern void RNGSTDCALL ZLAQPS(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *auxv, doublecomplex *f, rng_int_t *ldf);
extern void RNGSTDCALL ZLAQR0(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZLAQR1(rng_int_t *n, doublecomplex *h, rng_int_t*ldh, doublecomplex *s1, doublecomplex *s2, doublecomplex *v);
extern void RNGSTDCALL ZLAQR2(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void RNGSTDCALL ZLAQR3(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void RNGSTDCALL ZLAQR4(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void RNGSTDCALL ZLAQR5(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, doublecomplex *s, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *v, rng_int_t *ldv, doublecomplex *u, rng_int_t *ldu, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, rng_int_t *nh, doublecomplex *wh, rng_int_t *ldwh);
extern void RNGSTDCALL ZLAQSB(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQSP(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAQSY(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void RNGSTDCALL ZLAR1V(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, doublecomplex *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void RNGSTDCALL ZLAR2V(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *z, rng_int_t *incx, double *c, doublecomplex *s, rng_int_t *incc);
extern void RNGSTDCALL ZLARCM(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void RNGSTDCALL ZLARFB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL ZLARF(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void RNGSTDCALL ZLARFG(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void RNGSTDCALL ZLARFT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL ZLARFX(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void RNGSTDCALL ZLARGV(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void RNGSTDCALL ZLARNV(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, doublecomplex *x);
extern void RNGSTDCALL ZLARRV(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void RNGSTDCALL ZLARTG(doublecomplex *f, doublecomplex *g, double *cs, doublecomplex *sn, doublecomplex *r);
extern void RNGSTDCALL ZLARTV(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, doublecomplex *s, rng_int_t *incc);
extern void RNGSTDCALL ZLARZB(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL ZLARZ(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void RNGSTDCALL ZLARZT(char *direct, char *storev, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void RNGSTDCALL ZLASCL(char *type, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void RNGSTDCALL ZLASET(char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *beta, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLASR(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, double *c, double *s, doublecomplex *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void RNGSTDCALL ZLASWP(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void RNGSTDCALL ZLASYF(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLATBS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL ZLATDF(rng_int_t *ijob, rng_int_t *n, doublecomplex *z, rng_int_t *ldz, doublecomplex *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void RNGSTDCALL ZLATPS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, doublecomplex *ap, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL ZLATRD(char *uplo, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *e, doublecomplex *tau, doublecomplex *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLATRS(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void RNGSTDCALL ZLATRZ(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work);
extern void RNGSTDCALL ZLATZM(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c1, doublecomplex *c2, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void RNGSTDCALL ZLAUU2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZLAUUM(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPBTF2(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPOTF2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZPTTS2(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb);
extern void RNGSTDCALL ZROT(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, double *c, doublecomplex *s);
extern void RNGSTDCALL ZSPMV(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSPR(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *ap, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYMV(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYR(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZSYTF2(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void RNGSTDCALL ZTGEX2(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void RNGSTDCALL ZTGSY2(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *info, rng_strlen_t trans_len);
extern void RNGSTDCALL ZTRTI2(char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void RNGSTDCALL ZUNG2L(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNG2R(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNGL2(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNGR2(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void RNGSTDCALL ZUNM2L(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNM2R(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNML2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMR2(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void RNGSTDCALL ZUNMR3(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);

/* FFT routines */
extern void RNGSTDCALL CFFT1D(rng_int_t *mode, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1DX(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1M(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT1MX(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT2DX(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3DX(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *y, complex *comm, rng_int_t *info);
extern void RNGSTDCALL CFFT3DY(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, complex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, complex *comm, rng_int_t *lcomm, rng_int_t *info);
extern void RNGSTDCALL CSFFT(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT1D(rng_int_t *mode, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex * x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex * x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, complex *x, float *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL CSFFTM(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT1D(rng_int_t *mode, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL DZFFTM(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT1D(rng_int_t *mode, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, float *x, complex *y, float *comm, rng_int_t *info);
extern void RNGSTDCALL SCFFTM(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT1D(rng_int_t *mode, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT1M(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t * n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZDFFTM(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1D(rng_int_t *mode, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1DX(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1M(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT1MX(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT2D(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT2DX(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3D(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3DX(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *comm, rng_int_t *info);
extern void RNGSTDCALL ZFFT3DY(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, doublecomplex *comm, rng_int_t *lcomm, rng_int_t *info);

/* Sparse BLAS routines */
extern void RNGSTDCALL CAXPYI(rng_int_t *nz, complex *a, complex *x, rng_int_t *indx, complex *y);
extern complex RNGSTDCALL CDOTCI(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CDOTCISUB(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern complex RNGSTDCALL CDOTUI(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CDOTUISUB(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL CGTHR(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGSTDCALL CGTHRZ(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void RNGSTDCALL CSCTR(rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void RNGSTDCALL DAXPYI(rng_int_t *nz, double *a, double *x, rng_int_t *indx, double *y);
extern double RNGSTDCALL DDOTI(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void RNGSTDCALL DGTHR(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void RNGSTDCALL DGTHRZ(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void RNGSTDCALL DROTI(rng_int_t *nz, double *x, rng_int_t *indx, double *y, double *c, double *s);
extern void RNGSTDCALL DSCTR(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void RNGSTDCALL SAXPYI(rng_int_t *nz, float *a, float *x, rng_int_t *indx, float *y);
extern float RNGSTDCALL SDOTI(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void RNGSTDCALL SGTHR(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void RNGSTDCALL SGTHRZ(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void RNGSTDCALL SROTI(rng_int_t *nz, float *x, rng_int_t *indx, float *y, float *c, float *s);
extern void RNGSTDCALL SSCTR(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void RNGSTDCALL ZAXPYI(rng_int_t *nz, doublecomplex *a, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGSTDCALL ZDOTCI(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZDOTCISUB(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex RNGSTDCALL ZDOTUI(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZDOTUISUB(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void RNGSTDCALL ZGTHR(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGSTDCALL ZGTHRZ(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void RNGSTDCALL ZSCTR(rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);

/* Random number generators */
extern void RNGSTDCALL DRANDBETA(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDBINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDBINOMIALREFERENCE(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDBLUMBLUMSHUB(rng_int_t *n, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDCAUCHY(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDCHISQUARED(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDDISCRETEUNIFORM(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDEXPONENTIAL(rng_int_t *n, double *a, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDF(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGAMMA(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGAUSSIAN(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGENERALDISCRETE(rng_int_t *n, double *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGEOMETRIC(rng_int_t *n, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDGEOMETRICREFERENCE(double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDHYPERGEOMETRIC(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDHYPERGEOMETRICREFERENCE(rng_int_t *np, rng_int_t *ns, rng_int_t *m, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZE(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZEBBS(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDINITIALIZEUSER(RNG_DRANDINITIALIZEUSER_UINI uini, RNG_DRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL DRANDLEAPFROG(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL DRANDLOGISTIC(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDLOGNORMAL(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMALREFERENCE(rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMALR(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTSTREFERENCE(rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTSTR(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDNEGATIVEBINOMIAL(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDNEGATIVEBINOMIALREFERENCE(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDPOISSON(rng_int_t *n, double *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL DRANDPOISSONREFERENCE(double *lambda, double *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL DRANDSKIPAHEAD(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL DRANDSTUDENTST(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDTRIANGULAR(rng_int_t *n, double *xmin, double *xmed, double *xmax, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDUNIFORM(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDVONMISES(rng_int_t *n, double *vk, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDWEIBULL(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTINORMAL(rng_int_t *n, rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL DRANDMULTISTUDENTST(rng_int_t *n, rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDBETA(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBLUMBLUMSHUB(rng_int_t *n, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDBINOMIALREFERENCE(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDCAUCHY(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDCHISQUARED(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDDISCRETEUNIFORM(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDEXPONENTIAL(rng_int_t *n, float *a, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDF(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGAMMA(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGAUSSIAN(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGENERALDISCRETE(rng_int_t *n, float *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGEOMETRIC(rng_int_t *n, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDGEOMETRICREFERENCE(float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDHYPERGEOMETRIC(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDHYPERGEOMETRICREFERENCE(rng_int_t *np, rng_int_t *ns, rng_int_t *m, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZE(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZEBBS(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDINITIALIZEUSER(RNG_SRANDINITIALIZEUSER_UINI uini, RNG_SRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void RNGSTDCALL SRANDLEAPFROG(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL SRANDLOGISTIC(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDLOGNORMAL(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMALREFERENCE(rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMALR(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTSTREFERENCE(rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTSTR(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDNEGATIVEBINOMIAL(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDNEGATIVEBINOMIALREFERENCE(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDPOISSON(rng_int_t *n, float *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void RNGSTDCALL SRANDPOISSONREFERENCE(float *lambda, float *ref, rng_int_t *lref, rng_int_t *info);
extern void RNGSTDCALL SRANDSKIPAHEAD(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void RNGSTDCALL SRANDSTUDENTST(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDTRIANGULAR(rng_int_t *n, float *xmin, float *xmed, float *xmax, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDUNIFORM(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDVONMISES(rng_int_t *n, float *vk, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDWEIBULL(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTINORMAL(rng_int_t *n, rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void RNGSTDCALL SRANDMULTISTUDENTST(rng_int_t *n, rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);

/* RNG version information */
extern void RNGSTDCALL RNGVERSION(rng_int_t *major, rng_int_t *minor, rng_int_t *patch);
extern void RNGSTDCALL RNGINFO(void);

/* OMP interfaces */
extern rng_int_t RNGSTDCALL RNGGETMAXTHREADS(void);
extern rng_int_t RNGSTDCALL RNGGETNUMTHREADS(void);
extern void RNGSTDCALL RNGSETNUMTHREADS(rng_int_t *numthreads);
extern rng_int_t RNGSTDCALL RNGGETNUMPROCS(void);

/* Putenv and getenv utilities */
extern void RNGSTDCALL RNGPUTENV(char *name, char *value, rng_strlen_t name_len, rng_strlen_t value_len);
extern void RNGSTDCALL RNGGETENV(char *name, char *value, rng_strlen_t name_len, rng_strlen_t value_len);
extern void RNGSTDCALL RNGLOCATION(char *message, void *arg, rng_strlen_t message_len);
extern void RNGSTDCALL RNGLOCATIONSTRING(char *message, void *arg, char *string, rng_strlen_t message_len, rng_strlen_t string_len);

#else /* ! WIN32 */

/* BLAS routines */
extern void caxpy_(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void ccopy_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex cdotc_(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void cdotcsub_(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern complex cdotu_(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void cdotusub_(complex *ret_val, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void cgbmv_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void cgemm_(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void cgemv_(char *trans, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void cgerc_(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void cgeru_(rng_int_t *m, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda);
extern void chbmv_(char *uplo, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void chemm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void chemv_(char *uplo, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void cher_(char *uplo, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void cher2_(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void cher2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void cherk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void chpmv_(char *uplo, rng_int_t *n, complex *alpha, complex *a, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void chpr_(char *uplo, rng_int_t *n, float *alpha, complex *x, rng_int_t *incx, complex *a, rng_strlen_t uplo_len);
extern void chpr2_(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *a, rng_strlen_t uplo_len);
extern void classq_(rng_int_t *n, complex *x, rng_int_t *incx, float *scale, float *sumsq);
extern void crotg_(complex *a, complex *b, float *c, complex *s);
extern void cscal_(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx);
extern void csrot_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, float *s);
extern void csscal_(rng_int_t *n, float *alpha, complex *x, rng_int_t *incx);
extern void cstemr_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void cswap_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy);
extern void csymm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void csyr2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void csyrk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, complex *alpha, complex *a, rng_int_t *lda, complex *beta, complex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void ctbmv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctbsv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctpmv_(char *uplo, char *trans, char *diag, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctpsv_(char *uplo, char *trans, char *diag, rng_int_t *n, complex *ap, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctrmm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void ctrmv_(char *uplo, char *trans, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctrsm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void ctrsv_(char *uplo, char *trans, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern double dasum_(rng_int_t *n, double *x, rng_int_t *incx);
extern void daxpy_(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double dcabs1_(doublecomplex *z);
extern void dcopy_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern double ddot_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void dgbmv_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void dgemm_(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void dgemv_(char *trans, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void dger_(rng_int_t *m, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda);
extern double dnrm2_(rng_int_t *n, double *x, rng_int_t *incx);
extern void drot_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s);
extern void drotg_(double *a, double *b, double *c, double *s);
extern void drotm_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *param);
extern void drotmg_(double *d1, double *d2, double *b1, double *b2, double *param);
extern void dsbmv_(char *uplo, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void dscal_(rng_int_t *n, double *alpha, double *x, rng_int_t *incx);
extern double dsdot_(rng_int_t *n, float *sx, rng_int_t *incx, float *sy, rng_int_t *incy);
extern void dspmv_(char *uplo, rng_int_t *n, double *alpha, double *ap, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void dspr_(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *ap, rng_strlen_t uplo_len);
extern void dspr2_(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ap, rng_strlen_t uplo_len);
extern void dswap_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy);
extern void dsymm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void dsymv_(char *uplo, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void dsyr_(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void dsyr2_(char *uplo, rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void dsyr2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *beta, double *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dsyrk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dtbmv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtbsv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtpmv_(char *uplo, char *trans, char *diag, rng_int_t *n, double *ap, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtpsv_(char *uplo, char *trans, char *diag, rng_int_t *n, double *ap, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtrmm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void dtrmv_(char *uplo, char *trans, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtrsm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void dtrsv_(char *uplo, char *trans, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern double dzasum_(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern double dznrm2_(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t icamax_(rng_int_t *n, complex *x, rng_int_t *incx);
extern rng_int_t idamax_(rng_int_t *n, double *x, rng_int_t *incx);
extern rng_int_t isamax_(rng_int_t *n, float *x, rng_int_t *incx);
extern rng_int_t izamax_(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern rng_int_t lsame_(char *ca, char *cb, rng_strlen_t ca_len, rng_strlen_t cb_len);
extern float sasum_(rng_int_t *n, float *x, rng_int_t *incx);
extern void saxpy_(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float scasum_(rng_int_t *n, complex *x, rng_int_t *incx);
extern float scnrm2_(rng_int_t *n, complex *x, rng_int_t *incx);
extern void scopy_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float sdot_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern float sdsdot_(rng_int_t *n, float *b, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void sgbmv_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void sgemm_(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void sgemv_(char *trans, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void sger_(rng_int_t *m, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda);
extern float snrm2_(rng_int_t *n, float *x, rng_int_t *incx);
extern void srot_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s);
extern void srotg_(float *a, float *b, float *c, float *s);
extern void srotm_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *param);
extern void srotmg_(float *d1, float *d2, float *b1, float *b2, float *param);
extern void ssbmv_(char *uplo, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void sscal_(rng_int_t *n, float *alpha, float *x, rng_int_t *incx);
extern void sspmv_(char *uplo, rng_int_t *n, float *alpha, float *ap, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void sspr_(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *ap, rng_strlen_t uplo_len);
extern void sspr2_(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ap, rng_strlen_t uplo_len);
extern void sstemr_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void sswap_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy);
extern void ssymm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void ssymv_(char *uplo, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void ssyr_(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void ssyr2_(char *uplo, rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void ssyr2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *beta, float *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void ssyrk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void stbmv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stbsv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stpmv_(char *uplo, char *trans, char *diag, rng_int_t *n, float *ap, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stpsv_(char *uplo, char *trans, char *diag, rng_int_t *n, float *ap, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void strmm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void strmv_(char *uplo, char *trans, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void strsm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void strsv_(char *uplo, char *trans, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void xerbla_(const char *srname, rng_int_t *info, rng_strlen_t srname_len);
extern void zaxpy_(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void zcopy_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex zdotc_(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void zdotcsub_(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern doublecomplex zdotu_(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void zdotusub_(doublecomplex *ret_val, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void zdrot_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, double *s);
extern void zdscal_(rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx);
extern void zgbmv_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void zgemm_(char *transa, char *transb, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t transa_len, rng_strlen_t transb_len);
extern void zgemv_(char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t trans_len);
extern void zgerc_(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void zgeru_(rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda);
extern void zhbmv_(char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void zhemm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void zhemv_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void zher_(char *uplo, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void zher2_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void zher2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void zherk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void zhpmv_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void zhpr_(char *uplo, rng_int_t *n, double *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_strlen_t uplo_len);
extern void zhpr2_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *a, rng_strlen_t uplo_len);
extern void zlassq_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, double *scale, double *sumsq);
extern void zrotg_(doublecomplex *a, doublecomplex *b, double *c, doublecomplex *s);
extern void zscal_(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx);
extern void zstemr_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void zswap_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy);
extern void zsymm_(char *side, char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t side_len, rng_strlen_t uplo_len);
extern void zsyr2k_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void zsyrk_(char *uplo, char *trans, rng_int_t *n, rng_int_t *k, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *beta, doublecomplex *c, rng_int_t *ldc, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void ztbmv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztbsv_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztpmv_(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztpsv_(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztrmm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void ztrmv_(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztrsm_(char *side, char *uplo, char *transa, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t transa_len, rng_strlen_t diag_len);
extern void ztrsv_(char *uplo, char *trans, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);

/* LAPACK routines */
extern void cbbcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *rwork, rng_int_t *lrwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void cbdsqr_(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, complex *vt, rng_int_t *ldvt, complex *u, rng_int_t *ldu, complex *c, rng_int_t *ldc, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cgbbrd_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *pt, rng_int_t *ldpt, complex *c, rng_int_t *ldc, complex *work, float *rwork, rng_int_t *info, rng_strlen_t vect_len);
extern void cgbcon_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void cgbequ_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void cgbequb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void cgbrfs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void cgbrfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgbsv_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void cgbsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgbsvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgbtrf_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void cgbtrs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void cgebak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void cgebal_(char *job, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info, rng_strlen_t job_len);
extern void cgebrd_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgecon_(char *norm, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void cgeequ_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void cgeequb_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void cgees_(char *jobvs, char *sort, RNG_CGEES_SELECT select, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void cgeesx_(char *jobvs, char *sort, RNG_CGEESX_SELECT select, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *sdim, complex *w, complex *vs, rng_int_t *ldvs, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void cgeev_(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void cgeevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void cgegs_(char *jobvsl, char *jobvsr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void cgegv_(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void cgehrd_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgelqf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgels_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void cgelsd_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void cgelss_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void cgelsx_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *info);
extern void cgelsy_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void cgemqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cgeqlf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgeqp3_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info);
extern void cgeqpf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, complex *work, float *rwork, rng_int_t *info);
extern void cgeqr2p_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgeqrf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgeqrfp_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgeqrt2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void cgeqrt3_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void cgeqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void cgerfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void cgerfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgerqf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgesdd_(char *jobz, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void cgesv_(rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void cgesvd_(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *s, complex *u, rng_int_t *ldu, complex *vt, rng_int_t *ldvt, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void cgesvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgesvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void cgetrf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void cgetri_(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgetrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void cggbak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, complex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void cggbal_(char *job, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info, rng_strlen_t job_len);
extern void cgges_(char *jobvsl, char *jobvsr, char *sort, RNG_CGGES_SELCTG selctg, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void cggesx_(char *jobvsl, char *jobvsr, char *sort, RNG_CGGESX_SELCTG selctg, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *sdim, complex *alpha, complex *beta, complex *vsl, rng_int_t *ldvsl, complex *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void cggev_(char *jobvl, char *jobvr, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void cggevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void cggglm_(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *d, complex *x, complex *y, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cgghrd_(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void cgglse_(rng_int_t *m, rng_int_t *n, rng_int_t *p, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, complex *d, complex *x, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cggqrf_(rng_int_t *n, rng_int_t *m, rng_int_t *p, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cggrqf_(rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *taua, complex *b, rng_int_t *ldb, complex *taub, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cggsvd_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void cggsvp_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, rng_int_t *iwork, float *rwork, complex *tau, complex *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void cgtcon_(char *norm, rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t norm_len);
extern void cgtrfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void cgtsv_(rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void cgtsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *dlf, complex *df, complex *duf, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void cgttrf_(rng_int_t *n, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void cgttrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void chbev_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chbevd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chbevx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void chbgst_(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *x, rng_int_t *ldx, complex *work, float *rwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void chbgv_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chbgvd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chbgvx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, complex *ab, rng_int_t *ldab, complex *bb, rng_int_t *ldbb, complex *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void chbtrd_(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *d, float *e, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void checon_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void cheequb_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void cheev_(char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void cheevd_(char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void cheevr_(char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void cheevx_(char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void chegst_(rng_int_t *itype, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chegv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chegvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *w, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chegvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void cherfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cherfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void chesv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void chesvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void chesvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cheswapr_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void chetrd_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetrf_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetri2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetri2x_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetri_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chfrk_(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, complex *a, rng_int_t *lda, float *beta, complex *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void chgeqz_(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void chla_transtype_(char *ret_val, rng_strlen_t ret_val_len, rng_int_t *trans);
extern void chpcon_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void chpev_(char *jobz, char *uplo, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chpevd_(char *jobz, char *uplo, rng_int_t *n, complex *ap, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chpevx_(char *jobz, char *range, char *uplo, rng_int_t *n, complex *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void chpgst_(rng_int_t *itype, char *uplo, rng_int_t *n, complex *ap, complex *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void chpgv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chpgvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void chpgvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, complex *ap, complex *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void chprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void chpsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chpsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void chptrd_(char *uplo, rng_int_t *n, complex *ap, float *d, float *e, complex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void chptrf_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void chptri_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void chptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chsein_(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void chseqr_(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern void cla_gbamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, complex *ab, rng_int_t *ldab, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float cla_gbrcond_c_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern float cla_gbrcond_x_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern void cla_gbrfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float cla_gbrpvgrw_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb);
extern void cla_geamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float cla_gercond_c_(char *trans, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern float cla_gercond_x_(char *trans, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t trans_len);
extern void cla_gerfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *errs_n, float *errs_c, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float cla_gerpvgrw_(rng_int_t *n, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf);
extern void cla_heamv_(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float cla_hercond_c_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float cla_hercond_x_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void cla_herfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float cla_herpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void cla_lin_berr_(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, complex *res, float *ayb, float *berr);
extern float cla_porcond_c_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float cla_porcond_x_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void cla_porfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float cla_porpvgrw_(char *uplo, rng_int_t *ncols, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *work, rng_strlen_t uplo_len);
extern void cla_syamv_(rng_int_t *uplo, rng_int_t *n, float *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern float cla_syrcond_c_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *c, int *capply, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern float cla_syrcond_x_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *x, rng_int_t *info, complex *work, float *rwork, rng_strlen_t uplo_len);
extern void cla_syrfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, complex *b, rng_int_t *ldb, complex *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, complex *res, float *ayb, complex *dy, complex *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern float cla_syrpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void cla_wwaddw_(rng_int_t *n, complex *x, complex *y, complex *w);
extern float clanhf_(char *norm, char *transr, char *uplo, rng_int_t *n, complex *a, float *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void clapmr_(int *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void clarfgp_(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void clarscl2_(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void clascl2_(rng_int_t *m, rng_int_t *n, float *d, complex *x, rng_int_t *ldx);
extern void cpbcon_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbequ_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbrfs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbstf_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbsv_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *afb, rng_int_t *ldafb, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cpbtrf_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbtrs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpftrf_(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void cpftri_(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void cpftrs_(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void cpocon_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpoequ_(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void cpoequb_(rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void cporfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cporfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cposvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cposvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cpotrf_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpotri_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpotrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cppcon_(char *uplo, rng_int_t *n, complex *ap, float *anorm, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cppequ_(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cppsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cppsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void cpptrf_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpptri_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpstf2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpstrf_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void cptcon_(rng_int_t *n, float *d, complex *e, float *anorm, float *rcond, float *rwork, rng_int_t *info);
extern void cpteqr_(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void cptrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cptsv_(rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info);
extern void cptsvx_(char *fact, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, float *df, complex *ef, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len);
extern void cpttrf_(rng_int_t *n, float *d, complex *e, rng_int_t *info);
extern void cpttrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cspcon_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cspsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cspsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *afp, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void csptrf_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void csptri_(char *uplo, rng_int_t *n, complex *ap, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *ap, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void cstedc_(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void cstegr_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void cstein_(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, complex *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void csteqr_(char *compz, rng_int_t *n, float *d, float *e, complex *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void csycon_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csyconv_(char *uplo, char *way, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void csyequb_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csyrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void csyrfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void csysv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void csysvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void csysvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, complex *work, float *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void csyswapr_(char *uplo, rng_int_t *n, complex *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void csytrf_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void csytri2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void csytri2x_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void csytri_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csytrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void csytrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void ctbcon_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctbrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctbtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, complex *ab, rng_int_t *ldab, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctfsm_(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, complex *alpha, complex *a, complex *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctftri_(char *transr, char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctfttp_(char *transr, char *uplo, rng_int_t *n, complex *arf, complex *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ctfttr_(char *transr, char *uplo, rng_int_t *n, complex *arf, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ctgevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void ctgexc_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void ctgsen_(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *alpha, complex *beta, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void ctgsja_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, complex *u, rng_int_t *ldu, complex *v, rng_int_t *ldv, complex *q, rng_int_t *ldq, complex *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void ctgsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void ctgsyl_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *dif, complex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void ctpcon_(char *norm, char *uplo, char *diag, rng_int_t *n, complex *ap, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctpmqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void ctpqrt2_(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, rng_int_t *info);
extern void ctpqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *t, rng_int_t *ldt, complex *work, rng_int_t *info);
extern void ctprfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void ctprfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctptri_(char *uplo, char *diag, rng_int_t *n, complex *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctptrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *ap, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctpttf_(char *transr, char *uplo, rng_int_t *n, complex *ap, complex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ctpttr_(char *uplo, rng_int_t *n, complex *ap, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void ctrcon_(char *norm, char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, float *rcond, complex *work, float *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctrevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, complex *work, float *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void ctrexc_(char *compq, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info, rng_strlen_t compq_len);
extern void ctrrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *x, rng_int_t *ldx, float *ferr, float *berr, complex *work, float *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctrsen_(char *job, char *compq, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *q, rng_int_t *ldq, complex *w, rng_int_t *m, float *s, float *sep, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void ctrsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, complex *t, rng_int_t *ldt, complex *vl, rng_int_t *ldvl, complex *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, complex *work, rng_int_t *ldwork, float *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void ctrsyl_(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void ctrtri_(char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ctrtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ctrttf_(char *transr, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ctrttp_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void ctzrqf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, rng_int_t *info);
extern void ctzrzf_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cunbdb_(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, float *phi, complex *taup1, complex *taup2, complex *tauq1, complex *tauq2, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void cuncsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, complex *x11, rng_int_t *ldx11, complex *x12, rng_int_t *ldx12, complex *x21, rng_int_t *ldx21, complex *x22, rng_int_t *ldx22, float *theta, complex *u1, rng_int_t *ldu1, complex *u2, rng_int_t *ldu2, complex *v1t, rng_int_t *ldv1t, complex *v2t, rng_int_t *ldv2t, complex *work, rng_int_t *lwork, float *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void cungbr_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void cunghr_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cunglq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cungql_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cungqr_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cungrq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void cungtr_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void cunmbr_(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmhr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmlq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmql_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmqr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmrq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmrz_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void cupgtr_(char *uplo, rng_int_t *n, complex *ap, complex *tau, complex *q, rng_int_t *ldq, complex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void cupmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, complex *ap, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dbbcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void dbdsdc_(char *uplo, char *compq, rng_int_t *n, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *q, rng_int_t *iq, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t compq_len);
extern void dbdsqr_(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void ddisna_(char *job, rng_int_t *m, rng_int_t *n, double *d, double *sep, rng_int_t *info, rng_strlen_t job_len);
extern void dgbbrd_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *pt, rng_int_t *ldpt, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t vect_len);
extern void dgbcon_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void dgbequ_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void dgbequb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void dgbrfs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void dgbrfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgbsv_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void dgbsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgbsvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgbtrf_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void dgbtrs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void dgebak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void dgebal_(char *job, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info, rng_strlen_t job_len);
extern void dgebrd_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgecon_(char *norm, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void dgeequ_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void dgeequb_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void dgees_(char *jobvs, char *sort, RNG_DGEES_SELECT select, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void dgeesx_(char *jobvs, char *sort, RNG_DGEESX_SELECT select, char *sense, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *sdim, double *wr, double *wi, double *vs, rng_int_t *ldvs, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void dgeev_(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void dgeevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void dgegs_(char *jobvsl, char *jobvsr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void dgegv_(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void dgehrd_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgejsv_(char *joba, char *jobu, char *jobv, char *jobr, char *jobt, char *jobp, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobr_len, rng_strlen_t jobt_len, rng_strlen_t jobp_len);
extern void dgelqf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgels_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void dgelsd_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void dgelss_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgelsx_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *info);
extern void dgelsy_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgemqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dgeqlf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgeqp3_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgeqpf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *work, rng_int_t *info);
extern void dgeqr2p_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgeqrf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgeqrfp_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgeqrt2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void dgeqrt3_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, rng_int_t *info);
extern void dgeqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void dgerfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void dgerfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgerqf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgesdd_(char *jobz, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void dgesv_(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info);
extern void dgesvd_(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void dgesvj_(char *joba, char *jobu, char *jobv, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len);
extern void dgesvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgesvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void dgetrf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void dgetri_(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgetrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void dggbak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, double *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void dggbal_(char *job, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info, rng_strlen_t job_len);
extern void dgges_(char *jobvsl, char *jobvsr, char *sort, RNG_DGGES_DELCTG delctg, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void dggesx_(char *jobvsl, char *jobvsr, char *sort, RNG_DGGESX_DELCTG delctg, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *sdim, double *alphar, double *alphai, double *beta, double *vsl, rng_int_t *ldvsl, double *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void dggev_(char *jobvl, char *jobvr, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void dggevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void dggglm_(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *d, double *x, double *y, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dgghrd_(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void dgglse_(rng_int_t *m, rng_int_t *n, rng_int_t *p, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, double *d, double *x, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dggqrf_(rng_int_t *n, rng_int_t *m, rng_int_t *p, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dggrqf_(rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *taua, double *b, rng_int_t *ldb, double *taub, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dggsvd_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void dggsvp_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, rng_int_t *iwork, double *tau, double *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void dgsvj0_(char *jobv, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void dgsvj1_(char *jobv, rng_int_t *m, rng_int_t *n, rng_int_t *n1, double *a, rng_int_t *lda, double *d, double *sva, rng_int_t *mv, double *v, rng_int_t *ldv, double *eps, double *sfmin, double *tol, rng_int_t *nsweep, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void dgtcon_(char *norm, rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void dgtrfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void dgtsv_(rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *b, rng_int_t *ldb, rng_int_t *info);
extern void dgtsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *dlf, double *df, double *duf, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void dgttrf_(rng_int_t *n, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, rng_int_t *info);
extern void dgttrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void dhgeqz_(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void dhsein_(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void dhseqr_(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern rng_int_t disnan_(double *din);
extern void dla_gbamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, double *ab, rng_int_t *ldab, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double dla_gbrcond_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void dla_gbrfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double dla_gbrpvgrw_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb);
extern void dla_geamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double dla_gercond_(char *trans, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void dla_gerfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double dla_gerpvgrw_(rng_int_t *n, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf);
extern void dla_lin_berr_(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, double *res, double *ayb, double *berr);
extern double dla_porcond_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void dla_porfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double dla_porpvgrw_(char *uplo, rng_int_t *ncols, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *work, rng_strlen_t uplo_len);
extern void dla_syamv_(rng_int_t *uplo, rng_int_t *n, double *alpha, double *a, rng_int_t *lda, double *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double dla_syrcond_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, double *c, rng_int_t *info, double *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void dla_syrfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, double *b, rng_int_t *ldb, double *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, double *res, double *ayb, double *dy, double *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double dla_syrpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void dla_wwaddw_(rng_int_t *n, double *x, double *y, double *w);
extern double dlamch_(char *cmach, rng_strlen_t cmach_len);
extern double dlansf_(char *norm, char *transr, char *uplo, rng_int_t *n, double *a, double *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dlapmr_(int *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern void dlarfgp_(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void dlarft_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt,  rng_strlen_t direct_len,  rng_strlen_t storev_len);
extern void dlarscl2_(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void dlartgp_(double *f, double *g, double *cs, double *sn, double *r_);
extern void dlartgs_(double *x, double *y, double *sigma, double *cs, double *sn);
extern void dlascl2_(rng_int_t *m, rng_int_t *n, double *d, double *x, rng_int_t *ldx);
extern void dlasrt_(char *id, rng_int_t *n, double *d, rng_int_t *info, rng_strlen_t id_len);
extern void dlassq_(rng_int_t *n, double *x, rng_int_t *incx, double *scale, double *sumsq);
extern void dlat2s_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info, rng_strlen_t uplo_len);
extern void dopgtr_(char *uplo, rng_int_t *n, double *ap, double *tau, double *q, rng_int_t *ldq, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dopmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, double *ap, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dorbdb_(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *phi, double *taup1, double *taup2, double *tauq1, double *tauq2, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void dorcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *x11, rng_int_t *ldx11, double *x12, rng_int_t *ldx12, double *x21, rng_int_t *ldx21, double *x22, rng_int_t *ldx22, double *theta, double *u1, rng_int_t *ldu1, double *u2, rng_int_t *ldu2, double *v1t, rng_int_t *ldv1t, double *v2t, rng_int_t *ldv2t, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void dorgbr_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void dorghr_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dorglq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dorgql_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dorgqr_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dorgrq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dorgtr_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dormbr_(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormhr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormlq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormql_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormqr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormrq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormrz_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dpbcon_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbequ_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbrfs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbstf_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbsv_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *afb, rng_int_t *ldafb, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dpbtrf_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpbtrs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpftrf_(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dpftri_(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dpftrs_(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dpocon_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpoequ_(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void dpoequb_(rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void dporfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dporfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dposvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dposvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dpotrf_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpotri_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpotrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dppcon_(char *uplo, rng_int_t *n, double *ap, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dppequ_(char *uplo, rng_int_t *n, double *ap, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dppsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dppsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dpptrf_(char *uplo, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpptri_(char *uplo, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpstf2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpstrf_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dptcon_(rng_int_t *n, double *d, double *e, double *anorm, double *rcond, double *work, rng_int_t *info);
extern void dpteqr_(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void dptrfs_(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *info);
extern void dptsv_(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void dptsvx_(char *fact, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *df, double *ef, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *info, rng_strlen_t fact_len);
extern void dpttrf_(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void dpttrs_(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, rng_int_t *info);
extern void dsbev_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsbevd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsbevx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsbgst_(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *x, rng_int_t *ldx, double *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void dsbgv_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsbgvd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsbgvx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, double *ab, rng_int_t *ldab, double *bb, rng_int_t *ldbb, double *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsbtrd_(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *d, double *e, double *q, rng_int_t *ldq, double *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern double dsecnd_(void);
extern void dsfrk_(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, double *a, rng_int_t *lda, double *beta, double *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void dsgesv_(rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info);
extern void dspcon_(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dspev_(char *jobz, char *uplo, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dspevd_(char *jobz, char *uplo, rng_int_t *n, double *ap, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dspevx_(char *jobz, char *range, char *uplo, rng_int_t *n, double *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dspgst_(rng_int_t *itype, char *uplo, rng_int_t *n, double *ap, double *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void dspgv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dspgvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *ap, double *bp, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dspgvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, double *ap, double *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *work, float *swork, rng_int_t *iter, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dspsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dspsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, double *afp, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void dsptrd_(char *uplo, rng_int_t *n, double *ap, double *d, double *e, double *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsptrf_(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsptri_(char *uplo, rng_int_t *n, double *ap, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *ap, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dstebz_(char *range, char *order, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, double *d, double *e, rng_int_t *m, rng_int_t *nsplit, double *w, rng_int_t *iblock, rng_int_t *isplit, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void dstedc_(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void dstegr_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void dstein_(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void dstemr_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *nzc, rng_int_t *isuppz, rng_int_t *tryrac, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void dsteqr_(char *compz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void dsterf_(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void dstev_(char *jobz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t jobz_len);
extern void dstevd_(char *jobz, rng_int_t *n, double *d, double *e, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void dstevr_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void dstevx_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void dsycon_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsyconv_(char *uplo, char *way, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void dsyequb_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsyev_(char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsyevd_(char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsyevr_(char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsyevx_(char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsygst_(rng_int_t *itype, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsygv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsygvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *w, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void dsygvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void dsyrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsyrfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dsysv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsysvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void dsysvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dsyswapr_(char *uplo, rng_int_t *n, double *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void dsytrd_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytrf_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytri2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytri2x_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytri_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, rng_int_t *ipiv, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dtbcon_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtbrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtbtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, double *ab, rng_int_t *ldab, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtfsm_(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, double *alpha, double *a, double *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtftri_(char *transr, char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtfttp_(char *transr, char *uplo, rng_int_t *n, double *arf, double *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dtfttr_(char *transr, char *uplo, rng_int_t *n, double *arf, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dtgevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void dtgexc_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dtgsen_(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void dtgsja_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, double *u, rng_int_t *ldu, double *v, rng_int_t *ldv, double *q, rng_int_t *ldq, double *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void dtgsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void dtgsyl_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *dif, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void dtpcon_(char *norm, char *uplo, char *diag, rng_int_t *n, double *ap, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtpmqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dtpqrt2_(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, rng_int_t *info);
extern void dtpqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *t, rng_int_t *ldt, double *work, rng_int_t *info);
extern void dtprfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void dtprfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtptri_(char *uplo, char *diag, rng_int_t *n, double *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtptrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *ap, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtpttf_(char *transr, char *uplo, rng_int_t *n, double *ap, double *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dtpttr_(char *uplo, rng_int_t *n, double *ap, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dtrcon_(char *norm, char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, double *rcond, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtrevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void dtrexc_(char *compq, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, double *work, rng_int_t *info, rng_strlen_t compq_len);
extern void dtrrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *x, rng_int_t *ldx, double *ferr, double *berr, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtrsen_(char *job, char *compq, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, double *wr, double *wi, rng_int_t *m, double *s, double *sep, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void dtrsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, double *t, rng_int_t *ldt, double *vl, rng_int_t *ldvl, double *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, double *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void dtrsyl_(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void dtrtri_(char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dtrtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void dtrttf_(char *transr, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void dtrttp_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void dtzrqf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, rng_int_t *info);
extern void dtzrzf_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *lwork, rng_int_t *info);
extern rng_int_t ilaenv_(rng_int_t *ispec, const char *name, const char *opts, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4, rng_strlen_t name_len, rng_strlen_t opts_len);
extern void ilaenvset_(rng_int_t *ispec, const char *name, const char *opts, rng_int_t *n1, rng_int_t *n2, rng_int_t *n3, rng_int_t *n4, rng_int_t *nvalue, rng_int_t *info, rng_strlen_t name_len, rng_strlen_t opts_len);
extern void ilaver_(rng_int_t *vers_major, rng_int_t *vers_minor, rng_int_t *vers_patch);
extern rng_int_t ilaclc_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t ilaclr_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda);
extern rng_int_t iladiag_(char *diag, rng_strlen_t diag_len);
extern rng_int_t iladlc_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t iladlr_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda);
extern rng_int_t ilaprec_(char *prec, rng_strlen_t prec_len);
extern rng_int_t ilaslc_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t ilaslr_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda);
extern rng_int_t ilatrans_(char *trans, rng_strlen_t trans_len);
extern rng_int_t ilauplo_(char *uplo, rng_strlen_t uplo_len);
extern rng_int_t ilazlc_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern rng_int_t ilazlr_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda);
extern void sbbcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *theta, float *phi, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *b11d, float *b11e, float *b12d, float *b12e, float *b21d, float *b21e, float *b22d, float *b22e, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void sbdsdc_(char *uplo, char *compq, rng_int_t *n, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *q, rng_int_t *iq, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t compq_len);
extern void sbdsqr_(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void sdisna_(char *job, rng_int_t *m, rng_int_t *n, float *d, float *sep, rng_int_t *info, rng_strlen_t job_len);
extern float second_(void);
extern void sgbbrd_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *pt, rng_int_t *ldpt, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t vect_len);
extern void sgbcon_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void sgbequ_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void sgbequb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void sgbrfs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void sgbrfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgbsv_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void sgbsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgbsvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgbtrf_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void sgbtrs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void sgebak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void sgebal_(char *job, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, float *scale, rng_int_t *info, rng_strlen_t job_len);
extern void sgebrd_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgecon_(char *norm, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void sgeequ_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void sgeequb_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, rng_int_t *info);
extern void sgees_(char *jobvs, char *sort, RNG_SGEES_SELECT select, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void sgeesx_(char *jobvs, char *sort, RNG_SGEESX_SELECT select, char *sense, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *sdim, float *wr, float *wi, float *vs, rng_int_t *ldvs, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void sgeev_(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void sgeevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *scale, float *abnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void sgegs_(char *jobvsl, char *jobvsr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void sgegv_(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void sgehrd_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgejsv_(char *joba, char *jobu, char *jobv, char *jobr, char *jobt, char *jobp, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobr_len, rng_strlen_t jobt_len, rng_strlen_t jobp_len);
extern void sgelqf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgels_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void sgelsd_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info);
extern void sgelss_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *s, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgelsx_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *info);
extern void sgelsy_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *jpvt, float *rcond, rng_int_t *rank, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgemqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sgeqlf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgeqp3_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgeqpf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *work, rng_int_t *info);
extern void sgeqr2p_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgeqrf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgeqrfp_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgeqrt2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void sgeqrt3_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, rng_int_t *info);
extern void sgeqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void sgerfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void sgerfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgerqf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgesdd_(char *jobz, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void sgesv_(rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info);
extern void sgesvd_(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void sgesvj_(char *joba, char *jobu, char *jobv, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t joba_len, rng_strlen_t jobu_len, rng_strlen_t jobv_len);
extern void sgesvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgesvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *r, float *c, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void sgetrf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void sgetri_(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgetrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void sggbak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, rng_int_t *m, float *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void sggbal_(char *job, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *work, rng_int_t *info, rng_strlen_t job_len);
extern void sgges_(char *jobvsl, char *jobvsr, char *sort, RNG_SGGES_SELCTG selctg, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *work, rng_int_t *lwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void sggesx_(char *jobvsl, char *jobvsr, char *sort, RNG_SGGESX_SELCTG selctg, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *sdim, float *alphar, float *alphai, float *beta, float *vsl, rng_int_t *ldvsl, float *vsr, rng_int_t *ldvsr, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void sggev_(char *jobvl, char *jobvr, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void sggevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, float *lscale, float *rscale, float *abnrm, float *bbnrm, float *rconde, float *rcondv, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void sggglm_(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *d, float *x, float *y, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sgghrd_(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void sgglse_(rng_int_t *m, rng_int_t *n, rng_int_t *p, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, float *d, float *x, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sggqrf_(rng_int_t *n, rng_int_t *m, rng_int_t *p, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sggrqf_(rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *taua, float *b, rng_int_t *ldb, float *taub, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sggsvd_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void sggsvp_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, rng_int_t *k, rng_int_t *l, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, rng_int_t *iwork, float *tau, float *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void sgsvj0_(char *jobv, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void sgsvj1_(char *jobv, rng_int_t *m, rng_int_t *n, rng_int_t *n1, float *a, rng_int_t *lda, float *d, float *sva, rng_int_t *mv, float *v, rng_int_t *ldv, float *eps, float *sfmin, float *tol, rng_int_t *nsweep, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobv_len);
extern void sgtcon_(char *norm, rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len);
extern void sgtrfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void sgtsv_(rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *b, rng_int_t *ldb, rng_int_t *info);
extern void sgtsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *dlf, float *df, float *duf, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void sgttrf_(rng_int_t *n, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, rng_int_t *info);
extern void sgttrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void shgeqz_(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void shsein_(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void shseqr_(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern rng_int_t sisnan_(float *sin);
extern void sla_gbamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *alpha, float *ab, rng_int_t *ldab, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double sla_gbrcond_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void sla_gbrfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double sla_gbrpvgrw_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb);
extern void sla_geamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double sla_gercond_(char *trans, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t trans_len);
extern void sla_gerfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info);
extern float sla_gerpvgrw_(rng_int_t *n, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf);
extern void sla_lin_berr_(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, float *res, float *ayb, float *berr);
extern double sla_porcond_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void sla_porfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double sla_porpvgrw_(char *uplo, rng_int_t *ncols, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *work, rng_strlen_t uplo_len);
extern void sla_syamv_(rng_int_t *uplo, rng_int_t *n, float *alpha, float *a, rng_int_t *lda, float *x, rng_int_t *incx, float *beta, float *y, rng_int_t *incy);
extern double sla_syrcond_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, rng_int_t *cmode, float *c, rng_int_t *info, float *work, rng_int_t *iwork, rng_strlen_t uplo_len);
extern void sla_syrfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, float *c, float *b, rng_int_t *ldb, float *y, rng_int_t *ldy, float *berr_out, rng_int_t *n_norms, float *err_bnds_norm, float *err_bnds_comp, float *res, float *ayb, float *dy, float *y_tail, float *rcond, rng_int_t *ithresh, float *rthresh, float *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double sla_syrpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *work, rng_strlen_t uplo_len);
extern void sla_wwaddw_(rng_int_t *n, float *x, float *y, float *w);
extern float slamch_(char *cmach, rng_strlen_t cmach_len);
extern float slansf_(char *norm, char *transr, char *uplo, rng_int_t *n, float *a, float *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void slapmr_(int *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern void slarfgp_(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void slarft_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt, rng_strlen_t direct_len,  rng_strlen_t storev_len);
extern void slarscl2_(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void slartgp_(float *f, float *g, float *cs, float *sn, float *r_);
extern void slartgs_(float *x, float *y, float *sigma, float *cs, float *sn);
extern void slascl2_(rng_int_t *m, rng_int_t *n, float *d, float *x, rng_int_t *ldx);
extern void slasrt_(char *id, rng_int_t *n, float *d, rng_int_t *info, rng_strlen_t id_len);
extern void slassq_(rng_int_t *n, float *x, rng_int_t *incx, float *scale, float *sumsq);
extern void sopgtr_(char *uplo, rng_int_t *n, float *ap, float *tau, float *q, rng_int_t *ldq, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void sopmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, float *ap, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void sorbdb_(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *phi, float *taup1, float *taup2, float *tauq1, float *tauq2, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void sorcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, float *x11, rng_int_t *ldx11, float *x12, rng_int_t *ldx12, float *x21, rng_int_t *ldx21, float *x22, rng_int_t *ldx22, float *theta, float *u1, rng_int_t *ldu1, float *u2, rng_int_t *ldu2, float *v1t, rng_int_t *ldv1t, float *v2t, rng_int_t *ldv2t, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void sorgbr_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void sorghr_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sorglq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sorgql_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sorgqr_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sorgrq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void sorgtr_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sormbr_(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormhr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormlq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormql_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormqr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormrq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormrz_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void spbcon_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbequ_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbrfs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbstf_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbsv_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *afb, rng_int_t *ldafb, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void spbtrf_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void spbtrs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void spftrf_(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void spftri_(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void spftrs_(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void spocon_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void spoequ_(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void spoequb_(rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, rng_int_t *info);
extern void sporfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sporfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void sposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void sposvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void sposvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void spotrf_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void spotri_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void spotrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void sppcon_(char *uplo, rng_int_t *n, float *ap, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sppequ_(char *uplo, rng_int_t *n, float *ap, float *s, float *scond, float *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void spprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sppsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void sppsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void spptrf_(char *uplo, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void spptri_(char *uplo, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void spptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void spstf2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void spstrf_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, float *tol, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void sptcon_(rng_int_t *n, float *d, float *e, float *anorm, float *rcond, float *work, rng_int_t *info);
extern void spteqr_(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void sptrfs_(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *info);
extern void sptsv_(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void sptsvx_(char *fact, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *df, float *ef, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *info, rng_strlen_t fact_len);
extern void spttrf_(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void spttrs_(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, rng_int_t *info);
extern void ssbev_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssbevd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssbevx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssbgst_(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *x, rng_int_t *ldx, float *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void ssbgv_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssbgvd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssbgvx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, float *ab, rng_int_t *ldab, float *bb, rng_int_t *ldbb, float *q, rng_int_t *ldq, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssbtrd_(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *d, float *e, float *q, rng_int_t *ldq, float *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void ssfrk_(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, float *alpha, float *a, rng_int_t *lda, float *beta, float *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void sspcon_(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sspev_(char *jobz, char *uplo, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void sspevd_(char *jobz, char *uplo, rng_int_t *n, float *ap, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void sspevx_(char *jobz, char *range, char *uplo, rng_int_t *n, float *ap, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void sspgst_(rng_int_t *itype, char *uplo, rng_int_t *n, float *ap, float *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void sspgv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void sspgvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *ap, float *bp, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void sspgvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, float *ap, float *bp, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void sspsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void sspsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, float *afp, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void ssptrd_(char *uplo, rng_int_t *n, float *ap, float *d, float *e, float *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssptrf_(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssptri_(char *uplo, rng_int_t *n, float *ap, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *ap, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void sstebz_(char *range, char *order, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, float *d, float *e, rng_int_t *m, rng_int_t *nsplit, float *w, rng_int_t *iblock, rng_int_t *isplit, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void sstedc_(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void sstegr_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void sstein_(rng_int_t *n, float *d, float *e, rng_int_t *m, float *w, rng_int_t *iblock, rng_int_t *isplit, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void ssteqr_(char *compz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t compz_len);
extern void ssterf_(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void sstev_(char *jobz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *info, rng_strlen_t jobz_len);
extern void sstevd_(char *jobz, rng_int_t *n, float *d, float *e, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void sstevr_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void sstevx_(char *jobz, char *range, rng_int_t *n, float *d, float *e, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void ssycon_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *anorm, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssyconv_(char *uplo, char *way, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void ssyequb_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssyev_(char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssyevd_(char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssyevr_(char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssyevx_(char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssygst_(rng_int_t *itype, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssygv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssygvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *w, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void ssygvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *abstol, rng_int_t *m, float *w, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void ssyrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssyrfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void ssysv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssysvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *ferr, float *berr, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void ssysvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, float *s, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *rcond, float *rpvgrw, float *berr, rng_int_t *n_err_bnds, float *err_bnds_norm, float *err_bnds_comp, rng_int_t *nparams, float *params, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void ssyswapr_(char *uplo, rng_int_t *n, float *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void ssytrd_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytrf_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytri2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytri2x_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytri_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, rng_int_t *ipiv, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void stbcon_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void stbrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stbtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, float *ab, rng_int_t *ldab, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stfsm_(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, float *alpha, float *a, float *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stftri_(char *transr, char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void stfttp_(char *transr, char *uplo, rng_int_t *n, float *arf, float *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void stfttr_(char *transr, char *uplo, rng_int_t *n, float *arf, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void stgevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void stgexc_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *lwork, rng_int_t *info);
extern void stgsen_(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *m, float *pl, float *pr, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void stgsja_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *tola, float *tolb, float *alpha, float *beta, float *u, rng_int_t *ldu, float *v, rng_int_t *ldv, float *q, rng_int_t *ldq, float *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void stgsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *dif, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void stgsyl_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *dif, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void stpcon_(char *norm, char *uplo, char *diag, rng_int_t *n, float *ap, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void stpmqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void stpqrt2_(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, rng_int_t *info);
extern void stpqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *t, rng_int_t *ldt, float *work, rng_int_t *info);
extern void stprfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void stprfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stptri_(char *uplo, char *diag, rng_int_t *n, float *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void stptrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *ap, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void stpttf_(char *transr, char *uplo, rng_int_t *n, float *ap, float *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void stpttr_(char *uplo, rng_int_t *n, float *ap, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void strcon_(char *norm, char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, float *rcond, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void strevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void strexc_(char *compq, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, float *work, rng_int_t *info, rng_strlen_t compq_len);
extern void strrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *x, rng_int_t *ldx, float *ferr, float *berr, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void strsen_(char *job, char *compq, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, float *wr, float *wi, rng_int_t *m, float *s, float *sep, float *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void strsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, float *t, rng_int_t *ldt, float *vl, rng_int_t *ldvl, float *vr, rng_int_t *ldvr, float *s, float *sep, rng_int_t *mm, rng_int_t *m, float *work, rng_int_t *ldwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void strsyl_(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void strtri_(char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void strtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void strttf_(char *transr, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void strttp_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void stzrqf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, rng_int_t *info);
extern void stzrzf_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *lwork, rng_int_t *info);
extern void xerbla_array_(char *srname_array, rng_int_t *srname_len, rng_int_t *info, rng_strlen_t srname_array_len);
extern void zbbcsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, rng_int_t *m, rng_int_t *p, rng_int_t *q, double *theta, double *phi, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, double *b11d, double *b11e, double *b12d, double *b12e, double *b21d, double *b21e, double *b22d, double *b22e, double *rwork, rng_int_t *lrwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len);
extern void zbdsqr_(char *uplo, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *u, rng_int_t *ldu, doublecomplex *c, rng_int_t *ldc, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zcgesv_(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, rng_int_t *iter, rng_int_t *info);
extern void zcposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, complex *swork, double *rwork, rng_int_t *iter, rng_int_t *info, rng_strlen_t uplo_len);
extern void zgbbrd_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *ncc, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *pt, rng_int_t *ldpt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t vect_len);
extern void zgbcon_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void zgbequ_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void zgbequb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void zgbrfs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void zgbrfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgbsv_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void zgbsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgbsvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgbtrf_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void zgbtrs_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void zgebak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void zgebal_(char *job, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ilo, rng_int_t *ihi, double *scale, rng_int_t *info, rng_strlen_t job_len);
extern void zgebrd_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgecon_(char *norm, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len);
extern void zgeequ_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void zgeequb_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, rng_int_t *info);
extern void zgees_(char *jobvs, char *sort, RNG_ZGEES_SELECT select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len);
extern void zgeesx_(char *jobvs, char *sort, RNG_ZGEESX_SELECT select, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *sdim, doublecomplex *w, doublecomplex *vs, rng_int_t *ldvs, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvs_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void zgeev_(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void zgeevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *scale, double *abnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void zgegs_(char *jobvsl, char *jobvsr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len);
extern void zgegv_(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void zgehrd_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgelqf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgels_(char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len);
extern void zgelsd_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void zgelss_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *s, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void zgelsx_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *info);
extern void zgelsy_(rng_int_t *m, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *jpvt, double *rcond, rng_int_t *rank, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void zgemqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zgeqlf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgeqp3_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info);
extern void zgeqpf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, doublecomplex *work, double *rwork, rng_int_t *info);
extern void zgeqr2p_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgeqrf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgeqrfp_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgeqrt2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void zgeqrt3_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void zgeqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void zgerfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void zgerfsx_(char *trans, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgerqf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgesdd_(char *jobz, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobz_len);
extern void zgesv_(rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void zgesvd_(char *jobu, char *jobvt, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, doublecomplex *u, rng_int_t *ldu, doublecomplex *vt, rng_int_t *ldvt, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobvt_len);
extern void zgesvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgesvxx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *r, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len, rng_strlen_t equed_len);
extern void zgetrf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void zgetri_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgetrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void zggbak_(char *job, char *side, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, rng_int_t *m, doublecomplex *v, rng_int_t *ldv, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t side_len);
extern void zggbal_(char *job, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *work, rng_int_t *info, rng_strlen_t job_len);
extern void zgges_(char *jobvsl, char *jobvsr, char *sort, RNG_ZGGES_DELCTG delctg, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len);
extern void zggesx_(char *jobvsl, char *jobvsr, char *sort, RNG_ZGGESX_DELCTG delctg, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *sdim, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vsl, rng_int_t *ldvsl, doublecomplex *vsr, rng_int_t *ldvsr, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t jobvsl_len, rng_strlen_t jobvsr_len, rng_strlen_t sort_len, rng_strlen_t sense_len);
extern void zggev_(char *jobvl, char *jobvr, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len);
extern void zggevx_(char *balanc, char *jobvl, char *jobvr, char *sense, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *ilo, rng_int_t *ihi, double *lscale, double *rscale, double *abnrm, double *bbnrm, double *rconde, double *rcondv, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *bwork, rng_int_t *info, rng_strlen_t balanc_len, rng_strlen_t jobvl_len, rng_strlen_t jobvr_len, rng_strlen_t sense_len);
extern void zggglm_(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *d, doublecomplex *x, doublecomplex *y, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zgghrd_(char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *info, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void zgglse_(rng_int_t *m, rng_int_t *n, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, doublecomplex *d, doublecomplex *x, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zggqrf_(rng_int_t *n, rng_int_t *m, rng_int_t *p, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zggrqf_(rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *taua, doublecomplex *b, rng_int_t *ldb, doublecomplex *taub, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zggsvd_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *n, rng_int_t *p, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void zggsvp_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, rng_int_t *k, rng_int_t *l, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, rng_int_t *iwork, double *rwork, doublecomplex *tau, doublecomplex *work, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void zgtcon_(char *norm, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t norm_len);
extern void zgtrfs_(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t trans_len);
extern void zgtsv_(rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void zgtsvx_(char *fact, char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *dlf, doublecomplex *df, doublecomplex *duf, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t trans_len);
extern void zgttrf_(rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, rng_int_t *info);
extern void zgttrs_(char *trans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t trans_len);
extern void zhbev_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhbevd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhbevx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zhbgst_(char *vect, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *x, rng_int_t *ldx, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void zhbgv_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhbgvd_(char *jobz, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhbgvx_(char *jobz, char *range, char *uplo, rng_int_t *n, rng_int_t *ka, rng_int_t *kb, doublecomplex *ab, rng_int_t *ldab, doublecomplex *bb, rng_int_t *ldbb, doublecomplex *q, rng_int_t *ldq, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zhbtrd_(char *vect, char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t uplo_len);
extern void zhecon_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zheequb_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zheev_(char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zheevd_(char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zheevr_(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zheevx_(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zhegst_(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhegv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhegvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *w, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhegvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zherfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zherfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zhesv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhesvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void zhesvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zheswapr_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void zhetrd_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetrf_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetri2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetri2x_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetri_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhfrk_(char *transr, char *uplo, char *trans, rng_int_t *n, rng_int_t *k, double *alpha, doublecomplex *a, rng_int_t *lda, double *beta, doublecomplex *c, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void zhgeqz_(char *job, char *compq, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len, rng_strlen_t compz_len);
extern void zhpcon_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhpev_(char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhpevd_(char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhpevx_(char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *ap, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zhpgst_(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhpgv_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhpgvd_(rng_int_t *itype, char *jobz, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t uplo_len);
extern void zhpgvx_(rng_int_t *itype, char *jobz, char *range, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *bp, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len, rng_strlen_t uplo_len);
extern void zhprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhpsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhpsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void zhptrd_(char *uplo, rng_int_t *n, doublecomplex *ap, double *d, double *e, doublecomplex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhptrf_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhptri_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhsein_(char *side, char *eigsrc, char *initv, rng_int_t *select, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *ifaill, rng_int_t *ifailr, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t eigsrc_len, rng_strlen_t initv_len);
extern void zhseqr_(char *job, char *compz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compz_len);
extern void zla_gbamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *alpha, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double zla_gbrcond_c_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern double zla_gbrcond_x_(char *trans, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern void zla_gbrfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double zla_gbrpvgrw_(rng_int_t *n, rng_int_t *kl, rng_int_t *ku, rng_int_t *ncols, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb);
extern void zla_geamv_(rng_int_t *trans, rng_int_t *m, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double zla_gercond_c_(char *trans, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern double zla_gercond_x_(char *trans, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t trans_len);
extern void zla_gerfsx_extended_(rng_int_t *prec_type, rng_int_t *trans_type, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *errs_n, double *errs_c, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info);
extern double zla_gerpvgrw_(rng_int_t *n, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf);
extern void zla_heamv_(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double zla_hercond_c_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double zla_hercond_x_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void zla_herfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double zla_herpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void zla_lin_berr_(rng_int_t *n, rng_int_t *nz, rng_int_t *nrhs, doublecomplex *res, double *ayb, double *berr);
extern double zla_porcond_c_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double zla_porcond_x_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void zla_porfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double zla_porpvgrw_(char *uplo, rng_int_t *ncols, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *work, rng_strlen_t uplo_len);
extern void zla_syamv_(rng_int_t *uplo, rng_int_t *n, double *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, double *beta, double *y, rng_int_t *incy);
extern double zla_syrcond_c_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *c, int *capply, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern double zla_syrcond_x_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *x, rng_int_t *info, doublecomplex *work, double *rwork, rng_strlen_t uplo_len);
extern void zla_syrfsx_extended_(rng_int_t *prec_type, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, int *colequ, double *c, doublecomplex *b, rng_int_t *ldb, doublecomplex *y, rng_int_t *ldy, double *berr_out, rng_int_t *n_norms, double *err_bnds_norm, double *err_bnds_comp, doublecomplex *res, double *ayb, doublecomplex *dy, doublecomplex *y_tail, double *rcond, rng_int_t *ithresh, double *rthresh, double *dz_ub, int *ignore_cwise, rng_int_t *info, rng_strlen_t uplo_len);
extern double zla_syrpvgrw_(char *uplo, rng_int_t *n, rng_int_t *info, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *work, rng_strlen_t uplo_len);
extern void zla_wwaddw_(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *w);
extern double zlanhf_(char *norm, char *transr, char *uplo, rng_int_t *n, doublecomplex *a, double *work, rng_strlen_t norm_len, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void zlapmr_(int *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void zlarfgp_(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void zlarscl2_(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void zlascl2_(rng_int_t *m, rng_int_t *n, double *d, doublecomplex *x, rng_int_t *ldx);
extern void zlat2c_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbcon_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbequ_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbrfs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbstf_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbsv_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *afb, rng_int_t *ldafb, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zpbtrf_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbtrs_(char *uplo, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpftrf_(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void zpftri_(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void zpftrs_(char *transr, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void zpocon_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpoequ_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void zpoequb_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, rng_int_t *info);
extern void zporfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zporfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zposv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zposvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zposvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zpotrf_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpotri_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpotrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zppcon_(char *uplo, rng_int_t *n, doublecomplex *ap, double *anorm, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zppequ_(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zppsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zppsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zpptrf_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpptri_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpstf2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpstrf_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *piv, rng_int_t *rank, double *tol, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zptcon_(rng_int_t *n, double *d, doublecomplex *e, double *anorm, double *rcond, double *rwork, rng_int_t *info);
extern void zpteqr_(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void zptrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zptsv_(rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info);
extern void zptsvx_(char *fact, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, double *df, doublecomplex *ef, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len);
extern void zpttrf_(rng_int_t *n, double *d, doublecomplex *e, rng_int_t *info);
extern void zpttrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zspcon_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsprfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zspsv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zspsvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *afp, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void zsptrf_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsptri_(char *uplo, rng_int_t *n, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsptrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zstedc_(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t compz_len);
extern void zstegr_(char *jobz, char *range, rng_int_t *n, double *d, double *e, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *abstol, rng_int_t *m, double *w, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info, rng_strlen_t jobz_len, rng_strlen_t range_len);
extern void zstein_(rng_int_t *n, double *d, double *e, rng_int_t *m, double *w, rng_int_t *iblock, rng_int_t *isplit, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *iwork, rng_int_t *ifail, rng_int_t *info);
extern void zsteqr_(char *compz, rng_int_t *n, double *d, double *e, doublecomplex *z, rng_int_t *ldz, double *work, rng_int_t *info, rng_strlen_t compz_len);
extern void zsycon_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, double *anorm, double *rcond, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsyconv_(char *uplo, char *way, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t way_len);
extern void zsyequb_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsyrfs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsyrfsx_(char *uplo, char *equed, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zsysv_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsysvx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *ferr, double *berr, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len);
extern void zsysvxx_(char *fact, char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *af, rng_int_t *ldaf, rng_int_t *ipiv, char *equed, double *s, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *rcond, double *rpvgrw, double *berr, rng_int_t *n_err_bnds, double *err_bnds_norm, double *err_bnds_comp, rng_int_t *nparams, double *params, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t fact_len, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zsyswapr_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *i1, rng_int_t *i2, rng_strlen_t uplo_len);
extern void zsytrf_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsytri2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsytri2x_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *nb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsytri_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsytrs2_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zsytrs_(char *uplo, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void ztbcon_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztbrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztbtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *kd, rng_int_t *nrhs, doublecomplex *ab, rng_int_t *ldab, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztfsm_(char *transr, char *side, char *uplo, char *trans, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, doublecomplex *b, rng_int_t *ldb, rng_strlen_t transr_len, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztftri_(char *transr, char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztfttp_(char *transr, char *uplo, rng_int_t *n, doublecomplex *arf, doublecomplex *ap, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ztfttr_(char *transr, char *uplo, rng_int_t *n, doublecomplex *arf, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ztgevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void ztgexc_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info);
extern void ztgsen_(rng_int_t *ijob, rng_int_t *wantq, rng_int_t *wantz, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *alpha, doublecomplex *beta, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *m, double *pl, double *pr, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *liwork, rng_int_t *info);
extern void ztgsja_(char *jobu, char *jobv, char *jobq, rng_int_t *m, rng_int_t *p, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, double *tola, double *tolb, double *alpha, double *beta, doublecomplex *u, rng_int_t *ldu, doublecomplex *v, rng_int_t *ldv, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *ncycle, rng_int_t *info, rng_strlen_t jobu_len, rng_strlen_t jobv_len, rng_strlen_t jobq_len);
extern void ztgsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *dif, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void ztgsyl_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *dif, doublecomplex *work, rng_int_t *lwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t trans_len);
extern void ztpcon_(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztpmqrt_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, rng_int_t *nb, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void ztpqrt2_(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, rng_int_t *info);
extern void ztpqrt_(rng_int_t *m, rng_int_t *n, rng_int_t *l, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *t, rng_int_t *ldt, doublecomplex *work, rng_int_t *info);
extern void ztprfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void ztprfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztptri_(char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztptrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *ap, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztpttf_(char *transr, char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ztpttr_(char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void ztrcon_(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *rcond, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztrevc_(char *side, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, rng_int_t *mm, rng_int_t *m, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t howmny_len);
extern void ztrexc_(char *compq, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, rng_int_t *ifst, rng_int_t *ilst, rng_int_t *info, rng_strlen_t compq_len);
extern void ztrrfs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *x, rng_int_t *ldx, double *ferr, double *berr, doublecomplex *work, double *rwork, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztrsen_(char *job, char *compq, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *q, rng_int_t *ldq, doublecomplex *w, rng_int_t *m, double *s, double *sep, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t compq_len);
extern void ztrsna_(char *job, char *howmny, rng_int_t *select, rng_int_t *n, doublecomplex *t, rng_int_t *ldt, doublecomplex *vl, rng_int_t *ldvl, doublecomplex *vr, rng_int_t *ldvr, double *s, double *sep, rng_int_t *mm, rng_int_t *m, doublecomplex *work, rng_int_t *ldwork, double *rwork, rng_int_t *info, rng_strlen_t job_len, rng_strlen_t howmny_len);
extern void ztrsyl_(char *trana, char *tranb, rng_int_t *isgn, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *scale, rng_int_t *info, rng_strlen_t trana_len, rng_strlen_t tranb_len);
extern void ztrtri_(char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void ztrtrs_(char *uplo, char *trans, char *diag, rng_int_t *n, rng_int_t *nrhs, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len);
extern void ztrttf_(char *transr, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *arf, rng_int_t *info, rng_strlen_t transr_len, rng_strlen_t uplo_len);
extern void ztrttp_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *ap, rng_int_t *info, rng_strlen_t uplo_len);
extern void ztzrqf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, rng_int_t *info);
extern void ztzrzf_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zunbdb_(char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, double *phi, doublecomplex *taup1, doublecomplex *taup2, doublecomplex *tauq1, doublecomplex *tauq2, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void zuncsd_(char *jobu1, char *jobu2, char *jobv1t, char *jobv2t, char *trans, char *signs, rng_int_t *m, rng_int_t *p, rng_int_t *q, doublecomplex *x11, rng_int_t *ldx11, doublecomplex *x12, rng_int_t *ldx12, doublecomplex *x21, rng_int_t *ldx21, doublecomplex *x22, rng_int_t *ldx22, double *theta, doublecomplex *u1, rng_int_t *ldu1, doublecomplex *u2, rng_int_t *ldu2, doublecomplex *v1t, rng_int_t *ldv1t, doublecomplex *v2t, rng_int_t *ldv2t, doublecomplex *work, rng_int_t *lwork, double *rwork, rng_int_t *lrwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t jobu1_len, rng_strlen_t jobu2_len, rng_strlen_t jobv1t_len, rng_strlen_t jobv2t_len, rng_strlen_t trans_len, rng_strlen_t signs_len);
extern void zungbr_(char *vect, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len);
extern void zunghr_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zunglq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zungql_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zungqr_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zungrq_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zungtr_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void zunmbr_(char *vect, char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t vect_len, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmhr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmlq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmql_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmqr_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmrq_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmrz_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *lwork, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);
extern void zupgtr_(char *uplo, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *q, rng_int_t *ldq, doublecomplex *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void zupmtr_(char *side, char *uplo, char *trans, rng_int_t *m, rng_int_t *n, doublecomplex *ap, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t uplo_len, rng_strlen_t trans_len);

/* LAPACK auxiliaries */
extern void cgbtf2_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void cgebd2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *work, rng_int_t *info);
extern void cgehd2_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgelq2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgeql2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgeqr2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgerq2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cgesc2_(rng_int_t *n, complex *a, rng_int_t *lda, complex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void cgetc2_(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void cgetf2_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void cgtts2_(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, complex *dl, complex *d, complex *du, complex *du2, rng_int_t *ipiv, complex *b, rng_int_t *ldb);
extern void chegs2_(rng_int_t *itype, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetd2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *d, float *e, complex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void chetf2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void clabrd_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *d, float *e, complex *tauq, complex *taup, complex *x, rng_int_t *ldx, complex *y, rng_int_t *ldy);
extern void clacgv_(rng_int_t *n, complex *x, rng_int_t *incx);
extern void clacn2_(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase, rng_int_t *isave);
extern void clacon_(rng_int_t *n, complex *v, complex *x, float *est, rng_int_t *kase);
extern void clacp2_(char *uplo, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void clacpy_(char *uplo, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void clacrm_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void clacrt_(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, complex *c, complex *s);
extern complex cladiv_(complex *ret_val, complex *x, complex *y);
extern void claed0_(rng_int_t *qsiz, rng_int_t *n, float *d, float *e, complex *q, rng_int_t *ldq, complex *qstore, rng_int_t *ldqs, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void claed7_(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, complex *q, rng_int_t *ldq, float *rho, rng_int_t *indxq, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void claed8_(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, complex *q, rng_int_t *ldq, float *d, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, complex *q2, rng_int_t *ldq2, float *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *info);
extern void claein_(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, complex *h, rng_int_t *ldh, complex *w, complex *v, complex *b, rng_int_t *ldb, float *rwork, float *eps3, float *smlnum, rng_int_t *info);
extern void claesy_(complex *a, complex *b, complex *c, complex *rt1, complex *rt2, complex *evscal, complex *cs1, complex *sn1);
extern void claev2_(complex *a, complex *b, complex *c, float *rt1, float *rt2, float *cs1, complex *sn1);
extern void clag2z_(rng_int_t *m, rng_int_t *n, complex *sa, rng_int_t *ldsa, doublecomplex *a, rng_int_t *lda, rng_int_t *info);
extern void clags2_(rng_int_t *upper, float *a1, complex *a2, float *a3, float *b1, complex *b2, float *b3, float *csu, complex *snu, float *csv, complex *snv, float *csq, complex *snq);
extern void clagtm_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *alpha, complex *dl, complex *d, complex *du, complex *x, rng_int_t *ldx, float *beta, complex *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void clahef_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void clahqr_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *info);
extern void clahr2_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void clahrd_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, complex *a, rng_int_t *lda, complex *tau, complex *t, rng_int_t *ldt, complex *y, rng_int_t *ldy);
extern void claic1_(rng_int_t *job, rng_int_t *j, complex *x, float *sest, complex *w, complex *gamma, float *sestpr, complex *s, complex *c);
extern void clals0_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *rwork, rng_int_t *info);
extern void clalsa_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, complex *b, rng_int_t *ldb, complex *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *rwork, rng_int_t *iwork, rng_int_t *info);
extern void clalsd_(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, complex *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, complex *work, float *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern float clangb_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len);
extern float clange_(char *norm, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float clangt_(char *norm, rng_int_t *n, complex *dl, complex *d, complex *du, rng_strlen_t norm_len);
extern float clanhb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clanhe_(char *norm, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clanhp_(char *norm, char *uplo, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clanhs_(char *norm, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float clanht_(char *norm, rng_int_t *n, float *d, complex *e, rng_strlen_t norm_len);
extern float clansb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clansp_(char *norm, char *uplo, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clansy_(char *norm, char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float clantb_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, complex *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float clantp_(char *norm, char *uplo, char *diag, rng_int_t *n, complex *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float clantr_(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void clapll_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *ssmin);
extern void clapmt_(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *ldx, rng_int_t *k);
extern void claqgb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, complex *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void claqge_(rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void claqhb_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void claqhe_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void claqhp_(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void claqp2_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *work);
extern void claqps_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *jpvt, complex *tau, float *vn1, float *vn2, complex *auxv, complex *f, rng_int_t *ldf);
extern void claqr0_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void claqr1_(rng_int_t *n, complex *h, rng_int_t *ldh, complex *s1, complex *s2, complex *v);
extern void claqr2_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void claqr3_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, complex *sh, complex *v, rng_int_t *ldv, rng_int_t *nh, complex *t, rng_int_t *ldt, rng_int_t *nv, complex *wv, rng_int_t *ldwv, complex *work, rng_int_t *lwork);
extern void claqr4_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, complex *h, rng_int_t *ldh, complex *w, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *work, rng_int_t *lwork, rng_int_t *info);
extern void claqr5_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, complex *s, complex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, complex *z, rng_int_t *ldz, complex *v, rng_int_t *ldv, complex *u, rng_int_t *ldu, rng_int_t *nv, complex *wv, rng_int_t *ldwv, rng_int_t *nh, complex *wh, rng_int_t *ldwh);
extern void claqsb_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void claqsp_(char *uplo, rng_int_t *n, complex *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void claqsy_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void clar1v_(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, complex *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void clar2v_(rng_int_t *n, complex *x, complex *y, complex *z, rng_int_t *incx, float *c, complex *s, rng_int_t *incc);
extern void clarcm_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, float *rwork);
extern void clarfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void clarf_(char *side, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void clarfg_(rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *tau);
extern void clarft_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void clarfx_(char *side, rng_int_t *m, rng_int_t *n, complex *v, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void clargv_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void clarnv_(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, complex *x);
extern void clarrv_(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, complex *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void clartg_(complex *f, complex *g, float *cs, complex *sn, complex *r);
extern void clartv_(rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, float *c, complex *s, rng_int_t *incc);
extern void clarzb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *v, rng_int_t *ldv, complex *t, rng_int_t *ldt, complex *c, rng_int_t *ldc, complex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void clarz_(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *v, rng_int_t *incv, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void clarzt_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, complex *v, rng_int_t *ldv, complex *tau, complex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void clascl_(char *type, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void claset_(char *uplo, rng_int_t *m, rng_int_t *n, complex *alpha, complex *beta, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void clasr_(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, float *c, float *s, complex *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void claswp_(rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void clasyf_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, complex *a, rng_int_t *lda, rng_int_t *ipiv, complex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void clatbs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void clatdf_(rng_int_t *ijob, rng_int_t *n, complex *z, rng_int_t *ldz, complex *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void clatps_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, complex *ap, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void clatrd_(char *uplo, rng_int_t *n, rng_int_t *nb, complex *a, rng_int_t *lda, float *e, complex *tau, complex *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void clatrs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, complex *a, rng_int_t *lda, complex *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void clatrz_(rng_int_t *m, rng_int_t *n, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *work);
extern void clatzm_(char *side, rng_int_t *m, rng_int_t *n, complex *v, rng_int_t *incv, complex *tau, complex *c1, complex *c2, rng_int_t *ldc, complex *work, rng_strlen_t side_len);
extern void clauu2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void clauum_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpbtf2_(char *uplo, rng_int_t *n, rng_int_t *kd, complex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void cpotf2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void cptts2_(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, float *d, complex *e, complex *b, rng_int_t *ldb);
extern void crot_(rng_int_t *n, complex *cx, rng_int_t *incx, complex *cy, rng_int_t *incy, float *c, complex *s);
extern void cspmv_(char *uplo, rng_int_t *n, complex *alpha, complex *ap, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void cspr_(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *ap, rng_strlen_t uplo_len);
extern void csrscl_(rng_int_t *n, float *sa, complex *sx, rng_int_t *incx);
extern void csymv_(char *uplo, rng_int_t *n, complex *alpha, complex *a, rng_int_t *lda, complex *x, rng_int_t *incx, complex *beta, complex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void csyr_(char *uplo, rng_int_t *n, complex *alpha, complex *x, rng_int_t *incx, complex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void csytf2_(char *uplo, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void ctgex2_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *q, rng_int_t *ldq, complex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void ctgsy2_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, complex *a, rng_int_t *lda, complex *b, rng_int_t *ldb, complex *c, rng_int_t *ldc, complex *d, rng_int_t *ldd, complex *e, rng_int_t *lde, complex *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *info, rng_strlen_t trans_len);
extern void ctrti2_(char *uplo, char *diag, rng_int_t *n, complex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void cung2l_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cung2r_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cungl2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cungr2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *work, rng_int_t *info);
extern void cunm2l_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunm2r_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunml2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmr2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void cunmr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, complex *a, rng_int_t *lda, complex *tau, complex *c, rng_int_t *ldc, complex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dgbtf2_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void dgebd2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *work, rng_int_t *info);
extern void dgehd2_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgelq2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgeql2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgeqr2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgerq2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dgesc2_(rng_int_t *n, double *a, rng_int_t *lda, double *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void dgetc2_(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void dgetf2_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void dgtts2_(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, double *dl, double *d, double *du, double *du2, rng_int_t *ipiv, double *b, rng_int_t *ldb);
extern void dlabad_(double *small, double *large);
extern void dlabrd_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *d, double *e, double *tauq, double *taup, double *x, rng_int_t *ldx, double *y, rng_int_t *ldy);
extern void dlacn2_(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase, rng_int_t *isave);
extern void dlacon_(rng_int_t *n, double *v, double *x, rng_int_t *isgn, double *est, rng_int_t *kase);
extern void dlacpy_(char *uplo, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void dladiv_(double *a, double *b, double *c, double *d, double *p, double *q);
extern void dlae2_(double *a, double *b, double *c, double *rt1, double *rt2);
extern void dlaebz_(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, double *abstol, double *reltol, double *pivmin, double *d, double *e, double *e2, rng_int_t *nval, double *ab, double *c, rng_int_t *mout, rng_int_t *nab, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlaed0_(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, double *d, double *e, double *q, rng_int_t *ldq, double *qstore, rng_int_t *ldqs, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlaed1_(rng_int_t *n, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlaed2_(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, double *z, double *dlamda, double *w, double *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void dlaed3_(rng_int_t *k, rng_int_t *n, rng_int_t *n1, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *q2, rng_int_t *indx, rng_int_t *ctot, double *w, double *s, rng_int_t *info);
extern void dlaed4_(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam, rng_int_t *info);
extern void dlaed5_(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dlam);
extern void dlaed6_(rng_int_t *kniter, rng_int_t *orgati, double *rho, double *d, double *z, double *finit, double *tau, rng_int_t *info);
extern void dlaed7_(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlaed8_(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, double *d, double *q, rng_int_t *ldq, rng_int_t *indxq, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, double *q2, rng_int_t *ldq2, double *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void dlaed9_(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, double *d, double *q, rng_int_t *ldq, double *rho, double *dlamda, double *w, double *s, rng_int_t *lds, rng_int_t *info);
extern void dlaeda_(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, double *q, rng_int_t *qptr, double *z, double *ztemp, rng_int_t *info);
extern void dlaein_(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, double *h, rng_int_t *ldh, double *wr, double *wi, double *vr, double *vi, double *b, rng_int_t *ldb, double *work, double *eps3, double *smlnum, double *bignum, rng_int_t *info);
extern void dlaev2_(double *a, double *b, double *c, double *rt1, double *rt2, double *cs1, double *sn1);
extern void dlaexc_(rng_int_t *wantq, rng_int_t *n, double *t, rng_int_t *ldt, double *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *info);
extern void dlag2_(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *safmin, double *scale1, double *scale2, double *wr1, double *wr2, double *wi);
extern void dlag2s_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, float *sa, rng_int_t *ldsa, rng_int_t *info);
extern void dlags2_(rng_int_t *upper, double *a1, double *a2, double *a3, double *b1, double *b2, double *b3, double *csu, double *snu, double *csv, double *snv, double *csq, double *snq);
extern void dlagtf_(rng_int_t *n, double *a, double *lambda, double *b, double *c, double *tol, double *d, rng_int_t *in, rng_int_t *info);
extern void dlagtm_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *alpha, double *dl, double *d, double *du, double *x, rng_int_t *ldx, double *beta, double *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void dlagts_(rng_int_t *job, rng_int_t *n, double *a, double *b, double *c, double *d, rng_int_t *in, double *y, double *tol, rng_int_t *info);
extern void dlagv2_(double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *alphar, double *alphai, double *beta, double *csl, double *snl, double *csr, double *snr);
extern void dlahqr_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *info);
extern void dlahr2_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void dlahrd_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, double *a, rng_int_t *lda, double *tau, double *t, rng_int_t *ldt, double *y, rng_int_t *ldy);
extern void dlaic1_(rng_int_t *job, rng_int_t *j, double *x, double *sest, double *w, double *gamma, double *sestpr, double *s, double *c);
extern rng_int_t dlaisnan_(double *din1, double *din2);
extern void dlaln2_(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, double *smin, double *ca, double *a, rng_int_t *lda, double *d1, double *d2, double *b, rng_int_t *ldb, double *wr, double *wi, double *x, rng_int_t *ldx, double *scale, double *xnorm, rng_int_t *info);
extern void dlals0_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *info);
extern void dlalsa_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *b, rng_int_t *ldb, double *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlalsd_(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void dlamrg_(rng_int_t *n1, rng_int_t *n2, double *a, rng_int_t *dtrd1, rng_int_t *dtrd2, rng_int_t *index);
extern rng_int_t dlaneg_(rng_int_t *n, double *d, double *lld, double *sigma, double *pivmin, rng_int_t *r);
extern double dlangb_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len);
extern double dlange_(char *norm, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double dlangt_(char *norm, rng_int_t *n, double *dl, double *d, double *du, rng_strlen_t norm_len);
extern double dlanhs_(char *norm, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double dlansb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double dlansp_(char *norm, char *uplo, rng_int_t *n, double *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double dlanst_(char *norm, rng_int_t *n, double *d, double *e, rng_strlen_t norm_len);
extern double dlansy_(char *norm, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double dlantb_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, double *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double dlantp_(char *norm, char *uplo, char *diag, rng_int_t *n, double *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double dlantr_(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void dlanv2_(double *a, double *b, double *c, double *d, double *rt1r, double *rt1i, double *rt2r, double *rt2i, double *cs, double *sn);
extern void dlapll_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *ssmin);
extern void dlapmt_(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, double *x, rng_int_t *ldx, rng_int_t *k);
extern double dlapy2_(double *x, double *y);
extern double dlapy3_(double *x, double *y, double *z);
extern void dlaqgb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, double *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void dlaqge_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void dlaqp2_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *work);
extern void dlaqps_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *jpvt, double *tau, double *vn1, double *vn2, double *auxv, double *f, rng_int_t *ldf);
extern void dlaqr0_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dlaqr1_(rng_int_t *n, double *h, rng_int_t *ldh, double *sr1, double *si1, double *sr2, double *si2, double *v);
extern void dlaqr2_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double *v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t *nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void dlaqr3_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, double *h, rng_int_t * ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, double *sr, double *si, double * v, rng_int_t *ldv, rng_int_t *nh, double *t, rng_int_t *ldt, rng_int_t * nv, double *wv, rng_int_t *ldwv, double *work, rng_int_t *lwork);
extern void dlaqr4_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, double *h, rng_int_t *ldh, double *wr, double *wi, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dlaqr5_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, double *sr, double *si, double *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, double *z, rng_int_t *ldz, double *v, rng_int_t *ldv, double *u, rng_int_t *ldu, rng_int_t *nv, double *wv, rng_int_t *ldwv, rng_int_t *nh, double *wh, rng_int_t *ldwh);
extern void dlaqsb_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dlaqsp_(char *uplo, rng_int_t *n, double *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dlaqsy_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void dlaqtr_(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, double *t, rng_int_t *ldt, double *b, double *w, double *scale, double *x, double *work, rng_int_t *info);
extern void dlar1v_(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, double *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void dlar2v_(rng_int_t *n, double *x, double *y, double *z, rng_int_t *incx, double *c, double *s, rng_int_t *incc);
extern void dlarfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void dlarf_(char *side, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void dlarfg_(rng_int_t *n, double *alpha, double *x, rng_int_t *incx, double *tau);
extern void dlarfx_(char *side, rng_int_t *m, rng_int_t *n, double *v, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void dlargv_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void dlarnv_(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, double *x);
extern void dlarra_(rng_int_t *n, double *d, double *e, double *e2, double *spltol, double *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void dlarrb_(rng_int_t *n, double *d, double *lld, rng_int_t *ifirst, rng_int_t *ilast, double *rtol1, double *rtol2, rng_int_t *offset, double *w, double *wgap, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *twist, rng_int_t *info);
extern void dlarrc_(char *jobt, rng_int_t *n, double *vl, double *vu, double *d, double *e, double *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info, rng_strlen_t jobt_len);
extern void dlarrd_(char *range, char *order, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *gers, double *reltol, double *d, double *e, double *e2, double *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wl, double *wu, rng_int_t *iblock, rng_int_t *indexw, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void dlarre_(char *range, rng_int_t *n, double *vl, double *vu, rng_int_t *il, rng_int_t *iu, double *d, double *e, double *e2, double *rtol1, double *rtol2, double *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *pivmin, double *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len);
extern void dlarrf_(rng_int_t *n, double *d, double *l, double *ld, rng_int_t *clstrt, rng_int_t *clend, double *w, double *wgap, double *werr, double *spdiam, double *clgapl, double *clgapr, double *pivmin, double *sigma, double *dplus, double *lplus, double *work, rng_int_t *info);
extern void dlarrj_(rng_int_t *n, double *d, double *e2, rng_int_t *ifirst, rng_int_t *ilast, double *rtol, rng_int_t *offset, double *w, double *werr, double *work, rng_int_t *iwork, double *pivmin, double *spdiam, rng_int_t *info);
extern void dlarrk_(rng_int_t *n, rng_int_t *iw, double *gl, double *gu, double *d, double *e2, double *pivmin, double *reltol, double *w, double *werr, rng_int_t *info);
extern void dlarrr_(rng_int_t *n, double *d, double *e, rng_int_t *info);
extern void dlarrv_(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, double *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlartg_(double *f, double *g, double *cs, double *sn, double *r);
extern void dlartv_(rng_int_t *n, double *x, rng_int_t *incx, double *y, rng_int_t *incy, double *c, double *s, rng_int_t *incc);
extern void dlaruv_(rng_int_t *iseed, rng_int_t *n, double *x);
extern void dlarzb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, double *v, rng_int_t *ldv, double *t, rng_int_t *ldt, double *c, rng_int_t *ldc, double *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void dlarz_(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, double *v, rng_int_t *incv, double *tau, double *c, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void dlarzt_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, double *v, rng_int_t *ldv, double *tau, double *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void dlas2_(double *f, double *g, double *h, double *ssmin, double *ssmax);
extern void dlascl_(char *type, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void dlasd0_(rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, double *work, rng_int_t *info);
extern void dlasd1_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, double *work, rng_int_t *info);
extern void dlasd2_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *alpha, double *beta, double *u, rng_int_t *ldu, double *vt, rng_int_t *ldvt, double *dsigma, double *u2, rng_int_t *ldu2, double *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void dlasd3_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *q, rng_int_t *ldq, double *dsigma, double *u, rng_int_t *ldu, double *u2, rng_int_t *ldu2, double *vt, rng_int_t *ldvt, double *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, double *z, rng_int_t *info);
extern void dlasd4_(rng_int_t *n, rng_int_t *i, double *d, double *z, double *delta, double *rho, double *sigma, double *work, rng_int_t *info);
extern void dlasd5_(rng_int_t *i, double *d, double *z, double *delta, double *rho, double *dsigma, double *work);
extern void dlasd6_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, double *d, double *vf, double *vl, double *alpha, double *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlasd7_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, double *d, double *z, double *zw, double *vf, double *vfw, double *vl, double *vlw, double *alpha, double *beta, double *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *c, double *s, rng_int_t *info);
extern void dlasd8_(rng_int_t *icompq, rng_int_t *k, double *d, double *z, double *vf, double *vl, double *difl, double *difr, rng_int_t *lddifr, double *dsigma, double *work, rng_int_t *info);
extern void dlasda_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, double *d, double *e, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *work, rng_int_t *iwork, rng_int_t *info);
extern void dlasdq_(char *uplo, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, double *d, double *e, double *vt, rng_int_t *ldvt, double *u, rng_int_t *ldu, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void dlasdt_(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void dlaset_(char *uplo, rng_int_t *m, rng_int_t *n, double *alpha, double *beta, double *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void dlasq1_(rng_int_t *n, double *d, double *e, double *work, rng_int_t *info);
extern void dlasq2_(rng_int_t *n, double *z, rng_int_t *info);
extern void dlasq3_(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *sigma, double *desig, double *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *g, double *tau);
extern void dlasq4_(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, rng_int_t *n0in, double *dmin, double *dmin1, double *dmin2, double *dn, double *dn1, double *dn2, double *tau, rng_int_t *ttype, double *g);
extern void dlasq5_(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *tau, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2, rng_int_t *ieee);
extern void dlasq6_(rng_int_t *i0, rng_int_t *n0, double *z, rng_int_t *pp, double *dmin, double *dmin1, double *dmin2, double *dn, double *dnm1, double *dnm2);
extern void dlasr_(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, double *c, double *s, double *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void dlasv2_(double *f, double *g, double *h, double *ssmin, double *ssmax, double *snr, double *csr, double *snl, double *csl);
extern void dlaswp_(rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void dlasy2_(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, double *tl, rng_int_t *ldtl, double *tr, rng_int_t *ldtr, double *b, rng_int_t *ldb, double *scale, double *x, rng_int_t *ldx, double *xnorm, rng_int_t *info);
extern void dlasyf_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, double *a, rng_int_t *lda, rng_int_t *ipiv, double *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void dlatbs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void dlatdf_(rng_int_t *ijob, rng_int_t *n, double *z, rng_int_t *ldz, double *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void dlatps_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, double *ap, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void dlatrd_(char *uplo, rng_int_t *n, rng_int_t *nb, double *a, rng_int_t *lda, double *e, double *tau, double *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void dlatrs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, double *a, rng_int_t *lda, double *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void dlatrz_(rng_int_t *m, rng_int_t *n, rng_int_t *l, double *a, rng_int_t *lda, double *tau, double *work);
extern void dlatzm_(char *side, rng_int_t *m, rng_int_t *n, double *v, rng_int_t *incv, double *tau, double *c1, double *c2, rng_int_t *ldc, double *work, rng_strlen_t side_len);
extern void dlauu2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dlauum_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dorg2l_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dorg2r_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dorgl2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dorgr2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *work, rng_int_t *info);
extern void dorm2l_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dorm2r_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dorml2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dormr2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, double *a, rng_int_t *lda, double *tau, double *c, rng_int_t *ldc, double *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void dpbtf2_(char *uplo, rng_int_t *n, rng_int_t *kd, double *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void dpotf2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void dptts2_(rng_int_t *n, rng_int_t *nrhs, double *d, double *e, double *b, rng_int_t *ldb);
extern void drscl_(rng_int_t *n, double *sa, double *sx, rng_int_t *incx);
extern void dsygs2_(rng_int_t *itype, char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytd2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, double *d, double *e, double *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void dsytf2_(char *uplo, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void dtgex2_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *q, rng_int_t *ldq, double *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, double *work, rng_int_t *lwork, rng_int_t *info);
extern void dtgsy2_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, double *b, rng_int_t *ldb, double *c, rng_int_t *ldc, double *d, rng_int_t *ldd, double *e, rng_int_t *lde, double *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info, rng_strlen_t trans_len);
extern void dtrti2_(char *uplo, char *diag, rng_int_t *n, double *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double dzsum1_(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t icmax1_(rng_int_t *n, complex *cx, rng_int_t *incx);
extern rng_int_t ieeeck_(rng_int_t *ispec, float *zero, float *one);
extern rng_int_t iparmq_(rng_int_t *ispec, char *name, char *opts, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, rng_int_t *lwork, rng_strlen_t name_len, rng_strlen_t opts_len);
extern rng_int_t izmax1_(rng_int_t *n, doublecomplex *cx, rng_int_t *incx);
extern rng_int_t lsamen_(rng_int_t *n, char *ca, char *cb, rng_strlen_t ca_len, rng_strlen_t cb_len);
extern float scsum1_(rng_int_t *n, complex *cx, rng_int_t *incx);
extern void sgbtf2_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void sgebd2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *work, rng_int_t *info);
extern void sgehd2_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgelq2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgeql2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgeqr2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgerq2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sgesc2_(rng_int_t *n, float *a, rng_int_t *lda, float *rhs, rng_int_t *ipiv, rng_int_t *jpiv, float *scale);
extern void sgetc2_(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void sgetf2_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void sgtts2_(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, float *dl, float *d, float *du, float *du2, rng_int_t *ipiv, float *b, rng_int_t *ldb);
extern void slabad_(float *small, float *large);
extern void slabrd_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *d, float *e, float *tauq, float *taup, float *x, rng_int_t *ldx, float *y, rng_int_t *ldy);
extern void slacn2_(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase, rng_int_t *isave);
extern void slacon_(rng_int_t *n, float *v, float *x, rng_int_t *isgn, float *est, rng_int_t *kase);
extern void slacpy_(char *uplo, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void sladiv_(float *a, float *b, float *c, float *d, float *p, float *q);
extern void slae2_(float *a, float *b, float *c, float *rt1, float *rt2);
extern void slaebz_(rng_int_t *ijob, rng_int_t *nitmax, rng_int_t *n, rng_int_t *mmax, rng_int_t *minp, rng_int_t *nbmin, float *abstol, float *reltol, float *pivmin, float *d, float *e, float *e2, rng_int_t *nval, float *ab, float *c, rng_int_t *mout, rng_int_t *nab, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slaed0_(rng_int_t *icompq, rng_int_t *qsiz, rng_int_t *n, float *d, float *e, float *q, rng_int_t *ldq, float *qstore, rng_int_t *ldqs, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slaed1_(rng_int_t *n, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *work, rng_int_t * iwork, rng_int_t *info);
extern void slaed2_(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, float *z, float *dlamda, float *w, float *q2, rng_int_t *indx, rng_int_t *indxc, rng_int_t *indxp, rng_int_t *coltyp, rng_int_t *info);
extern void slaed3_(rng_int_t *k, rng_int_t *n, rng_int_t *n1, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *q2, rng_int_t *indx, rng_int_t *ctot, float *w, float *s, rng_int_t *info);
extern void slaed4_(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam, rng_int_t *info);
extern void slaed5_(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dlam);
extern void slaed6_(rng_int_t *kniter, rng_int_t *orgati, float *rho, float *d, float *z, float *finit, float *tau, rng_int_t *info);
extern void slaed7_(rng_int_t *icompq, rng_int_t *n, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slaed8_(rng_int_t *icompq, rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, float *d, float *q, rng_int_t *ldq, rng_int_t *indxq, float *rho, rng_int_t *cutpnt, float *z, float *dlamda, float *q2, rng_int_t *ldq2, float *w, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, rng_int_t *indxp, rng_int_t *indx, rng_int_t *info);
extern void slaed9_(rng_int_t *k, rng_int_t *kstart, rng_int_t *kstop, rng_int_t *n, float *d, float *q, rng_int_t *ldq, float *rho, float *dlamda, float *w, float *s, rng_int_t *lds, rng_int_t *info);
extern void slaeda_(rng_int_t *n, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, float *givnum, float *q, rng_int_t *qptr, float *z, float *ztemp, rng_int_t *info);
extern void slaein_(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, float *h, rng_int_t *ldh, float *wr, float *wi, float *vr, float *vi, float *b, rng_int_t *ldb, float *work, float *eps3, float *smlnum, float *bignum, rng_int_t *info);
extern void slaev2_(float *a, float *b, float *c, float *rt1, float *rt2, float *cs1, float *sn1);
extern void slaexc_(rng_int_t *wantq, rng_int_t *n, float *t, rng_int_t *ldt, float *q, rng_int_t *ldq, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *info);
extern void slag2d_(rng_int_t *m, rng_int_t *n, float *sa, rng_int_t *ldsa, double *a, rng_int_t *lda, rng_int_t *info);
extern void slag2_(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *safmin, float *scale1, float *scale2, float *wr1, float *wr2, float *wi);
extern void slags2_(rng_int_t *upper, float *a1, float *a2, float *a3, float *b1, float *b2, float *b3, float *csu, float *snu, float *csv, float *snv, float *csq, float *snq);
extern void slagtf_(rng_int_t *n, float *a, float *lambda, float *b, float *c, float *tol, float *d, rng_int_t *in, rng_int_t *info);
extern void slagtm_(char *trans, rng_int_t *n, rng_int_t *nrhs, float *alpha, float *dl, float *d, float *du, float *x, rng_int_t *ldx, float *beta, float *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void slagts_(rng_int_t *job, rng_int_t *n, float *a, float *b, float *c, float *d, rng_int_t *in, float *y, float *tol, rng_int_t *info);
extern void slagv2_(float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *alphar, float *alphai, float *beta, float *csl, float *snl, float *csr, float *snr);
extern void slahqr_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *info);
extern void slahr2_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void slahrd_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, float *a, rng_int_t *lda, float *tau, float *t, rng_int_t *ldt, float *y, rng_int_t *ldy);
extern void slaic1_(rng_int_t *job, rng_int_t *j, float *x, float *sest, float *w, float *gamma, float *sestpr, float *s, float *c);
extern rng_int_t slaisnan_(float *sin1, float *sin2);
extern void slaln2_(rng_int_t *ltrans, rng_int_t *na, rng_int_t *nw, float *smin, float *ca, float *a, rng_int_t *lda, float *d1, float *d2, float *b, rng_int_t *ldb, float *wr, float *wi, float *x, rng_int_t *ldx, float *scale, float *xnorm, rng_int_t *info);
extern void slals0_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *info);
extern void slalsa_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *b, rng_int_t *ldb, float *bx, rng_int_t *ldbx, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slalsd_(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb, float *rcond, rng_int_t *rank, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern void slamrg_(rng_int_t *n1, rng_int_t *n2, float *a, rng_int_t *strd1, rng_int_t *strd2, rng_int_t *index);
extern rng_int_t slaneg_(rng_int_t *n, float *d, float *lld, float *sigma, float *pivmin, rng_int_t *r);
extern float slangb_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len);
extern float slange_(char *norm, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float slangt_(char *norm, rng_int_t *n, float *dl, float *d, float *du, rng_strlen_t norm_len);
extern float slanhs_(char *norm, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len);
extern float slansb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float slansp_(char *norm, char *uplo, rng_int_t *n, float *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float slanst_(char *norm, rng_int_t *n, float *d, float *e, rng_strlen_t norm_len);
extern float slansy_(char *norm, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern float slantb_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, float *ab, rng_int_t *ldab, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float slantp_(char *norm, char *uplo, char *diag, rng_int_t *n, float *ap, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern float slantr_(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void slanv2_(float *a, float *b, float *c, float *d, float *rt1r, float *rt1i, float *rt2r, float *rt2i, float *cs, float *sn);
extern void slapll_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *ssmin);
extern void slapmt_(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, float *x, rng_int_t *ldx, rng_int_t *k);
extern float slapy2_(float *x, float *y);
extern float slapy3_(float *x, float *y, float *z);
extern void slaqgb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, float *ab, rng_int_t *ldab, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void slaqge_(rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *r, float *c, float *rowcnd, float *colcnd, float *amax, char *equed, rng_strlen_t equed_len);
extern void slaqp2_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *work);
extern void slaqps_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *jpvt, float *tau, float *vn1, float *vn2, float *auxv, float *f, rng_int_t *ldf);
extern void slaqr0_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void slaqr1_(rng_int_t *n, float *h, rng_int_t *ldh, float *sr1, float *si1, float *sr2, float *si2, float *v);
extern void slaqr2_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float *work, rng_int_t *lwork);
extern void slaqr3_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, float *sr, float *si, float *v, rng_int_t *ldv, rng_int_t *nh, float *t, rng_int_t *ldt, rng_int_t *nv, float *wv, rng_int_t *ldwv, float * work, rng_int_t *lwork);
extern void slaqr4_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, float *h, rng_int_t *ldh, float *wr, float *wi, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *work, rng_int_t *lwork, rng_int_t *info);
extern void slaqr5_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, float *sr, float *si, float *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, float *z, rng_int_t *ldz, float *v, rng_int_t *ldv, float *u, rng_int_t *ldu, rng_int_t *nv, float *wv, rng_int_t *ldwv, rng_int_t *nh, float *wh, rng_int_t *ldwh);
extern void slaqsb_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void slaqsp_(char *uplo, rng_int_t *n, float *ap, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void slaqsy_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *s, float *scond, float *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void slaqtr_(rng_int_t *ltran, rng_int_t *lfloat, rng_int_t *n, float *t, rng_int_t *ldt, float *b, float *w, float *scale, float *x, float *work, rng_int_t *info);
extern void slar1v_(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, float *lambda, float *d, float *l, float *ld, float *lld, float *pivmin, float *gaptol, float *z, rng_int_t *wantnc, rng_int_t *negcnt, float *ztz, float *mingma, rng_int_t *r, rng_int_t *isuppz, float *nrminv, float *resid, float *rqcorr, float *work);
extern void slar2v_(rng_int_t *n, float *x, float *y, float *z, rng_int_t *incx, float *c, float *s, rng_int_t *incc);
extern void slarfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void slarf_(char *side, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void slarfg_(rng_int_t *n, float *alpha, float *x, rng_int_t *incx, float *tau);
extern void slarfx_(char *side, rng_int_t *m, rng_int_t *n, float *v, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void slargv_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, rng_int_t *incc);
extern void slarnv_(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, float *x);
extern void slarra_(rng_int_t *n, float *d, float *e, float *e2, float *spltol, float *tnrm, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *info);
extern void slarrb_(rng_int_t *n, float *d, float *lld, rng_int_t *ifirst, rng_int_t *ilast, float *rtol1, float *rtol2, rng_int_t *offset, float *w, float *wgap, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *twist, rng_int_t *info);
extern void slarrc_(char *jobt, rng_int_t *n, float *vl, float *vu, float *d, float *e, float *pivmin, rng_int_t *eigcnt, rng_int_t *lcnt, rng_int_t *rcnt, rng_int_t *info, rng_strlen_t jobt_len);
extern void slarrd_(char *range, char *order, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *gers, float *reltol, float *d, float *e, float *e2, float *pivmin, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wl, float *wu, rng_int_t *iblock, rng_int_t *indexw, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len, rng_strlen_t order_len);
extern void slarre_(char *range, rng_int_t *n, float *vl, float *vu, rng_int_t *il, rng_int_t *iu, float *d, float *e, float *e2, float *rtol1, float *rtol2, float *spltol, rng_int_t *nsplit, rng_int_t *isplit, rng_int_t *m, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *pivmin, float *work, rng_int_t *iwork, rng_int_t *info, rng_strlen_t range_len);
extern void slarrf_(rng_int_t *n, float *d, float *l, float *ld, rng_int_t *clstrt, rng_int_t *clend, float *w, float *wgap, float *werr, float *spdiam, float *clgapl, float *clgapr, float *pivmin, float *sigma, float *dplus, float *lplus, float *work, rng_int_t *info);
extern void slarrj_(rng_int_t *n, float *d, float *e2, rng_int_t *ifirst, rng_int_t *ilast, float *rtol, rng_int_t *offset, float *w, float *werr, float *work, rng_int_t *iwork, float *pivmin, float *spdiam, rng_int_t *info);
extern void slarrk_(rng_int_t *n, rng_int_t *iw, float *gl, float *gu, float *d, float *e2, float *pivmin, float *reltol, float *w, float *werr, rng_int_t *info);
extern void slarrr_(rng_int_t *n, float *d, float *e, rng_int_t *info);
extern void slarrv_(rng_int_t *n, float *vl, float *vu, float *d, float *l, float *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, float *minrgp, float *rtol1, float *rtol2, float *w, float *werr, float *wgap, rng_int_t *iblock, rng_int_t *indexw, float *gers, float *z, rng_int_t *ldz, rng_int_t *isuppz, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slartg_(float *f, float *g, float *cs, float *sn, float *r);
extern void slartv_(rng_int_t *n, float *x, rng_int_t *incx, float *y, rng_int_t *incy, float *c, float *s, rng_int_t *incc);
extern void slaruv_(rng_int_t *iseed, rng_int_t *n, float *x);
extern void slarzb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, float *v, rng_int_t *ldv, float *t, rng_int_t *ldt, float *c, rng_int_t *ldc, float *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void slarz_(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, float *v, rng_int_t *incv, float *tau, float *c, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void slarzt_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, float *v, rng_int_t *ldv, float *tau, float *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void slas2_(float *f, float *g, float *h, float *ssmin, float *ssmax);
extern void slascl_(char *type, rng_int_t *kl, rng_int_t *ku, float *cfrom, float *cto, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void slasd0_(rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *smlsiz, rng_int_t *iwork, float *work, rng_int_t *info);
extern void slasd1_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, rng_int_t *idxq, rng_int_t *iwork, float *work, rng_int_t *info);
extern void slasd2_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *alpha, float *beta, float *u, rng_int_t *ldu, float *vt, rng_int_t *ldvt, float *dsigma, float *u2, rng_int_t *ldu2, float *vt2, rng_int_t *ldvt2, rng_int_t *idxp, rng_int_t *idx, rng_int_t *idxc, rng_int_t *idxq, rng_int_t *coltyp, rng_int_t *info);
extern void slasd3_(rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *q, rng_int_t *ldq, float *dsigma, float *u, rng_int_t *ldu, float *u2, rng_int_t *ldu2, float *vt, rng_int_t *ldvt, float *vt2, rng_int_t *ldvt2, rng_int_t *idxc, rng_int_t *ctot, float *z, rng_int_t *info);
extern void slasd4_(rng_int_t *n, rng_int_t *i, float *d, float *z, float *delta, float *rho, float *sigma, float *work, rng_int_t *info);
extern void slasd5_(rng_int_t *i, float *d, float *z, float *delta, float *rho, float *dsigma, float *work);
extern void slasd6_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, float *d, float *vf, float *vl, float *alpha, float *beta, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *poles, float *difl, float *difr, float *z, rng_int_t *k, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slasd7_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *k, float *d, float *z, float *zw, float *vf, float *vfw, float *vl, float *vlw, float *alpha, float *beta, float *dsigma, rng_int_t *idx, rng_int_t *idxp, rng_int_t *idxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, float *givnum, rng_int_t *ldgnum, float *c, float *s, rng_int_t *info);
extern void slasd8_(rng_int_t *icompq, rng_int_t *k, float *d, float *z, float *vf, float *vl, float *difl, float *difr, rng_int_t *lddifr, float *dsigma, float *work, rng_int_t *info);
extern void slasda_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *sqre, float *d, float *e, float *u, rng_int_t *ldu, float *vt, rng_int_t *k, float *difl, float *difr, float *z, float *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, float *givnum, float *c, float *s, float *work, rng_int_t *iwork, rng_int_t *info);
extern void slasdq_(char *uplo, rng_int_t *sqre, rng_int_t *n, rng_int_t *ncvt, rng_int_t *nru, rng_int_t *ncc, float *d, float *e, float *vt, rng_int_t *ldvt, float *u, rng_int_t *ldu, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t uplo_len);
extern void slasdt_(rng_int_t *n, rng_int_t *lvl, rng_int_t *nd, rng_int_t *inode, rng_int_t *ndiml, rng_int_t *ndimr, rng_int_t *msub);
extern void slaset_(char *uplo, rng_int_t *m, rng_int_t *n, float *alpha, float *beta, float *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void slasq1_(rng_int_t *n, float *d, float *e, float *work, rng_int_t *info);
extern void slasq2_(rng_int_t *n, float *z, rng_int_t *info);
extern void slasq3_(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *sigma, float *desig, float *qmax, rng_int_t *nfail, rng_int_t *iter, rng_int_t *ndiv, rng_int_t *ieee, rng_int_t *ttype, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *g, float *tau);
extern void slasq4_(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, rng_int_t *n0in, float *dmin, float *dmin1, float *dmin2, float *dn, float *dn1, float *dn2, float *tau, rng_int_t *ttype, float *g);
extern void slasq5_(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *tau, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2, rng_int_t *ieee);
extern void slasq6_(rng_int_t *i0, rng_int_t *n0, float *z, rng_int_t *pp, float *dmin, float *dmin1, float *dmin2, float *dn, float *dnm1, float *dnm2);
extern void slasr_(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, float *c, float *s, float *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void slasv2_(float *f, float *g, float *h, float *ssmin, float *ssmax, float *snr, float *csr, float *snl, float *csl);
extern void slaswp_(rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void slasy2_(rng_int_t *ltranl, rng_int_t *ltranr, rng_int_t *isgn, rng_int_t *n1, rng_int_t *n2, float *tl, rng_int_t *ldtl, float *tr, rng_int_t *ldtr, float *b, rng_int_t *ldb, float *scale, float *x, rng_int_t *ldx, float *xnorm, rng_int_t *info);
extern void slasyf_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, float *a, rng_int_t *lda, rng_int_t *ipiv, float *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void slatbs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void slatdf_(rng_int_t *ijob, rng_int_t *n, float *z, rng_int_t *ldz, float *rhs, float *rdsum, float *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void slatps_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, float *ap, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void slatrd_(char *uplo, rng_int_t *n, rng_int_t *nb, float *a, rng_int_t *lda, float *e, float *tau, float *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void slatrs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, float *a, rng_int_t *lda, float *x, float *scale, float *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void slatrz_(rng_int_t *m, rng_int_t *n, rng_int_t *l, float *a, rng_int_t *lda, float *tau, float *work);
extern void slatzm_(char *side, rng_int_t *m, rng_int_t *n, float *v, rng_int_t *incv, float *tau, float *c1, float *c2, rng_int_t *ldc, float *work, rng_strlen_t side_len);
extern void slauu2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void slauum_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void sorg2l_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sorg2r_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sorgl2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sorgr2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *work, rng_int_t *info);
extern void sorm2l_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sorm2r_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sorml2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void sormr2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, float *a, rng_int_t *lda, float *tau, float *c, rng_int_t *ldc, float *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void spbtf2_(char *uplo, rng_int_t *n, rng_int_t *kd, float *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void spotf2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void sptts2_(rng_int_t *n, rng_int_t *nrhs, float *d, float *e, float *b, rng_int_t *ldb);
extern void srscl_(rng_int_t *n, float *sa, float *sx, rng_int_t *incx);
extern void ssygs2_(rng_int_t *itype, char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytd2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, float *d, float *e, float *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void ssytf2_(char *uplo, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void stgex2_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *q, rng_int_t *ldq, float *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *n1, rng_int_t *n2, float *work, rng_int_t *lwork, rng_int_t *info);
extern void stgsy2_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, float *a, rng_int_t *lda, float *b, rng_int_t *ldb, float *c, rng_int_t *ldc, float *d, rng_int_t *ldd, float *e, rng_int_t *lde, float *f, rng_int_t *ldf, float *scale, float *rdsum, float *rdscal, rng_int_t *iwork, rng_int_t *pq, rng_int_t *info, rng_strlen_t trans_len);
extern void strti2_(char *uplo, char *diag, rng_int_t *n, float *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void zdrscl_(rng_int_t *n, double *sa, doublecomplex *sx, rng_int_t *incx);
extern void zgbtf2_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, rng_int_t *ipiv, rng_int_t *info);
extern void zgebd2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *work, rng_int_t *info);
extern void zgehd2_(rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgelq2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgeql2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgeqr2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgerq2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zgesc2_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *rhs, rng_int_t *ipiv, rng_int_t *jpiv, double *scale);
extern void zgetc2_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *jpiv, rng_int_t *info);
extern void zgetf2_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info);
extern void zgtts2_(rng_int_t *itrans, rng_int_t *n, rng_int_t *nrhs, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *du2, rng_int_t *ipiv, doublecomplex *b, rng_int_t *ldb);
extern void zhegs2_(rng_int_t *itype, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetd2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tau, rng_int_t *info, rng_strlen_t uplo_len);
extern void zhetf2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void zlabrd_(rng_int_t *m, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *d, double *e, doublecomplex *tauq, doublecomplex *taup, doublecomplex *x, rng_int_t *ldx, doublecomplex *y, rng_int_t *ldy);
extern void zlacgv_(rng_int_t *n, doublecomplex *x, rng_int_t *incx);
extern void zlacn2_(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase, rng_int_t *isave);
extern void zlacon_(rng_int_t *n, doublecomplex *v, doublecomplex *x, double *est, rng_int_t *kase);
extern void zlacp2_(char *uplo, rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void zlacpy_(char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, rng_strlen_t uplo_len);
extern void zlacrm_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void zlacrt_(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, doublecomplex *c, doublecomplex *s);
extern doublecomplex zladiv_(doublecomplex *ret_val, doublecomplex *x, doublecomplex *y);

extern void zlaed0_(rng_int_t *qsiz, rng_int_t *n, double *d, double *e, doublecomplex *q, rng_int_t *ldq, doublecomplex *qstore, rng_int_t *ldqs, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void zlaed7_(rng_int_t *n, rng_int_t *cutpnt, rng_int_t *qsiz, rng_int_t *tlvls, rng_int_t *curlvl, rng_int_t *curpbm, double *d, doublecomplex *q, rng_int_t *ldq, double *rho, rng_int_t *indxq, double *qstore, rng_int_t *qptr, rng_int_t *prmptr, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void zlaed8_(rng_int_t *k, rng_int_t *n, rng_int_t *qsiz, doublecomplex *q, rng_int_t *ldq, double *d, double *rho, rng_int_t *cutpnt, double *z, double *dlamda, doublecomplex *q2, rng_int_t *ldq2, double *w, rng_int_t *indxp, rng_int_t *indx, rng_int_t *indxq, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, double *givnum, rng_int_t *info);
extern void zlaein_(rng_int_t *rightv, rng_int_t *noinit, rng_int_t *n, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, doublecomplex *v, doublecomplex *b, rng_int_t *ldb, double *rwork, double *eps3, double *smlnum, rng_int_t *info);
extern void zlaesy_(doublecomplex *a, doublecomplex *b, doublecomplex *c, doublecomplex *rt1, doublecomplex *rt2, doublecomplex *evscal, doublecomplex *cs1, doublecomplex *sn1);
extern void zlaev2_(doublecomplex *a, doublecomplex *b, doublecomplex *c, double *rt1, double *rt2, double *cs1, doublecomplex *sn1);
extern void zlag2c_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, complex *sa, rng_int_t *ldsa, rng_int_t *info);
extern void zlags2_(rng_int_t *upper, double *a1, doublecomplex * a2, double *a3, double *b1, doublecomplex *b2, double *b3, double *csu, doublecomplex *snu, double *csv, doublecomplex * snv, double *csq, doublecomplex *snq);
extern void zlagtm_(char *trans, rng_int_t *n, rng_int_t *nrhs, double *alpha, doublecomplex *dl, doublecomplex *d, doublecomplex *du, doublecomplex *x, rng_int_t *ldx, double *beta, doublecomplex *b, rng_int_t *ldb, rng_strlen_t trans_len);
extern void zlahef_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void zlahqr_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *info);
extern void zlahr2_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void zlahrd_(rng_int_t *n, rng_int_t *k, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, doublecomplex *y, rng_int_t *ldy);
extern void zlaic1_(rng_int_t *job, rng_int_t *j, doublecomplex *x, double *sest, doublecomplex *w, doublecomplex *gamma, double *sestpr, doublecomplex *s, doublecomplex *c);
extern void zlals0_(rng_int_t *icompq, rng_int_t *nl, rng_int_t *nr, rng_int_t *sqre, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, rng_int_t *perm, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, double *givnum, rng_int_t *ldgnum, double *poles, double *difl, double *difr, double *z, rng_int_t *k, double *c, double *s, double *rwork, rng_int_t *info);
extern void zlalsa_(rng_int_t *icompq, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, doublecomplex *b, rng_int_t *ldb, doublecomplex *bx, rng_int_t *ldbx, double *u, rng_int_t *ldu, double *vt, rng_int_t *k, double *difl, double *difr, double *z, double *poles, rng_int_t *givptr, rng_int_t *givcol, rng_int_t *ldgcol, rng_int_t *perm, double *givnum, double *c, double *s, double *rwork, rng_int_t *iwork, rng_int_t *info);
extern void zlalsd_(char *uplo, rng_int_t *smlsiz, rng_int_t *n, rng_int_t *nrhs, double *d, double *e, doublecomplex *b, rng_int_t *ldb, double *rcond, rng_int_t *rank, doublecomplex *work, double *rwork, rng_int_t *iwork, rng_int_t *info, rng_strlen_t uplo_len);
extern double zlangb_(char *norm, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len);
extern double zlange_(char *norm, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double zlangt_(char *norm, rng_int_t *n, doublecomplex *dl, doublecomplex *d, doublecomplex *du, rng_strlen_t norm_len);
extern double zlanhb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlanhe_(char *norm, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlanhp_(char *norm, char *uplo, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlanhs_(char *norm, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len);
extern double zlanht_(char *norm, rng_int_t *n, double *d, doublecomplex *e, rng_strlen_t norm_len);
extern double zlansb_(char *norm, char *uplo, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlansp_(char *norm, char *uplo, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlansy_(char *norm, char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len);
extern double zlantb_(char *norm, char *uplo, char *diag, rng_int_t *n, rng_int_t *k, doublecomplex *ab, rng_int_t *ldab, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double zlantp_(char *norm, char *uplo, char *diag, rng_int_t *n, doublecomplex *ap, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern double zlantr_(char *norm, char *uplo, char *diag, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *work, rng_strlen_t norm_len, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void zlapll_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *ssmin);
extern void zlapmt_(rng_int_t *forwrd, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *ldx, rng_int_t *k);
extern void zlaqgb_(rng_int_t *m, rng_int_t *n, rng_int_t *kl, rng_int_t *ku, doublecomplex *ab, rng_int_t *ldab, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void zlaqge_(rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *r, double *c, double *rowcnd, double *colcnd, double *amax, char *equed, rng_strlen_t equed_len);
extern void zlaqhb_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlaqhe_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlaqhp_(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlaqp2_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *work);
extern void zlaqps_(rng_int_t *m, rng_int_t *n, rng_int_t *offset, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *jpvt, doublecomplex *tau, double *vn1, double *vn2, doublecomplex *auxv, doublecomplex *f, rng_int_t *ldf);
extern void zlaqr0_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zlaqr1_(rng_int_t *n, doublecomplex *h, rng_int_t*ldh, doublecomplex *s1, doublecomplex *s2, doublecomplex *v);
extern void zlaqr2_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void zlaqr3_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nw, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, rng_int_t *ns, rng_int_t *nd, doublecomplex *sh, doublecomplex *v, rng_int_t *ldv, rng_int_t *nh, doublecomplex *t, rng_int_t *ldt, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, doublecomplex *work, rng_int_t *lwork);
extern void zlaqr4_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *n, rng_int_t *ilo, rng_int_t *ihi, doublecomplex *h, rng_int_t *ldh, doublecomplex *w, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *work, rng_int_t *lwork, rng_int_t *info);
extern void zlaqr5_(rng_int_t *wantt, rng_int_t *wantz, rng_int_t *kacc22, rng_int_t *n, rng_int_t *ktop, rng_int_t *kbot, rng_int_t *nshfts, doublecomplex *s, doublecomplex *h, rng_int_t *ldh, rng_int_t *iloz, rng_int_t *ihiz, doublecomplex *z, rng_int_t *ldz, doublecomplex *v, rng_int_t *ldv, doublecomplex *u, rng_int_t *ldu, rng_int_t *nv, doublecomplex *wv, rng_int_t *ldwv, rng_int_t *nh, doublecomplex *wh, rng_int_t *ldwh);
extern void zlaqsb_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlaqsp_(char *uplo, rng_int_t *n, doublecomplex *ap, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlaqsy_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, double *s, double *scond, double *amax, char *equed, rng_strlen_t uplo_len, rng_strlen_t equed_len);
extern void zlar1v_(rng_int_t *n, rng_int_t *b1, rng_int_t *bn, double *lambda, double *d, double *l, double *ld, double *lld, double *pivmin, double *gaptol, doublecomplex *z, rng_int_t *wantnc, rng_int_t *negcnt, double *ztz, double *mingma, rng_int_t *r, rng_int_t *isuppz, double *nrminv, double *resid, double *rqcorr, double *work);
extern void zlar2v_(rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *z, rng_int_t *incx, double *c, doublecomplex *s, rng_int_t *incc);
extern void zlarcm_(rng_int_t *m, rng_int_t *n, double *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, double *rwork);
extern void zlarfb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void zlarf_(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void zlarfg_(rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *tau);
extern void zlarft_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void zlarfx_(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void zlargv_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, rng_int_t *incc);
extern void zlarnv_(rng_int_t *idist, rng_int_t *iseed, rng_int_t *n, doublecomplex *x);
extern void zlarrv_(rng_int_t *n, double *vl, double *vu, double *d, double *l, double *pivmin, rng_int_t *isplit, rng_int_t *m, rng_int_t *dol, rng_int_t *dou, double *minrgp, double *rtol1, double *rtol2, double *w, double *werr, double *wgap, rng_int_t *iblock, rng_int_t *indexw, double *gers, doublecomplex *z, rng_int_t *ldz, rng_int_t *isuppz, double *work, rng_int_t *iwork, rng_int_t *info);
extern void zlartg_(doublecomplex *f, doublecomplex *g, double *cs, doublecomplex *sn, doublecomplex *r);
extern void zlartv_(rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, double *c, doublecomplex *s, rng_int_t *incc);
extern void zlarzb_(char *side, char *trans, char *direct, char *storev, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *v, rng_int_t *ldv, doublecomplex *t, rng_int_t *ldt, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *ldwork, rng_strlen_t side_len, rng_strlen_t trans_len, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void zlarz_(char *side, rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void zlarzt_(char *direct, char *storev, rng_int_t *n, rng_int_t *k, doublecomplex *v, rng_int_t *ldv, doublecomplex *tau, doublecomplex *t, rng_int_t *ldt, rng_strlen_t direct_len, rng_strlen_t storev_len);
extern void zlascl_(char *type, rng_int_t *kl, rng_int_t *ku, double *cfrom, double *cto, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t type_len);
extern void zlaset_(char *uplo, rng_int_t *m, rng_int_t *n, doublecomplex *alpha, doublecomplex *beta, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void zlasr_(char *side, char *pivot, char *direct, rng_int_t *m, rng_int_t *n, double *c, double *s, doublecomplex *a, rng_int_t *lda, rng_strlen_t side_len, rng_strlen_t pivot_len, rng_strlen_t direct_len);
extern void zlaswp_(rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *k1, rng_int_t *k2, rng_int_t *ipiv, rng_int_t *incx);
extern void zlasyf_(char *uplo, rng_int_t *n, rng_int_t *nb, rng_int_t *kb, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, doublecomplex *w, rng_int_t *ldw, rng_int_t *info, rng_strlen_t uplo_len);
extern void zlatbs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void zlatdf_(rng_int_t *ijob, rng_int_t *n, doublecomplex *z, rng_int_t *ldz, doublecomplex *rhs, double *rdsum, double *rdscal, rng_int_t *ipiv, rng_int_t *jpiv);
extern void zlatps_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, doublecomplex *ap, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void zlatrd_(char *uplo, rng_int_t *n, rng_int_t *nb, doublecomplex *a, rng_int_t *lda, double *e, doublecomplex *tau, doublecomplex *w, rng_int_t *ldw, rng_strlen_t uplo_len);
extern void zlatrs_(char *uplo, char *trans, char *diag, char *normin, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *x, double *scale, double *cnorm, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t trans_len, rng_strlen_t diag_len, rng_strlen_t normin_len);
extern void zlatrz_(rng_int_t *m, rng_int_t *n, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work);
extern void zlatzm_(char *side, rng_int_t *m, rng_int_t *n, doublecomplex *v, rng_int_t *incv, doublecomplex *tau, doublecomplex *c1, doublecomplex *c2, rng_int_t *ldc, doublecomplex *work, rng_strlen_t side_len);
extern void zlauu2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void zlauum_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpbtf2_(char *uplo, rng_int_t *n, rng_int_t *kd, doublecomplex *ab, rng_int_t *ldab, rng_int_t *info, rng_strlen_t uplo_len);
extern void zpotf2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len);
extern void zptts2_(rng_int_t *iuplo, rng_int_t *n, rng_int_t *nrhs, double *d, doublecomplex *e, doublecomplex *b, rng_int_t *ldb);
extern void zrot_(rng_int_t *n, doublecomplex *cx, rng_int_t *incx, doublecomplex *cy, rng_int_t *incy, double *c, doublecomplex *s);
extern void zspmv_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *ap, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void zspr_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *ap, rng_strlen_t uplo_len);
extern void zsymv_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *a, rng_int_t *lda, doublecomplex *x, rng_int_t *incx, doublecomplex *beta, doublecomplex *y, rng_int_t *incy, rng_strlen_t uplo_len);
extern void zsyr_(char *uplo, rng_int_t *n, doublecomplex *alpha, doublecomplex *x, rng_int_t *incx, doublecomplex *a, rng_int_t *lda, rng_strlen_t uplo_len);
extern void zsytf2_(char *uplo, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *ipiv, rng_int_t *info, rng_strlen_t uplo_len);
extern void ztgex2_(rng_int_t *wantq, rng_int_t *wantz, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *q, rng_int_t *ldq, doublecomplex *z, rng_int_t *ldz, rng_int_t *j1, rng_int_t *info);
extern void ztgsy2_(char *trans, rng_int_t *ijob, rng_int_t *m, rng_int_t *n, doublecomplex *a, rng_int_t *lda, doublecomplex *b, rng_int_t *ldb, doublecomplex *c, rng_int_t *ldc, doublecomplex *d, rng_int_t *ldd, doublecomplex *e, rng_int_t *lde, doublecomplex *f, rng_int_t *ldf, double *scale, double *rdsum, double *rdscal, rng_int_t *info, rng_strlen_t trans_len);
extern void ztrti2_(char *uplo, char *diag, rng_int_t *n, doublecomplex *a, rng_int_t *lda, rng_int_t *info, rng_strlen_t uplo_len, rng_strlen_t diag_len);
extern void zung2l_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zung2r_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zungl2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zungr2_(rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *work, rng_int_t *info);
extern void zunm2l_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunm2r_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunml2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmr2_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);
extern void zunmr3_(char *side, char *trans, rng_int_t *m, rng_int_t *n, rng_int_t *k, rng_int_t *l, doublecomplex *a, rng_int_t *lda, doublecomplex *tau, doublecomplex *c, rng_int_t *ldc, doublecomplex *work, rng_int_t *info, rng_strlen_t side_len, rng_strlen_t trans_len);

/* FFT routines */
extern void cfft1d_(rng_int_t *mode, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void cfft1dx_(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *n, complex *x, rng_int_t *incx, complex *y, rng_int_t *incy, complex *comm, rng_int_t *info);
extern void cfft1m_(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void cfft1mx_(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void cfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void cfft2dx_(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, complex *y, rng_int_t *incy1, rng_int_t *incy2, complex *comm, rng_int_t *info);
extern void cfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *comm, rng_int_t *info);
extern void cfft3dx_(rng_int_t *mode, float *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, complex *y, complex *comm, rng_int_t *info);
extern void cfft3dy_(rng_int_t *mode, float *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, complex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, complex *comm, rng_int_t *lcomm, rng_int_t *info);
extern void csfft1d_(rng_int_t *mode, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void csfft1m_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void csfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void csfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, complex *x, float *y, float *comm, rng_int_t *info);
extern void csfft_(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void csfftm_(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void dzfft1d_(rng_int_t *mode, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void dzfft1m_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void dzfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void dzfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, double *x, doublecomplex *y, double *comm, rng_int_t *info);
extern void dzfft_(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void dzfftm_(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void scfft1d_(rng_int_t *mode, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void scfft1m_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void scfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void scfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, float *x, complex *y, float *comm, rng_int_t *info);
extern void scfft_(rng_int_t *mode, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void scfftm_(rng_int_t *nseq, rng_int_t *n, float *x, float *comm, rng_int_t *info);
extern void zdfft1d_(rng_int_t *mode, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void zdfft1m_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void zdfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void zdfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, double *y, double *comm, rng_int_t *info);
extern void zdfft_(rng_int_t *mode, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void zdfftm_(rng_int_t *nseq, rng_int_t *n, double *x, double *comm, rng_int_t *info);
extern void zfft1d_(rng_int_t *mode, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void zfft1dx_(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *n, doublecomplex *x, rng_int_t *incx, doublecomplex *y, rng_int_t *incy, doublecomplex *comm, rng_int_t *info);
extern void zfft1m_(rng_int_t *mode, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void zfft1mx_(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *nseq, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void zfft2d_(rng_int_t *mode, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void zfft2dx_(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, doublecomplex *comm, rng_int_t *info);
extern void zfft3d_(rng_int_t *mode, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *comm, rng_int_t *info);
extern void zfft3dx_(rng_int_t *mode, double *scale, rng_int_t *ltrans, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, doublecomplex *y, doublecomplex *comm, rng_int_t *info);
extern void zfft3dy_(rng_int_t *mode, double *scale, rng_int_t *inpl, rng_int_t *l, rng_int_t *m, rng_int_t *n, doublecomplex *x, rng_int_t *incx1, rng_int_t *incx2, rng_int_t *incx3, doublecomplex *y, rng_int_t *incy1, rng_int_t *incy2, rng_int_t *incy3, doublecomplex *comm, rng_int_t *lcomm, rng_int_t *info);


/* Sparse BLAS routines */
extern void caxpyi_(rng_int_t *nz, complex *a, complex *x, rng_int_t *indx, complex *y);
extern complex cdotci_(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void cdotcisub_(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern complex cdotui_(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void cdotuisub_(complex *ret_val, rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void cgthr_(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void cgthrz_(rng_int_t *nz, complex *y, complex *x, rng_int_t *indx);
extern void csctr_(rng_int_t *nz, complex *x, rng_int_t *indx, complex *y);
extern void daxpyi_(rng_int_t *nz, double *a, double *x, rng_int_t *indx, double *y);
extern double ddoti_(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void dgthr_(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void dgthrz_(rng_int_t *nz, double *y, double *x, rng_int_t *indx);
extern void droti_(rng_int_t *nz, double *x, rng_int_t *indx, double *y, double *c, double *s);
extern void dsctr_(rng_int_t *nz, double *x, rng_int_t *indx, double *y);
extern void saxpyi_(rng_int_t *nz, float *a, float *x, rng_int_t *indx, float *y);
extern float sdoti_(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void sgthr_(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void sgthrz_(rng_int_t *nz, float *y, float *x, rng_int_t *indx);
extern void sroti_(rng_int_t *nz, float *x, rng_int_t *indx, float *y, float *c, float *s);
extern void ssctr_(rng_int_t *nz, float *x, rng_int_t *indx, float *y);
extern void zaxpyi_(rng_int_t *nz, doublecomplex *a, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex zdotci_(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void zdotcisub_(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern doublecomplex zdotui_(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void zdotuisub_(doublecomplex *ret_val, rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);
extern void zgthr_(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void zgthrz_(rng_int_t *nz, doublecomplex *y, doublecomplex *x, rng_int_t *indx);
extern void zsctr_(rng_int_t *nz, doublecomplex *x, rng_int_t *indx, doublecomplex *y);

/* Random number generators */
extern void drandbeta_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandbinomial_(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandbinomialreference_(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandblumblumshub_(rng_int_t *n, rng_int_t *state, double *x, rng_int_t *info);
extern void drandcauchy_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandchisquared_(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void dranddiscreteuniform_(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandexponential_(rng_int_t *n, double *a, rng_int_t *state, double *x, rng_int_t *info);
extern void drandf_(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, double *x, rng_int_t *info);
extern void drandgamma_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandgaussian_(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void drandgeneraldiscrete_(rng_int_t *n, double *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandgeometric_(rng_int_t *n, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandgeometricreference_(double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandhypergeometric_(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandhypergeometricreference_(rng_int_t *np, rng_int_t *ns, rng_int_t *m, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandinitialize_(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void drandinitializebbs_(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void drandinitializeuser_(RNG_DRANDINITIALIZEUSER_UINI uini, RNG_DRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void drandleapfrog_(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void drandlogistic_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandlognormal_(rng_int_t *n, double *xmu, double *var, rng_int_t *state, double *x, rng_int_t *info);
extern void drandmultinomial_(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void drandmultinormalreference_(rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandmultinormalr_(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void drandmultistudentstreference_(rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandmultistudentstr_(rng_int_t *n, double *ref, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void drandnegativebinomial_(rng_int_t *n, rng_int_t *m, double *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandnegativebinomialreference_(rng_int_t *m, double *p, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandpoisson_(rng_int_t *n, double *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void drandpoissonreference_(double *lambda, double *ref, rng_int_t *lref, rng_int_t *info);
extern void drandskipahead_(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void drandstudentst_(rng_int_t *n, rng_int_t *df, rng_int_t *state, double *x, rng_int_t *info);
extern void drandtriangular_(rng_int_t *n, double *xmin, double *xmed, double *xmax, rng_int_t *state, double *x, rng_int_t *info);
extern void dranduniform_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandvonmises_(rng_int_t *n, double *vk, rng_int_t *state, double *x, rng_int_t *info);
extern void drandweibull_(rng_int_t *n, double *a, double *b, rng_int_t *state, double *x, rng_int_t *info);
extern void drandmultinormal_(rng_int_t *n, rng_int_t *m, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void drandmultistudentst_(rng_int_t *n, rng_int_t *m, rng_int_t *df, double *xmu, double *c, rng_int_t *ldc, rng_int_t *state, double *x, rng_int_t *ldx, rng_int_t *info);
extern void srandbeta_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandblumblumshub_(rng_int_t *n, rng_int_t *state, float *x, rng_int_t *info);
extern void srandbinomial_(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandbinomialreference_(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandcauchy_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandchisquared_(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void sranddiscreteuniform_(rng_int_t *n, rng_int_t *a, rng_int_t *b, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandexponential_(rng_int_t *n, float *a, rng_int_t *state, float *x, rng_int_t *info);
extern void srandf_(rng_int_t *n, rng_int_t *df1, rng_int_t *df2, rng_int_t *state, float *x, rng_int_t *info);
extern void srandgamma_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandgaussian_(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void srandgeneraldiscrete_(rng_int_t *n, float *ref, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandgeometric_(rng_int_t *n, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandgeometricreference_(float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandhypergeometric_(rng_int_t *n, rng_int_t *np, rng_int_t *ns, rng_int_t *m, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandhypergeometricreference_(rng_int_t *np, rng_int_t *ns, rng_int_t *m, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandinitialize_(rng_int_t *genid, rng_int_t *subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void srandinitializebbs_(rng_int_t *nbits, rng_int_t *lp, rng_int_t *p, rng_int_t *lq, rng_int_t *q, rng_int_t *ls, rng_int_t *s, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void srandinitializeuser_(RNG_SRANDINITIALIZEUSER_UINI uini, RNG_SRANDINITIALIZEUSER_UGEN ugen, rng_int_t genid, rng_int_t subid, rng_int_t *seed, rng_int_t *lseed, rng_int_t *state, rng_int_t *lstate, rng_int_t *info);
extern void srandleapfrog_(rng_int_t *n, rng_int_t *k, rng_int_t *state, rng_int_t *info);
extern void srandlogistic_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandlognormal_(rng_int_t *n, float *xmu, float *var, rng_int_t *state, float *x, rng_int_t *info);
extern void srandmultinomial_(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *k, rng_int_t *state, rng_int_t *x, rng_int_t *ldx, rng_int_t *info);
extern void srandmultinormalreference_(rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandmultinormalr_(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void srandmultistudentstreference_(rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandmultistudentstr_(rng_int_t *n, float *ref, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void srandnegativebinomial_(rng_int_t *n, rng_int_t *m, float *p, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandnegativebinomialreference_(rng_int_t *m, float *p, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandpoisson_(rng_int_t *n, float *lambda, rng_int_t *state, rng_int_t *x, rng_int_t *info);
extern void srandpoissonreference_(float *lambda, float *ref, rng_int_t *lref, rng_int_t *info);
extern void srandskipahead_(rng_int_t *n, rng_int_t *state, rng_int_t *info);
extern void srandstudentst_(rng_int_t *n, rng_int_t *df, rng_int_t *state, float *x, rng_int_t *info);
extern void srandtriangular_(rng_int_t *n, float *xmin, float *xmed, float *xmax, rng_int_t *state, float *x, rng_int_t *info);
extern void sranduniform_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandvonmises_(rng_int_t *n, float *vk, rng_int_t *state, float *x, rng_int_t *info);
extern void srandweibull_(rng_int_t *n, float *a, float *b, rng_int_t *state, float *x, rng_int_t *info);
extern void srandmultinormal_(rng_int_t *n, rng_int_t *m, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);
extern void srandmultistudentst_(rng_int_t *n, rng_int_t *m, rng_int_t *df, float *xmu, float *c, rng_int_t *ldc, rng_int_t *state, float *x, rng_int_t *ldx, rng_int_t *info);

/* RNG version information */
extern void rngversion_(rng_int_t *major, rng_int_t *minor, rng_int_t *patch, rng_int_t *build);
extern void rnginfo_(void);

/* OMP interfaces */
extern rng_int_t rnggetmaxthreads_(void);
extern rng_int_t rnggetnumthreads_(void);
extern void rngsetnumthreads_(rng_int_t *numthreads);
extern rng_int_t rnggetnumprocs_(void);

/* Putenv and getenv utilities */
extern void rngputenv_(char *name, char *value, rng_strlen_t name_len, rng_strlen_t value_len);
extern void rnggetenv_(char *name, char *value, rng_strlen_t name_len, rng_strlen_t value_len);
extern void rnglocation_(char *message, void *arg, rng_strlen_t message_len);
extern void rnglocationstring_(char *message, void *arg, char *string, rng_strlen_t message_len, rng_strlen_t string_len);

#endif /* ! WIN32 */
/* ------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif  /* !defined(_RNG_H) */
